
# Load necessary libraries
library(haven)
library(dplyr)

# Load the dataset for 2024 (update the file path accordingly) - this is the name of the output from
# the identifier file - backup csv is dataframe_24.csv - saved in identifier file

# NOTE: Fin12 is a question that comes before Fin13 - We use this as a filter question and code everyone who answers
# "No" to Fin12 as not having a MM account regardless of how they answer FIn13 

# Keep only the selected years
dataframe_2024 <- dataframe_2024 %>%
  filter(year %in% c(2011, 2014, 2015, 2016, 2017, 2018, 2019, 2020, 2021, 2022, 2023, 2024)) %>%
  mutate(wp19480_r_f = ifelse(wp19479_r != 1 & wp19480_r == 1, 2, wp19480_r)) #FIN12 FILTER!!!!!!

# Global variables (mirroring global definitions in Stata)
a2024_1a <- c("wp19548_r", #1: account: fin inst
              "wp14888_r", #2: debit card: own
              "wp19516_r", #3: payment into account; benefits
              "wp19508_r", #4: payment into account; wages 
              "wp19523_r") #5: payment into account; agr. revenue

a2024_1b <- c("wp21389_r", #1: payment into a card; benefits
              "wp21385_r", #2: payment into a card; wages
              "wp21393_r") #3. payment into card; ag.

a2024_1c <- c("wp19504_r") #1: payment from account; utility
# WP24009 if you answer yes to paying utility from account 


a2024_2a <- c("wp19480_r_f") #1: mobile: GSMA MMU - this includes the fin12 filter
a2024_2a_nf <- c("wp19480_r") #1: mobile: FIN13 -SAME AS ABOVE BUT THERE IS NO FILTER FOR FIN12

a2024_2b <- c("wp19517_r", #1: payment into mobile; benefits
              "wp19509_r", #2: payment into mobile; wages
              "wp19524") #3: payment into mobile; agr. revenue

a2024_2c <- c("wp19505") #1: payment from mobile; utility, there is no _R with this variable in questionairre? how to treat it?


# Create 2024 financial institution account variables
dataframe_2024 <- dataframe_2024 %>%
  mutate(u1_1 = case_when(wp19548_r == 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ 0,
                          TRUE ~ NA), #account at financial institution 
         u1_2 = if_else(wp14888_r == 1 & !is.na(i24), 1, u1_1), #debit card: own - THIS IS THE BASELINE ACCOUNT OWNERSHIP NUMBER!!
         u1_3 = case_when(wp19516_r == 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ u1_2,
                          TRUE ~ NA), #payment into account; transfers
         u1_3_marginal = case_when(wp19516_r == 1 & u1_2 != 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ 0,
                          TRUE ~ NA), #payment into account; transfers
         u1_4 = case_when(wp19508_r == 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ u1_3,
                          TRUE ~ NA), #payment into account; wages 
         u1_4_marginal = case_when(wp19508_r == 1 & u1_2 != 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ 0,
                          TRUE ~ NA), #payment into account; wages 
         u1_5 = case_when(wp19523_r == 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ u1_4,
                          TRUE ~ NA), #payment into account; agr. revenue
         u1_5_marginal = case_when(wp19523_r == 1 & u1_2 != 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ 0,
                          TRUE ~ NA), #payment into account; agr. revenue
         u1_6 = case_when(wp21389_r == 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ u1_5,
                          TRUE ~ NA), #payment into a card; benefits
         u1_6_marginal = case_when(wp21389_r == 1 & u1_2 != 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ 0,
                          TRUE ~ NA), #payment into a card; benefits
         u1_7 = case_when(wp21385_r == 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ u1_6,
                          TRUE ~ NA), #payment into a card; wages
         u1_7_marginal = case_when(wp21385_r == 1 & u1_2 != 1 & !is.na(i24) ~ 1, 
                         !is.na(i24) ~ 0,
                         TRUE ~ NA), #payment into a card; wages
         u1_8 = case_when(wp19504_r == 1 & !is.na(i24) ~ 1, 
                           !is.na(i24) ~ u1_7,
                           TRUE ~ NA), #payment from account; utility
         u1_8_marginal = case_when(wp19504_r == 1 & u1_2 != 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ 0,
                          TRUE ~ NA), #payment from account; utility
         u1_9 = case_when(wp21393_r == 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ u1_8,
                          TRUE ~ NA), #payment into card; ag.
         u1_9_marginal = case_when(wp21393_r == 1 & u1_2 != 1 & !is.na(i24) ~ 1, 
                          !is.na(i24) ~ 0,
                          TRUE ~ NA)) #payment into card; ag.


# Create 2024 mobile account variables

dataframe_2024 <- dataframe_2024 %>%
  mutate(u2_1 = case_when(wp19480_r_f == 1 & !is.na(m24) ~ 1, 
                          !is.na(m24) & wp19480_r_f != 1 ~ 0,
                          TRUE ~ NA), # mobile: GSMA MMU
         u2_2 = case_when(wp19517_r == 1 & !is.na(m24) ~ 1, 
                          !is.na(m24) ~ u2_1,
                          TRUE ~ NA), #payment into mobile; benefits
         u2_2_marginal = case_when(wp19517_r == 1 & u2_1 != 1 & !is.na(m24) ~ 1, 
                          !is.na(m24) ~ 0,
                          TRUE ~ NA), #payment into mobile; benefits
         u2_3 = case_when(wp19509_r == 1 & !is.na(m24) ~ 1, 
                          !is.na(m24) ~ u2_2,
                          TRUE ~ NA), #payment into mobile; wages
         u2_3_marginal = case_when(wp19509_r == 1 & u2_1 != 1 & !is.na(m24) ~ 1, 
                          !is.na(m24) ~ 0,
                          TRUE ~ NA), #payment into mobile; wages
         u2_4 = case_when(wp19524 == 1 & !is.na(m24) ~ 1, 
                          !is.na(m24) ~ u2_3,
                          TRUE ~ NA), #payment into mobile; agr. revenue
         u2_4_marginal = case_when(wp19524 == 1 & u2_1 != 1 & !is.na(m24) ~ 1, 
                          !is.na(m24) ~ 0,
                          TRUE ~ NA), #payment into mobile; agr. revenue
         u2_5 =  case_when(wp19505 == 1 & !is.na(m24) ~ 1, 
                           !is.na(m24) ~ u2_4,
                           TRUE ~ NA), #payment from mobile; utility
         u2_5_marginal =  case_when(wp19505 == 1 & u2_1 != 1 & !is.na(m24) ~ 1, 
                           !is.na(m24) ~ 0,
                           TRUE ~ NA)) #payment from mobile; utility

# Create metrics for financial inclusion in 2024
fi_var_list <- c(a2024_1a, a2024_1b, a2024_1c)
mm_var_list <- c(a2024_2a, a2024_2b)


dataframe_2024 <- dataframe_2024 %>%
  mutate(
    acc24fin = case_when(
      i24 == 1 & rowSums(across(all_of(fi_var_list)) == 1, na.rm = TRUE) > 0 ~ 1,
      i24 == 1 & rowSums(across(all_of(fi_var_list)) == 1, na.rm = TRUE) == 0 ~ 0,
      TRUE ~ NA
    ),
    acc24mob = case_when(
      m24 == 1 & rowSums(across(all_of(mm_var_list)) == 1, na.rm = TRUE) > 0 ~ 1,
      m24 == 1 & rowSums(across(all_of(mm_var_list)) == 1, na.rm = TRUE) == 0 ~ 0,
      TRUE ~ NA
    ),
    acc24any = case_when(
      acc24fin == 1 | acc24mob == 1 ~ 1,
      acc24fin != 1 & acc24mob != 1 & m24 == 1 ~ 0,
      acc24fin != 1 & i24 == 1 ~ 0,
      TRUE ~ NA
    ),
    unbanked24 = case_when(
      acc24any == 0 ~ 1,
      acc24any == 1 ~ 0,
      TRUE ~ NA
    )
  )


# Adjusting for only financial institution account, only mobile account, and both accounts
dataframe_2024 <- dataframe_2024 %>%
  mutate(
acc24fin_o = case_when(m24 == 1 & acc24fin == 1 & acc24mob != 1 ~ 1,
                       i24 == 1 & is.na(m24) & acc24fin == 1 ~ 1,
                       i24 == 1 ~ 0,
                       TRUE ~ NA),
acc24mob_o = case_when(m24 == 1 & acc24fin != 1 & acc24mob == 1 ~ 1,
                       m24 == 1 ~ 0,
                       TRUE ~ NA),
acc24any_b = case_when(m24 == 1 & acc24fin == 1 & acc24mob == 1 ~ 1,
                       m24 == 1 ~ 0,
                       TRUE ~ NA))
         
# Create variables for financial inclusion across multiple years (2011, 2014, 2017, etc.)
# NOTE: WHEN OLD AD FILE IS CONVERTED TO R, CREATE TIME SERIES 



#############################################################
# Adjustments - different ways to calculate account ownership
#############################################################


# NO FILTER FOR FIN12!!! - nf stands for no filter
mm_var_list2 <- c(a2024_2a_nf, a2024_2b)

dataframe_2024 <- dataframe_2024 %>%
  mutate(
    acc24mob_nf = case_when(
      m24 == 1 & rowSums(across(all_of(mm_var_list2)) == 1, na.rm = TRUE) > 0 ~ 1,
      m24 == 1 & rowSums(across(all_of(mm_var_list2)) == 1, na.rm = TRUE) == 0 ~ 0,
      TRUE ~ NA),
    acc24any_nf = case_when(
      acc24fin == 1 | acc24mob_nf == 1 ~ 1,
      acc24fin != 1 & acc24mob_nf != 1 & m24 == 1 ~ 0,
      i24 == 1 ~ 0,
      TRUE ~ NA))



# Create account without utility payments in 2024

fi_var_list_noutil <- c(a2024_1a, a2024_1b)

dataframe_2024 <- dataframe_2024 %>%
  mutate(
    acc24fin_noutil = case_when(
      i24 == 1 & rowSums(across(all_of(fi_var_list_noutil)) == 1, na.rm = TRUE) > 0 ~ 1,
      i24 == 1 & rowSums(across(all_of(fi_var_list_noutil)) == 1, na.rm = TRUE) == 0 ~ 0,
      TRUE ~ NA), 
      acc24any_noutil = case_when(
        acc24fin_noutil == 1 | acc24mob == 1 ~ 1,
        acc24fin_noutil != 1 & acc24mob != 1 & m24 ==1 ~ 0,
        acc24fin_noutil != 1 & i24 ==1 ~ 0,
        TRUE ~ NA),
    # using the new utility question about whether you paid using an account but did so by handing cash to a bank agent
    # this is the general number
    util_dig_cash_fi = case_when(wp19504_r == 1 & wp24009 == 1 ~ 1,
                                 !is.na(i24) ~ 0,
                                 TRUE ~ NA),
    # this is how many of the marginal utility addition people paid in cash to bank agent
    util_dig_cash_marginal = case_when(wp24009 == 1 & u1_8_marginal == 1 ~ 1, 
                                                 !is.na(i24) ~ 0,
                                                 TRUE ~ NA),
    # this is how many of the marginal utility addition people paid in cash to bank agent - WHO WEREN"T MARGINALLY ADDED IN ANY OTHER WAY!
    util_dig_cash_marginal_only = case_when((wp24009 == 1 & u1_8_marginal == 1) & acc24fin_noutil != 1 ~ 1, 
                                       !is.na(i24) ~ 0,
                                       TRUE ~ NA),
    acc24fin_no_cash_util = case_when(acc24fin_noutil == 1 | 
                                  (u1_8_marginal == 1 & util_dig_cash_marginal_only != 1) ~ 1, # FI account w/ additions and only util add if not cash to bank agent
                                !is.na(i24) ~ 0,
                                TRUE ~ NA),
    acc24any_no_cash_util = case_when(
      acc24fin_no_cash_util == 1 | acc24mob == 1 ~ 1,
      acc24fin_no_cash_util != 1 & acc24mob != 1 & m24 == 1 ~ 0,
      acc24fin_noutil != 1 & i24 == 1 ~ 0,
      TRUE ~ NA)
    )
    
  



