# Sometimes we want to look at other regions in addition to the normal geograhic ones - in this file we code in columns containing these additional regions


# here - we create lists with th countries included in the region at the top of the file and then add them to the data

# FCI REGIONS
# as listed here: https://worldbankgroup.sharepoint.com/:p:/r/sites/WBFinance/Documents/FCI%20Org%20Charts%20and%20Brochures/FCI%20Org%20Chart%20with%20Regional%20Coverage%20-%20July%202024.pptx?d=w9256528910d04dc1a0709f86fbb335ca&csf=1&web=1&e=RprvOp
afr_1.1 <- c("Eritrea", "Ethiopia", "Kenya", "Malawi", "Rwanda", "Somalia", "South Sudan", "Sudan", "Tanzania", "Uganda", "Zambia", "Zimbabwe")
afr_1.2 <- c("Angola", "Botswana", "Burundi", "Comoros", "Congo, Dem. Rep.", "Eswatini", "Lesotho", "Madagascar", "Mauritius", "Mozambique", "Namibia", "Sao Tome & Principe", "Seychelles", "South Africa")
afr_2.1 <- c("Benin", "Burkina Faso", "Cape Verde", "Chad", "Cote d'Ivoire", "Guinea", "Guinea Bissau", "Mali", "Mauritania", "Niger", "Senegal", "Gambia, The", "Togo")
afr_2.2 <- c("Cameroon", "Central African Republic", "Congo, Rep.", "Equatorial Guinea", "Gabon", "Ghana", "Liberia", "Nigeria", "Sierra Leone")
eap_1 = c("Cambodia", "China", "Korea", "Lao PDR", "Mongolia", "Myanmar", "Viet Nam")
eap_2 <- c("Fiji", "Indonesia", "Kiribati", "Marshall Islands", "Micronesia", "Palau", "Papua New Guinea", "Samoa", "Solomon Islands", "Timor-Leste", "Tonga", "Vanuatu", "Brunei", "Malaysia", "Philippines", "Singapore", "Thailand")
eca_1 <- c("Armenia", "Azerbaijan", "Bulgaria", "Croatia", "Cyprus", "Czechia", "Estonia", "Georgia", "Hungary", "Kazakhstan", "Kyrgyz Republic", "Latvia", "Lithuania", "Poland", "Romania", "Russian Federation", "Slovak Republic", "Slovenia", "Tajikistan", "Turkmenistan", "Uzbekistan")
eca_2 <- c("Albania", "Belarus", "Bosnia and Herzegovina", "North Macedonia", "Kosovo", "Moldova", "Montenegro", "Serbia", "Turkiye", "Ukraine")
lcr <- c("Antigua and Barbuda", "Argentina", "Bahamas", "Barbados", "Belize", "Bolivia", "Brazil", "Chile", "Colombia", "Costa Rica", "Dominica", "Dominican Republic", "Ecuador", "El Salvador", "Grenada", "Guatemala", "Guyana", "Haiti", "Honduras", "Jamaica", "Mexico", "Nicaragua", "Panama", "Paraguay", "Peru", "St Kitts & Nevis", "St Lucia", "St Vincent & the Grenadines", "Suriname", "Trinidad & Tobago", "Uruguay", "Venezuela, RB")
mna_1 <- c("Algeria", "Djibouti", "Egypt", "Libya", "Malta", "Morocco", "Tunisia", "Yemen")
mna_2 <- c("Bahrain", "Iran", "Iraq", "Jordan", "Kuwait", "Lebanon", "Oman", "Qatar", "Saudi Arabia", "Syrian Arab Republic", "United Arab Emirates", "West Bank and Gaza")
sar <- c("Bangladesh", "Bhutan", "India", "Maldives", "Nepal", "Sri Lanka", "Afghanistan", "Pakistan")


# African Union Sub-Regions

AU_North <- c("Algeria", "Egypt, Arab Rep.", "Libya", "Mauritania", "Morocco", "Tunisia")
AU_West <- c("Benin", "Burkina Faso", "Cabo Verde", "Cote d'Ivoire", "Gambia, The","Ghana", "Guinea", "Guinea-Bissau", "Liberia", "Mali", "Niger", "Nigeria","Senegal", "Sierra Leone", "Togo")
AU_Central <- c("Burundi", "Cameroon", "Central African Republic", "Chad","Congo, Dem. Rep.", "Congo, Rep.", "Equitorial Guinea", "Gabon","Sao Tome and Principe")
AU_Southern <- c("Angola", "Botswana", "Eswatini", "Lesotho", "Malawi", "Mozambique","Namibia", "South Africa", "Zambia", "Zimbabwe") 
AU_East <- c("Comoros", "Djibouti", "Eritrea", "Ethiopia", "Kenya", "Madagascar","Mauritius", "Rwanda", "Seychelles", "Somalia", "South Sudan","Sudan", "Tanzania", "Uganda") 

# Fragile and conflict-affected situations
# https://thedocs.worldbank.org/en/doc/b3c737c4687db176ec98f5c434d0de91-0090082024/original/FCSListFY25.pdf

fcs_fy25 <- c("Afghanistan", "Burkina Faso", "Cameroon", "Central African Republic", 
  "Congo, Dem. Rep.", "Ethiopia", "Haiti", "Iraq", "Lebanon", 
  "Mali", "Mozambique", "Myanmar", "Niger", "Nigeria", "Somalia", 
  "South Sudan", "Sudan", "Syrian Arab Rep.", "Ukraine", 
  "West Bank and Gaza", "Yemen, Rep.", "Burundi", 
  "Chad", "Comoros", "Congo, Rep.", "Eritrea", "Guinea-Bissau", 
  "Kiribati", "Kosovo", "Libya", "Marshall Islands", 
  "Micronesia, Federated States of", "Papua New Guinea", 
  "So Tom and Prncipe", "Solomon Islands", "Timor-Leste", 
  "Tuvalu", "Venezuela, RB", "Zimbabwe")






# Code in the new region columns
TS <- TS %>%
  mutate(fci_region = case_when(countrynewwb %in% c(afr_1.1) ~ "AFR 1.1",
                                countrynewwb %in% c(afr_1.2) ~ "AFR 1.2",
                                countrynewwb %in% c(afr_2.1) ~ "AFR 2.1",
                                countrynewwb %in% c(afr_2.2) ~ "AFR 2.2",
                                countrynewwb %in% c(eap_1) ~ "EAP 1",
                                countrynewwb %in% c(eap_2) ~ "EAP 2",
                                countrynewwb %in% c(eca_1) ~ "ECA 1",
                                countrynewwb %in% c(eca_2) ~ "ECA 2",
                                countrynewwb %in% c(lcr) ~ "LCR",
                                countrynewwb %in% c(mna_1) ~ "MNA 1",
                                countrynewwb %in% c(mna_2) ~ "MNA 2",
                                countrynewwb %in% c(sar) ~ "SAR",
                                TRUE ~ NA),
         African_Union = case_when(countrynewwb %in% AU_North ~ "AU_North",    
                                   countrynewwb %in% AU_West ~ "AU_West",    
                                   countrynewwb %in% AU_Central ~ "AU_Central",    
                                   countrynewwb %in% AU_Southern ~ "AU_Southern",    
                                   countrynewwb %in% AU_East ~ "AU_East",
                                   TRUE ~ NA),
         fcs_fy25 = ifelse(countrynewwb %in% c(fcs_fy25), 1, 0))