
dataframe_2024 <- dataframe_2024 %>%
  # filter only for people asked connectivity questions
  # filter(c24 == 1) %>%
  
  # Own mobile phone (age 15+)
  mutate(con1_all = case_when(c24 == 1 & wp17624_con == 1 ~ 1,
                           c24 == 1 ~ 0,
                           TRUE ~ NA)) %>%
  set_variable_labels(con1_all = "Own a mobile phone (age 15+)") %>%
  
  # No mobile phone due to lack of money (age 15+)
  mutate(con2a_all = case_when(lc24 == 1 & wp24019 == 1 & con1_all != 1 ~ 1,
                            lc24 == 1 ~ 0,
                            TRUE ~ NA)) %>%
  set_variable_labels(con2a_all = "No mobile phone due to lack of money (age 15+)") %>%
  
  # No mobile phone due to lack of money (no phone owners)
  mutate(con2a_np_mon = case_when(lc24 == 1 & wp24019 == 1 & con1_all != 1 ~ 1, 
                                  lc24 == 1 &  con1_all != 1 ~ 0, 
                               TRUE ~ NA)) %>%
  set_variable_labels(con2a_np_mon = "No mobile phone due to lack of money (no phone owners)") %>%
  
  # No mobile phone because buying mobile minutes is too expensive (age 15+)
  mutate(con2b_all = case_when(lc24 == 1 & wp24020 == 1 & con1_all != 1 ~ 1, 
                            lc24 == 1 ~ 0,
                            TRUE ~ NA)) %>%
  set_variable_labels(con2b_all = "No mobile phone due to expensive minutes (age 15+)") %>%
  
  # No mobile phone because buying mobile minutes is too expensive (no phone owners)
  mutate(con2b_np_exp = case_when(lc24 == 1 & wp24020 == 1 & con1_all != 1 ~ 1,
                                  lc24 == 1 & con1_all != 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con2b_np_exp = "No mobile phone due to expensive minutes (no phone owners)") %>%
  
  # No mobile phone because of no reliable coverage (age 15+)
  mutate(con2c_all = case_when(lc24 == 1 & wp24021 == 1 & con1_all != 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con2c_all = "No mobile phone due to unreliable coverage (age 15+)") %>%
  
  # No mobile phone because of no reliable coverage (no phone owners)
  mutate(con2c_np_cov = case_when(lc24 == 1 & wp24021 == 1 & con1_all != 1 ~ 1,
                                  lc24 == 1 & con1_all != 1 ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(con2c_np_cov = "No mobile phone due to unreliable coverage (no phone owners)") %>%
  
  # No mobile phone due to reading or typing difficulties (age 15+)
  mutate(con2d_all = case_when(lc24 == 1 & wp24022 == 1 & con1_all != 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con2d_all = "No mobile phone due to reading or typing difficulties (age 15+)") %>%
  
  # No mobile phone due to reading or typing difficulties (no phone owners)
  mutate(con2d_np_typ = case_when(lc24 == 1 & wp24022 == 1 & con1_all != 1 ~ 1,
                                  lc24 == 1 & con1_all != 1 ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(con2d_np_typ = "No mobile phone due to reading or typing difficulties (no phone owners)") %>%
  
  # No mobile phone because of family/community disapproval (age 15+)
  mutate(con2e_all = case_when(lc24 == 1 & wp24023 == 1 & con1_all != 1 ~ 1, 
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con2e_all = "No mobile phone due to family or community disapproval (age 15+)") %>%
  
  # No mobile phone because of family/community disapproval (no phone owners)
  mutate(con2e_np_cov = case_when(lc24 == 1 & wp24023 == 1 & con1_all != 1 ~ 1,
                                  lc24 == 1 & con1_all != 1 ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(con2e_np_cov = "No mobile phone due to family or community disapproval (no phone owners)") %>%
  
  # No mobile phone due to personal safety/security concerns (age 15+)
  mutate(con2f_all = case_when(lc24 == 1 & wp24024 == 1 & con1_all != 1 ~ 1, 
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con2f_all = "No mobile phone due to personal safety concerns (age 15+)") %>%
  
  # No mobile phone due to personal safety/security concerns (no phone owners)
  mutate(con2f_np_sec = case_when(lc24 == 1 & wp24024 == 1 & con1_all != 1 ~ 1,
                                  lc24 == 1 & con1_all != 1 ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(con2f_np_sec = "No mobile phone due to personal safety concerns (no phone owners)") %>%
  
  # No mobile phone because using someone else's phone (age 15+)
  mutate(con2g_all = case_when(lc24 == 1 & wp24025 == 1 & con1_all != 1 ~ 1, 
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con2g_all = "No mobile phone because using someone else's phone (age 15+)") %>%
  
  # No mobile phone because using someone else's phone (no phone owners)
  mutate(con2g_np_els = case_when(lc24 == 1 & wp24025 == 1 & con1_all != 1 ~ 1,
                                  lc24 == 1 & con1_all != 1 ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(con2g_np_els = "No mobile phone because using someone else's phone (no phone owners)") %>%
  
  # Main reason for no phone: Not enough money to buy one (all adults)
  mutate(con3_all_mon = case_when(lc24 == 1 & wp24026 == 1 & con1_all != 1 ~ 1, 
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con3_all_mon = "Main reason for no phone: Not enough money (all adults)") %>%
  
  # Main reason for no phone: Not enough money to buy one (no phone owners)
  mutate(con3_np_mon = case_when(lc24 == 1 & wp24026 == 1 & con1_all != 1 ~ 1,
                                 lc24 == 1 & con1_all != 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con3_np_mon = "Main reason for no phone: Not enough money (no phone owners)") %>%
  
  # Main reason for no phone: Buying mobile minutes too expensive (all adults)
  mutate(con3_all_exp = case_when(lc24 == 1 & wp24026 == 2 & con1_all != 1 ~ 1,
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con3_all_exp = "Main reason for no phone: Buying minutes too expensive (all adults)") %>%
  
  # Main reason for no phone: Buying mobile minutes too expensive (no phone owners)
  mutate(con3_np_exp = case_when(lc24 == 1 & wp24026 == 2 & con1_all != 1 ~ 1, 
                                 lc24 == 1 & con1_all != 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con3_np_exp = "Main reason for no phone: Buying minutes too expensive (no phone owners)") %>%
  
  # Main reason for no phone: No reliable coverage (all adults)
  mutate(con3_all_cov = case_when(lc24 == 1 & wp24026 == 3 & con1_all != 1 ~ 1, 
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con3_all_cov = "Main reason for no phone: No reliable coverage (all adults)") %>%
  
  # Main reason for no phone: No reliable coverage (no phone owners)
  mutate(con3_np_cov = case_when(lc24 == 1 & wp24026 == 3 & con1_all != 1 ~ 1,
                                 lc24 == 1 & con1_all != 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con3_np_cov = "Main reason for no phone: No reliable coverage (no phone owners)") %>%
  
  # Main reason for no phone: Difficulty reading or typing (all adults)
  mutate(con3_all_typ = case_when(lc24 == 1 & wp24026 == 4 & con1_all != 1 ~ 1, 
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con3_all_typ = "Main reason for no phone: Difficulty reading or typing (all adults)") %>%
  
  # Main reason for no phone: Difficulty reading or typing (no phone owners)
  mutate(con3_np_typ = case_when(lc24 == 1 & wp24026 == 4 & con1_all != 1 ~ 1, 
                                 lc24 == 1 & con1_all != 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con3_np_typ = "Main reason for no phone: Difficulty reading or typing (no phone owners)") %>%
  
  # Main reason for no phone: Family/community disapproval (all adults)
  mutate(con3_all_fam = case_when(lc24 == 1 & wp24026 == 5 & con1_all != 1 ~ 1, 
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con3_all_fam = "Main reason for no phone: Family/community disapproval (all adults)") %>%
  
  # Main reason for no phone: Family/community disapproval (no phone owners)
  mutate(con3_np_fam = case_when(lc24 == 1 & wp24026 == 5 & con1_all != 1 ~ 1, 
                                 lc24 == 1 & con1_all != 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con3_np_fam = "Main reason for no phone: Family/community disapproval (no phone owners)") %>%
  
  # Main reason for no phone: Personal safety/security concerns (all adults)
  mutate(con3_all_sec = case_when(lc24 == 1 & wp24026 == 6 & con1_all != 1 ~ 1,
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con3_all_sec = "Main reason for no phone: Personal safety/security concerns (all adults)") %>%
  
  # Main reason for no phone: Personal safety/security concerns (no phone owners)
  mutate(con3_np_sec = case_when(lc24 == 1 & wp24026 == 6 & con1_all != 1 ~ 1, 
                                 lc24 == 1 & con1_all != 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con3_np_sec = "Main reason for no phone: Personal safety/security concerns (no phone owners)") %>%
  
  # Main reason for no phone: Use someone else's phone (all adults)
  mutate(con3_all_els = case_when(lc24 == 1 & wp24026 == 7 & con1_all != 1 ~ 1,
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con3_all_els = "Main reason for no phone: Use someone else's phone (all adults)") %>%
  
  # Main reason for no phone: Use someone else's phone (no phone owners)
  mutate(con3_np_els = case_when(lc24 == 1 & wp24026 == 7 & con1_all != 1 ~ 1, 
                                 lc24 == 1 & con1_all != 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con3_np_els = "Main reason for no phone: Use someone else's phone (no phone owners)") %>%
  
  # Main reason for no phone: Some other reason (all adults)
  mutate(con3_all_other = case_when(lc24 == 1 & wp24026 == 97 & con1_all != 1 ~ 1, 
                                    lc24 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con3_all_other = "Main reason for no phone: Some other reason (all adults)") %>%
  
  # Main reason for no phone: Some other reason (no phone owners)
  mutate(con3_np_other = case_when(lc24 == 1 & wp24026 == 97 & con1_all != 1 ~ 1, 
                                   lc24 == 1 & con1_all != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con3_np_other = "Main reason for no phone: Some other reason (no phone owners)") %>%
  
  # Used someone else's phone in past 3 months (all adults)
  mutate(con4_all = case_when(lc24 == 1 & wp24027 == 1 & con1_all != 1 ~ 1, 
                              lc24 == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(con4_all = "Used someone else's phone in past 3 months (all adults)") %>%
  
  # Used someone else's phone in past 3 months (no phone owners)
  mutate(con4_np_els = case_when(lc24 == 1 & wp24027 == 1 & con1_all != 1 ~ 1, 
                                 lc24 == 1 & con1_all != 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con4_np_els = "Used someone else's phone in past 3 months (no phone owners)") %>%
  
  # Phone used was a smartphone (all adults)
  mutate(con5_all = case_when(lc24 == 1 & wp24028 == 1 & con4_all == 1 ~ 1, 
                              lc24 == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(con5_all = "Phone used was a smartphone (all adults)") %>%
  
  # Phone used was a smartphone (no phone owners)
  mutate(con5_np_smart = case_when(lc24 == 1 & wp24028 == 1 ~ 1, 
                                   lc24 == 1 & con1_all != 1 ~ 0, 
                                     TRUE ~ NA)) %>%
  set_variable_labels(con5_np_smart = "Phone used was a smartphone (no phone owners)") %>%
  
  # Phone used was a smartphone (used someone else's phone)
  mutate(con5_els_sp = case_when(lc24 == 1 & wp24028 == 1 & con4_all == 1 ~ 1,
                                 lc24 == 1 & con4_all == 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con5_els_sp = "Phone used was a smartphone (used someone else's phone)") %>%
  
  # Phone used was a basic text phone (all adults)
  mutate(con5_all_basic = case_when(lc24 == 1 & wp24028 == 2 & con4_all == 1 ~ 1, 
                                    lc24 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con5_all_basic = "Phone used was a basic text phone (all adults)") %>%
  
  # Phone used was a basic text phone (no phone owners)
  mutate(con5_np_basic = case_when(lc24 == 1 & wp24028 == 2 ~ 1, 
                                   lc24 == 1 & con1_all != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con5_np_basic = "Phone used was a basic text phone (no phone owners)") %>%
  
  # Phone used was a basic text phone (used someone else's phone)
  mutate(con5_els_basic = case_when(lc24 == 1 & wp24028 == 2 & con4_all == 1 ~ 1, 
                                    wp24028 != 2 & con4_all == 1 ~ 0, 
                                    TRUE ~ NA)) %>%
  set_variable_labels(con5_els_basic = "Phone used was a basic text phone (used someone else's phone)") %>%
  
  # Used personal SIM card in someone else's phone (all adults)
  mutate(con6_all = case_when(lc24 == 1 & wp24029 == 1 ~ 1, 
                              lc24 == 1 ~ 0, 
                              TRUE ~ NA)) %>%
  set_variable_labels(con6_all = "Used personal SIM card in someone else's phone (all adults)") %>%

# Used personal SIM card in someone else's phone (no phone owners)
mutate(con6_np_sim = case_when(lc24 == 1 & wp24029 == 1 & con1_all != 1 ~ 1,
                               lc24 == 1 & con1_all != 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con6_np_sim = "Used personal SIM card in someone else's phone (no phone owners)") %>%

  # Used personal SIM card in someone else's phone (used someone else's phone)
  mutate(con6_els_sim = case_when(lc24 == 1 & wp24029 == 1 & con4_all == 1 ~ 1,
                                  wp24029 != 1 & con4_all == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con6_els_sim = "Used personal SIM card in someone else's phone (used someone else's phone)") %>%

  # Family member sets rules for mobile phone use (age 15+)
  mutate(con7_all = case_when(lc24 == 1 & wp24030 == 1 ~ 1,
                              lc24 == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(con7_all = "Family member sets rules for mobile phone use (age 15+)") %>%

  # Family member sets rules for mobile phone use (no phone owners)
  mutate(con7_np_els = case_when(lc24 == 1 & wp24030 == 1 ~ 1,
                                 lc24 == 1 & con1_all != 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con7_np_els = "Family member sets rules for mobile phone use (no phone owners)") %>%

  # Someone in household owns a mobile phone (age 15+)
  mutate(con8_all = case_when(lc24 == 1 & wp24031 == 1 & con1_all != 1 ~ 1,
                              lc24 == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(con8_all = "Someone in household owns a mobile phone (age 15+)") %>%

  # Main mobile phone is a smartphone (age 15+)
  mutate(con9_all_smart = case_when(c24 == 1 & connect_q != 4 & wp24032 == 1 & con1_all == 1 ~ 1,
                                    c24 == 1 & connect_q != 4 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con9_all_smart = "Main mobile phone is a smartphone (age 15+)") %>%

  # Main mobile phone is a basic text phone (age 15+)
  mutate(con9_all_basic = case_when(c24 == 1 & connect_q != 4 & wp24032 == 2 & con1_all == 1 ~ 1,
                                    c24 == 1 & connect_q != 4 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con9_all_basic = "Main mobile phone is a basic text phone (age 15+)") %>%

  # Can use WhatsApp on basic text phone (age 15+)
  mutate(con10_all = case_when(lc24 == 1 & wp24033 == 1 & con9_all_basic == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con10_all = "Can use WhatsApp on basic text phone (age 15+)") %>%

  # Could you use WhatsApp on this basic text phone if you wanted to? applied only to those who said YES to owning a basic phone
  mutate(con10_basic_wa = case_when(lc24 == 1 & wp24033 == 1 & con9_all_basic == 1 ~ 1,
                                    lc24 == 1 & con9_all_basic == 1 ~ 0,
                          TRUE ~ NA)) %>%
  set_variable_labels(con10_basic_wa = "Can use WhatsApp on basic text phone (owners of basic phone)") %>%

  # Is the SIM number in this mobile phone registered in your name? (all adults)
  mutate(con11_all = case_when(lc24 == 1 & con1_all == 1 & wp24034 == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con11_all = "SIM number registered in own name (all adults)") %>%


  # Is the SIM number in this mobile phone registered in your name? (% of people with phone)
  mutate(con11_m_sim = case_when(lc24 == 1 & wp24034 == 1 & con1_all == 1 ~ 1,
                                 lc24 == 1 & con1_all == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con11_m_sim = "SIM number registered in own name (phone owners)") %>%
  
  
  # Is the SIM number in this mobile phone registered in your name? (% of people with phone)
  mutate(con11_m_sim_n = case_when(lc24 == 1 & wp24034 == 2 & con1_all == 1 ~ 1,
                                 lc24 == 1 & con1_all == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con11_m_sim_n = "SIM number registered in own name (phone owners)") %>%
  
  
  # Is the SIM number in this mobile phone registered in your name? (% of people with phone)
  mutate(con11_m_sim_dk = case_when(lc24 == 1 & wp24034 %in% c(8,9) & con1_all == 1 ~ 1,
                                   lc24 == 1 & con1_all == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con11_m_sim_dk = "SIM number registered in own name (phone owners)") %>%
  
  
  # SIM NOT in your own name and have MM (all adults)
  mutate(con11_NO_mm = case_when(lc24 == 1 & m24 == 1 & con11_all != 1 & acc24mob == 1 ~ 1,
                               lc24 == 1 & m24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con11_NO_mm = "DO NOT have a SIM number registered in own name but do have mobile money account (all adults)") %>%

  # How frequently do you use a mobile phone: Daily, as share of all adults
  mutate(con12_all_d = case_when(lc24 == 1 & wp24035 == 1 & con1_all == 1 ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con12_all_d = "Daily mobile phone use (all adults)") %>%

  # How frequently do you use a mobile phone: Daily, as share of phone owners
  mutate(con12_m_d = case_when(lc24 == 1 & wp24035 == 1 & con1_all == 1 ~ 1,
                               con1_all == 1 & wp24035 != 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con12_m_d = "Daily mobile phone use (phone owners)") %>%

  # How frequently do you use a mobile phone: Daily, as share of smartphone owners
  mutate(con12_sp_d = case_when(lc24 == 1 & wp24035 == 1 & con9_all_smart == 1 ~ 1,
                                lc24 == 1 & con9_all_smart == 1 ~ 0,
                            TRUE ~ NA)) %>%
  set_variable_labels(con12_sp_d = "Daily mobile phone use (smartphone owners)") %>%

  # How frequently do you use a mobile phone: Weekly, as share of all adults
  mutate(con12_all_w = case_when(lc24 == 1 & wp24035 == 2 & con1_all == 1 ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con12_all_w = "Weekly mobile phone use (all adults)") %>%

  # How frequently do you use a mobile phone: Weekly, as share of phone owners
  mutate(con12_m_w = case_when(lc24 == 1 & wp24035 == 2 & con1_all == 1 ~ 1,
                               lc24 == 1 & con1_all == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con12_m_w = "Weekly mobile phone use (phone owners)") %>%

  # How frequently do you use a mobile phone: Weekly, as share of smartphone owners
  mutate(con12_sp_w = case_when(lc24 == 1 & wp24035 == 2 & con9_all_smart == 1 ~ 1,
                                lc24 == 1 & con9_all_smart == 1 ~ 0,
                       TRUE ~ NA)) %>%
  set_variable_labels(con12_sp_w = "Weekly mobile phone use (smartphone owners)") %>%

  # How frequently do you use a mobile phone: Monthly (all adults)
  mutate(con12_all_m = case_when(lc24 == 1 & wp24035 == 3 & con1_all == 1 ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con12_all_m = "Monthly mobile phone use (all adults)") %>%

  # How frequently do you use a mobile phone: Monthly (phone owners)
  mutate(con12_m_m = case_when(lc24 == 1 & wp24035 == 3 & con1_all == 1 ~ 1,
                               lc24 == 1 & con1_all == 1 ~ 0,
                            TRUE ~ NA)) %>%
  set_variable_labels(con12_m_m = "Monthly mobile phone use (phone owners)") %>%

  # How frequently do you use a mobile phone: Monthly (smartphone owners)
  mutate(con12_sp_m = case_when(lc24 == 1 & wp24035 == 3 & con9_all_smart == 1 ~ 1,
                                lc24 == 1 & con9_all_smart == 1 ~ 0,
                           TRUE ~ NA)) %>%
  set_variable_labels(con12_sp_m = "Monthly mobile phone use (smartphone owners)") %>%

  # How frequently do you use a mobile phone: Less than once a month (all adults)
  mutate(con12_all_lm = case_when(lc24 == 1 & wp24035 == 4 & con1_all == 1 ~ 1,
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con12_all_lm = "Less than once a month mobile phone use (all adults)") %>%

  # How frequently do you use a mobile phone: Less than once a month (phone owners)
  mutate(con12_m_lm = case_when(lc24 == 1 & wp24035 == 4 & con1_all == 1 ~ 1,
                                lc24 == 1 & con1_all == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con12_m_lm = "Less than once a month mobile phone use (phone owners)") %>%

  # How frequently do you use a mobile phone: Less than once a month (smartphone owners)
  mutate(con12_sp_lm = case_when(lc24 == 1 & wp24035 == 4 & con9_all_smart == 1 ~ 1,
                                 lc24 == 1 & con9_all_smart == 1 ~ 0,
                        TRUE ~ NA)) %>%
  set_variable_labels(con12_sp_lm = "Less than once a month mobile phone use (smartphone owners)") %>%

  ####
  mutate(con12_all_n = case_when(lc24 == 1 & wp24035 == 7 & con1_all == 1 ~ 1,
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con12_all_n = "Never: mobile phone use (all adults)") %>%
  
  # How frequently do you use a mobile phone: Never (phone owners)
  mutate(con12_m_n = case_when(lc24 == 1 & wp24035 == 7 & con1_all == 1 ~ 1,
                                lc24 == 1 & con1_all == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con12_m_n = "Never: mobile phone use (phone owners)") %>%
  
  # How frequently do you use a mobile phone: Never (smartphone owners)
  mutate(con12_sp_n = case_when(lc24 == 1 & wp24035 == 7 & con9_all_smart == 1 ~ 1,
                                 lc24 == 1 & con9_all_smart == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con12_sp_n = "Never: mobile phone use (smartphone owners)") %>%
  
  # Did you use a mobile phone in the PAST 3 MONTHS? (all adults)
  mutate(con13_all = case_when(lc24 == 1 & wp24036 == 1 & wp24035 %in% c(4, 7, 8, 9) ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con13_all = "Used a mobile phone in the past 3 months (all adults)") %>%

    # Did you use a mobile phone in the PAST 3 MONTHS? Applied only to those who said YES to owning a phone
    mutate(con13_m = case_when(lc24 == 1 & wp24036 == 1 & wp24035 %in% c(4, 7, 8, 9) & con1_all == 1 ~ 1,
                               lc24 == 1 & con1_all == 1 ~ 0,
                               TRUE ~ NA)) %>%
    set_variable_labels(con13_m = "Used a mobile phone in the past 3 months (phone owners)") %>%
  
  # Have you ever READ a text message on a mobile phone? This can include an SMS or text message or a message on a messaging app like WhatsApp? (all adults)
  mutate(con14_all = case_when(lc24 == 1 & wp24037 == 1 & con1_all == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con14_all = "Read a text message on a mobile phone (all adults)") %>%

  # Have you ever READ a text message on a mobile phone? This can include an SMS or text message or a message on a messaging app like WhatsApp? (phone owners)
  mutate(con14_p = case_when(lc24 == 1 & wp24037 == 1 & con1_all == 1 ~ 1,
                                lc24 == 1 & con1_all == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con14_p = "Read a text message on a mobile phone (phone owners)") %>%

  # NOTE:: CON15 is only for South Asia - variable won't exist and will throw an error until we have data for region
  # IMPORTANT!!!!! each language of the questionnaire has a different numeric suffix at the end - I use the coalesc code to merge them all into one column because they are mutually exclusive
  # Could you read and understand a text message in [insert language of interview] that is written using English letters, like "A", "B", and "C"? This can include an SMS or text message or a message on a messaging app like WhatsApp.
  mutate(wp24038 = coalesce(!!!select(., starts_with("wp24038_")))) %>%
  
  mutate(con15_all = case_when(regionwb24_hi == "South Asia (excluding high income)" & wp24038 == 1 & con1_all == 1 ~ 1,
                               regionwb24_hi == "South Asia (excluding high income)" ~ 0,
                                                  TRUE ~ NA)) %>%
  set_variable_labels(con15_all = "Can read and understand a text message using English letters (all adults)") %>%

  # Have you ever SENT a text message on a mobile phone? This can include an SMS or text message or a message sent through a messaging app like WhatsApp.
  mutate(con16_all = case_when(lc24 == 1 & wp24039 == 1 & con1_all == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con16_all = "Sent a text message on a mobile phone (all adults)") %>%

  # If the government needed to communicate important news, would you prefer to receive it by SMS or text message?
  mutate(con17_all_text = case_when(lc24 == 1 & wp24040 == 1 & con1_all == 1 ~ 1,
                                    lc24 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con17_all_text = "Prefers receiving government news by SMS or text (all adults)") %>%

  # If the government needed to communicate important news, would you prefer to receive it by phone call?
  mutate(con17_all_call = case_when(lc24 == 1 & wp24040 == 2 & con1_all == 1 ~ 1,
                                    lc24 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con17_all_call = "Prefers receiving government news by phone call (all adults)") %>%

  # If the government needed to communicate important news, would you prefer to receive it by NEITHER
  mutate(con17_all_n = case_when(lc24 == 1 & wp24040 == 3 & con1_all == 1 ~ 1,
                                    lc24 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con17_all_n = "Prefers receiving government news by NEITHER call or text (all adults)") %>%
  
  # If the government needed to communicate important news, would you prefer to receive it by BOTH
  mutate(con17_all_b = case_when(lc24 == 1 & wp24040 == 4 & con1_all == 1 ~ 1,
                                    lc24 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con17_all_b = "Prefers receiving government news by BOTH call or text (all adults)") %>%

  # Is there a lock on the mobile phone that you use, such as a PIN, password, or fingerprint?
  mutate(con18_all = case_when(lc24 == 1 & wp24041 == 1 & con1_all == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con18_all = "Phone has a lock (PIN, password, fingerprint) (all adults)") %>%

  # Is there a lock on the mobile phone that you use, such as a PIN, password, or fingerprint?, as share of phone owners
  mutate(con18_m = case_when(lc24 == 1 & wp24041 == 1 & con1_all == 1 ~ 1,
                             lc24 == 1 & con1_all == 1 ~ 0,
                             TRUE ~ NA)) %>%
  set_variable_labels(con18_m = "Phone has a lock (PIN, password, fingerprint) (phone owners)") %>%

  # Are you able to change the PIN or password on the mobile phone that you use without help?
  mutate(con19_all = case_when(lc24 == 1 & wp24042 == 1 & con18_all == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con19_all = "Can change PIN or password on mobile phone without help (all adults)") %>%

  # Does someone, such as a family member, set rules about how you can use a mobile phone?
  mutate(con20_all = case_when(lc24 == 1 & wp24043 == 1 & con1_all == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con20_all = "Family member sets rules for mobile phone use (all adults)") %>%

  # In the past 12 months, did you receive a phone call or SMS asking you to send money?
  mutate(con21_all = case_when(lc24 == 1 & wp24044 == 1 & con1_all == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con21_all = "Received phone call or SMS asking for money in the past 12 months (all adults)") %>%

  # In the past 12 months, did you receive a phone call or SMS asking you to send money?
  mutate(con21_p = case_when(lc24 == 1 & wp24044 == 1 & con1_all == 1 ~ 1,
                               lc24 == 1 & con1_all == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con21_p = "Received phone call or SMS asking for money in the past 12 months (of phone owners)") %>%
  
  
  # Did you send money to this person?
  mutate(con22_all = case_when(lc24 == 1 & wp24045 == 1 & con21_all == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con22_all = "Sent money to person asking for it via phone/SMS (all adults)") %>%

  # In the past 12 months, have you received unwanted and offensive messages, photos, or videos on your mobile phone?
  mutate(con23_all = case_when(lc24 == 1 & wp24046 == 1 & con1_all == 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con23_all = "Received unwanted offensive messages, photos, or videos (all adults)") %>%
  
  
  # In the past 12 months, have you received unwanted and offensive messages, photos, or videos on your mobile phone?
  mutate(con23_p = case_when(lc24 == 1 & wp24046 == 1 & con1_all == 1 ~ 1,
                               lc24 == 1 & con1_all == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con23_p = "Received unwanted offensive messages, photos, or videos (of phone owners)") %>%
  
  

  # Have you used the Internet in the past seven days, whether on a mobile phone, a computer, or some other device?, as share of all adults
  mutate(con24_all = case_when(c24 == 1 & wp15862_con == 1 ~ 1,
                               c24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con24_all = "Used the Internet in the past 7 days (all adults)") %>%

  # Did you use the Internet in the PAST THREE MONTHS?, as share of all adults
  mutate(con25_all = case_when(c24 == 1 & wp24047 == 1 ~ 1,
                               c24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con25_all = "Used the Internet in the past 3 months (all adults)") %>%

  # In a typical month, how frequently do you use the Internet: Daily, share of all adults
  mutate(con26_all_d = case_when(lc24 == 1 & wp24048 == 1 & (con24_all == 1 | con25_all == 1) ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con26_all_d = "Daily Internet use (all adults)") %>%

  # In a typical month, how frequently do you use the Internet: Daily, share of internet users
  mutate(con26_int_d = case_when(lc24 == 1 & wp24048 == 1 & (con24_all == 1 | con25_all == 1) ~ 1,
                                 lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
         TRUE ~ NA)) %>%
  set_variable_labels(con26_int_d = "Daily Internet use (internet users)") %>%

  # In a typical month, how frequently do you use the Internet: Weekly, share of all adults
  mutate(con26_all_w = case_when(lc24 == 1 & wp24048 == 2 & (con24_all == 1 | con25_all == 1) ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con26_all_w = "Weekly Internet use (all adults)") %>%

  # In a typical month, how frequently do you use the Internet: Weekly, share of internet users
  mutate(con26_int_w = case_when(lc24 == 1 & wp24048 == 2 & (con24_all == 1 | con25_all == 1) ~ 1,
                                 lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(con26_int_w = "Weekly Internet use (internet users)") %>%

  # In a typical month, how frequently do you use the Internet: Monthly, share of all adults
  mutate(con26_all_m = case_when(lc24 == 1 & wp24048 == 3 & (con24_all == 1 | con25_all == 1) ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con26_all_m = "Monthly Internet use (all adults)") %>%

  # In a typical month, how frequently do you use the Internet: Monthly, share of internet users
  mutate(con26_int_m = case_when(lc24 == 1 & wp24048 == 3 & (con24_all == 1 | con25_all == 1) ~ 1,
                                 lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
         TRUE ~ NA)) %>%
  set_variable_labels(con26_int_m = "Monthly Internet use (internet users)") %>%

  # In a typical month, how frequently do you use the Internet: Less than once a month, share of all adults
  mutate(con26_all_lm = case_when(lc24 == 1 & wp24048 == 4 & (con24_all == 1 | con25_all == 1) ~ 1,
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con26_all_lm = "Less than once a month Internet use (all adults)") %>%

  # In a typical month, how frequently do you use the Internet: Less than once a month, share of internet users
  mutate(con26_int_lm = case_when(lc24 == 1 & wp24048 == 4 & (con24_all == 1 | con25_all == 1) ~ 1,
                                  lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(con26_int_lm = "Less than once a month Internet use (internet users)") %>%

  ####
  
  mutate(con26_all_n = case_when(lc24 == 1 & wp24048 == 7 & (con24_all == 1 | con25_all == 1) ~ 1,
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con26_all_n = "Never: Internet use (all adults)") %>%
  
  # In a typical month, how frequently do you use the Internet: Never, share of internet users
  mutate(con26_int_n = case_when(lc24 == 1 & wp24048 == 7  & (con24_all == 1 | con25_all == 1) ~ 1,
                                  lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con26_int_n = "Never: Internet use (internet users)") %>%
  
  # Do you buy a data package to use the Internet?, share of all adults
  mutate(con27_all = case_when(lc24 == 1 & wp24049 == 1 & (con24_all == 1 | con25_all == 1) ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con27_all = "Buys data package for Internet use (all adults)") %>%

  # Do you buy a data package to use the Internet?, share of internet users
  mutate(con27_int = case_when(lc24 == 1 & wp24049 == 1 & (con24_all == 1 | con25_all == 1) ~ 1,
                               lc24 == 1 &  (con24_all == 1 | con25_all == 1) ~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(con27_int = "Buys data package for Internet use (internet users)") %>%

  # How frequently do you buy your data package to use the Internet: Daily, share of all adults
  mutate(con28_all_d = case_when(lc24 == 1 & wp24050 == 1 & con27_all == 1 ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con28_all_d = "Buys data package daily (all adults)") %>%

  # How frequently do you buy your data package to use the Internet: Daily, share of internet users
  mutate(con28_int_d = case_when(lc24 == 1 & wp24050 == 1 & con27_all == 1 ~ 1,
                                 lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con28_int_d = "Buys data package daily (internet users)") %>%

  # How frequently do you buy your data package to use the Internet: Weekly, share of all adults
  mutate(con28_all_w = case_when(lc24 == 1 & wp24050 == 2 & con27_all == 1 ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con28_all_w = "Buys data package weekly (all adults)") %>%

  # How frequently do you buy your data package to use the Internet: Weekly, share of internet users
  mutate(con28_int_w = case_when(lc24 == 1 & wp24050 == 2 & con27_all == 1 ~ 1,
                                 lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con28_int_w = "Buys data package weekly (internet users)") %>%

  # How frequently do you buy your data package to use the Internet: Monthly, as share of all adults
  mutate(con28_all_m = case_when(lc24 == 1 & wp24050 == 3 & con27_all == 1 ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con28_all_m = "Buys data package monthly (all adults)") %>%

  # How frequently do you buy your data package to use the Internet: Monthly, as share of internet users
  mutate(con28_int_m = case_when(lc24 == 1 & wp24050 == 3 & con27_all == 1 ~ 1,
                                 lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con28_int_m = "Buys data package monthly (internet users)") %>%

  # How frequently do you buy your data package to use the Internet: Less than once a month, as share of all adults
  mutate(con28_all_lm = case_when(lc24 == 1 & wp24050 == 4 & con27_all == 1 ~ 1,
                                  lc24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con28_all_lm = "Buys data package less than once a month (all adults)") %>%

  # How frequently do you buy your data package to use the Internet: Less than once a month, as share of internet users
  mutate(con28_int_lm = case_when(lc24 == 1 & wp24050 == 4 & con27_all == 1 ~ 1,
                                  lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con28_int_lm = "Buys data package less than once a month (internet users)") %>%

  # How frequently do you buy your data package to use the Internet: Never, as share of all adults
  mutate(con28_all_n = case_when(lc24 == 1 & wp24050 == 7 & con27_all == 1 ~ 1,
                                 lc24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con28_all_n = "Never buys data package (all adults)") %>%

  # How frequently do you buy your data package to use the Internet: Never, as share of internet users
  mutate(con28_int_n = case_when(lc24 == 1 & wp24050 == 7 & con27_all == 1 ~ 1,
                                 lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(con28_int_n = "Never buys data package (internet users)") %>%

  # Do you connect to the Internet ONLY through FREE WiFi?, as share of all adults
  mutate(con29_all = case_when(lc24 == 1 & wp24051 == 1 & con27_all != 1 ~ 1,
                               lc24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con29_all = "Connects to Internet only through free WiFi (all adults)") %>%

  # Sent a voice message from a mobile phone in the past 3 months, as share of all adults
  mutate(con30a_all = case_when(lc24 == 1 & wp24052 == 1 & (con9_all_smart == 1 | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30a_all = "Sent a voice message in past 3 months (all adults)") %>%

  # Sent a voice message from a mobile phone in the past 3 months, as share of smartphone owners
  mutate(con30a_sp = case_when(lc24 == 1 & wp24052 == 1 & con9_all_smart == 1 ~ 1,
                               lc24 == 1 & (con9_all_smart == 1 & wp24052 != 1) ~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(con30a_sp = "Sent a voice message in past 3 months (smartphone owners)") %>%

  # Sent a photo from a mobile phone in the past 3 months, as share of all adults
  mutate(con30b_all = case_when(lc24 == 1 & wp24053 == 1 & (con9_all_smart == 1 | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30b_all = "Sent a photo in past 3 months (all adults)") %>%

  # Sent a photo from a mobile phone in the past 3 months, as share of smartphone users
  mutate(con30b_sp = case_when(lc24 == 1 & wp24053 == 1 & con9_all_smart == 1 ~ 1,
                               lc24 == 1 & con9_all_smart == 1 ~ 0,
                     TRUE ~ NA)) %>%
  set_variable_labels(con30b_sp = "Sent a photo in past 3 months (smartphone users)") %>%

  # Used social media on a mobile phone in the past 3 months, as share of all adults
  mutate(con30c_all = case_when(lc24 == 1 & wp24054 == 1 & (con9_all_smart == 1 | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30c_all = "Used social media in past 3 months (all adults)") %>%

  # Used social media on a mobile phone in the past 3 months, as share of smartphone users
  mutate(con30c_sp = case_when(lc24 == 1 & wp24054 == 1 & con9_all_smart == 1 ~ 1,
                               lc24 == 1 & con9_all_smart == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(con30c_sp = "Used social media in past 3 months (smartphone users)") %>%

  # Read news or current events online in the past 3 months, as share of all adults
  mutate(con30d_all = case_when(lc24 == 1 & wp24055 == 1 & (con9_all_smart == 1 | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30d_all = "Read news or current events online in past 3 months (all adults)") %>%

  # Read news or current events online in the past 3 months, as share of smartphone owners
  mutate(con30d_sp = case_when(lc24 == 1 & wp24055 == 1 & con9_all_smart == 1 ~ 1,
                               lc24 == 1 & con9_all_smart == 1~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(con30d_sp = "Read news or current events online in past 3 months (smartphone owners)") %>%

  ##################### YET TO EDIT


  # Accessed information online to learn, train, or educate yourself or others, as share of all adults
  mutate(con30e_all = case_when(lc24 == 1 & wp24056 == 1 & (con9_all_smart == 1 | con24_all == 1 | con25_all == 1) ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30e_all = "Accessed online info to learn/train/educate in past 3 months (all adults)") %>%

  # In the PAST 3 MONTHS, accessed information online to learn, train, or educate, as share of smartphone owners
  mutate(con30e_sp = case_when(lc24 == 1 & wp24056 == 1 & con9_all_smart == 1 ~ 1,
                               lc24 == 1 & con9_all_smart == 1 ~ 0, 
                            TRUE ~ NA)) %>%
  set_variable_labels(con30e_sp = "Accessed online info to learn/train/educate in past 3 months (smartphone owners)") %>%
  

  # In the PAST 3 MONTHS, used apps or websites to earn money, as share of all adults
  mutate(con30f_all = case_when(lc24 == 1 & wp24057 == 1 & (con9_all_smart == 1 | con24_all == 1 | con25_all == 1) ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30f_all = "Used apps/websites to earn money in past 3 months (all adults)") %>%

  # In the PAST 3 MONTHS, used apps or websites to earn money, as share of smartphone owners
  mutate(con30f_sp = case_when(lc24 == 1 & wp24057 == 1 & con9_all_smart == 1 ~ 1,
                               lc24 == 1 & con9_all_smart == 1 ~ 0, 
                               TRUE ~ NA)) %>%
  set_variable_labels(con30f_sp = "Used apps/websites to earn money in past 3 months (smartphone owners)") %>%

  # In the PAST 3 MONTHS, accessed government services or searched for government info online, as share of all adults
  mutate(con30g_all = case_when(lc24 == 1 & wp24058 == 1 & (con9_all_smart == 1 | con24_all == 1 | con25_all == 1) ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30g_all = "Accessed government services/info online in past 3 months (all adults)") %>%

  # In the PAST 3 MONTHS, accessed government services or searched for government info online, as share of smartphone owners
  mutate(con30g_sp = case_when(lc24 == 1 & wp24058 == 1 & con9_all_smart == 1 ~ 1,
                               lc24 == 1 & con9_all_smart == 1 ~ 0, 
                               TRUE ~ NA)) %>%
  set_variable_labels(con30g_sp = "Accessed government services/info online in past 3 months (smartphone owners)") %>%

  # In the PAST 3 MONTHS, searched or applied for a job online, as share of all adults
  mutate(con30h_all = case_when(lc24 == 1 & wp24059 == 1 & (con9_all_smart == 1 | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30h_all = "Searched/applied for a job online in past 3 months (all adults)") %>%

  # In the PAST 3 MONTHS, searched or applied for a job online, as share of smartphone owners
  mutate(con30h_sp = case_when(lc24 == 1 & wp24059 == 1 & con9_all_smart == 1 ~ 1,
                               lc24 == 1 & con9_all_smart == 1 ~ 0, 
                              TRUE ~ NA)) %>%
  set_variable_labels(con30h_sp = "Searched/applied for a job online in past 3 months (smartphone owners)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. You don't have enough money to buy a smartphone
  mutate(con31a_all = case_when(lc24 == 1 & wp24060 == 1 & con9_all_smart != 1 ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31a_all = "Does not own a smartphone due to cost (all adults)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. You don't have enough money to buy a smartphone, as share of no-smartphone owners
  mutate(con31a_nsp = case_when(lc24 == 1 & wp24060 == 1 & con9_all_smart != 1 ~ 1,
                                lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(con31a_nsp = "Does not own a smartphone due to cost (no-smartphone owners)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. Buying a mobile data plan is too expensive, as share of all adults
  mutate(con31b_all = case_when(lc24 == 1 & wp24061 == 1 & con9_all_smart != 1 ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31b_all = "Does not own a smartphone due to data cost (all adults)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. Buying a mobile data plan is too expensive, as share of non-smartphone owners
  mutate(con31b_nsp = case_when(lc24 == 1 & wp24061 == 1 & con9_all_smart != 1 ~ 1,
                                lc24 == 1 & con9_all_smart != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31b_nsp = "Does not own a smartphone due to data cost (non-smartphone owners)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. There is not reliable Internet coverage where you live
  mutate(con31c_all = case_when(lc24 == 1 & wp24062 == 1 & con9_all_smart != 1 ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31c_all = "Does not own a smartphone due to lack of reliable Internet coverage (all adults)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. There is not reliable Internet coverage where you live, as share of non-smartphone owners
  mutate(con31c_nsp = case_when(lc24 == 1 & wp24062 == 1 & con9_all_smart != 1 ~ 1,
                                lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(con31c_nsp = "Does not own a smartphone due to lack of reliable Internet coverage (non-smartphone owners)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. You have difficulties reading or typing on a smartphone
  mutate(con31d_all = case_when(lc24 == 1 & wp24063 == 1 & con9_all_smart != 1 ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31d_all = "Does not own a smartphone due to difficulty reading/typing on a smartphone (all adults)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. You have difficulties reading or typing on a smartphone, as share of non-smartphone owners
  mutate(con31d_nsp = case_when(lc24 == 1 & wp24063 == 1 & con9_all_smart != 1 ~ 1,
                                lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(con31d_nsp = "Does not own a smartphone due to difficulty reading/typing on a smartphone (non-smartphone owners)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. People in your family or community do not approve of you using a smartphone
  mutate(con31e_all = case_when(lc24 == 1 & wp24064 == 1 & con9_all_smart != 1 ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31e_all = "Does not own a smartphone due to disapproval from family/community (all adults)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. People in your family or community do not approve of you using a smartphone, as share of non-smartphone owners
  mutate(con31e_nsp = case_when(lc24 == 1 & wp24064 == 1 & con9_all_smart != 1 ~ 1,
                                lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(con31e_nsp = "Does not own a smartphone due to disapproval from family/community (non-smartphone owners)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. Worried about personal safety or security
  mutate(con31f_all = case_when(lc24 == 1 & wp24065 == 1 & con9_all_smart != 1 ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31f_all = "Does not own a smartphone due to safety/security concerns (all adults)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. Worried about personal safety or security, as share of non-smartphone owners
  mutate(con31f_nsp = case_when(lc24 == 1 & wp24065 == 1 & con9_all_smart != 1 ~ 1,
                                lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(con31f_nsp = "Does not own a smartphone due to safety/security concerns (non-smartphone owners)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. You use someone else's smartphone
  mutate(con31g_all = case_when(lc24 == 1 & wp24066 == 1 & con9_all_smart != 1 ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31g_all = "Does not own a smartphone because they use someone else's (all adults)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. You use someone else's smartphone, as share of non-smartphone owners
  mutate(con31g_nsp = case_when(lc24 == 1 & wp24066 == 1 & con9_all_smart != 1 ~ 1,
                                lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(con31g_nsp = "Does not own a smartphone because they use someone else's (non-smartphone owners)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. You have no need for a smartphone, as share of all adults
  mutate(con31h_all = case_when(lc24 == 1 & wp24067 == 1 & con9_all_smart != 1 ~ 1, 
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con31h_all = "Does not own a smartphone due to no need (all adults)") %>%

  # Please tell me whether each of the following are reasons why you do NOT OWN a smartphone. You have no need for a smartphone, as share of non-smartphone owners
  mutate(con31h_nsp = case_when(lc24 == 1 & wp24067 == 1 & con9_all_smart != 1 ~ 1,
                                lc24 == 1 & con9_all_smart != 1 ~ 0, 
                              TRUE ~ NA)) %>%
  set_variable_labels(con31h_nsp = "Does not own a smartphone due to no need (non-smartphone owners)") %>%

  # What is the MAIN reason you do not own a smartphone: Not enough money to buy a smartphone, as share of all adults
  mutate(con32_all_mon = case_when(lc24 == 1 & wp24068 == 1 & con9_all_smart != 1 ~ 1, 
                                   lc24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_all_mon = "Main reason for not owning a smartphone: lack of money (all adults)") %>%

  # What is the MAIN reason you do not own a smartphone: Not enough money to buy a smartphone, as share of non-smartphone owners
  mutate(con32_nsp_mon = case_when(lc24 == 1 & wp24068 == 1 & con9_all_smart != 1 ~ 1,
                                   lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_nsp_mon = "Main reason for not owning a smartphone: lack of money (non-smartphone owners)") %>%

  # What is the MAIN reason you do not own a smartphone: Buying mobile minutes is too expensive, as share of all adults
  mutate(con32_all_exp = case_when(lc24 == 1 & wp24068 == 2 & con9_all_smart != 1 ~ 1, 
                                   lc24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_all_exp = "Main reason for not owning a smartphone: mobile minutes too expensive (all adults)") %>%

  # What is the MAIN reason you do not own a smartphone: Buying mobile minutes is too expensive, as share of non-smartphone owners
  mutate(con32_nsp_exp = case_when(lc24 == 1 & wp24068 == 2 & con9_all_smart != 1 ~ 1,
                                   lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_nsp_exp = "Main reason for not owning a smartphone: mobile minutes too expensive (non-smartphone owners)") %>%

  # What is the MAIN reason you do not own a smartphone: There is not reliable coverage where you live, as share of all adults
  mutate(con32_all_cov = case_when(lc24 == 1 & wp24068 == 3 & con9_all_smart != 1 ~ 1, 
                                   lc24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_all_cov = "Main reason for not owning a smartphone: no reliable coverage (all adults)") %>%

  # What is the MAIN reason you do not own a smartphone: There is not reliable coverage where you live, as share of non-smartphone owners
  mutate(con32_nsp_cov = case_when(lc24 == 1 & wp24068 == 3 & con9_all_smart != 1 ~ 1,
                                   lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_nsp_cov = "Main reason for not owning a smartphone: no reliable coverage (non-smartphone owners)") %>%

  # What is the MAIN reason you do not own a smartphone: Difficulties reading or typing on a smartphone, as share of all adults
  mutate(con32_all_typ = case_when(lc24 == 1 & wp24068 == 4 & con9_all_smart != 1 ~ 1, 
                                   lc24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_all_typ = "Main reason for not owning a smartphone: difficulty reading/typing (all adults)") %>%

  # What is the MAIN reason you do not own a smartphone: Difficulties reading or typing on a smartphone, as share of non-smartphone owners
  mutate(con32_nsp_typ = case_when(lc24 == 1 & wp24068 == 4 & con9_all_smart != 1 ~ 1,
                                   lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_nsp_typ = "Main reason for not owning a smartphone: difficulty reading/typing (non-smartphone owners)") %>%

  # What is the MAIN reason you do not own a smartphone: People in your family/community do not approve of smartphone use, as share of all adults
  mutate(con32_all_fam = case_when(lc24 == 1 & wp24068 == 5 & con9_all_smart != 1 ~ 1, 
                                   lc24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_all_fam = "Main reason for not owning a smartphone: family/community disapproval (all adults)") %>%

  # What is the MAIN reason you do not own a smartphone: People in your family or community do not approve of you using a smartphone, as share of no-smartphone
  mutate(con32_nsp_fam = case_when(lc24 == 1 & wp24068 == 5 & con9_all_smart != 1 ~ 1,
                                   lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_nsp_fam = "Main reason for not owning a smartphone: family/community disapproval (non-smartphone owners)") %>%

  # What is the MAIN reason you do not own a smartphone: Worried about personal safety or security, as share of all adults
  mutate(con32_all_sec = case_when(lc24 == 1 & wp24068 == 6 & con9_all_smart != 1 ~ 1, 
                                   lc24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_all_sec = "Main reason for not owning a smartphone: safety/security concerns (all adults)") %>%

  # What is the MAIN reason you do not own a smartphone: Worried about personal safety or security, as share of non-smartphone owners
  mutate(con32_nsp_sec = case_when(lc24 == 1 & wp24068 == 6 & con9_all_smart != 1 ~ 1,
                                   lc24 == 1 & con9_all_smart != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_nsp_sec = "Main reason for not owning a smartphone: safety/security concerns (non-smartphone owners)") %>%

  # What is the MAIN reason you do not own a smartphone: You use someone else's mobile phone, as share of all adults
  mutate(con32_all_els = case_when(lc24 == 1 & wp24068 == 7 & con9_all_smart != 1 ~ 1, 
                                   lc24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_all_els = "Main reason for not owning a smartphone: uses someone else's phone (all adults)") %>%

  # What is the MAIN reason you do not own a smartphone: You use someone else's mobile phone, as share of non-smartphone owners
  mutate(con32_nsp_els = case_when(lc24 == 1 & wp24068 == 7 & con9_all_smart != 1 ~ 1,
                                   lc24 == 1 &  con9_all_smart != 1 ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con32_nsp_els = "Main reason for not owning a smartphone: uses someone else's phone (non-smartphone owners)") %>%

  # What is the MAIN reason you do not own a smartphone: No need for a smartphone, as share of all adults
  mutate(con32_all_need = case_when(lc24 == 1 & wp24068 == 8 & con9_all_smart != 1 ~ 1, 
                                    lc24 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con32_all_need = "Main reason for not owning a smartphone: no need for a smartphone (all adults)") %>%

  # What is the MAIN reason you do not own a smartphone: No need for a smartphone, as share of non-smartphone owners
  mutate(con32_nsp_need = case_when(lc24 == 1 & wp24068 == 8 & con9_all_smart != 1 ~ 1,
                                    lc24 == 1 &  con9_all_smart != 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con32_nsp_need = "Main reason for not owning a smartphone: no need for a smartphone (non-smartphone owners)") %>%

  # How worried are you about personal information getting stolen: very worried (all adults)
  mutate(con33a_all = case_when(cy24 == 1 & wp24069 == 1 & (con24_all == 1 | con25_all == 1) ~ 1, 
                                cy24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con33a_all = "Very worried about personal info theft (all adults)") %>%

  # How worried are you about personal information getting stolen: very worried (internet users)
  mutate(con33a_int_vw = case_when(cy24 == 1 & (con24_all == 1 | con25_all == 1) & wp24069 == 1 ~ 1,
                                   cy24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(con33a_int_vw = "Very worried about personal info theft (internet users)") %>%

  # How worried are you about personal information getting stolen: somewhat worried (all adults)
  mutate(con33a_all_sw = case_when(cy24 == 1 & wp24069 == 2 & (con24_all == 1 | con25_all == 1) ~ 1, 
                                   cy24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33a_all_sw = "Somewhat worried about personal info theft (all adults)") %>%

  # How worried are you about personal information getting stolen: somewhat worried (internet users)
  mutate(con33a_int_sw = case_when(cy24 == 1 & ((con24_all == 1 | con25_all == 1) & wp24069 == 2) ~ 1,
                                   cy24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(con33a_int_sw = "Somewhat worried about personal info theft (internet users)") %>%

  # How worried are you about personal information getting stolen: not worried (all adults)
  mutate(con33a_all_nw = case_when(cy24 == 1 & (wp24069 == 3 & (con24_all == 1 | con25_all == 1)) ~ 1, 
                                   cy24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33a_all_nw = "Not worried about personal info theft (all adults)") %>%

  # How worried are you about personal information getting stolen: not worried (internet users)
  mutate(con33a_int_nw = case_when((con24_all == 1 | con25_all == 1) & wp24069 == 3 ~ 1,
                                   cy24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(con33a_int_nw = "Not worried about personal info theft (internet users)") %>%

  # How worried are you about government using personal information without permission: very worried (all adults)
  mutate(con33b_all_vw = case_when(cy24 == 1 & wp24070 == 1 & (con24_all == 1 | con25_all == 1) ~ 1, 
                                   cy24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33b_all_vw = "Very worried about govt use of personal info (all adults)") %>%

  # How worried are you about government using personal information without permission: very worried (internet users)
  mutate(con33b_int_vw = case_when(cy24 == 1 &((con24_all == 1 | con25_all == 1) & wp24070 == 1) ~ 1,
                                   cy24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(con33b_int_vw = "Very worried about govt use of personal info (internet users)") %>%

  # How worried are you about government using personal information without permission: somewhat worried (all adults)
  mutate(con33b_all_sw = case_when(cy24==1 & wp24070 == 2 & (con24_all == 1 | con25_all == 1) ~ 1, 
                                   cy24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33b_all_sw = "Somewhat worried about govt use of personal info (all adults)") %>%

  # How worried are you about government using personal information without permission: somewhat worried (internet users)
  mutate(con33b_int_sw = case_when((cy24 == 1 & (con24_all == 1 | con25_all == 1)) & wp24070 == 2 ~ 1,
                                   cy24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33b_int_sw = "Somewhat worried about govt use of personal info (internet users)") %>%

  # How worried are you about government using personal information without permission: not worried (all adults)
  mutate(con33b_all_nw = case_when(cy24 == 1 & wp24070 == 3 & (con24_all == 1 | con25_all == 1) ~ 1, 
                                   cy24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33b_all_nw = "Not worried about govt use of personal info (all adults)") %>%

  # How worried are you about government using personal information without permission: not worried (internet users)
  mutate(con33b_int_nw = case_when(cy24 == 1 & (con24_all == 1 | con25_all == 1) & wp24070 == 3 ~ 1,
                                   cy24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(con33b_int_nw = "Not worried about govt use of personal info (internet users)") %>%
    
  # How worried are you about companies using personal information without permission: very worried (all adults)
  mutate(con33c_all_vw = case_when(cy24 == 1 & connect_q != 4 & wp24071 == 1 & (con24_all == 1 | con25_all == 1) ~ 1, 
                                   cy24 == 1 & connect_q != 4 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33c_all_vw = "Very worried about company use of personal info (all adults)") %>%

  # How worried are you about companies using personal information without permission: very worried (internet users)
  mutate(con33c_int_vw = case_when((cy24 == 1 & connect_q != 4 & (con24_all == 1 | con25_all == 1)) & wp24071 == 1 ~ 1,
                                   cy24 == 1 & connect_q != 4 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33c_int_vw = "Very worried about company use of personal info (internet users)") %>%

  # How worried are you about companies using personal information without permission: somewhat worried (all adults)
  mutate(con33c_all_sw = case_when(cy24 == 1 & connect_q != 4 & wp24071 == 2 & (con24_all == 1 | con25_all == 1) ~ 1, 
                                   cy24 == 1 & connect_q != 4 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33c_all_sw = "Somewhat worried about company use of personal info (all adults)") %>%

  # How worried are you about companies using personal information without permission: somewhat worried (internet users)
  mutate(con33c_int_sw = case_when((cy24 == 1 & connect_q != 4 & (con24_all == 1 | con25_all == 1)) & wp24071 == 2 ~ 1,
                                   cy24 == 1 & connect_q != 4 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(con33c_int_sw = "Somewhat worried about company use of personal info (internet users)") %>%

  # How worried are you about companies using personal information without permission: not worried (all adults)
  mutate(con33c_all_nw = case_when(cy24 == 1 & connect_q != 4 & wp24071 == 3 & (con24_all == 1 | con25_all == 1) ~ 1, 
                                   cy24 == 1 & connect_q != 4 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33c_all_nw = "Not worried about company use of personal info (all adults)") %>%

  # How worried are you about companies using personal information without permission: not worried (internet users)
  mutate(con33c_int_nw = case_when((cy24 == 1 & connect_q != 4  & (con24_all == 1 | con25_all == 1)) & wp24071 == 3 ~ 1,
                                   cy24 == 1 & connect_q != 4 & (con24_all == 1 | con25_all == 1) ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(con33c_int_nw = "Not worried about company use of personal info (internet users)")
