dataframe_2024 <- dataframe_2024 %>%
  mutate(ts_mobaccount = case_when(acc14mob == 1 & m14 == 1 ~ 1,
                                   acc17mob == 1 & m17 == 1 ~ 1,
                                   acc21_22mob == 1 & m21_22 == 1 ~ 1,
                                   acc24mob == 1 & m24 == 1 ~ 1,
                                   m14 == 1 | m17 == 1 | m21_22 == 1 | m24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  
  mutate(fin_FIdormant = case_when(dev24 == 1 & acc24fin == 1 & wp19477_r %in% c(2,3,4) ~ 1, 
                                   dev24 == 1 ~ 0, 
                                   TRUE ~ NA)) %>% 
  set_variable_labels(fin_FIdormant = "Dormant BANK Account (% adults)") %>%
  # Note: mobile money accounts can't be dormant in our data because we ask if they used one
  mutate(fin_FIdormant_noMM = case_when(dev24 == 1 & acc24fin == 1 & wp19477_r %in% c(2,3,4) & acc24mob != 1 ~ 1, 
                                        dev24 == 1 ~ 0, 
                                        TRUE ~ NA)) %>% 
  set_variable_labels(fin_FIdormant_noMM = "Dormant BANK Account (% adults) do not have MM account") %>%  
  
  
  mutate(fin_FIdormant_b = case_when(dev24 == 1 & acc24fin == 1 & wp19477_r %in% c(2,3,4) ~ 1, 
                                     dev24 == 1 & acc24fin == 1  ~ 0 , 
                                     TRUE ~ NA)) %>% 
  set_variable_labels(fin_FIdormant_b = "BANKED: Dormant BANK Account (% banked adults)") %>%
  
  # adults who are filtered out by the filter question
  mutate(fin_mm_filtered24 = case_when(m24 == 1 & acc24any != 1 & wp19480_r == 1 ~ 1, 
                                       m24 == 1 ~ 0 , 
                                       TRUE ~ NA)) %>% 
  set_variable_labels(fin_mm_filtered24 = "Adults who answered yes to fin13 but were filtered out and do not have an FI account (2024)") %>%
  
  mutate(fin_mm_filtered21 = case_when(m21_22 == 1 & acc21_22any != 1 & wp19480 == 1 ~ 1, 
                                       m21_22 == 1 ~ 0 , 
                                       TRUE ~ NA)) %>% 
  set_variable_labels(fin_mm_filtered21 = "Adults who answered yes to fin13 but were filtered out and do not have an FI account (2021)") %>%
  
  mutate(fin15_noFI = case_when(m24 == 1 & acc24any != 1 & fin15_all == 1 ~ 1, 
                                m24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>% 
  set_variable_labels(fin15_noFI = "Adults without an account who use someone else's MM") %>%
  
  
##########################################################
# Saving and borrowing
##########################################################

# these are all coded in time series - PLEASE CHECK THERE 

# Any Savings
mutate(fin_anysavings24 = case_when(dev24 == 1 & (wp15165_r == 1 | wp21375_r == 1 | wp19486_r == 1 | wp21374_r == 1 | wp14914_r == 1) ~ 1,
                                    dev24 == 1 ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_anysavings24 = "Any Savings") %>%
  
  # Formal Savings (includes mobile money)
  mutate(fin_savfor_fi_mm = case_when(dev24 == 1 & fin17A_all == 1 ~ 1,
                                      m24 == 1 & fin17B_all == 1 ~ 1,
                                      dev24 == 1 ~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_savfor_fi_mm = "Formal Savings (includes mobile money)") %>%
  
  # Formal Savings (includes mobile money)
  mutate(fin_savfor_fi = case_when(dev24 == 1 & fin17A_all == 1 ~ 1,
                                   dev24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_savfor_fi = "Formal Savings using a bank") %>%
  
  # Formal Savings (excluding mobile money)
  mutate(fin_savfor_fi_o = case_when(dev24 == 1 & fin17A_all  == 1 & (fin17B_all != 1 | is.na(fin17B_all)) ~ 1, #Saved money in the past 12 months: Used an account at a bank or similar financial institution (age 15+)
                                     dev24 == 1 ~ 0,
                                     TRUE~ NA)) %>%
  set_variable_labels(fin_savfor_fi_o = "Formal Savings (excluding mobile money)") %>%
  #   
  # Formal Savings (mobile money only)
  mutate(fin_savfor_mm_o = case_when(fin17B_all == 1 & (fin17A_all != 1 | is.na(fin17A_all)) & m24 == 1 ~ 1, #Saved money in the past 12 months: Only used a mobile money account (age 15+)
                                     m24 == 1 ~ 0,
                                     TRUE~ NA)) %>%
  set_variable_labels(fin_savfor_mm_o = "Formal Savings (Mobile money ONLY)") %>%
  #   
  # any formal savings and earned interest
  mutate(fin_interest_fi_mm = case_when(dev24 == 1 & fin_savfor_fi_mm == 1 & fin17E_all == 1 ~ 1, # Saved money using MM or FI and earned interest (age 15+)
                                        dev24 == 1 ~ 0,
                                        TRUE~ NA)) %>%
  set_variable_labels(fin_interest_fi_mm = "Saved formally using an FI or MM account and earned interest") %>%
  
  # any bank savings and earned interest
  mutate(fin_interest_fi = case_when(dev24 == 1 & fin_savfor_fi == 1 & fin17E_all == 1 ~ 1, # Saved money using MM or FI and earned interest (age 15+)
                                     dev24 == 1 ~ 0,
                                     TRUE~ NA)) %>%
  set_variable_labels(fin_interest_fi = "Saved formally using an FI and earned interest") %>%
  
  ##Adding - Ananya 
  
  mutate(fin_interest_fi_o = case_when(dev24 == 1 & fin_savfor_fi_o == 1 & fin17E_all == 1 ~ 1, # Saved money using MM or FI and earned interest (age 15+)
                                       dev24 == 1 ~ 0,
                                       TRUE~ NA)) %>%
  set_variable_labels(fin_interest_fi_o = "Saved formally using an FI Only and earned interest") %>%
  
  ## done adding by ananya 
  
  # Formally saved only using MM and earned interest
  mutate(fin_interest_mm_o = case_when(fin_savfor_mm_o == 1 & fin17E_all == 1 & m24 == 1 ~ 1, # Saved money using MM only and earned interest (age 15+)
                                       m24 == 1 ~ 0,
                                       TRUE~ NA)) %>%
  set_variable_labels(fin_interest_mm_o = "Saved formally only using a MM account and earned interest") %>%
  
  #Semiformal Savings
  mutate(fin_savsemfor = case_when(dev24 == 1 & fin17C_all == 1 ~ 1, #Saved money in the past 12 months: Using informal savings group/club or someone outside family (age 15+)
                                   dev24 == 1 ~ 0 ,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_savsemfor = "Semiformal Savings") %>%
  
  mutate(fin_savsemfor_ub = case_when(dev24 == 1 & fin17C_all == 1 & acc24any == 0 ~ 1, #Saved money in the past 12 months: Using informal savings group/club or someone outside family (age 15+)
                                      dev24 == 1 ~ 0 ,
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_savsemfor_ub = "Semiformal Savings and unbanked (% adults)") %>%
  
  
  # adults who save using mobile money only who report that they want a bank account because MM doesn't meet needs
  mutate(fin13_1b_mmsave = case_when(ml24 == 1 & fin13_1b == 1 & fin_savfor_mm_o == 1 ~ 1,
                                     ml24 == 1 ~ 0 , 
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin13_1b_mmsave = "Mobile money account does not meet financial needs/want bank account; save only using mobile money (age 15+)") %>%
  
  
  # Saving for old age for FI account
  
  mutate(fin_savfor_old = case_when(dev24 == 1 & fin_savfor_fi_mm == 1 & fin17F_all == 1  ~ 1,
                                    dev24 == 1 ~ 0 ,
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_savfor_old = "Saving formally and saved for old age") %>%
  
  
  # Saving for old age for MM account only
  
  mutate(fin_savfor_mm_o_old = case_when(dev24 == 1 & fin_savfor_mm_o == 1 & fin17F_all == 1  ~ 1,
                                         dev24 == 1 ~ 0 ,
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_savfor_mm_o_old = "Formal Savings (Mobile money ONLY) and saved for old age") %>%
  
  # Made payments to an insurance company and saved for old age
  
  mutate(fin_savforold_insurance = case_when(dev24 == 1 & fin17F_all == 1 & fin19_all == 1  ~ 1,
                                             dev24 == 1 ~ 0 ,
                                             TRUE ~ NA)) %>%
  set_variable_labels(fin_savforold_insurance = "Made payments to an insurance company and saved for old age") %>%
  
  
  
  # Any Borrowing
  mutate(fin_anyborrowing24 = case_when(dev24 == 1 & (wp19489_r == 1 | wp23996 == 1 | wp19490_r == 1 | wp19491_r == 1 | wp19487_r == 1 | wp23997 == 1 | wp23998 == 1 | wp19476_r == 1 | wp14924_r == 1) ~ 1,
                                        dev24 == 1 ~ 0 , 
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_anyborrowing24 = "Any Borrowing") %>%
  
  # Formal Borrowing (FI account)
  mutate(fin_borfor_fi = case_when(dev24 == 1 & fin22A_all == 1 ~ 1, #Borrowed in the past 12 months: bank or similar financial institution (age 15+)
                                   dev24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_fi = "Formal Borrowing (FI account)") %>%
  
  #Formal Borrowing (FI and Credit Card)
  mutate(fin_borfor_fi_cc = case_when(dev24 == 1 & (fin22A_all == 1 | fin22G_all == 1) ~ 1,  # borrow using a credit card OR FI account
                                      dev24 == 1 & i24 == 1 ~ 0,  # Only applies if dev24 and i24 are both 1, but neither condition above is met
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_fi_cc = "Formal Borrowing (FI account or Credit Card)") %>%
  
  #Formal Borrowing (MOBILE MONEY)
  mutate(fin_borfor_mm = case_when(dev24 == 1 & m24 == 1 & fin22A_1_all == 1 ~ 1, #Received loan from mobile money provider in the past 12 months (age 15+)
                                   dev24 == 1 & m24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_mm = "Formal Borrowing (Mobile Money)") %>%
  
  #Formal Borrowing (FI + CC + MM)
  mutate(fin_borfor_fi_cc_mm = case_when(dev24 == 1 & fin_borfor_fi_cc == 1 ~ 1,
                                         m24 == 1 & fin22A_1_all == 1 ~ 1,  # Requires FI + CC + MM borrowing
                                         dev24 == 1 ~ 0,  # If dev24 is 1 but the condition above is not met, sets to 0
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_fi_cc_mm = "Formal Borrowing (FI + CC + MM)") %>%
  
  mutate(fin_borfor_fi_mm_o = case_when(dev24 == 1 & fin_borfor_fi == 1 & fin22G_all != 1 ~ 1,
                                        m24 == 1 & fin22A_1_all == 1 & fin22G_all != 1 ~ 1, 
                                        dev24 == 1 ~ 0,  
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_fi_mm_o = "Formal Borrowing (FI + MM, no credit card )") %>%
  
  #Semiformal Borrowing
  mutate(fin_borsemfor = case_when(dev24 == 1 & fin22C_all == 1  ~ 1, #Received loan from an informal savings group/club in the past 12 months (age 15+)
                                   dev24 == 1 ~ 0 ,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_borsemfor = "Semiformal Borrowing") %>%
  
  #Borrowing from friends and family
  mutate(fin_borfam = case_when(dev24 == 1 & fin22B_all == 1  ~ 1, #Received loan from family, relatives, or friends in the past 12 months (age 15+)
                                dev24 == 1 ~ 0 ,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin_borfam = "Borrowing from friends and family") %>%
  
  
  # borrowed formally AND borrowed for business
  mutate(fin_borfor_o_buz = case_when(dev24 == 1 & fin_borfor_fi_mm_o == 1 & fin22E_all == 1  ~ 1,
                                      dev24 == 1 ~ 0 ,
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_o_buz = "Borrowing formally (FI + MM) and borrow for business") %>%
  
  
  # borrowed not formally only digital credit AND borrowed for business
  mutate(fin_bor_dig_o_buz = case_when(dev24 == 1 & fin21_all ==1 & fin_borfor_fi_mm_o != 1 & fin22E_all == 1  ~ 1,
                                       dev24 == 1 ~ 0 ,
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin_bor_dig_o_buz = "Borrowing no formally (FI + MM) only digital and borrow for business") %>%
  
  # borrowed not formally or digital only use credit card AND borrowed for business
  mutate(fin_bor_cc_o_buz = case_when(dev24 == 1 & fin21_all !=1 & fin_borfor_fi_mm_o != 1 & fin22G_all == 1 & fin22E_all == 1  ~ 1,
                                      dev24 == 1 ~ 0 ,
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_bor_cc_o_buz = "Borrowing no formally (FI + MM) and digital and only use credit cards borrow for business") %>%
  
  
  # borrowed formally AND borrowed for health
  mutate(fin_borfor_o_health = case_when(dev24 == 1 & fin_borfor_mm == 1 & fin22D_all == 1  ~ 1,
                                         dev24 == 1 ~ 0 ,
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_o_health = "Borrowing formally (FI + MM) and borrow for health") %>%
  
  ## Adding - Ananya 
  # borrowed formally AND borrowed for health
  mutate(fin_borfor_fi_cc_mm_health = case_when(dev24 == 1 & fin_borfor_fi_cc_mm == 1 & fin22D_all == 1  ~ 1,
                                                dev24 == 1 ~ 0 ,
                                                TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_fi_cc_mm_health = "Borrowing formally (FI + MM + CC) and borrow for health") %>%
  
  # borrowed formally AND borrowed for business
  mutate(fin_borfor_fi_cc_mm_buz = case_when(dev24 == 1 & fin_borfor_fi_cc_mm == 1 & fin22E_all == 1  ~ 1,
                                             dev24 == 1 ~ 0 ,
                                             TRUE ~ NA)) %>%
  set_variable_labels(fin_borfor_fi_cc_mm_buz = "Borrowing formally (FI + MM + CC) and borrow for business") %>%
  
  #################

# borrowed not formally only digital credit AND borrowed for health
mutate(fin_bor_dig_o_health = case_when(dev24 == 1 & fin21_all ==1 & fin_borfor_fi_mm_o != 1 & fin22D_all == 1  ~ 1,
                                        dev24 == 1 ~ 0 ,
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_bor_dig_o_health = "Borrowing no formally (FI + MM) only digital and borrow for health") %>%
  
  # borrowed not formally or digital only use credit card AND borrowed for health
  mutate(fin_bor_cc_o_health = case_when(dev24 == 1 & fin21_all !=1 & fin_borfor_fi_mm_o != 1 & fin22G_all == 1 & fin22D_all == 1  ~ 1,
                                         dev24 == 1 ~ 0 ,
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_bor_cc_o_health = "Borrowing no formally (FI + MM) and digital and only use credit cards borrow for health") %>%
  
  
  
  # people who receive a loan that they applied for using a mobile phone but who did not otherwise access formal credit
  mutate(fin_digloan_nborfor = case_when(dev24 == 1 & fin21_all == 1 & fin_borfor_fi_cc_mm != 1 ~ 1,
                                         dev24 == 1 ~ 0 ,
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_digloan_nborfor = "Received loan applied for using a mobile phone in the past 12 months and DO NOT otherwise borrow formally (FI + CC+ MM)") %>%
  
  
  # people who use a credit card but who don't otherwise borrow formally or have a loan from a phone
  mutate(fin_cc_noloans = case_when(dev24 == 1 & fin22G_all != 1 & fin_borfor_fi_mm_o == 1 & fin21_all != 1 ~ 1,
                                    dev24 == 1 ~ 0 ,
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_cc_noloans = "Used credit card in last 12 months but did not borrow using mobile phone or access formal credit (FI + CC + MM)  [of adults]") %>%
  
  
  # 
  # people who borrowed using a phone but not report using formal credit
  mutate(fin_bor_dig_infor= case_when(dev24 == 1 & fin21_all == 1 & fin_borfor_fi_cc_mm != 1 ~ 1,
                                      dev24 == 1 ~ 0 ,
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_bor_dig_infor = "Borrowed informal using a phone (But did NOT resport using formal credit),  [of adults]") %>%
  
  # USED a credit card, but did NOT borrow from a bank and did NOT borrow using a phone. 
  mutate(fin_bor_cc_o = case_when(dev24 == 1 & fin22G_all == 1 & fin21_all != 1 & fin_borfor_fi_mm_o != 1 ~ 1,
                                  dev24 == 1 ~ 0 ,
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_bor_cc_o  = "people who used a credit card, but did NOT borrow from a bank and did NOT borrow using a phone.") %>%
  
  
  
  ################

# how long you can last in an emergency (for people who lost income due to climate)
mutate(fin24B_less2weeks_climate = case_when(fin24B_less2weeks == 1 & fin24D_1 == 1 ~ 1,
                                             dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24B_less2weeks_climate = "Lost income due to climate event: Less than two weeks can be covered using savings, borrowing, selling something, seeking help from friends and family, or other ways, in case household loses its main source of income (age 15+)") %>%
  
  mutate(fin24B_about1month_climate = case_when(fin24B_about1month == 1 & fin24D_1 == 1 ~ 1,
                                                dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about1month_climate = "Lost income due to climate event: About one month can be covered using savings, borrowing, selling something, seeking help from friends and family, or other ways, in case household loses its main source of income (age 15+)") %>%
  
  mutate(fin24B_about2month_climate = case_when(fin24B_about2month == 1 & fin24D_1 == 1 ~ 1,
                                                dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about2month_climate = "Lost income due to climate event: About two months can be covered using savings, borrowing, selling something, seeking help from friends and family, or other ways, in case household loses its main source of income (age 15+)") %>%
  
  mutate(fin24B_more2month_climate = case_when(fin24B_more2month == 1 & fin24D_1 == 1  ~ 1,
                                               dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24B_more2month_climate = "Lost income due to climate event: More than two months can be covered using savings, borrowing, selling something, seeking help from friends and family, or other ways, in case household loses its main source of income (age 15+)") %>%
  
  ##########################################################
# Digital Payments
##########################################################  

#Made a Digital Payment - using the same variables as in 2021 - can be found in the 2021 digital payments do file

mutate(fin_digpay_make = case_when(dev24 == 1 & acc24any == 1 & findex_q != 5 &
                                     (wp19480_r_f == 1 | # used mobile money
                                        # used debit card not part of this series - was in 2021/22
                                        wp19476_r == 1 | # used credit card
                                        (wp19504_r == 1 | (wp19505 == 1 & acc24mob == 1)) | # paid bills (acc and mob)
                                        wp21379_r == 1 | # sent remittances using account or mobile
                                        (wp21369_r == 1 | (wp21370_r == 1 & (wp21371_r == 1 | wp21371_r == 3)))) ~ 1, # internet
                                   dev24 == 1 & findex_q != 5 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_digpay_make = "Made a Digital Payment") %>%
  
  
  mutate(fin_digpay_make_q5 = case_when(dev24 == 1 & acc24any == 1 & 
                                          (wp19480_r_f == 1 | # used mobile money
                                             # used debit card not part of this series - was in 2021/22
                                             wp19476_r == 1 | # used credit card
                                             (wp19504_r == 1 | (wp19505 == 1 & acc24mob == 1)) | # paid bills (acc and mob)
                                             wp21379_r == 1 | # sent remittances using account or mobile
                                             (wp21369_r == 1 | (wp21370_r == 1 & (wp21371_r == 1 | wp21371_r == 3)))) ~ 1, # internet
                                        dev24 == 1 ~ 0,
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_digpay_make = "Made a Digital Payment - includes countries that didn't also have option to report receiving digital paymetns - questionnaire 5") %>%
  
  
  #Received a Digital Payment
  mutate(fin_digpay_receive = case_when(dev24 == 1 & findex_q != 5 & acc24any == 1 & 
                                          (wp21381_r == 1 | # received remittances (acc and mob)
                                             (wp19523_r == 1 | (wp19524 == 1 & acc24mob == 1)) | # agricultural payments (acc and mob)
                                             (wp19508_r == 1 | (wp19509_r == 1 & acc24mob == 1) | wp21385_r == 1) | # wages
                                             ((wp21386 == 1 & wp19515 != 1) & ((wp19516_r == 1 | wp21389_r == 1) | (wp19517_r == 1 & acc24mob == 1))) | #government transfers (acc and mob)
                                             (wp19515 == 1 & ((wp19516_r == 1 | wp21389_r == 1) | (wp19517_r == 1 & acc24mob == 1)))) ~ 1, # pension (acc and mob)
                                        dev24 == 1 & findex_q != 5 ~ 0,
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_digpay_receive = "Received a Digital Payment") %>%
  
  #Made OR Received a Digital Payment
  mutate(fin_digpay = case_when(dev24 == 1 & findex_q != 5 & (fin_digpay_receive == 1 |
                                                                fin_digpay_make == 1 |
                                                                # instore purchases in 2021 were included in any digital payment but not in made a digital payment
                                                                wp24006 == 1) ~ 1, #used a mobile or a card to make an IN-STORE purchase
                                dev24 == 1 & findex_q != 5 ~ 0 ,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin_digpay = "Made OR Received a Digital Payment") %>%
  
  #Made AND Received a Digital Payment
  mutate(fin_digpay_both = case_when(dev24 == 1 & findex_q != 5 & (fin_digpay_receive == 1 & fin_digpay_make == 1) ~ 1,
                                     dev24 == 1 & findex_q != 5 ~ 0 ,
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin_digpay_both = "Made AND Received a Digital Payment") %>%
  
  
  ############################################
#MERCHANT PAYMENTS

# MERCHANT PAYMENTS 
mutate(fin_merpaydig = case_when(dev24 == 1 & ((fin27a == 1 | fin27c == 1) | fin25E_2 == 1) ~ 1,  # bought online and payed digitally and used a card or phone to make in-store purchase
                                 dev24 == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin_merpaydig = "Made a digital merchant payment (age 15+)") %>%
  
  # NOTE: this is the variable you should use - to make a real dig pay, you need an account! 
  mutate(fin_merpaydig_acc = case_when(dev24 == 1 & ((fin27a == 1 | fin27c == 1) | fin25E_2 == 1) & acc24any == 1 ~ 1,  # same as above but with the added caveat of account ownership incase some people say yes but don't have accounts
                                       dev24 == 1 ~ 0 , 
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin_merpaydig_acc = "Made a digital merchant payment and have an account (age 15+)") %>%
  
  
  mutate(fin_ol_merpaydig = case_when(dev24 == 1 & (fin27a == 1 | fin27c == 1) ~ 1,  # bought online and payed digitally 
                                      dev24 == 1 ~ 0 , 
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_ol_merpaydig = "Made a digital ONLINE merchant payment (age 15+)") %>%
  
  mutate(fin_store_merpaydig = case_when(dev24 == 1 & fin25E_2 == 1 ~ 1,  # Used mobile phone or card to pay for in-store purchase in the past 12 months (age 15+)
                                         dev24 == 1 ~ 0 , 
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_store_merpaydig = "Made a digital IN-STORE merchant payment (age 15+)") %>%
  
  mutate(fin_dig_acc = case_when(acc24mob == 1 | fin3_all == 1 | (fin_store_merpaydig == 1 & acc24any == 1) ~ 1,
                          dev24 == 1 ~ 0,
                          TRUE ~ NA)) %>%
  set_variable_labels(fin_dig_acc = "Have a digitally-enabled account (MM, card/phone patyment, or in-store merchant payment with an account) (age 15+)") %>%
  
  
##########################################################
# Payments
##########################################################

#Received Any Wages
mutate(fin_wage = case_when(dev24 == 1 & findex_q != 5 & fin32 == 1 ~ 1, #Received salary or wages from an employer in the past 12 months(age 15+)
                            dev24 == 1 & findex_q != 5 ~ 0 ,
                            TRUE ~ NA)) %>%
  set_variable_labels(fin_wage = "Received Any Wages") %>%
  
  
  #Received Wages Digitally
  mutate(fin_wage_dig = case_when(dev24 == 1 & findex_q != 5 &
                                    (fin34A == 1 | #Wage payments: directly into an account at a bank or a financial institution (age 15+)
                                       fin34B == 1 | #Wage payments: through a mobile phone (age 15+)
                                       fin34D == 1) ~ 1, #Wage payments: into a card (age 15+)
                                  dev24 == 1 & findex_q != 5 ~ 0 ,
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_wage_dig = "Received Wages Digitally") %>%
  
  
  #Received Wages in Cash
  mutate(fin_wage_cashonly = case_when(dev24 == 1 & findex_q != 5 &
                                         fin34C == 1 & #Wage payments: in cash (age 15+)
                                         (fin34A != 1 & #Wage payments: directly into an account at a bank or a financial institution (age 15+)
                                            fin34B != 1 & #Wage payments: through a mobile phone (age 15+)
                                            fin34D != 1) ~ 1, #Wage payments: into a card (age 15+)
                                       dev24 == 1 & findex_q != 5 ~ 0,
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin_wage_cashonly = "Received Wages in Cash Only") %>%
  
  
  #Received Wages in Other Ways
  mutate(fin_wage_other = case_when(dev24 == 1 & findex_q != 5 & fin32 == 1 & #Received salary or wages from an employer in the past 12 months(age 15+)
                                      fin34A != 1 &  #Wage payments: directly into an account at a bank or a financial institution (age 15+)
                                      fin34B != 1 &  #Wage payments: through a mobile phone (age 15+)
                                      fin34D != 1 &  #Wage payments: into a card (age 15+)
                                      fin34C != 1 ~ 1, #Wage payments: in cash (age 15+)
                                    dev24 == 1 & findex_q != 5 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_wage_other = "Received Wages Other") %>%
  
  
  
  #Received Any Private Sector Wages
  mutate(fin_wgpriv = case_when(fin32 == 1 & wp14945_r %in% c(2,3,4) ~ 1, # Received private sector wages
                                dev24 == 1 & findex_q != 5 ~ 0, # Received wages but from public sector
                                TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpriv = "Received Any Private Sector Wages") %>%
  
  #Received Pvt Sector Wages Digitally
  mutate(fin_wgpriv_dig = case_when(dev24 == 1 & findex_q != 5 & wp14945_r %in% c(2,3,4) & (fin34A == 1 | fin34B == 1 | fin34D == 1) ~ 1, # Private sector wage received digitally
                                    dev24 == 1 & findex_q != 5 ~ 0, # Private sector wage received but not digitally
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpriv_dig = "Received Pvt Sector Wages Digitally") %>%
  
  #Received Pvt Sector Wages in Cash Only
  mutate(fin_wgpriv_cashonly = case_when(dev24 == 1 & findex_q != 5 & fin32 == 1 & wp14945_r %in% c(2,3,4) & 
                                           fin34C == 1 & #Wage payments: in cash (age 15+)
                                           fin33 != 1 & #Employed by the government, military, or public sector in the past 12 months (age 15+)
                                           fin34A != 1 &  #Wage payments: directly into an account at a bank or a financial institution (age 15+)
                                           fin34B != 1 &  #Wage payments: through a mobile phone (age 15+)
                                           fin34D != 1 ~ 1,  #Wage payments: into a card (age 15+)
                                         dev24 == 1 & findex_q != 5 ~ 0 ,
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpriv_cashonly = "Received Pvt Sector Wages in Cash Only") %>%
  
  
  #Received Pvt Sector Wages in cash only and unbanked
  mutate(fin_wgpriv_cashonly_ub = case_when(dev24 == 1 & findex_q != 5 & fin_wgpriv_cashonly == 1 & acc24any == 0 ~ 1,
                                            dev24 == 1 & findex_q != 5 ~ 0, # Private sector wage received but not digitally
                                            TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpriv_cashonly_ub = "Received Pvt Sector Wages in cash only and are unbanked (% adults)") %>%
  
  #Received Pvt Wages in Other Ways
  mutate(fin_wgpriv_other = case_when(dev24 == 1 & findex_q != 5 & fin32 == 1 & wp14945_r %in% c(2,3,4) &
                                        fin34A != 1 & fin34B != 1 & fin34D != 1 & fin34C != 1 ~ 1, # Received private wages by an unspecified other method
                                      dev24 == 1 & findex_q != 5 ~ 0,  # Received private wages by a specified method (bank, mobile, card, cash)
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpriv_other = "Received Pvt Wages Other") %>%
  
  #Received Any Public Sector Wages
  mutate(fin_wgpub = case_when(dev24 == 1 & findex_q != 5 &
                                 fin32 == 1 & #Received salary or wages from an employer in the past 12 months(age 15+)
                                 fin33 == 1 ~ 1, #Employed by the government, military, or public sector in the past 12 months (age 15+)
                               dev24 == 1 & findex_q != 5 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpub = "Received Any Public Sector Wages") %>%
  
  #Received Public Sector Wages Digitally
  mutate(fin_wgpub_dig = case_when(dev24 == 1 & findex_q != 5 & fin32 == 1 & 
                                     fin33 == 1 & #Employed by the government, military, or public sector in the past 12 months (age 15+)
                                     (fin34A == 1 |  #Wage payments: directly into an account at a bank or a financial institution (age 15+)
                                        fin34B == 1 | #Wage payments: through a mobile phone (age 15+)
                                        fin34D == 1) ~ 1, #Wage payments: into a card (age 15+)
                                   dev24 == 1 & findex_q != 5 ~ 0 ,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpub_dig = "Received Public Sector Wages Digitally") %>%
  
  #Received Public Sector Wages into a mobile
  mutate(fin_wgpub_mob = case_when(dev24 == 1 & findex_q != 5 & fin32 == 1 & 
                                     fin33 == 1 & #Employed by the government, military, or public sector in the past 12 months (age 15+)
                                     fin34B == 1 ~ 1, #Wage payments: through a mobile phone (age 15+)
                                   dev24 == 1 & findex_q != 5 ~ 0 ,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpub_mob = "Received Public Sector Wages into a mobile phone") %>%
  
  #Received Public Sector Wages in Cash Only
  mutate(fin_wgpub_cashonly = case_when(dev24 == 1 & findex_q != 5 & fin32 == 1 & fin33 == 1 & #Employed by the government, military, or public sector in the past 12 months (age 15+)
                                          fin34C == 1 & #Wage payments: in cash (age 15+)
                                          (fin34A != 1 & #Wage payments: directly into an account at a bank or a financial institution (age 15+)
                                             fin34B != 1 & #Wage payments: through a mobile phone (age 15+)
                                             fin34D != 1) ~ 1, #Wage payments: into a card (age 15+)
                                        dev24 == 1 & findex_q != 5 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpub_cashonly = "Received Public Sector Wages in Cash Only") %>%
  
  # #Received Public Wages in Other Ways
  mutate(fin_wgpub_other = case_when(dev24 == 1 & findex_q != 5 & fin32 == 1 & fin33 == 1 & fin34A != 1 & fin34B != 1 & fin34D != 1 & fin34C != 1 ~ 1, # Other methods
                                     dev24 == 1 & findex_q != 5 ~ 0, # No public wages received in other ways
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin_wgpub_other = "Received Public Wages Other") %>%
  
  # Government Transfer into an account
  mutate(fin_gt_dig = case_when(dev24 == 1 & findex_q != 5 &
                                  (fin37 == 1 & #Government transfer payment
                                     fin39A == 1 | fin39B == 1) ~ 1,
                                dev24 == 1 & findex_q != 5 ~ 0 ,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin_gt_dig = "Received a gov transfer Payment into an account") %>%
  
  
  #Received a G2P Payment
  mutate(fin_g2p_any = case_when(dev24 == 1 & findex_q != 5 &
                                   (fin37 == 1 | #Government transfer payment
                                      fin38 == 1 | #Received Pension
                                      fin_wgpub == 1) ~ 1,
                                 dev24 == 1 & findex_q != 5 ~ 0 ,
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin_g2p_any = "Received a G2P Payment") %>%
  
  #Received a G2P Payment into an account
  mutate(fin_g2p_dig = case_when(dev24 == 1 & findex_q != 5 &
                                   (fin39A == 1 | #Government transfer payment or pension into an account
                                      fin39B == 1 | #Government transfer payment or pension into an mobile phone
                                      fin39D == 1 | #Government transfer payment or pension into a card
                                      fin_wgpub_dig == 1) ~ 1,
                                 dev24 == 1 & findex_q != 5 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin_g2p_dig = "Received a G2P Payment into an account") %>%
  
  
  #Received a G2P Payment into a mobile
  mutate(fin_g2p_mob = case_when(dev24 == 1 & findex_q != 5 &
                                   (fin39B == 1 | #Government transfer payment or pension into an mobile phone
                                      fin_wgpub_mob == 1) ~ 1,
                                 dev24 == 1 & findex_q != 5 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin_g2p_mob = "Received a G2P Payment into a mobile") %>%
  
  #Received a G2P Payment in Cash Only
  mutate(fin_g2p_cashonly = case_when(dev24 == 1 & findex_q != 5 &
                                        (fin39C == 1 | fin_wgpub_cashonly == 1) & # fin39C Government payments: in cash (age 15+)
                                        fin39A != 1 &  # gov pay into account
                                        fin39B != 1 &  # gov pay into mob
                                        fin_g2p_dig != 1 ~ 1,
                                      dev24 == 1 & findex_q != 5 ~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_g2p_cashonly = "Received a G2P Payment in Cash Only") %>%
  
  # received a G2P payment in cash only AND do not have an account
  
  mutate(fin_g2p_cashonly_ub = case_when(dev24 == 1 & findex_q != 5 & fin_g2p_cashonly == 1 & acc24any == 0 ~ 1,
                                         dev24 == 1 & findex_q != 5 ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_g2p_cashonly_ub = "Received a G2P Payment in Cash Only and are unbanked (% adults)") %>%
  
  #Received a Government Payment (similar to G2P but without the wages)
  mutate(fin_gpay_any = case_when(dev24 == 1 & findex_q != 5 &
                                    (fin37 == 1 | #Government transfer payment
                                       fin38 == 1) ~ 1, #Received Pension
                                  dev24 == 1 & findex_q != 5 ~ 0 ,
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_gpay_any = "Received a government transfer Payment or pension") %>%
  
  #Received a G2P Payment into an account
  mutate(fin_gpay_dig = case_when(dev24 == 1 & findex_q != 5 &
                                    (fin39A == 1 | #Government transfer payment or pension into an account
                                       fin39B == 1 | #Government transfer payment or pension into an mobile phone
                                       fin39D == 1) ~ 1, #Government transfer payment or pension into a card
                                  dev24 == 1 & findex_q != 5 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin_gpay_dig = "Received a government transfer Payment or pension into an account") %>%
  
  #Received a government transfer Payment into a mobile
  mutate(fin_gpay_mob = case_when(dev24 == 1 & findex_q != 5 &
                                    (fin39B == 1) ~ 1, #Government transfer payment or pension into an mobile phone
                                  dev24 == 1 & findex_q != 5 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin_gpay_mob= "Received a government transfer Payment or pension into a mobile") %>%
  
  #Received a Government transfer Payment in Cash Only
  mutate(fin_gpay_cashonly = case_when(dev24 == 1 & findex_q != 5 &
                                         fin39C == 1 & # fin39C Government payments: in cash (age 15+)
                                         fin_gpay_dig != 1 ~ 1,
                                       dev24 == 1 & findex_q != 5 ~ 0,
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin_gpay_cashonly = "Received a government transfer Payment in Cash Only") %>%
  
  
  #Received a g overnment transfer Payment in Some Other Way
  mutate(fin_gpay_other = case_when(dev24 == 1 & findex_q != 5 &
                                      fin_gpay_any == 1 &
                                      fin_gpay_cashonly != 1 &
                                      fin_gpay_dig != 1 ~ 1,
                                    dev24 == 1 & findex_q != 5 ~ 0 ,
                                    TRUE ~ NA)) %>% 
  set_variable_labels(fin_gpay_other = "Received a Government transfer Payment in Some Other Way") %>%
  
  
  #Have a Credit Card OR Debit Card
  mutate(fin_ccard_or_dcard = case_when(dev24 == 1 & findex_q != 5 &
                                          (fin10_all == 1 | #Own a credit card (age 15+)
                                             fin2_all == 1) ~ 1, #Own debit card (age 15+)
                                        dev24 == 1 & findex_q != 5 ~ 0 ,
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_ccard_or_dcard = "Have a Credit Card OR Debit Card") %>%
  
  #Have a Credit Card and Debit Card
  mutate(fin_ccard_and_dcard = case_when(dev24 == 1 & findex_q != 5 &
                                           fin10_all == 1 & #Own a credit card (age 15+)
                                           fin2_all == 1 ~ 1, #Own debit card (age 15+)
                                         dev24 == 1 & findex_q != 5 ~ 0 ,
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_ccard_and_dcard = "Have a Credit Card AND Debit Card") %>%
  
  # Received agricultural payment
  mutate(fin_agpay_any = case_when(dev24 == 1  & fin42 == 1 & findex_q != 5 ~ 1,
                                   dev24 == 1 & findex_q != 5 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any = "Received agricultural payment") %>%
  
  #  Received agricultural payment digitally (FIN43A+43B+43D)
  mutate(fin_agpay_dig = case_when(dev24 == 1 & findex_q != 5 & (wp19523_r == 1 | wp19524 == 1 | wp21393_r == 1) ~ 1,
                                   dev24 == 1 & findex_q != 5 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_dig = "Received agricultural payment digitally (FIN43A+43B+43D)") %>%
  
  # Received agricultural payment into a mobile phone
  mutate(fin_agpay_mob = case_when(dev24 == 1 & findex_q != 5 & wp19524 == 1 ~ 1,
                                   dev24 == 1 & findex_q != 5 ~ 0 ,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_dig = "Received agricultural payment into a mobile phone") %>%
  
  #Received agricultural payment exclusively in cash
  mutate(fin_agpay_cashonly = case_when(dev24 == 1 & findex_q != 5  & fin43C == 1 & fin43A != 1 & fin43B != 1 & fin43D != 1 ~ 1,
                                        dev24 == 1 & findex_q != 5 ~ 0 , 
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_cashonly = "Received agricultural payment exclusively in cash") %>%
  
  #Received agricultural payment exclusively in cash and do not have account
  mutate(fin_agpay_cashonly_ub = case_when(dev24 == 1 & findex_q != 5 & fin_agpay_cashonly == 1 & acc24any == 0 ~ 1,
                                           dev24 == 1 & findex_q != 5 ~ 0 , 
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_cashonly_ub = "Received agricultural payment exclusively in cash and are unbanked (% adults)") %>%
  
  # paid higher than expected fees to take money out of an account (fin41+fin35)
  mutate(fin_highfee_all = case_when(dev24 == 1 & findex_q != 5 & (fin35 == 1 |  fin41 == 1) ~ 1,
                                     dev24 == 1 & findex_q != 5 ~ 0 , 
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin_highfee_all = "withdrew private sector wage or government payment from account and paid higher than expected fees") %>%
  
  mutate(fin_mm_highfee = case_when(dev24 == 1 & findex_q != 5 & (fin35 == 1 |  fin41 == 1) & acc24mob ~ 1,
                                    dev24 == 1 & findex_q != 5 ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_mm_highfee = "Withdrew wage or government payment from account (have a MM account) and paid higher than expected fees") %>%
  
  mutate(fin_highfee_wgpriv = case_when(dev24 == 1 & findex_q != 5 & fin_wgpriv_dig == 1 & fin35 == 1 ~ 1, 
                                        dev24 == 1 & findex_q != 5 ~ 0 , 
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_highfee_wgpriv = "Received PVT. wg. into acc and and paid higher than expected fees to withdraw money (% adults)") %>%
  
  mutate(fin_highfee_wgpub = case_when(dev24 == 1 & findex_q != 5 & fin_wgpub_dig == 1 & fin35 == 1 ~ 1,
                                       dev24 == 1 & findex_q != 5 ~ 0 , 
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin_highfee_wgpub = "Received PUB. wg. into acc and and paid higher than expected fees to withdraw money (% adults)") %>%
  
  mutate(fin_g2p_wgpriv_dig = case_when(dev24 == 1 & findex_q != 5 & fin_g2p_dig == 1 | fin_wgpriv_dig == 1 ~ 1,
                                        dev24 == 1 & findex_q != 5 ~ 0 , 
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_g2p_wgpriv_dig = "Received private wage or G2P payment into an account (% adults)") %>%
  
  # withdraw money immediately
  mutate(fin_wdall_wgpriv = case_when(dev24 == 1 & findex_q != 5 & fin_wgpriv_dig == 1 & fin36_cash == 1 ~ 1, 
                                      dev24 ==1 & findex_q != 5 ~ 0 , 
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin_wdall_wgpriv = "Received PVT. wg. into acc and withdrew all money (% adults)") %>%
  
  mutate(fin_wdall_wgpub = case_when(dev24 == 1 & findex_q != 5 & fin_wgpub_dig == 1 & fin36_cash == 1 ~ 1, 
                                     dev24 == 1 & findex_q != 5 ~ 0 , 
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin_wdall_wgpub = "Received PUB wg. into acc and into acc and withdrew all money (% adults)") %>%
  
  mutate(fin_wdall_gpay = case_when(dev24 == 1 & findex_q != 5 & fin_gpay_dig == 1 & fin40_cash == 1 ~ 1, 
                                    dev24 == 1 & findex_q != 5 ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_wdall_gpay = "Received gov transfer or pension into acc and withdrew all money (% adults)") %>%
  
  # Utility
  
  mutate(fin_util_any = case_when(dev24 == 1 & findex_q != 5 & fin30 == 1 ~ 1,
                                  dev24 == 1 & findex_q != 5 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_util_any = "Made a utility payment") %>%
  
  mutate(fin_util_dig = case_when(dev24 == 1 & findex_q != 5 & (fin31A == 1 | fin31B == 1) ~ 1,
                                  dev24 == 1 & findex_q != 5 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_util_dig = "Made a utility payment digitally (fin31a+ fin31b)") %>%
  
  mutate(fin_util_mob = case_when(dev24 == 1 & findex_q != 5 & fin31B == 1 ~ 1,
                                  dev24 == 1 & findex_q != 5 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_util_mob = "Made a digital utility payment using a mobile phone") %>%
  
  mutate(fin_util_agent = case_when(dev24 == 1 & findex_q != 5 & fin31C == 1 ~ 1,
                                    dev24 == 1 & findex_q != 5 ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_util_agent = "Made a  utility payment by handing cash to an agent") %>%
  
  mutate(fin_util_cashonly = case_when(dev24 == 1 & findex_q != 5 & fin31D == 1 & fin31A != 1 & fin31B != 1 ~ 1,
                                       dev24 == 1 ~ 0 , 
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin_util_cashonly = "Paid utilities exclusively in cash") %>%
  
  
  
  
  # REMITTANCES
  
  
  mutate(fin_Srem = case_when(dev24 == 1 & findex_q != 5 & !is.na(wp19494_r) & wp19494_r == 1 ~ 1, 
                              dev24 == 1 & findex_q != 5  ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin_Srem = "Sent money to relatives or friends living in a different city inside the country in the past 12 months (age 15+)") %>%
  
  mutate(fin_Srem_dig = case_when(dev24 == 1 & findex_q != 5  & !is.na(wp21379_r) & wp21379_r == 1 ~ 1, 
                                  dev24 == 1 & findex_q != 5  ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_Srem_dig = "Sent money to relatives or friends living in a different city directly from an account or phone in the past 12 months (age 15+)") %>%
  
  mutate(fin_Rrem = case_when(dev24 == 1 & findex_q != 5  & !is.na(wp24018) & wp24018 == 1 ~ 1, 
                              dev24 == 1 & findex_q != 5  ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin_Rrem = "Received money from relatives or friends living in a different city in the past 12 months (age 15+)") %>%
  
  mutate(fin_Rrem_dig = case_when(dev24 == 1 & findex_q != 5  & !is.na(wp21381_r) & wp21381_r == 1 ~ 1, 
                                  dev24 == 1 & findex_q != 5  ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_Rrem_dig = "Received money from relatives or friends living in a different city directly into an account or phone in the past 12 months (age 15+)")  %>%
  
  mutate(fin_SRrem = case_when(dev24 == 1 & (fin_Srem == 1 | fin_Rrem == 1) ~ 1,
                               dev24 == 1 & findex_q != 5  ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(fin_SRrem = "Sent OR Received domestic remittances (age 15+)")  %>%
  
  mutate(fin_SRrem_dig = case_when(dev24 == 1 & (fin_Srem_dig == 1 | fin_Rrem_dig == 1) ~ 1,
                                   dev24 == 1 & findex_q != 5  ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_SRrem_dig = "Sent OR Received domestic remittances digitally (age 15+)")  %>%
  
  mutate(fin_Rrem_intl = case_when(dev24 == 1 & findex_q != 5 & wp24008 == 1 ~ 1, 
                                   dev24 == 1 & findex_q != 5  ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_Rrem_intl = "Received money from relatives or friends living in a different country (age 15+)") %>%
  
  
  ##########################################################
# FREQUENCY
##########################################################

# Frequency for adults saving with MM (may include FI)
mutate(fin_sav_mm_freq_w = case_when(dev24 == 1 & fin17B_all == 1 & wp23991 == 1 ~ 1,  # Weekly frequency
                                     dev24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin_sav_mm_freq_w = "Frequency of saving using MM: Weekly (age 15+)") %>%
  
  mutate(fin_sav_mm_freq_m = case_when(dev24 == 1 & fin17B_all == 1 & wp23991 == 2 ~ 1,  # monthly
                                       dev24 == 1 ~ 0,
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin_sav_mm_freq_m = "Frequency of saving using MM: Monthly (age 15+)") %>%
  
  mutate(fin_sav_mm_freq_lm = case_when(dev24 == 1 & fin17B_all == 1 & wp23991 == 3 ~ 1,  # less than once a month
                                        dev24 == 1 ~ 0,
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_sav_mm_freq_lm = "Frequency of saving using MM: Less than once a month (age 15+)") %>%
  
  # Frequency for adults saving only with FI (no MM)
  mutate(fin_sav_fionly_freq_w = case_when(dev24 == 1 & fin17A_all == 1 & (fin17B_all != 1 | is.na(fin17B_all)) & wp23991 == 1 ~ 1,  # Weekly frequency, FI only
                                           dev24 == 1 ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin_sav_fionly_freq_w = "Frequency of saving using only FI: Weekly  (age 15+)") %>%
  
  mutate(fin_sav_fionly_freq_m = case_when(dev24 == 1 & fin17A_all == 1 & (fin17B_all != 1 | is.na(fin17B_all))& wp23991 == 2 ~ 1,  # monthly frequency, FI only
                                           dev24 == 1 ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin_sav_fionly_freq_m = "Frequency of saving using only FI: Monthly  (age 15+)") %>%
  
  mutate(fin_sav_fionly_freq_lm = case_when(dev24 == 1 & fin17A_all == 1 & (fin17B_all != 1 | is.na(fin17B_all)) & wp23991 == 3 ~ 1,  # Weekly frequency, FI only
                                            dev24 == 1 ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(fin_sav_fionly_freq_lm = "Frequency of saving using only FI: less than once a month (age 15+)") %>%
  
  
  # How long savings can last based off of what the main source of emergency money is
  
  mutate(fin24B_less2weeks_fam = case_when(dev24 == 1 & fin24_family == 1 & fin24B_less2weeks == 1 ~ 1,
                                           dev24 == 1 & fin24_family == 1 ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin24B_less2weeks_fam = "Adults who cite FAMILY as main source of emergency money: less than two weeks can be covered") %>%
  
  mutate(fin24B_less2weeks_sav = case_when(dev24 == 1 & fin24_savings == 1 & fin24B_less2weeks == 1 ~ 1,
                                           dev24 == 1 & fin24_savings == 1 ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin24B_less2weeks_sav = "Adults who cite SAVINGS as main source of emergency money: less than two weeks can be covered") %>%
  
  mutate(fin24B_less2weeks_work= case_when(dev24 == 1 & fin24_working == 1 & fin24B_less2weeks == 1 ~ 1,
                                           dev24 == 1 & fin24_working == 1 ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin24B_less2weeks_fam = "Adults who cite WORKING as main source of emergency money: less than two weeks can be covered") %>%
  
  # about 1 month
  mutate(fin24B_about1month_fam = case_when(dev24 == 1 & fin24_family == 1 & fin24B_about1month == 1 ~ 1,
                                            dev24 == 1 & fin24_family == 1 ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about1month_fam = "Adults who cite FAMILY as main source of emergency money: about one month can be covered") %>%
  
  mutate(fin24B_about1month_sav = case_when(dev24 == 1 & fin24_savings == 1 & fin24B_about1month == 1 ~ 1,
                                            dev24 == 1 & fin24_savings == 1 ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about1month_sav = "Adults who cite SAVINGS as main source of emergency money: about one month can be covered") %>%
  
  mutate(fin24B_about1month_work= case_when(dev24 == 1 & fin24_working == 1 & fin24B_about1month == 1 ~ 1,
                                            dev24 == 1 & fin24_working == 1 ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about1month_fam = "Adults who cite WORKING as main source of emergency money: about one month can be covered") %>%
  
  # about two months
  mutate(fin24B_about2month_fam = case_when(dev24 == 1 & fin24_family == 1 & fin24B_about2month == 1 ~ 1,
                                            dev24 == 1 & fin24_family == 1 ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about2month_fam = "Adults who cite FAMILY as main source of emergency money: about two months can be covered") %>%
  
  mutate(fin24B_about2month_sav = case_when(dev24 == 1 & fin24_savings == 1 & fin24B_about2month == 1 ~ 1,
                                            dev24 == 1 & fin24_savings == 1 ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about2month_sav = "Adults who cite SAVINGS as main source of emergency money: about two months can be covered") %>%
  
  mutate(fin24B_about2month_work= case_when(dev24 == 1 & fin24_working == 1 & fin24B_about2month == 1 ~ 1,
                                            dev24 == 1 & fin24_working == 1 ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about2month_fam = "Adults who cite WORKING as main source of emergency money: about two months can be covered") %>%
  
  # more than two months
  mutate(fin24B_more2month_fam = case_when(dev24 == 1 & fin24_family == 1 & fin24B_more2month == 1 ~ 1,
                                           dev24 == 1 & fin24_family == 1 ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin24B_more2month_fam = "Adults who cite FAMILY as main source of emergency money: more than two months can be covered") %>%
  
  mutate(fin24B_more2month_sav = case_when(dev24 == 1 & fin24_savings == 1 & fin24B_more2month == 1 ~ 1,
                                           dev24 == 1 & fin24_savings == 1 ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin24B_more2month_sav = "Adults who cite SAVINGS as main source of emergency money: more than two months can be covered") %>%
  
  mutate(fin24B_more2month_work= case_when(dev24 == 1 & fin24_working == 1 & fin24B_more2month == 1 ~ 1,
                                           dev24 == 1 & fin24_working == 1 ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin24B_more2month_fam = "Adults who cite WORKING as main source of emergency money: more than two months can be covered") %>%
  
  ##########################################################
# RESILIENCE/WATERFALL FIGURES
##########################################################

mutate(fin24_poss = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r %in% c(1,2,3,4,5,6) ~ 1,
                              dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_poss = "Possible to come up with emergency money in 30 days: POSSIBLE (age 15+)") %>%
  
  mutate(fin24_Nposs = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 7 ~ 1,
                                 dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_Nposs = "Possible to come up with emergency money in 30 days: NOT POSSIBLE (age 15+)") %>%
  
  mutate(fin24_dkr = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r %in% c(8,9) ~ 1,
                               dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_dkr = "Possible to come up with emergency money in 30 days: DK/Refused (age 15+)") %>%
  
  # difficulty for POSSIBLE - these are the 24A series from earlier
  mutate(fin24A_SD_ND = case_when(dev24 == 1 & !is.na(wp21377_r) & wp21377_r %in% c(2,3) ~ 1,
                                  dev24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin24A_SD_ND = "Coming up with emergency money: Somewhat or not difficult (age 15+)") %>%
  
  # SOMEWHAT OR NOT DIFFICULT BY EMERGENCY MONEY MODE
  
  mutate(fin24_savings_SD_ND = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 1 & fin24A_SD_ND == 1 ~ 1,
                                         dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_savings_SD_ND  = "Main source of money in case of emergency: Savings, somewhat or not difficult (age 15+)") %>%
  
  mutate(fin24_family_SD_ND  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 2  & fin24A_SD_ND == 1 ~ 1,
                                         dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_family_SD_ND  = "Main source of money in case of emergency: Family, relatives or friends, somewhat or not difficult (age 15+)") %>%
  
  mutate(fin24_working_SD_ND  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 3 & fin24A_SD_ND == 1 ~ 1,
                                          dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_working_SD_ND  = "Main source of money in case of emergency: Money from working, somewhat or not difficult (age 15+)") %>%
  
  mutate(fin24_loan_SD_ND  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 4  & fin24A_SD_ND == 1 ~ 1,
                                       dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_loan_SD_ND  = "Main source of money in case of emergency: A loan from a financial institution, an employer or private lender, somewhat or not difficult (age 15+)") %>%
  
  mutate(fin24_selling_SD_ND  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r ==5  & fin24A_SD_ND == 1 ~ 1,
                                          dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_selling_SD_ND  = "Main source of money in case of emergency: Selling something of own such as jewellery or livestock, somewhat or not difficult (age 15+)") %>%
  
  mutate(fin24_other_SD_ND  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 6  & fin24A_SD_ND == 1 ~ 1,
                                        dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_other_SD_ND  = "Main source of money in case of emergency: Some other source, somewhat or not difficult (age 15+)") %>%
  
  
  # VERY DIFFICULT BY EMERGENCY MONEY MODE - fin24A_VD is coded in findex raw variable file
  
  mutate(fin24_savings_VD = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 1 & fin24A_VD == 1 ~ 1,
                                      dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_savings_VD  = "Main source of money in case of emergency: Savings, very difficult (age 15+)") %>%
  
  mutate(fin24_family_VD  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 2  & fin24A_VD == 1 ~ 1,
                                      dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_family_VD  = "Main source of money in case of emergency: Family, relatives or friends, very difficult (age 15+)") %>%
  
  mutate(fin24_working_VD  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 3 & fin24A_VD == 1 ~ 1,
                                       dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_working_VD  = "Main source of money in case of emergency: Money from working, very difficult (age 15+)") %>%
  
  mutate(fin24_loan_VD  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 4  & fin24A_VD == 1 ~ 1,
                                    dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_loan_VD  = "Main source of money in case of emergency: A loan from a financial institution, an employer or private lender, very difficult (age 15+)") %>%
  
  mutate(fin24_selling_VD  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r ==5  & fin24A_VD == 1 ~ 1,
                                       dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_selling_VD  = "Main source of money in case of emergency: Selling something of own such as jewellery or livestock, very difficult (age 15+)") %>%
  
  mutate(fin24_other_VD  = case_when(dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 6  & fin24A_VD == 1 ~ 1,
                                     dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin24_other_VD  = "Main source of money in case of emergency: Some other source, very difficult (age 15+)") %>%
  
  
  
  ##########################################################
# ID VARIABLES
##########################################################

# Either a digtial ID OR a regular ID]
mutate(id_any = case_when(id24 == 1 & fin46_all == 1 ~ 1,
                          did24 == 1 & fin50_all == 1 ~ 1,
                          id24 == 1 ~ 0,
                          TRUE ~ NA)) %>%
  set_variable_labels(id_any = "Adults with EITHER digital or regular ID (% adults)") %>%
  
  mutate(id_regular_o = case_when(id24 == 1 & fin46_all == 1 & is.na(did24) ~ 1,
                                  did24 == 1 & fin46_all == 1 & fin50_all != 1 ~ 1,
                                  id24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(id_regular_o = "Adults with only a regular ID (% adults)") %>%
  
  mutate(id_dig_o = case_when(did24 == 1 & fin46_all != 1 & fin50_all == 1 ~ 1,
                              did24 == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(id_regular_o = "Adults with only a digital ID (% adults)") %>%
  
  mutate(id_both = case_when(id24 == 1 & fin46_all == 1 & fin50_all == 1 ~ 1,
                             id24 == 1 ~ 0,
                             TRUE ~ NA)) %>%
  set_variable_labels(id_both = "Adults with both digital and regular ID (% adults)") %>%
  
  
  ##########################################################
# CONNECTIVITY VARIABLES
##########################################################

mutate(con_sp_world = case_when(c24 == 1 & con9_all_smart == 1 ~ 1,
                                c24 == 1 & is.na(con9_all_smart) & con1_all == 1 & wp19544 == 1 ~ 1,
                                c24 == 1 ~ 0,
                                TRUE ~ NA)) %>% 
  set_variable_labels(con_sp_world = "Adults with a smartphone OR adults in HI countries with a phone that can access the internet (% adults)") %>%
  
  mutate(con_internet3 = case_when(c24 == 1 & con24_all == 1 | con25_all == 1 ~ 1,
                                   c24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con_internet3 = "Adults who used the internet in the past 3 months (con24+ con25) (% adults)") %>%
  
  mutate(con_internet_access = case_when(c24 == 1 & con24_all == 1 | con25_all == 1 | wp16056 == 1 ~ 1,
                                         c24 == 1 ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(con_internet_access = "Adults who report having access to the internet or used internet in last 3 months (% adults)") %>% 
  
  mutate(con_internet_sp = case_when(c24 == 1 & con_internet3 == 1 & con9_all_smart == 1 ~ 1,
                                     c24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(con_internet_sp = "Adults who used the internet in the past 3 months AND have a smartphone (% adults)") %>%
  
  mutate(con_internet_else_sp = case_when(c24 == 1 & con_internet3 == 1 & con5_all == 1 ~ 1,
                                          c24 == 1 ~ 0,
                                          TRUE ~ NA)) %>%
  set_variable_labels(con_internet_else_sp = "Adults who used the internet in the past 3 months AND used someone else's smart phone (% adults)") %>%
  
  mutate(con_internet_nosp = case_when(c24 == 1 & con_internet3 == 1 & con9_all_smart != 1 ~ 1,
                                       c24 == 1 ~ 0,
                                       TRUE ~ NA)) %>%
  set_variable_labels(con_internet_nosp = "Adults who used the internet in the past 3 months AND DO NOT have a smartphone (% adults)") %>%
  
  # mutually exclusive texts
  mutate(con_send_text_o = case_when(lc24 == 1 & con16_all == 1 & con14_all != 1 ~ 1,
                                     lc24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(con_send_text_o = "Adults who sent a text but did not read one (% adults)") %>%
  
  mutate(con_read_text_o = case_when(lc24 == 1 & con16_all != 1 & con14_all == 1 ~ 1,
                                     lc24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(con_read_text_o = "Adults who read a text but did not send (% adults)") %>%
  
  mutate(con_text_b = case_when(lc24 == 1 & con16_all == 1 & con14_all == 1 ~ 1,
                                lc24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con_text_b = "Adults who both sent and read texts (% adults)") %>%
  
  mutate(
    con_text_b_n = case_when(
      lc24 == 1 & (con16_all != 1 | con14_all != 1) ~ 1,
      lc24 == 1 ~ 0,
      TRUE ~ NA_real_
    )
  ) %>%
  
  
  
  
  
  # Mobile Money and passwords
  
  # Have a mobile money account and have a password/PIN on mobile phone
  mutate(con18_mm = case_when(lc24 == 1  & acc24mob == 1 & con1_all == 1 & con18_all == 1 ~ 1,
                              lc24 == 1  ~ 0 ,
                              TRUE ~ NA)) %>%
  set_variable_labels(con18_mm = "MM account owners who have a password/pin on mobile (% adults)") %>%
  
  
  # mobile money account owners who are being able to change a password (% of all adults)
  mutate(con19_mm = case_when(lc24 == 1 & acc24mob == 1 & con1_all == 1 & con18_all == 1 & con19_all == 1 ~ 1,
                              lc24 == 1  ~ 0 ,
                              TRUE ~ NA)) %>%
  set_variable_labels(con19_mm = "MM account owners who have a password/pin on mobile and can change it (% adults)")%>%
  
  # MM account owners wihtout phones - this should be 0
  mutate(con_mm_nophone = case_when(lc24 == 1 & acc24mob == 1 & con1_all != 1 ~ 1,
                                    lc24 == 1  ~ 0 ,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con_mm_nophone = "MM account owners who do not have a phone (% adults)") %>%
  
  
  ################################# digital skills based on internet users
  
  # Sent a voice message from a mobile phone in the past 3 months, as share of internet users
  mutate(con30a_int = case_when(lc24 == 1 & wp24052 == 1 & (con9_all_smart | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 &  (con24_all == 1 | con25_all == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30a_int = "Sent a voice message in past 3 months (internet users)") %>%
  
  
  # Sent a photo from a mobile phone in the past 3 months, as share of internet users
  mutate(con30b_int = case_when(lc24 == 1 & wp24053 == 1 & (con9_all_smart | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30b_int = "Sent a photo in past 3 months (internet users)") %>%
  
  
  # Used social media on a mobile phone in the past 3 months, as share of internet users
  mutate(con30c_int = case_when(lc24 == 1 & wp24054 == 1 & (con9_all_smart | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30c_int = "Used social media in past 3 months (internet users)") %>%
  
  
  # Read news or current events online in the past 3 months, as share of internet users
  mutate(con30d_int = case_when(lc24 == 1 & wp24055 == 1 & (con9_all_smart | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30d_int = "Read news or current events online in past 3 months (internet users)") %>%
  
  
  # In the PAST 3 MONTHS, accessed information online to learn, train, or educate, as share of internet users
  mutate(con30e_int = case_when(lc24 == 1 & wp24056 == 1 &(con9_all_smart | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30e_int = "Accessed online info to learn/train/educate in past 3 months (internet users)") %>%
  
  
  # In the PAST 3 MONTHS, used apps or websites to earn money, as share of internet users
  mutate(con30f_int = case_when(lc24 == 1 & wp24057 == 1 & (con9_all_smart | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 &(con24_all == 1 | con25_all == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30f_int = "Used apps/websites to earn money in past 3 months (internet users)") %>%
  
  
  # In the PAST 3 MONTHS, accessed government services or searched for government info online, as share of internet users
  mutate(con30g_int = case_when(lc24 == 1 & wp24058 == 1 & (con9_all_smart | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30g_int = "Accessed government services/info online in past 3 months (internet users)") %>%
  
  
  # In the PAST 3 MONTHS, searched or applied for a job online, as share of internet users
  mutate(con30h_int = case_when(lc24 == 1 & wp24059 == 1 & (con9_all_smart | con24_all == 1 | con25_all == 1) ~ 1,
                                lc24 == 1 & (con24_all == 1 | con25_all == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(con30h_int = "Searched/applied for a job online in past 3 months (internet users)") %>%
  
  
  ##########################################################
# UNBANKED ADULTS - CROSS SECTION
##########################################################

mutate(fin_id_ub = case_when(id24 == 1 & id_any == 1 & acc24any != 1 ~ 1,
                             id24 == 1 ~ 0,
                             TRUE ~ NA)) %>%
  set_variable_labels(fin_id_ub = "Unbanked adults with ID (% adults)") %>%
  
  mutate(con_phone_ub = case_when(c24 == 1 & con1_all == 1 & acc24any != 1 ~ 1,
                                  c24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(con_phone_ub = "Unbanked adults with a mobile phone (% adults)") %>%
  
  mutate(con_internet_ub = case_when(c24 == 1 & con_internet3 == 1 & acc24any != 1 ~ 1,
                                     c24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(con_internet_ub = "Unbanked adults with Internet (% adults)") %>%
  
  ### unbanked with a phone but don't have SIM card in their own name
  mutate(con_phone_noSIM_ub = case_when(c24 == 1 & con1_all == 1 & con11_all != 1 & acc24any != 1 ~ 1,
                                        c24 == 1 ~ 0,
                                        TRUE ~ NA)) %>%
  set_variable_labels(con_phone_noSIM_ub = "Unbanked adults with a mobile phone and don't have SIM registered in their own name (% adults)") %>%
  
  ### added 031725
  mutate(con_smartP_ub = case_when(c24 == 1 & connect_q != 4 & con9_all_smart == 1 & con1_all == 1 & acc24any != 1 ~ 1,
                                   c24 == 1 & connect_q != 4  ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con_smartP_ub = "Unbanked adults with smart phone (% adults)") %>%
  
  mutate(con_basicP_ub = case_when(c24 == 1 & connect_q != 4 & con9_all_basic == 1& con1_all == 1 & acc24any != 1 ~ 1,
                                   c24 == 1 & connect_q != 4  ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(con_basicP_ub = "Unbanked adults with basic text phone (% adults)") %>%
  
  mutate(con_featureP_ub = case_when(c24 == 1 & connect_q != 4 & con10_all == 1 &  con9_all_basic == 1 & acc24any != 1 ~ 1,
                                     c24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(con_featureP_ub = "Unbanked adults with feature (Can use WhatsApp on basic text) phone (% adults)") %>%
  
  
  ### unbanked with no phone
  mutate(con_nophone_ub = case_when(c24 == 1 & con1_all == 0 & acc24any != 1 ~ 1,
                                    c24 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(con_nophone_ub = "Unbanked adults without a mobile phone (% adults)") %>%
  
  ######






mutate(fin11C_yesID = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & id24 == 1 & 
                                  id_any == 1 & fin11C_all == 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 & id24 == 1  ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11C_yesID = "adults who say 'documentation' is a barrier to having an account but have ID (% adults)") %>%
  
  # Only Barrier:  Distance from financial institutions
  mutate(fin11A_all_only = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 &
                                       fin11A_all == 1 & fin11B_all != 1 & fin11C_all != 1 & fin11D_all != 1 & fin11E_all != 1 & fin11F_all != 1 ~ 1,
                                     dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin11A_all_only  = " Only Barrier:  Distance from financial institutions(% adults)") %>%
  
  # Only Barrier: Financial service fees too expensive
  mutate(fin11B_all_only = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & 
                                       fin11B_all == 1 & fin11A_all != 1 & fin11C_all != 1 & fin11D_all != 1 & fin11E_all != 1 & fin11F_all != 1 ~ 1,
                                     dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin11B_all_only  = " Only Barrier: Financial service fees too expensive (% adults)") %>%
  
  # Only Barrier: Did not have the necessary documentation
  mutate(fin11C_all_only = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & 
                                       fin11C_all == 1 & fin11A_all != 1 & fin11B_all != 1 & fin11D_all != 1 & fin11E_all != 1 & fin11F_all != 1 ~ 1,
                                     dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin11C_all_only = "Only Barrier: Did not have the necessary documentation (% adults)")  %>%
  
  
  # Only Barrier: Not enough money
  mutate(fin11D_all_only = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 &
                                       fin11D_all == 1 & fin11A_all != 1 & fin11B_all != 1 & fin11C_all != 1 & fin11E_all != 1 & fin11F_all != 1 ~ 1,
                                     dev24 == 1 & findex_q != 5  &  nfi24 == 1  ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin11D_all_only  = " Only Barrier: Did not have enough money to open an account (% adults)") %>%
  
  
  # Only Barrier: Family member has an account
  mutate(fin11E_all_only = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 &
                                       fin11E_all == 1 & fin11A_all != 1 & fin11B_all != 1 & fin11C_all != 1 & fin11D_all != 1 & fin11F_all != 1 ~ 1,
                                     dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin11E_all_only = " Only Barrier: Family member has an account (% adults)") %>%
  
  # Only Barrier: Do not trust financial institutions
  mutate(fin11F_all_only = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 &
                                       fin11F_all == 1 & fin11A_all != 1 & fin11B_all != 1 & fin11C_all != 1 & fin11D_all != 1 & fin11E_all != 1  ~ 1,
                                     dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin11F_all_only = "Only Barrier: Do not trust financial institutions (% adults)") %>%
  
  mutate(fin19_nosavfor= case_when(dev24 == 1 & fin19_all== 1 & fin_savfor_fi_mm != 1 ~ 1, 
                                   dev24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin19_nosavfor = "Made regular payments to insurance agent or company in the past 12 months and do not do formal saving (age 15+)") %>%
  
  mutate(fin19_nosavfor= case_when(dev24 == 1 & fin19_all== 1 & fin_savfor_fi_mm != 1 ~ 1, 
                                   dev24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin19_nosavfor = "Made regular payments to insurance agent or company in the past 12 months and do not do formal saving (age 15+)") %>%
  
  mutate(fin25E_2cash_mm = case_when(dev24 == 1 & fin25E_2cash == 1 & acc24mob == 1  ~ 1, 
                                     dev24 == 1 ~ 0 , 
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin25E_2cash_mm = "TS: Made merchant payments only in cash and have a mobile money account (age 15+)") %>%
  
  mutate(fin11E_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1  & wp14900_r == 1 & acc24fin != 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11E_all = "Barrier: Family member has an account (age 15+)") %>%
  
  mutate(fin15_all = case_when(ml24 == 1 & wp23989 == 1 ~ 1, 
                               ml24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin15_all = "Used an agent or asked someone to make a mobile money payment (age 15+)") %>%
  
  mutate(con_phone_no_sp = case_when(lc24 == 1 & acc24mob == 1 & con1_all == 1 & con9_all_smart != 1 ~ 1, 
                                     lc24 == 1 ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(con_phone_no_sp = "Adults who have a phone but not a smart phone (% adults)") %>%
  
  
  
  
  #### 0318 25 added connectivity variables
  
  ### basic text phone owner with password
  
  mutate(con_basicP_lock_all = case_when(lc24 == 1  & con9_all_basic == 1 & con18_all == 1 ~ 1,
                                         lc24 == 1  ~ 0 ,
                                         TRUE ~ NA)) %>%
  set_variable_labels(con_basicP_lock_all = "text phone owner with password (% adults)") %>%
  
  
  
  ### basic text phone owner without password
  
  
  mutate(con_basicP_noLock_all = case_when(lc24 == 1  & con9_all_basic == 1 & con18_all == 0 ~ 1,
                                           lc24 == 1  ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(con_basicP_noLock_all = "text phone owner without password (% adults)") %>%
  
  ### smart phone owner with password
  mutate(con_smartP_lock_all = case_when(lc24 == 1  & con9_all_smart == 1 & con18_all == 1 ~ 1,
                                         lc24 == 1  ~ 0 ,
                                         TRUE ~ NA)) %>%
  set_variable_labels(con_smartP_lock_all  = "smart phone owner with password (% adults)") %>%
  
  ### smart phone owner without password
  
  mutate(con_smartP_noLock_all = case_when(lc24 == 1  & con9_all_smart == 1 & con18_all == 0 ~ 1,
                                           lc24 == 1  ~ 0 ,
                                           TRUE ~ NA)) %>%
  set_variable_labels(con_basicP_noLock_all = "smart phone owner without password (% adults)") %>%
  
  ### basic text phone owner with SIM card
  mutate(con_basicP_sim_all = case_when(lc24 == 1  & con9_all_basic == 1 & con11_all == 1 ~ 1,
                                        lc24 == 1  ~ 0 ,
                                        TRUE ~ NA)) %>%
  set_variable_labels(con_basicP_sim_all = "text phone owner with SIM registed in own name (% adults)") %>%
  
  
  ## basic text phone owner without SIM card
  mutate(con_basicP_noSim_all = case_when(lc24 == 1  & con9_all_basic ==1 & con11_all == 0 ~ 1,
                                          lc24 == 1  ~ 0 ,
                                          TRUE ~ NA)) %>%
  set_variable_labels(con_basicP_noSim_all = "text phone owner without SIM registed in own name (% adults)") %>%
  
  
  ### Smart phone owner with SIM card
  mutate(con_smartP_sim_all = case_when(lc24 == 1  & con9_all_smart == 1 & con11_all == 1 ~ 1,
                                        lc24 == 1  ~ 0 ,
                                        TRUE ~ NA)) %>%
  set_variable_labels(con_smartP_sim_all  = "smart phone owner with SIM registed in own name (% adults)") %>%
  
  ### Smart phone owner without SIM card
  mutate(con_smartP_noSim_all = case_when(lc24 == 1  & con9_all_smart == 1 & con11_all == 0 ~ 1,
                                          lc24 == 1  ~ 0 ,
                                          TRUE ~ NA)) %>%
  set_variable_labels(con_smartP_noSim_all  = "smart phone owner without SIM registed in own name (% adults)") %>%
  
  ####  added variables for 1) have a text phone use bank account or mm on their phone' 2) have a smart phone use bank account or MM on their phone
  ### smart phone but use bank account and MM on their phone
  mutate(con_smartP_FI_mm_all = case_when(lc24 == 1  & con9_all_smart == 1 & fin3_all_noMM == 1 & acc24mob == 1 ~ 1,
                                          lc24 == 1  ~ 0 ,
                                          TRUE ~ NA)) %>%
  set_variable_labels(con_smartP_FI_mm_all  = "smart phone owner use bank account or MM on their phone (% adults)") %>%
  
  ### basic phone but use bank account and MM on their phone  
  mutate(con_basicP_FI_mm_all = case_when(lc24 == 1  & con9_all_basic == 1 & fin3_all_noMM == 1 & acc24mob == 1 ~ 1,
                                          lc24 == 1  ~ 0 ,
                                          TRUE ~ NA)) %>%
  set_variable_labels(con_basicP_FI_mm_all  = "basic phone owner use bank account or MM on their phone (% adults)") %>%
  
  ##MM only and previously had FI account
  mutate(fin_MM_prevFI = case_when(dev24 == 1  & acc24mob_o == 1 & fin11_1_all == 1 ~ 1,
                                   dev24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin_MM_prevFI = "MM only and previously had FI account") %>%
  
  
  
  
  #############################################
# Adult without a phone - do they have ID?
mutate(con_np_id = case_when(c24 == 1 & id24 == 1 & con1_all == 0 & id_any == 1 ~ 1,
                             c24 == 1 & id24 == 1 ~ 0 , 
                             TRUE ~ NA)) %>%
  set_variable_labels(con_np_id = "Adults without a phone who have ID") %>%
  
  
  ######################################################
# Ag payment breakdowns

# Received agricultural payment and own a smartphone
mutate(fin_agppay_any_sphone = case_when(fin_agpay_any == 1 & con9_all_smart == 1 ~ 1,
                                         dev24 == 1 & findex_q != 5 ~ 0 , 
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin_agppay_any_sphone = "Received agricultural payment and have a smart phone") %>%
  
  # Received agricultural payment and own a basic phone
  mutate(fin_agppay_any_bphone = case_when(fin_agpay_any == 1 & con9_all_basic == 1 ~ 1,
                                           dev24 == 1 & findex_q != 5 ~ 0 , 
                                           TRUE ~ NA)) %>%
  set_variable_labels(fin_agppay_any_bphone = "Received agricultural payment and have a basic phone") %>%
  
  # Received agricultural payment and do not own a phone
  mutate(fin_agppay_any_no_phone = case_when(fin_agpay_any == 1 & con1_all != 1 ~ 1,
                                             dev24 == 1 & findex_q != 5 ~ 0 , 
                                             TRUE ~ NA)) %>%
  set_variable_labels(fin_agppay_any_no_phone = "Received agricultural payment and do not have a phone") %>%
  
  # Received agricultural payment and use internet and check for information
  mutate(fin_agpay_any_internet_info = case_when(fin_agpay_any == 1 & con_internet3 == 1 & fin44 == 1 ~ 1,
                                                 dev24 == 1 & findex_q != 5 ~ 0 , 
                                                 TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_internet_info = "Received agricultural payment and use the internet and check for agriculture information") %>%
  
  # Received agricultural payment and use internet and do not check for information
  mutate(fin_agpay_any_internet_no_info = case_when(fin_agpay_any == 1 & con_internet3 == 1 & fin44 == 0 ~ 1,
                                                    dev24 == 1 & findex_q != 5 ~ 0 , 
                                                    TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_internet_no_info = "Received agricultural payment and use the internet and do not check for information") %>%
  
  # Received agricultural payment any do not use the internet
  mutate(fin_agpay_any_no_internet = case_when(fin_agpay_any == 1 & con_internet3 == 0 ~ 1,
                                               dev24 == 1 & findex_q != 5 ~ 0 , 
                                               TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_no_internet = "Received agricultural payment and do not use the internet") %>%
  
  # Received agricultural payment and want to receive emergency govt info by text
  mutate(fin_agpay_any_emerg_text = case_when(fin_agpay_any == 1 & con17_all_text == 1 ~ 1,
                                              dev24 == 1 & findex_q != 5 ~ 0 , 
                                              TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_emerg_text = "Received agricultural payment and want to receive emergency govt info by text") %>%
  
  # Received agricultural payment and want to receive emergency govt info by call
  mutate(fin_agpay_any_emerg_call = case_when(fin_agpay_any == 1 & con17_all_call == 1 ~ 1,
                                              dev24 == 1 & findex_q != 5 ~ 0 , 
                                              TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_emerg_call = "Received agricultural payment and want to receive emergency govt info by call") %>%
  
  # Received agricultural payment and want to receive emergency govt info by either call or text
  mutate(fin_agpay_any_emerg_both = case_when(fin_agpay_any == 1 & con17_all_b == 1 ~ 1,
                                              dev24 == 1 & findex_q != 5 ~ 0 , 
                                              TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_emerg_both = "Received agricultural payment and want to receive emergency govt info by either call or text") %>%
  
  # Received agricultural payment and could pay expenses for less than 2 weeks if they lose their income source
  mutate(fin_agpay_any_payexp_l2w = case_when(fin_agpay_any == 1 & fin24B_less2weeks == 1 ~ 1,
                                              dev24 == 1 & findex_q != 5 ~ 0 , 
                                              TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_payexp_l2w = "Received agricultural payment and could pay expenses for less than 2 weeks if they lose their income source") %>%
  
  # Received agricultural payment and could pay expenses for about 1 month if they lose their income source
  mutate(fin_agpay_any_payexp_1m = case_when(fin_agpay_any == 1 & fin24B_about1month == 1 ~ 1,
                                             dev24 == 1 & findex_q != 5 ~ 0 , 
                                             TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_payexp_1m = "Received agricultural payment and could pay expenses for about 1 month if they lose their income source") %>%
  
  # Received agricultural payment and could pay expenses for about 2 months if they lose their income source
  mutate(fin_agpay_any_payexp_2m = case_when(fin_agpay_any == 1 & fin24B_about2month == 1 ~ 1,
                                             dev24 == 1 & findex_q != 5 ~ 0 , 
                                             TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_payexp_2m = "Received agricultural payment and could pay expenses for about 2 months if they lose their income source") %>%
  
  # Received agricultural payment and could pay expenses for more than 2 months if they lose their income source
  mutate(fin_agpay_any_payexp_m2m = case_when(fin_agpay_any == 1 & fin24B_more2month == 1 ~ 1,
                                              dev24 == 1 & findex_q != 5 ~ 0 , 
                                              TRUE ~ NA)) %>%
  set_variable_labels(fin_agpay_any_payexp_m2m = "Received agricultural payment and could pay expenses for more than 2 months if they lose their income source") %>%
  
  #################
# save for old age formally and earn interest

mutate(fin_old_interest_fi_mm = case_when(dev24 == 1 & fin_savfor_fi_mm == 1 & fin17E_all == 1 & fin17F_all == 1 ~ 1, 
                                          dev24 == 1 ~ 0,
                                          TRUE~ NA)) %>%
  set_variable_labels(fin_old_interest_fi_mm = "Saved formally using an FI or MM account for old age and earned interest") %>%
  
  mutate(fin_old_nointerest_fi_mm = case_when(dev24 == 1 & fin_savfor_fi_mm == 1 & fin17E_all != 1 & fin17F_all == 1 ~ 1, 
                                              dev24 == 1 ~ 0,
                                              TRUE~ NA)) %>%
  set_variable_labels(fin_old_nointerest_fi_mm = "Save for old age formally and no interest") %>%
  
  mutate(fin_old_notformal = case_when(dev24 == 1 & fin_savfor_fi_mm !=1 & fin17F_all == 1 ~ 1, 
                                       dev24 == 1 ~ 0,
                                       TRUE~ NA)) %>%
  set_variable_labels(fin_old_notformal = "Save for old age and save not formally") %>%
  
  mutate(fin_inactive_phone = case_when(dev24 == 1 & fin_FIdormant == 1 & con1_all == 1 ~ 1,
                                        dev24 == 1 ~ 0,
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin_inactive_phone = "Inactive Account but has phone") %>% 

# Owns credit card and did not use it in the past 12 months   
  mutate(fin_cc_nouse = case_when(dev24 == 1 & fin10_all == 1 & fin22G_all != 1 ~ 1,
                                dev24 == 1 ~ 0 ,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin_cc_nouse  = "Owns credit card and did not use it in the past 12 months") %>%
  

#Used credit card and paid balance 
  mutate(fin_cc_paid_balance = case_when(dev24 == 1 & fin22G_all == 1 & fin22H_all == 1 ~ 1,
                                dev24 == 1 ~ 0 ,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin_cc_paid_balance  = "Owns credit card and paid balance") %>%

  
#Used credit card and did not pay balance 
  mutate(fin_cc_nopaid_balance = case_when(dev24 == 1 & fin22G_all == 1 & fin22H_all != 1 ~ 1,
                                         dev24 == 1 ~ 0 ,
                                         TRUE ~ NA)) %>%
    set_variable_labels(fin_cc_nopaid_balance  = "Owns credit card and did not pay balance") 
  







  
