
dataframe_2024 <- dataframe_2024 %>%
  # Financial institution accounts
  mutate(fin1_all = case_when(wp19548_r == 1 ~ 1, 
                              !is.na(wp19548_r) & wp19548_r != 1 ~ 0, 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin1_all = "FIN1 (age 15+)") %>%
  
  mutate(fin2_all = case_when(wp14888_r == 1 ~ 1, 
                              !is.na(wp14888_r) & wp14888_r != 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin2_all = "Owns debit card (age 15+") %>%
  
  mutate(fin3_all = case_when(dev24 == 1 & wp23973 == 1 ~ 1,
                              dev24 == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(fin3_all = "Use a card or a mobile phone to make payments in the past 12 months (age 15+)") %>%
  
  mutate(fin3_all_noMM = case_when(dev24 == 1 & wp23973 == 1 & (acc24mob != 1 | is.na(acc24mob)) ~ 1,
                              dev24 == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(fin3_all_noMM = "Use a card or a mobile phone to make payments in the past 12 months and don't have MM account (age 15+)") %>%
  
  mutate(fin4_all = case_when(dev24 == 1 & wp23974 == 1 ~ 1,
                              dev24 == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(fin4_all = "Opened first account to receive a wage or salary payment or money from the government (age 15+)") %>%
  
  # NOTE: for frequency figures, questions are only asked of people who do either answer yes to having a FI
  # account or an ATM card - therefore, in the questions that are coded as a % of banked adults, we have to 
  # include (!is.na(wp19548_r) | !is.na(wp14888_r)) because otherwise the albeit small marginal additions would skew the number
  
  mutate(fin5_all_w = case_when(dev24 == 1 & findex_q != 5  & wp23975 == 1 ~ 1,
                                dev24 == 1 & findex_q != 5  ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin5_all_w = "Frequency of money deposited into account in a typical month: Weekly (age 15+)") %>%
  
  mutate(fin5_fi_w = case_when(dev24 == 1 & findex_q != 5  & wp23975 == 1 & acc24fin == 1 ~ 1,
                               dev24 == 1 & findex_q != 5  & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin == 1 ~ 0, 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin5_fi_w = "FI Banked: Frequency of money deposited into account in a typical month: Weekly, of FI banked (age 15+)") %>%
  
  mutate(fin5_all_m = case_when(dev24 == 1 & findex_q != 5  & wp23975 == 2 ~ 1,
                                dev24 == 1 & findex_q != 5 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin5_all_m = "Frequency of money deposited into account in a typical month: Monthly (age 15+)") %>%
  
  mutate(fin5_fi_m = case_when(dev24 == 1 & findex_q != 5  & wp23975  == 2 & acc24fin == 1 ~ 1,
                               dev24 == 1 & findex_q != 5  & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin5_fi_m = "FI Banked: Frequency of money deposited into account in a typical month: Monthly, of FI banked (age 15+)") %>%
  
  mutate(fin5_all_lm = case_when(dev24 == 1 & findex_q != 5  & wp23975 == 3 ~ 1,
                                 dev24 == 1 & findex_q != 5  ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin5_all_lm = "Frequency of money deposited into account in a typical month: Less than once a month (age 15+)") %>%
  
  mutate(fin5_fi_lm = case_when(dev24 == 1 & findex_q != 5  & wp23975 == 3 & acc24fin == 1 ~ 1,
                                dev24 == 1 & findex_q != 5  & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin5_fi_lm = "FI Banked: Frequency of money deposited into account in a typical month: Less than once a month, of FI banked (age 15+)") %>%
  
  mutate(fin5_all_n = case_when(dev24 == 1 & findex_q != 5  & wp23975 == 4 ~ 1,
                                dev24 == 1 & findex_q != 5  ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin5_all_n = "Frequency of money deposited into account in a typical month: Never (age 15+)") %>%
  
  mutate(fin5_fi_n = case_when(dev24 == 1 & findex_q != 5  & wp23975 == 4 & acc24fin == 1 ~ 1,
                               dev24 == 1 & findex_q != 5  & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin == 1 ~ 0, 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin5_fi_n = "FI Banked: Frequency of money deposited into account in a typical month: Never (age 15+)") %>%
  
  mutate(fin6_all_w = case_when(dev24 == 1 & findex_q != 5  & wp23976 == 1 ~ 1,
                                dev24 == 1 & findex_q != 5  ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin6_all_w = "Frequency of sending money or withdrawals in a typical month: Weekly (age 15+)") %>%
  
  mutate(fin6_fi_w = case_when(dev24 == 1 & findex_q != 5  & wp23976 == 1 & acc24fin == 1 ~ 1,
                               dev24 == 1 & findex_q != 5  & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin == 1 ~ 0, 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin6_fi_w = "FI Banked: Frequency of sending money or withdrawals in a typical month: Weekly, of FI banked (age 15+)") %>%
  
  mutate(fin6_all_m = case_when(dev24 == 1 & findex_q != 5  & wp23976 == 2 ~ 1,
                                dev24 == 1 & findex_q != 5  ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin6_all_m = "Frequency of sending money or withdrawals in a typical month: Monthly (age 15+)") %>%
  
  mutate(fin6_fi_m = case_when(dev24 == 1 & findex_q != 5  & wp23976 == 2 & acc24fin == 1 ~ 1,
                               dev24 == 1 & findex_q != 5  & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin6_fi_m = "FI Banked: Frequency of sending money or withdrawals in a typical month: Monthly, of FI banked (age 15+)") %>%
  
  mutate(fin6_all_lm = case_when(dev24 == 1 & findex_q != 5  & wp23976 == 3 ~ 1,
                                 dev24 == 1 & findex_q != 5  ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin6_all_lm = "Frequency of sending money or withdrawals in a typical month: Less than once a month (age 15+)") %>%
  
  mutate(fin6_fi_lm = case_when(dev24 == 1 & findex_q != 5  & wp23976 == 3 & acc24fin == 1 ~ 1,
                                dev24 == 1 & findex_q != 5  & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin6_fi_lm = "FI Banked: Frequency of sending money or withdrawals in a typical month: Less than once a month, of FI banked (age 15+)") %>%
  
  mutate(fin6_all_n = case_when(dev24 == 1 & findex_q != 5  & wp23976 == 4 ~ 1,
                                dev24 == 1 & findex_q != 5  ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin6_all_n = "Frequency of sending money or withdrawals in a typical month: Never (age 15+)") %>%
  
  mutate(fin6_fi_n = case_when(dev24 == 1 & findex_q != 5  & wp23976 == 4 & acc24fin == 1 ~ 1,
                               dev24 == 1 & findex_q != 5  & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin6_fi_n = "FI Banked: Frequency of sending money or withdrawals in a typical month: Never, of FI banked (age 15+)") %>%
  
  mutate(fin7_all = case_when(dev24 == 1 & findex_q != 5 & wp19477_r == 1 ~ 1, 
                              dev24 == 1 & findex_q != 5  ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin7_all = "Money put into or taken out of account in the past 12 months (age 15+)") %>%
  
  mutate(fin8_all = case_when(dev24 == 1 & findex_q != 5 & wp21360_r == 1 ~ 1, 
                              dev24 == 1 & findex_q != 5 ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin8_all = "Keep money in account (age 15+)") %>%
  
  mutate(fin9A_all = case_when(dev24 == 1 & findex_q != 5 & wp23977 == 1 ~ 1, 
                               dev24 == 1 & findex_q != 5  ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin9A_all = "Received information about account balance from bank through email, SMS, or text message on mobile in the past 12 months (age 15+)") %>%
  
  mutate(fin9B_all = case_when(dev24 == 1 & findex_q != 5 & wp23978 == 1 ~ 1, 
                               dev24 == 1 & findex_q != 5  ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin9B_all = "Checked account balance using mobile phone or computer in the past 12 months (age 15+)") %>%
  
  mutate(fin10_all = case_when(dev24 == 1 & wp14891_r == 1 ~ 1,
                               dev24 == 1  ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin10_all = "Own a credit card (age 15+)") %>%
  
  mutate(fin11_0_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp15153_r == 1 ~ 1,
                                 dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin11_0_all = "Own a card that you can add money to and use to send and receive money or make purchases (age 15+)") %>%
  
  mutate(fin11_0_noFI = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp15153_r == 1 & acc24fin != 1 ~ 1, 
                                  dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin11_0_noFI = "No FI account: Own a card that you can add money to and use to send and receive money or make purchases, of no FI account (age 15+)") %>%
  
  mutate(fin11_0_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp15153_r == 1 & acc24any != 1 ~ 1, 
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24any != 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11_0_ub = "UNBANKED: Own a card that you can add money to and use to send and receive money or make purchases, of unbanked: NO FI or MM (age 15+)") %>%
  
  
  # fin11_1_all
  mutate(fin11_1_all = case_when(dev24 == 1 & findex_q != 5  & nfi24 == 1 & wp23979 == 1 ~ 1,
                                 dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin11_1_all = "Ever had an account at a bank or similar financial institution (age 15+)") %>%
  
  # fin11_1_ub 
  mutate(fin11_1_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp23979 == 1 & acc24fin != 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11_1_ub = "NO FI account: Ever had an account at a bank or similar financial institution, of unbanked (age 15+)") %>%
  
  # fin11_2a_all
  mutate(fin11_2a_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp21361_r == 2 ~ 1,
                                  dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin11_2a_all = "Would need help of another person to use a newly opened bank account (age 15+)") %>%
  
  # fin11_2a_ub
  mutate(fin11_2a_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp21361_r == 2 & acc24fin != 1 ~ 1,
                                 dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin11_2a_ub = "NO FI account: Would need help of another person to use a newly opened bank account, of unbanked (age 15+)") %>%
  
  # fin11_2b_all
  mutate(fin11_2b_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp21361_r == 1 ~ 1, 
                                  dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin11_2b_all = "Would NOT need help of another person to use a newly opened bank account (age 15+)") %>%
  
  # fin11_2b_ub
  mutate(fin11_2b_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp21361_r == 1 & acc24fin != 1 ~ 1,
                                 dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin11_2b_ub = "NO FI account: Would NOT need help of another person to use a newly opened bank account, of unbanked (age 15+)") %>%
  
  # fin11A_all
  mutate(fin11A_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14894_r == 1 & acc24fin != 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11A_all = "Barrier: Distance from financial institutions (age 15+)") %>%
  
  # fin11A_all_ub
  mutate(fin11A_all_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14894_r == 1 & acc24fin != 1 ~ 1,
                                   dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin11A_all_ub = "Barrier: Distance from financial institutions, of unbanked (age 15+)") %>%
  
  # fin11B_all
  mutate(fin11B_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14895_r == 1 & acc24fin != 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11B_all = "Barrier: Financial service fees too expensive (age 15+)") %>%
  
  # fin11B_ub
  mutate(fin11B_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14895_r == 1 & acc24fin != 1 ~ 1,
                               dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & wp14895_r != 1 & acc24fin != 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin11B_ub = "Barrier: Financial service fees too expensive, of unbanked (age 15+)") %>%
  
  # fin11C_all
  mutate(fin11C_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp21362_r == 1 & acc24fin != 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11C_all = "Barrier: Did not have the necessary documentation (age 15+)") %>%
  
  # fin11C_ub
  mutate(fin11C_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp21362_r == 1 & acc24fin != 1 ~ 1,
                               dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin11C_ub = "Barrier: Did not have the necessary documentation, of unbanked (age 15+)") %>%
  
  # fin11D_all
  mutate(fin11D_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14898_r == 1 & acc24fin != 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11D_all = "Barrier: Did not have enough money to open an account (age 15+)") %>%
  
  # fin11D_ub
  mutate(fin11D_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14898_r == 1 & acc24fin != 1 ~ 1,
                               dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin11D_ub = "Barrier: Did not have enough money to open an account, of unbanked (age 15+)") %>%
  
  # fin11E_all
  mutate(fin11E_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1  & wp14900_r == 1 & acc24fin != 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin11E_all = "Barrier: Family member has an account (age 15+)") %>%
  
  # fin11E_ub
  mutate(fin11E_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14900_r == 1 & acc24fin != 1 ~ 1,
                               dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin11E_ub = "Barrier: Family member has an account, of unbanked (age 15+)") %>%
  
  # fin11F_all
  mutate(fin11F_all = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14897_r == 1 & acc24fin != 1 ~ 1,
                                dev24 == 1 & findex_q != 5  &  nfi24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin11F_all = "Barrier: Do not trust financial institutions (age 15+)") %>%
  
  mutate(fin11F_ub = case_when(dev24 == 1 & findex_q != 5  &  nfi24 == 1 & wp14897_r == 1 & acc24fin != 1 ~ 1,
                               dev24 == 1 & findex_q != 5  &  nfi24 == 1 & (!is.na(wp19548_r) | !is.na(wp14888_r)) & acc24fin != 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin11F_ub = "Barrier: Do not trust financial institutions, of unbanked (age 15+)") %>%
  
  
  
  # MOBILE MONEY SECTION
  
  # NOTE: because we add a filter condition to our definition of Mobile money account ownership - fin12 and fin13 must be equal to 1, we have to add the
  # filtered condition wp19480_r_f == 1 to all of the questions about mobile money
  
  
  mutate(fin12_all = case_when(i24 == 1 & wp19479_r == 1 ~ 1,
                               i24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin12_all = "Used a mobile phone to keep or save money, make payments, buy things, or to send or receive money in the past 12 months (age 15+)") %>%
  
  mutate(fin13_all = case_when(m24 == 1 & wp19480_r == 1 ~ 1,
                               m24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin13_all = "Used mobile money in the past 12 months (age 15+)") %>%
  
  mutate(fin13_1a = case_when(ml24 == 1 & wp23980 == 1 & acc24mob == 1 ~ 1,
                              ml24 == 1 ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin13_1a = "Mobile money account meets all financial needs (age 15+)") %>%
  
  mutate(fin13_1a_mm = case_when(ml24 == 1 &  wp23980 == 1 & acc24mob_o == 1 ~ 1,
                                 ml24 == 1 & acc24mob_o == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13_1a_mm = "Mobile money account meets all financial needs (age 15+), of people who ONLY have a MM account") %>%
  
  mutate(fin13_1b = case_when(ml24 == 1 & wp23980 == 2 & acc24mob == 1 ~ 1,
                              ml24 == 1 ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin13_1b = "Mobile money account does not meet financial needs; would like to open bank account (age 15+)") %>%
  
  mutate(fin13_1b_mm = case_when(ml24 == 1 & wp23980 == 2 & acc24mob_o == 1 ~ 1,
                                 ml24 == 1 & acc24mob_o == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13_1b_mm = "Mobile money account does not meet financial needs; would like to open bank account (age 15+), of people who ONLY have a MM account") %>%
  
  mutate(fin13A_all_w = case_when(ml24 == 1 & wp23981 == 1 & acc24mob == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13A_all_w = "Money deposited into mobile money accounts in a typical month: Weekly (age 15+)") %>%
  
  mutate(fin13A_mm_w = case_when(ml24 == 1 & wp23981 == 1 & acc24mob == 1 ~ 1,
                                 ml24 == 1 & acc24mob == 1 ~ 0 ,
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13A_mm_w = "Money deposited into mobile money accounts in a typical month: Weekly, of MM users (age 15+)") %>%
  
  mutate(fin13A_all_m = case_when(ml24 == 1 & wp23981 == 2 & acc24mob == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13A_all_m = "Money deposited into mobile money accounts in a typical month: Monthly (age 15+)") %>%
  
  mutate(fin13A_mm_m = case_when(ml24 == 1 & wp23981 == 2 & acc24mob == 1 ~ 1,
                                 ml24 == 1 & acc24mob == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13A_mm_m = "Money deposited into mobile money accounts in a typical month: Monthly, of MM users (age 15+)") %>%
  
  mutate(fin13A_all_lm = case_when(ml24 == 1 & wp23981 == 3 & acc24mob == 1 ~ 1,
                                   ml24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin13A_all_lm = "Money deposited into mobile money accounts in a typical month: Less than once a month (age 15+)") %>%
  
  mutate(fin13A_mm_lm =  case_when(ml24 == 1 & wp23981 == 3 & acc24mob == 1 ~ 1,
                                   ml24 == 1 & acc24mob == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin13A_mm_lm = "Money deposited into mobile money accounts in a typical month: Less than once a month, of MM users (age 15+)") %>%
  
  mutate(fin13A_all_n = case_when(ml24 == 1 & wp23981 == 4 & wp19480_r_f == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13A_all_n = "Money deposited into mobile money accounts in a typical month: Never (age 15+)") %>%
  
  mutate(fin13A_mm_n =  case_when(ml24 == 1 & wp23981 == 4 & wp19480_r_f == 1 & acc24mob == 1 ~ 1,
                                  ml24 == 1 & acc24mob == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13A_mm_n = "Money deposited into mobile money accounts in a typical month: Never, of MM users (age 15+)") %>%
  
  mutate(fin13B_all_w = case_when(ml24 == 1 & wp23982 == 1 & wp19480_r_f == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13B_all_w = "Money sent from mobile money account in a typical month: Weekly (age 15+)") %>%
  
  mutate(fin13B_mm_w = case_when(ml24 == 1 & wp23982 == 1 & acc24mob == 1 ~ 1,
                                 ml24 == 1 & acc24mob == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13B_mm_w = "Money sent from mobile money account in a typical month: Weekly, of MM users (age 15+)") %>%
  
  mutate(fin13B_all_m = case_when(ml24 == 1 & wp23982 == 2 & acc24mob == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13B_all_m = "Money sent from mobile money account in a typical month: Monthly (age 15+)") %>%
  
  mutate(fin13B_mm_m = case_when(ml24 == 1 & wp23982 == 2 & acc24mob == 1 ~ 1,
                                 ml24 == 1 & acc24mob == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13B_mm_m = "Money sent from mobile money account in a typical month: Monthly, of MM users (age 15+)") %>%
  
  mutate(fin13B_all_lm = case_when(ml24 == 1 & wp23982 == 3 & acc24mob == 1 ~ 1,
                                   ml24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin13B_all_lm = "Money sent from mobile money account in a typical month: Less than once a month (age 15+)") %>%
  
  mutate(fin13B_mm_lm = case_when(ml24 == 1 & wp23982 == 3 & acc24mob == 1 ~ 1,
                                  ml24 == 1 & acc24mob == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13B_mm_lm = "Money sent from mobile money account in a typical month: Less than once a month (age 15+), of MM users") %>%
  
  mutate(fin13B_all_n = case_when(ml24 == 1 & wp23982 == 4 & acc24mob == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13B_all_n = "Money sent from mobile money account in a typical month: Never (age 15+)") %>%
  
  mutate(fin13B_mm_n = case_when(ml24 == 1 & wp23982 == 4 & acc24mob == 1 ~ 1,
                                 ml24 == 1 & acc24mob == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13B_mm_n = "Money sent from mobile money account in a typical month: Never (age 15+), of MM users") %>%
  
  mutate(fin13C_all_w = case_when(ml24 == 1 & wp23983 ==1 & acc24mob == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13C_all_w = "Money taken out of mobile money account in a typical month: Weekly (age 15+)") %>%
  
  mutate(fin13C_mm_w = case_when(ml24 == 1 & wp23983 == 1 & acc24mob == 1 ~ 1,
                                 ml24 == 1 & acc24mob == 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13C_mm_w = "Money taken out of mobile money account in a typical month: Weekly, of MM users (age 15+)") %>%
  
  mutate(fin13C_all_m = case_when(ml24 == 1 & wp23983 == 2 & acc24mob == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13C_all_m = "Money taken out of mobile money account in a typical month: Monthly (age 15+)") %>%
  
  mutate(fin13C_mm_m = case_when(ml24 == 1 & wp23983 == 2 & acc24mob == 1 ~ 1,
                                 ml24 == 1 & acc24mob == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13C_mm_m = "Money taken out of mobile money account in a typical month: Monthly, of MM users (age 15+)") %>%
  
  mutate(fin13C_all_lm = case_when(ml24 == 1 & wp23983 == 3 & acc24mob == 1 ~ 1,
                                   ml24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin13C_all_lm = "Money taken out of mobile money account in a typical month: Less than once a month (age 15+)") %>%
  
  mutate(fin13C_mm_lm = case_when(ml24 == 1 & wp23983 == 3 & acc24mob == 1 ~ 1,
                                  ml24 == 1 & acc24mob == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13C_mm_lm = "Money taken out of mobile money account in a typical month: Less than once a month, of MM users (age 15+)") %>%
  
  ##
  mutate(fin13C_all_n = case_when(ml24 == 1 & wp23983 == 4 & acc24mob == 1 ~ 1,
                                  ml24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin13C_all_n = "Money taken out of mobile money account in a typical month: Never (age 15+)") %>%
  
  mutate(fin13C_mm_n = case_when(ml24 == 1 & wp23983 == 4 & acc24mob == 1 ~ 1,
                                 ml24 == 1 & acc24mob == 1 ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin13C_mm_n = "Money taken out of mobile money account in a typical month: Never, of MM users (age 15+)") %>%
  
  mutate(fin13D = case_when(ml24 == 1  & wp23984 == 1 & acc24mob == 1 ~ 1, 
                            ml24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin13D = "Keep money in mobile money account (age 15+)") %>%
  
  mutate(fin13E = case_when(ml24 == 1 & wp23985 == 1 & acc24mob == 1 ~ 1, 
                            ml24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin13E = "Received messages or calls from unknown numbers asking for PIN or password to mobile money account (age 15+)") %>%
  
  mutate(fin13F = case_when(ml24 == 1 & wp23986 == 1 & acc24mob == 1 ~ 1,
                            ml24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin13F = "Sent money from mobile money account to the wrong number (age 15+)") %>%
  
  mutate(fin13F_1 = case_when(ml24 == 1 & wp23987 == 1 & acc24mob == 1 ~ 1,  
                              ml24 == 1 ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin13F_1 = "Got back money that was sent to the wrong number (age 15+)") %>%
  
  mutate(fin14A_all = case_when(ml24 == 1 & wp21418_r == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14A_all = "Barrier MM: Distance from mobile money agents (age 15+)") %>%
  
  mutate(fin14A_nmm = case_when(ml24 == 1 & wp21418_r == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 & acc24mob != 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14A_nmm = "Barrier MM: Distance from mobile money agents, of no MM users (age 15+)") %>%
  
  mutate(fin14A_ub = case_when(ml24 == 1 & wp21418_r == 1 & acc24any != 1 ~ 1, 
                                ml24 == 1 & acc24any != 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14A_ub = "Barrier MM: Distance from mobile money agents, of UNBANKED (age 15+)") %>%
  
  mutate(fin14B_all = case_when(ml24 == 1 & wp21419_r == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14B_all = "Barrier MM: Mobile money products too expensive (age 15+)") %>%
  
  mutate(fin14B_nmm = case_when(ml24 == 1 & wp21419_r == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 & acc24mob != 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin14B_nmm = "Barrier MM: Mobile money products too expensive, of no MM users (age 15+)") %>%
  
  mutate(fin14B_ub = case_when(ml24 == 1 & wp21419_r == 1 & acc24any != 1 ~ 1, 
                                ml24 == 1 & acc24any != 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(fin14B_ub = "Barrier MM: Mobile money products too expensive, of UNBANKED (age 15+)") %>%
  
  mutate(fin14C_all = case_when(ml24 == 1 & wp21420_r == 1 ~ 1, 
                                ml24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14C_all = "Barrier MM: Did not have the necessary documentation (age 15+)") %>%
  
  mutate(fin14C_nmm = case_when(ml24 == 1 & wp21420_r == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 & acc24mob != 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14C_nmm = "Barrier MM: Did not have the necessary documentation, of no MM users (age 15+)") %>%
  
  mutate(fin14C_ub = case_when(ml24 == 1 & wp21420_r == 1 & acc24any != 1 ~ 1, 
                                ml24 == 1 & acc24any != 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14C_ub = "Barrier MM: Did not have the necessary documentation, of UNBANKED (age 15+)") %>%
  
  mutate(fin14D_all = case_when(ml24 == 1 & wp21421_r == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14D_all = "Barrier MM: Did not have enough money to use a mobile money account (age 15+)") %>%
  
  mutate(fin14D_nmm = case_when(ml24 == 1 & wp21421_r == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 & acc24mob != 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14D_nmm = "Barrier MM: Did not have enough money to use a mobile money account, of no MM users (age 15+)") %>%
  
  mutate(fin14D_ub = case_when(ml24 == 1 & wp21421_r == 1 & acc24any != 1 ~ 1, 
                                ml24 == 1 & acc24any != 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14D_ub = "Barrier MM: Did not have enough money to use a mobile money account, of unbanked (age 15+)") %>%
  
  mutate(fin14E_all = case_when(ml24 == 1 & wp23988 == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14E_all = "Barrier MM: Worried about safety of money in account (age 15+)") %>%
  
  mutate(fin14E_nmm = case_when(ml24 == 1 & wp23988 == 1 & acc24mob != 1 ~ 1, 
                                ml24 == 1 & acc24mob != 1 ~ 0 ,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14E_nmm = "Barrier MM: Worried about safety of money in account, of no MM users") %>%
  
  mutate(fin14E_ub = case_when(ml24 == 1 & wp23988 == 1 & acc24any != 1 ~ 1, 
                                ml24 == 1 & acc24any != 1 ~ 0 ,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin14E_ub = "Barrier MM: Worried about safety of money in account, of no MM users") %>%
  
  mutate(fin15_all = case_when(ml24 == 1 & wp23989 == 1 ~ 1, 
                               ml24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin15_all = "Used an agent or asked someone to make a mobile money payment (age 15+)") %>%
  
  mutate(fin16_all = case_when(ml24 == 1 & wp23990 == 1 ~ 1, 
                               ml24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin16_all = "EVER had a mobile money account (currently answers no to mobile money) (age 15+)") %>%
  
  # Savings
  
  mutate(anysavings24 = case_when(dev24 == 1 & (wp15165_r == 1 | wp21375_r == 1 | wp19486_r == 1 | wp21374_r == 1 | wp14914_r == 1) ~ 1, 
                                  dev24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(anysavings24 = "Any Savings") %>%
  
  mutate(fin17A_all = case_when(dev24 == 1 & wp15165_r == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin17A_all = "Saved money in the past 12 months: Used an account at a bank or similar financial institution (age 15+)") %>%
  
  # about saving using MM - had to add MM identifier
  mutate(fin17B_all = case_when(dev24 == 1 & m24 == 1 & wp21375_r == 1 ~ 1, 
                                dev24 == 1 & m24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin17B_all = "Saved money in the past 12 months: Using mobile money account (age 15+)") %>%
  
  mutate(fin17C_all = case_when(dev24 == 1 & wp19486_r == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin17C_all = "Saved money in the past 12 months: Using informal savings group/club or someone outside family (age 15+)") %>%
  
  mutate(fin17D_all_w = case_when(dev24 == 1 & findex_q != 5 & wp23991 == 1 ~ 1, 
                                  dev24 == 1 & findex_q != 5 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin17D_all_w = "Frequency of saving: Weekly (age 15+)") %>%
  
  mutate(fin17D_sv_w =  case_when(dev24 == 1 & findex_q != 5 & wp23991 == 1 ~ 1, 
                                  dev24 == 1 & findex_q != 5  & (fin17A_all == 1 | fin17B_all == 1) ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin17D_sv_w = "Frequency of saving: Weekly, of formal saving population (age 15+)") %>%
  
  mutate(fin17D_all_m = case_when(dev24 == 1 & findex_q != 5 & wp23991 == 2 ~ 1, 
                                  dev24 == 1 & findex_q != 5  ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin17D_all_m = "Frequency of saving: Monthly (age 15+)") %>%
  
  mutate(fin17D_sv_m = case_when(dev24 == 1 & findex_q != 5 & wp23991 == 2 ~ 1, 
                                 dev24 == 1 & findex_q != 5  & (fin17A_all == 1 | fin17B_all == 1) ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin17D_sv_m = "Frequency of saving: Monthly, of saving population (age 15+)") %>%
  
  mutate(fin17D_all_lm = case_when(dev24 == 1 & findex_q != 5 & wp23991 == 3 ~ 1, 
                                   dev24 == 1 & findex_q != 5  ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin17D_all_lm = "Frequency of saving: Less than once a month (age 15+)") %>%  
  
  mutate(fin17D_sv_lm = case_when(dev24 == 1 & findex_q != 5 & wp23991 == 3 ~ 1, 
                                  dev24 == 1 & findex_q != 5  & (fin17A_all == 1 | fin17B_all == 1) ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin17D_sv_lm = "Frequency of saving: Less than once a month, of saving population (age 15+)") %>%
  
  ##
  mutate(fin17D_all_n = case_when(dev24 == 1 & findex_q != 5 & wp23991 == 4 ~ 1, 
                                   dev24 == 1 & findex_q != 5  ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin17D_all_n = "Frequency of saving: Never (age 15+)") %>%  
  
  mutate(fin17D_sv_n = case_when(dev24 == 1 & findex_q != 5 & wp23991 == 4 ~ 1, 
                                  dev24 == 1 & findex_q != 5  & (fin17A_all == 1 | fin17B_all == 1)  ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin17D_sv_n = "Frequency of saving: Never, of formal saving population (age 15+)") %>%
  
  mutate(fin17E_all = case_when(dev24 == 1 & wp23992 == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin17E_all = "Received interest or additional money for savings in account in the past 12 months (age 15+)") %>%
  
  mutate(fin17F_all = case_when(dev24 == 1 & wp21374_r == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin17F_all = "Saved or set aside money for old age in the past 12 months (age 15+)") %>%
  
  mutate(fin18_all = case_when(dev24 == 1 & wp14914_r == 1 ~ 1, 
                               dev24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin18_all = "Saved or set aside money for any reason in the past 12 months (age 15+)") %>%
  
  mutate(fin19_all = case_when(dev24 == 1 & wp23993 == 1 ~ 1, 
                               dev24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin19_all = "Made regular payments to insurance agent or company in the past 12 months (age 15+)") %>%
  
  mutate(fin19_ub = case_when(dev24 == 1 & wp23993 == 1 & acc24any != 1 ~ 1, 
                              dev24 == 1 ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin19_ub = "Made regular payments to insurance agent or company in the past 12 months and do not have an account (age 15+)") %>%
  
  # Borrowing
  
  mutate(any24borrowings = case_when(dev24 == 1 & (wp19489_r == 1 | wp23996 == 1 | wp19490_r == 1 | wp19491_r == 1 | wp19487_r == 1 | wp23997 == 1 | wp23998 == 1 | wp19476_r == 1 | wp21357_r == 1 | wp14924_r == 1) ~ 1, 
                                     dev24 == 1 ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(any24borrowings = "Any Borrowings") %>%
  
  mutate(fin20_all = case_when(dev24 == 1 & wp23994 == 1 ~ 1, 
                               dev24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin20_all = "Applied for a loan using a mobile phone in the past 12 months (age 15+)") %>%
  
  mutate(fin21_all = case_when(dev24 == 1 & wp23995 == 1 ~ 1, 
                               dev24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin21_all = "Received loan applied for using a mobile phone in the past 12 months (age 15+)") %>%
  
  mutate(fin22A_all = case_when(dev24 == 1 & wp19489_r == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin22A_all = "Borrowed in the past 12 months: bank or similar financial institution (age 15+)") %>%
  
  mutate(fin22A_1_all = case_when(dev24 == 1 & m24 == 1 & wp23996 == 1 ~ 1, 
                                  dev24 == 1 & m24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin22A_1_all = "Received loan from mobile money provider in the past 12 months (age 15+)") %>%
  
  mutate(fin22B_all = case_when(dev24 == 1 & wp19490_r == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin22B_all = "Received loan from family, relatives, or friends in the past 12 months (age 15+)") %>%
  
  mutate(fin22C_all = case_when(dev24 == 1 & wp19491_r == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin22C_all = "Received loan from an informal savings group/club in the past 12 months (age 15+)")  %>%
  
  mutate(fin22D_all = case_when(dev24 == 1 & wp19487_r == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin22D_all = "Borrowed money for health or medical purposes in the past 12 months (age 15+)") %>%
  
  mutate(fin22E_all = case_when(dev24 == 1 & wp23997 == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin22E_all = "Borrowed money to start or operate a business in the past 12 months (age 15+)") %>%
  
  mutate(fin22F_all = case_when(dev24 == 1 & wp23998 == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin22F_all = "Bought household food but paid at a later date in the past 12 months (age 15+)") %>%
  
  mutate(fin22G_all = case_when(dev24 == 1 & wp19476_r == 1 ~ 1,   
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin22G_all = "Used credit card in past 12 months (age 15+)") %>%
  
  mutate(fin22H_all = case_when(dev24 == 1 & wp21357_r == 1 ~ 1, 
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin22H_all = "Paid off all credit card balances in full by due date in the past 12 months (age 15+)") %>%
  
  mutate(fin23_all = case_when(dev24 == 1 & wp14924_r == 1 ~ 1, 
                               dev24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin23_all = "Borrowed money from any source for any reason in the past 12 months (age 15+)")  %>%
  
  # Financial resilience
  mutate(fin24_savings = case_when(dev24 == 1 & wp21376_r == 1 ~ 1,
                                   dev24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin24_savings = "Main source of money in case of emergency: Savings (age 15+)") %>%
  
  mutate(fin24_family = case_when(dev24 == 1  & wp21376_r == 2 ~ 1,
                                  dev24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin24_family = "Main source of money in case of emergency: Family, relatives or friends (age 15+)") %>%
  
  mutate(fin24_working = case_when(dev24 == 1 & wp21376_r == 3 ~ 1,
                                   dev24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin24_working = "Main source of money in case of emergency: Money from working (age 15+)") %>%
  
  mutate(fin24_loan = case_when(dev24 == 1 & wp21376_r == 4 ~ 1,
                                dev24 == 1 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin24_loan = "Main source of money in case of emergency: A loan from a financial institution, an employer or private lender (age 15+)") %>%
  
  mutate(fin24_selling = case_when(dev24 == 1 & wp21376_r == 5 ~ 1,
                                   dev24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin24_selling = "Main source of money in case of emergency: Selling something of own such as jewellery or livestock (age 15+)") %>%
  
  mutate(fin24_other = case_when(dev24 == 1 & wp21376_r == 6 ~ 1,
                                 dev24 == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin24_other = "Main source of money in case of emergency: Some other source (age 15+)") %>%
  
  mutate(fin24_nomoney = case_when(dev24 == 1 & wp21376_r == 7 ~ 1,
                                   dev24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin24_nomoney = "Main source of money in case of emergency: I could not come up with the money (age 15+)") %>%
  
  mutate(fin24A_VD = case_when(dev24 == 1 & wp21377_r == 1 ~ 1,
                               dev24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin24A_VD = "Very difficult coming up with emergency money (age 15+)") %>%
  
  mutate(fin24A_SD = case_when(dev24 == 1 & wp21377_r == 2 ~ 1,
                               dev24 == 1 ~ 0 , 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin24A_SD = "Somewhat difficult coming up with emergency money (age 15+)") %>%
  
  mutate(fin24A_notdifficult = case_when(dev24 == 1 & wp21377_r == 3 ~ 1,
                                         dev24 == 1 ~ 0 , 
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin24A_notdifficult = "Not difficult at all coming up with emergency money (age 15+)") %>%
  
  mutate(fin24B_less2weeks = case_when(dev24 == 1 & wp23999 == 1 ~ 1,
                                       dev24 == 1 ~ 0 , 
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin24B_less2weeks = "Less than two weeks can be covered using savings, borrowing, selling something, seeking help from friends and family, or other ways, in case household loses its main source of income (age 15+)") %>%
  
  mutate(fin24B_about1month = case_when(dev24 == 1 & wp23999 == 2 ~ 1,
                                        dev24 == 1 ~ 0 , 
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about1month = "About one month can be covered using savings, borrowing, selling something, seeking help from friends and family, or other ways, in case household loses its main source of income (age 15+)") %>%
  
  mutate(fin24B_about2month = case_when(dev24 == 1 & wp23999 == 3 ~ 1,
                                        dev24 == 1 ~ 0 , 
                                        TRUE ~ NA)) %>%
  set_variable_labels(fin24B_about2month = "About two months can be covered using savings, borrowing, selling something, seeking help from friends and family, or other ways, in case household loses its main source of income (age 15+)") %>%
  
  mutate(fin24B_more2month = case_when(dev24 == 1 & wp23999 == 4 ~ 1,
                                       dev24 == 1 ~ 0 , 
                                       TRUE ~ NA)) %>%
  set_variable_labels(fin24B_more2month = "More than two months can be covered using savings, borrowing, selling something, seeking help from friends and family, or other ways, in case household loses its main source of income (age 15+)") %>%
  
  mutate(fin24C = case_when(dev24 == 1 & wp24000 == 1 ~ 1, 
                            dev24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin24C = "Experienced a natural disaster or severe weather event in the past three years (age 15+)") %>%
  
  mutate(fin24D_1 = case_when(dev24 == 1 & wp24001 == 1 ~ 1, 
                              dev24 == 1 ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin24D_1 = "Natural disaster in the past three years: Income lost or unable to work, by self or household member (age 15+)") %>%
  
  mutate(fin24D_2 = case_when(dev24 == 1 & wp24002 == 1 ~ 1, 
                              dev24 == 1 ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin24D_2 = "Natural disaster in the past three years: Damage to home or livestock (age 15+)") %>%
  
  mutate(fin24D_3 = case_when(dev24 == 1 & wp24003 == 1 ~ 1, 
                              dev24 == 1 ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin24D_3 = "Natural disaster in the past three years: Unable to access or use account to withdraw cash or to send or receive money (age 15+)") %>%
  
  mutate(fin25E_1 = case_when(dev24 == 1 & findex_q != 5 & wp24004 == 1 ~ 1, 
                              dev24 == 1 & findex_q != 5  ~ 0, 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin25E_1 = "Used mobile phone or card to pay for household food or cleaning supplies (age 15+)") %>%
  
  mutate(fin25E_2 = case_when(dev24 == 1 & wp24005 == 1 ~ 1, 
                              dev24 == 1 & countrynewwb != "Russian Federation" ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin25E_2 = "Used mobile phone or card to pay for in-store purchase in the past 12 months (age 15+)")  %>%
  
  mutate(fin25E_2cash = case_when(dev24 == 1 & wp24005 %in% c(2,3,4) ~ 1, 
                              dev24 == 1 & countrynewwb != "Russian Federation" ~ 0 , 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin25E_2cash = "Did NOT use mobile phone or card to pay for in-store purchase in the past 12 months (cash only) (age 15+)")  %>%
  
  mutate(fin25E_1only = case_when(dev24 == 1 & findex_q != 5  & fin25E_1 == 1 & fin25E_2 != 1 ~ 1, 
                              dev24 == 1 & findex_q != 5  ~ 0, 
                              TRUE ~ NA)) %>%
  set_variable_labels(fin25E_1only = "Used mobile phone or card to pay for household food or cleaning supplies and NO other in-store purchases (age 15+)") %>%
  
  
  mutate(fin25E_3_w = case_when(dev24 == 1 & wp24006 == 1 ~ 1,
                                dev24 == 1 & countrynewwb != "Russian Federation" ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin25E_3_w = "Frequency of use of mobile phone to pay for in-store purchases in a typical month: Weekly (age 15+)") %>%
  
  mutate(fin25E_3_m = case_when(dev24 == 1 & wp24006 == 2 ~ 1,
                                dev24 == 1 & countrynewwb != "Russian Federation"  ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin25E_3_m = "Frequency of use of mobile phone to pay for in-store purchases in a typical month: Monthly (age 15+)") %>%
  
  mutate(fin25E_3_lm = case_when(dev24 == 1 & wp24006 == 3 ~ 1,
                                 dev24 == 1 & countrynewwb != "Russian Federation" ~ 0, 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin25E_3_lm = "Frequency of use of mobile phone to pay for in-store purchases in a typical month: Less than once a month (age 15+)") %>%
  
  mutate(fin25E_3_n = case_when(dev24 == 1 & !wp24006 %in% c(1,2,3) ~ 1,
                                dev24 == 1 & countrynewwb != "Russian Federation"  ~ 0, 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin25E_3_n = "Frequency of use of mobile phone to pay for in-store purchases in a typical month: Never (age 15+)") %>%
  
  mutate(fin25E_4_cash = case_when(dev24 == 1 & findex_q != 5 & wp24007 == 1 ~ 1,
                                   dev24 == 1 & findex_q != 5  ~ 0, 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin25E_4_cash = "Reason for cash payment for in-store purchases in the past 12 months: merchant only accepts cash (age 15+)") %>%
  
  mutate(fin25E_4_exp = case_when(dev24 == 1 & findex_q != 5 & wp24007 == 2 ~ 1,
                                  dev24 == 1 & findex_q != 5  ~ 0, 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin25E_4_exp = "Reason for cash payment for in-store purchases in the past 12 months: More expensive to pay using a card or phone (age 15+)") %>%
  
  mutate(fin25E_4_notrust = case_when(dev24 == 1 & findex_q != 5 & wp24007 == 3 ~ 1,
                                      dev24 == 1 & findex_q != 5 ~ 0 , 
                                      TRUE ~ NA)) %>%
  set_variable_labels(fin25E_4_notrust = "Reason for cash payment for in-store purchases in the past 12 months: don't trust payments using a card or a phone (age 15+)") %>%
  
  mutate(fin25E_4_usedtocash = case_when(dev24 == 1 & findex_q != 5 & wp24007 == 4 ~ 1,
                                         dev24 == 1 & findex_q != 5 ~ 0, 
                                         TRUE ~ NA)) %>%
  set_variable_labels(fin25E_4_usedtocash = "Reason for cash payment for in-store purchases in the past 12 months: used to paying it with cash (age 15+)") %>%
  
  mutate(fin25E_4_other = case_when(dev24 == 1 & findex_q != 5 & wp24007 == 5 ~ 1,
                                    dev24 == 1 & findex_q != 5 ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin25E_4_other = "Reason for cash payment for in-store purchases in the past 12 months: other (age 15+)") %>%
  
  mutate(fin26A = case_when(dev24 == 1 & wp21369_r == 1 ~ 1, 
                            dev24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin26A = "Used a mobile phone or computer to make a bill payment in the past 12 months (age 15+)") %>%
  
  mutate(fin26B = case_when(dev24 == 1 & wp21370_r == 1 ~ 1, 
                            dev24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin26B = "Used a mobile phone or computer to buy something online that got delivered in the past 12 months (age 15+)") %>%
  
  mutate(fin27a = case_when(dev24 == 1 & wp21371_r == 1 ~ 1, 
                            dev24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin27a = "Paid online when order is delivered (age 15+)") %>%
  
  mutate(fin27b = case_when(dev24 == 1 & wp21371_r == 2 ~ 1, 
                            dev24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin27b = "Paid in cash when order is delivered (age 15+)") %>%
  
  mutate(fin27c = case_when(dev24 == 1 & wp21371_r == 3 ~ 1, 
                            dev24 == 1 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin27c = "Paid both in cash and online when order is delivered (age 15+)") %>%
  
  mutate(fh1 = case_when(dev24 == 1 & findex_q != 5 & wp19494_r == 1 ~ 1, 
                         dev24 == 1 & findex_q != 5  ~ 0 , 
                         TRUE ~ NA)) %>%
  set_variable_labels(fh1 = "Sent money to relatives or friends living in a different city inside in the past 12 months (age 15+)") %>%
  
  mutate(fin28 = case_when(dev24 == 1 & findex_q != 5 & wp21379_r == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5 ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin28 = "Sent money to relatives or friends living in a different city directly from an account or phone in the past 12 months (age 15+)") %>%
  
  mutate(fh2 = case_when(dev24 == 1 & findex_q != 5 & wp24018 == 1 ~ 1, 
                         dev24 == 1 & findex_q != 5 ~ 0 , 
                         TRUE ~ NA)) %>%
  set_variable_labels(fh2 = "Received money from relatives or friends living in a different city in the past 12 months (age 15+)") %>%
  
  mutate(fin29 = case_when(dev24 == 1 & findex_q != 5 & wp21381_r == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5  ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin29 = "Received money from relatives or friends living in a different city directly into an account or phone in the past 12 months (age 15+)")  %>%
  
  mutate(fh2a = case_when(dev24 == 1 & findex_q != 5 & wp24008 == 1 ~ 1, 
                          dev24 == 1 & findex_q != 5  ~ 0, 
                          TRUE ~ NA)) %>%
  set_variable_labels(fh2a = "Received money from relatives or friends living in a different country (age 15+)")  %>%
  
  # Utility Bills
  
  mutate(fin_util_dig = case_when(dev24 == 1 & findex_q != 5  & (wp19504_r == 1 | wp19505 == 1) ~ 1, 
                                  dev24 == 1 & findex_q != 5  ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin_util_dig = "Digital utility bill payment (FIN31A+31B)") %>%
  
  mutate(fin30 = case_when(dev24 == 1 & findex_q != 5 & wp14940 == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5 ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin30 = "Made regular payments for electricity, water, or trash collection in the past 12 months (age 15+)") %>%
  
  mutate(fin31A = case_when(dev24 == 1 & findex_q != 5 & wp19504_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin31A = "Utility bill payments: Used an account at a bank or similar financial institution (age 15+)") %>%
  
  mutate(fin31B = case_when(dev24 == 1 & findex_q != 5 & wp19505 == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin31B = "Utility bill payments: Used a mobile phone to make a payment (age 15+)") %>%
  
  mutate(fin31C = case_when(dev24 == 1 & findex_q != 5 & wp24009 == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin31C = "Utility bill payments: by handing cash to bank staff or an agent (age 15+)") %>%
  
  mutate(fin31D = case_when(dev24 == 1 & findex_q != 5 & wp24010 == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin31D = "Utility bill payments: Used cash (age 15+)")  %>%
  
  # Wages
  
  mutate(wagepayment24 = case_when(dev24 == 1 & findex_q != 5  & (wp19508_r == 1 | wp19509_r == 1 | wp21385_r == 1) ~ 1, 
                                   dev24 == 1 & findex_q != 5  ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(wagepayment24 = "Wage payment") %>%
  
  mutate(fin32 = case_when(dev24 == 1 & findex_q != 5 & wp19507_r == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5 ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin32 = "Received salary or wages from an employer in the past 12 months (age 15+)") %>%
  
  mutate(fin33 = case_when(dev24 == 1 & findex_q != 5 & wp14945_r == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5 ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin33 = "Employed by the government, military, or public sector in the past 12 months (age 15+)") %>%
  
  mutate(fin34A = case_when(dev24 == 1 & findex_q != 5 & wp19508_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin34A = "Wage payments: directly into an account at a bank or a financial institution (age 15+)") %>%
  
  mutate(fin34B = case_when(dev24 == 1 & findex_q != 5 & wp19509_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin34B = "Wage payments: through a mobile phone (age 15+)") %>%
  
  mutate(fin34C = case_when(dev24 == 1 & findex_q != 5 & wp21384_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin34C = "Wage payments: in cash (age 15+)") %>%
  
  mutate(fin34D = case_when( dev24 == 1 & findex_q != 5 & wp21385_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin34D = "Wage payments: into a card (age 15+)") %>%
  
  mutate(fin35 = case_when(dev24 == 1 & findex_q != 5 & wp24011 == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5  ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin35 = "Wage payments: Paid a fee that was more than expected after taking out salary or wage from account (age 15+)")  %>%
  
  mutate(fin36_cash = case_when(dev24 == 1 & findex_q != 5 & wp24012 == 1 ~ 1,
                                dev24 == 1 & findex_q != 5  ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin36_cash = "Wage payments: Take all money out of account (age 15+)") %>%
  
  mutate(fin36_account = case_when(dev24 == 1 & findex_q != 5 & wp24012 == 2 ~ 1,
                                   dev24 == 1 & findex_q != 5  ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin36_account = "Wage payments: Leave money from wages in the account (age 15+)") %>%
  
  mutate(fin36_transfer = case_when(dev24 == 1 & findex_q != 5 & wp24012 == 3 ~ 1,
                                    dev24 == 1 & findex_q != 5  ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin36_transfer = "Wage payments: Transfer money into another personal account (age 15+)") %>%
  
  # # # FIN36A is only asked in Bangladesh
  # # mutate(fin36A_self = case_when(countrynewwb == "Bangladesh" & wp24013 %in% c(1,3) ~ 1,
  # #                                countrynewwb == "Bangladesh" ~ 0 , 
  # #                                TRUE ~ NA)) %>%
  # # set_variable_labels(fin36A_self = "Wage payments: Took money out of account yourself (includes people who say both) (age 15+)") %>%
  # 
  # mutate(fin36A_fam_o = case_when(countrynewwb == "Bangladesh" & wp24013 %in% c(2) ~ 1,
  #                               countrynewwb == "Bangladesh" ~ 0, 
  #                               TRUE ~ NA)) %>%
  # set_variable_labels(fin36A_fam_o = "Wage payments: A friend or family member take money out for you, only (age 15+)") %>%
  # 
  # mutate(fin36A_both = case_when(countrynewwb == "Bangladesh" & wp24013 %in% c(3) ~ 1,
  #                                countrynewwb == "Bangladesh" ~ 0, 
  #                                TRUE ~ NA)) %>%
  # set_variable_labels(fin36A_both = "Wage payments: Yourself & Family and friends take out money (age 15+)") %>%

# Government payments (any)
mutate(governmentpayment24 = case_when(dev24 == 1 & findex_q != 5 & (wp19516_r == 1 | wp19517_r == 1 | wp21389_r == 1) ~ 1,
                                       dev24 == 1 & findex_q != 5 ~ 0 , 
                                       TRUE ~ NA)) %>%
  set_variable_labels(governmentpayment24 = "Received government payment digitally (FIN39A+39B+39D)") %>%
  
  mutate(fin37 = case_when(dev24 == 1 & findex_q != 5 & wp21386 == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5  ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin37 = "Received financial support from the government in the form of payments for educational or medical expenses, unemployment benefits or subsidy payments in the past 12 months (age 15+)") %>%
  
  mutate(fin38 = case_when(dev24 == 1 & findex_q != 5 & wp19515 == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5  ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin38 = "Received a pension from the government, military, or public sector in the past 12 months (age 15+)") %>%
  
  mutate(fin39A = case_when(dev24 == 1 & findex_q != 5 & wp19516_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin39A = "Government payments: Directly into an account at a bank or a similar financial institution (age 15+)") %>%
  
  mutate(fin39B = case_when(dev24 == 1 & findex_q != 5 & wp19517_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin39B = "Government payments: through a mobile phone (age 15+)") %>%
  
  mutate(fin39C = case_when(dev24 == 1 & findex_q != 5 & wp21388_r == 1 ~ 1,   
                            dev24 == 1 & findex_q != 5 ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin39C = "Government payments: in cash (age 15+)") %>%
  
  mutate(fin39D = case_when(dev24 == 1 & findex_q != 5 & wp21389_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin39D = "Government payments: into a card (age 15+)") %>%
  
  mutate(fin40_cash = case_when(dev24 == 1 & findex_q != 5 & wp24014 == 1 ~ 1,
                                dev24 == 1 & findex_q != 5 ~ 0 , 
                                TRUE ~ NA)) %>%
  set_variable_labels(fin40_cash = "Government payments: take out all cash at once (age 15+)") %>%
  
  mutate(fin40_account = case_when(dev24 == 1 & findex_q != 5 & wp24014 == 2 ~ 1,
                                   dev24 == 1 & findex_q != 5 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin40_account = "Government payments: leave some money in your account (age 15+)") %>%
  
  mutate(fin40_transfer = case_when(dev24 == 1 & findex_q != 5 & wp24014 == 3 ~ 1,
                                    dev24 == 1 & findex_q != 5  ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin40_transfer = "Government payments: Transfer money to another personal account (age 15+)") %>%
  
  mutate(fin41 = case_when(dev24 == 1 & findex_q != 5 & wp24015 == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5  ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin41 = "Government payments: Paid a fee that was more than expected while withdrawing or taking money out of your account (age 15+)") %>%
  
  # FIN 41A is asked in South Asia only!!
  mutate(fin41A_self = case_when(regionwb24_hi == "South Asia (excluding high income)" & wp24016 %in% c(1,3) ~ 1,
                                 regionwb24_hi == "South Asia (excluding high income)"  ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin41A_self = "Government payments: Took money out of account yourself (includes people who say both) (age 15+)") %>%
  
  mutate(fin41A_fam_o = case_when(regionwb24_hi == "South Asia (excluding high income)" & wp24016 %in% c(2) ~ 1,
                                regionwb24_hi == "South Asia (excluding high income)"  ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin41A_fam_o = "Government payments: A friend or family member take money out for you, ONLY (age 15+)") %>%
  
  mutate(fin41A_both = case_when(regionwb24_hi == "South Asia (excluding high income)" & wp24016 %in% c(3) ~ 1,
                               regionwb24_hi == "South Asia (excluding high income)" ~ 0, 
                               TRUE ~ NA)) %>%
  set_variable_labels(fin41A_both = "Government payments: Both - You and a friend or family member takes money out for you (age 15+)") %>%

# Agricultural payments
mutate(agri24payment = case_when(dev24 == 1 & findex_q != 5   & (wp19523_r == 1 | wp19524 == 1 | wp21393_r == 1) ~ 1,
                                 dev24 == 1 & findex_q != 5  ~ 0 , TRUE ~ NA)) %>%
  set_variable_labels(agri24payment = "Received agricultural payment digitally (FIN43A+43B+43D)") %>%
  
  mutate(fin42 = case_when(dev24 == 1 & findex_q != 5 & wp19522 == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5  ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin42 = "Received money from any source for the sale of agricultural products, crops, produce or livestock in the past 12 months (age 15+)") %>%
  
  mutate(fin43A = case_when(dev24 == 1 & findex_q != 5 & wp19523_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin43A = "Agricultural payments: directly into an account at a bank or a similar financial institution (age 15+)") %>%
  
  mutate(fin43B = case_when(dev24 == 1 & findex_q != 5 & wp19524 == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin43B = "Agricultural payments: through a mobile phone (age 15+)") %>%
  
  mutate(fin43C = case_when(dev24 == 1 & findex_q != 5 & wp21392_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin43C = "Agricultural payments: in cash (age 15+)") %>%
  
  mutate(fin43D = case_when(dev24 == 1 & findex_q != 5 & wp21393_r == 1 ~ 1, 
                            dev24 == 1 & findex_q != 5  ~ 0 , 
                            TRUE ~ NA)) %>%
  set_variable_labels(fin43D = "Agricultural payments: into a card (age 15+)") %>%
  
  mutate(fin44 = case_when(dev24 == 1 & findex_q != 5 & wp24017 == 1 ~ 1, 
                           dev24 == 1 & findex_q != 5  ~ 0 , 
                           TRUE ~ NA)) %>%
  set_variable_labels(fin44 = "Use a phone or the Internet to access information such as weather updates, pest control, or farming tips (age 15+)") %>%
  
  # Financial worry
  mutate(fin45_oldage = case_when(dev24 == 1 & wp21398_r == 1 ~ 1,
                                  dev24 == 1 ~ 0 , 
                                  TRUE ~ NA)) %>%
  set_variable_labels(fin45_oldage = "Most worried about not having enough money for old age (age 15+)") %>%
  
  mutate(fin45_business = case_when(dev24 == 1 & wp21398_r == 2 ~ 1,
                                    dev24 == 1 ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin45_business = "Most worried about not having enough money for own business (age 15+)") %>%
  
  mutate(fin45_medical = case_when(dev24 == 1 & wp21398_r == 3 ~ 1,
                                   dev24 == 1 ~ 0 , 
                                   TRUE ~ NA)) %>%
  set_variable_labels(fin45_medical = "Most worried about not having enough money for medical costs in case of a serious illness or accident (age 15+)") %>%
  
  mutate(fin45_expenses = case_when(dev24 == 1 & wp21398_r == 4 ~ 1,
                                    dev24 == 1 ~ 0 , 
                                    TRUE ~ NA)) %>%
  set_variable_labels(fin45_expenses = "Most worried about not having enough money for Monthly expenses, such as food, housing, or bills (age 15+)") %>%
  
  mutate(fin45_education = case_when(dev24 == 1 & wp21398_r == 5 ~ 1,
                                     dev24 == 1 ~ 0 , 
                                     TRUE ~ NA)) %>%
  set_variable_labels(fin45_education = "Most worried about not having enough money for school or education fees (age 15+)") %>%
  
  mutate(fin45_other = case_when(dev24 == 1 & wp21398_r == 6 ~ 1,
                                 dev24 == 1 ~ 0 , 
                                 TRUE ~ NA)) %>%
  set_variable_labels(fin45_other = "Most worried about not having enough money for: some other reason (age 15+)") 
  