
# ID Questionnaire Code 
library(dplyr)
library(labelled)

# .	c2id24 - "complete mobile money and asked about having two IDs" (fin46_1, fin47_1, fin48_1 series, fin19_1 series)
# .	NOTE: fin47A is only for Rwanda, Georgia, Israel, Lithuania, and Spain


dataframe_2024 <- dataframe_2024 %>%

  # ID related variables
  mutate(fin46_all = case_when(id24 == 1 & wp21399_r == 1 ~ 1,
                               id24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(fin46_all = "Have ID (age 15+)") %>%
  
  mutate(fin46_1_all = case_when(id24 == 1 & wp21399_r_1 == 1 ~ 1,
                               id24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(fin46_all = "Have SECONDARY ID (age 15+)") %>%
  
  
  mutate(fin47_all = case_when(cid24 == 1 & wp23971 == 1 ~ 1, #& fin46_all == 1 
                               cid24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(fin47_all = "ID information ever used without permission (age 15+)") %>%
  
  mutate(fin47_ID = case_when(cid24 == 1 & wp23971 == 1 & fin46_all == 1 ~ 1,
                              cid24 == 1 & fin46_all == 1 ~ 0,
                              TRUE ~ NA)) %>%
  set_variable_labels(fin47_ID = "ID information ever used without permission, of ID owners (age 15+)") %>%
  
  mutate(fin47A_all = case_when(id24 == 1 & countrynewwb %in% c("Spain", "Rwanda", "Georgia", "Israel", "Lithuania") & wp24080 == 1 ~ 1,
                                id24 == 1 & countrynewwb %in% c("Spain", "Rwanda", "Georgia", "Israel", "Lithuania") ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin47A_all = "Used ID online (age 15+)") %>%
  
  mutate(fin47_A_ID = case_when(id24 == 1 & countrynewwb %in% c("Spain", "Rwanda", "Georgia", "Israel", "Lithuania") & wp24080 == 1 & fin46_all == 1 ~ 1,
                                id24 == 1 & countrynewwb %in% c("Spain", "Rwanda", "Georgia", "Israel", "Lithuania") & fin46_all == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin47_A_ID = "Used ID online, of ID owners (age 15+)") %>%
  
  # Barrier to ID variables
  mutate(fin48A_all = case_when(cid24 == 1 & wp21401_r == 1 ~ 1, #  & fin46_all != 1
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48A_all = "Barrier to ID: another ID (age 15+)") %>%
  
  mutate(fin48A_nID = case_when(cid24 == 1 & wp21401_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48A_nID = "Barrier to ID: another ID, of no ID (age 15+)") %>%
  
  mutate(fin48B_all = case_when(cid24 == 1 & wp21402_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48B_all = "Barrier to ID: don't need (age 15+)") %>%
  
  mutate(fin48B_nID = case_when(cid24 == 1 & fin46_all != 1 & wp21402_r == 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48B_nID = "Barrier to ID: don't need, of no ID (age 15+)") %>%
  
  mutate(fin48C_all = case_when(cid24 == 1 & wp21403_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1  ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48C_all = "Barrier to ID: too expensive (age 15+)") %>%
  
  mutate(fin48C_nID = case_when(cid24 == 1 & wp21403_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48C_nID = "Barrier to ID: too expensive, of no ID (age 15+)") %>%
  
  mutate(fin48D_all = case_when(cid24 == 1 & wp21404_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48D_all = "Barrier to ID: no documents (age 15+)") %>%
  
  mutate(fin48D_nID = case_when(cid24 == 1 & wp21404_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48D_nID = "Barrier to ID: no documents, of no ID (age 15+)") %>%
  
  mutate(fin48E_all = case_when(cid24 == 1 & wp21405_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48E_all = "Barrier to ID: too far to apply (age 15+)") %>%
  
  mutate(fin48E_nID = case_when(cid24 == 1 & wp21405_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48E_nID = "Barrier to ID: too far to apply, of no ID (age 15+)") %>%
  
  mutate(fin48F_all = case_when(cid24 == 1 & wp21406_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48F_all = "Barrier to ID: uncomfortable giving info (age 15+)") %>%
  
  mutate(fin48F_nID = case_when(cid24 == 1 & wp21406_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 &  fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin48F_nID = "Barrier to ID: uncomfortable giving info, of no ID (age 15+)") %>%
  
  # Difficulty due to no ID variables
  mutate(fin49A_all = case_when(cid24 == 1 & wp21408_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49A_all = "Difficulty no ID: receiving support (age 15+)") %>%
  
  mutate(fin49A_nID = case_when(cid24 == 1 & wp21408_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 &  fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49A_nID = "Difficulty no ID: receiving support, of no ID (age 15+)") %>%
  
  mutate(fin49B_all = case_when(cid24 == 1 & wp21409_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49B_all = "Difficulty no ID: using financial services (age 15+)") %>%
  
  mutate(fin49B_nID = case_when(cid24 == 1 & wp21409_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49B_nID = "Difficulty no ID: using financial services, of no ID (age 15+)") %>%
  
  mutate(fin49C_all = case_when(cid24 == 1 & wp21410_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49C_all = "Difficulty no ID: obtaining SIM (age 15+)") %>%
  
  mutate(fin49C_nID = case_when(cid24 == 1 & wp21410_r == 1 & fin46_all  != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49C_nID = "Difficulty no ID: obtaining SIM, of no ID (age 15+)") %>%
  
  mutate(fin49D_all = case_when(cid24 == 1 & wp21411_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49D_all = "Difficulty no ID: participating in elections (age 15+)") %>%
  
  mutate(fin49D_nID = case_when(cid24 == 1 & wp21411_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49D_nID = "Difficulty no ID: participating in elections, of no ID (age 15+)") %>%
  
  mutate(fin49E_all = case_when(cid24 == 1 & wp21412_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49E_all = "Difficulty no ID: applying for a job (age 15+)") %>%
  
  mutate(fin49E_nID = case_when(cid24 == 1 & wp21412_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49E_nID = "Difficulty no ID: applying for a job, of no ID (age 15+)") %>%
  
  # Difficulty due to no ID variables continued
  mutate(fin49F_all = case_when(cid24 == 1 & wp21413_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49F_all = "Difficulty no ID: receiving medical care (age 15+)") %>%
  
  mutate(fin49F_nID = case_when(cid24 == 1 & wp21413_r == 1 & fin46_all != 1 ~ 1,
                                cid24 == 1 & fin46_all != 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin49F_nID = "Difficulty no ID: receiving medical care, of no ID (age 15+)") %>%
  
  # Digital ID variables
  mutate(fin50_all = case_when(did24 == 1 & wp23972 == 1 ~ 1,
                               did24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(fin50_all = "Have a digital ID (age 15+)") %>%
  
  
  mutate(fin51_all =  case_when(did24 == 1 & wp24081 == 1 & !is.na(did24) ~ 1,
                                did24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(fin51_all = "Used digital ID online (age 15+)") %>%
  
  mutate(fin51_DID = case_when(did24 == 1 & wp24081 == 1 & fin50_all == 1 & !is.na(did24) ~ 1,
                               did24 == 1 & fin50_all == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(fin51_DID = "Used digital ID online, of ID owners (age 15+)")
