

# Read FINDEX Module Mapping dataset - this dataset shows which countries were asked which questionnaire - taken from Gallup
df <- read_xlsx(file.path(folder_data, "Findex Module Mapping 2024.xlsx"),  sheet = 1) %>%
  transmute(Country, Mode, Findex = `Financial Inclusion/FINDEX (World Bank)`, 
            ID = `ID (World Bank)`, 
            Connectivity = `Connectivity (World Bank)`)


# NOTE: for all indicators, a printed list of all countries in the list is written but commented out - if we start to make
# exculsions, you can alter the written out list - just make a note of it

################################################################## 
# Switch Gallop name to WB official Country name 
# this prevents merging issues that are caused by different country spellings
# if you ever have merge issues, check these countries because they are the main culprits
################################################################## 

df$Country <- sub("_.*", "", df$Country)

# define country names switch from Gallop name to WB official country name
conversion_rules_all <- c(
  "Egypt" = "Egypt, Arab Rep.",
  "Gambia" = "Gambia, The",
  "Eswatini (Swaziland)"="Eswatini",
  "Congo, Democratic Republic of the" = "Congo, Dem. Rep.",
  "Congo-Brazzaville" = "Congo, Rep.",
  "Cote d'Ivoire (Ivory Coast)" = "Cote d'Ivoire",
  "Czech Republic" = "Czechia",
  "Hong Kong" = "Hong Kong SAR, China",
  "Iran" = "Iran, Islamic Rep.",
  "Kyrgyzstan" =  "Kyrgyz Republic",
  "Laos" = "Lao PDR",
  "Moldova, Republic of" = "Moldova",
  "Northern Cyprus" = "North Cyprus",
  "Palestine" = "West Bank and Gaza",
  "Turkey" = "Turkiye",
  "Russia" = "Russian Federation",
  "Saudi Arabia (KSA)" = "Saudi Arabia",
  "Slovakia" = "Slovak Republic",
  "South Korea" = "Korea, Rep.",
  "United Arab Emirates (UAE)" = "United Arab Emirates",
  "Venezuela" = "Venezuela, RB",
  "Vietnam" = "Viet Nam"
)

# create data frame with the countries that we needed to change the spellings for
conversion_df <- data.frame(
  Country = names(conversion_rules_all),
  Official_Name = conversion_rules_all,
  stringsAsFactors = FALSE
)

# Merge with the conversion rules to replace country names
df <- df %>%
  left_join(conversion_df, by = "Country") %>%
  mutate(Country = coalesce(Official_Name, Country)) %>%  # Replace Country with Official_Name where available
  select(-Official_Name)  # Drop the temporary Official_Name column

################################################################## 
# ALL FINDEX
################################################################## 

i24_countrylist <- df$Country

## All country list i24
# countrylist <- c("Afghanistan", "Albania", "Algeria", "Argentina", "Armenia", "Australia", "Austria", "Azerbaijan", "Bahrain", "Bangladesh", "Belgium", "Belize", "Benin", "Bolivia", "Bosnia and Herzegovina", "Botswana", "Brazil", "Bulgaria", "Burkina Faso", "Cambodia", "Cameroon", "Canada", "Chad", "Chile", "China", "Colombia", "Comoros", "Congo, Dem. Rep.", "Congo, Rep.", "Costa Rica", "Cote d'Ivoire","Croatia", "Cyprus", "Czechia", "Denmark", "Dominican Republic", "Ecuador", "Egypt, Arab Rep.", "El Salvador", "Estonia", "Eswatini", "Ethiopia", "Finland", "France", "Gabon", "Gambia, The", "Georgia", "Germany", "Ghana", "Greece", "Guatemala", "Guinea", "Honduras","Hong Kong SAR, China", "Hungary", "Iceland", "India", "Indonesia", "Iran, Islamic Rep.", "Iraq", "Ireland", "Israel", "Italy", "Japan", "Jordan", "Kazakhstan", "Kenya", "Kosovo", "Kuwait", "Kyrgyz Republic", "Lao PDR", "Latvia", "Lebanon", "Lesotho", "Liberia", "Libya", "Lithuania", "Madagascar", "Malawi", "Malaysia", "Mali", "Malta", "Mauritania", "Mauritius", "Mexico", "Moldova", "Mongolia", "Montenegro", "Morocco", "Mozambique", "Myanmar", "Namibia", "Nepal", "Netherlands", "New Zealand", "Nicaragua", "Niger", "Nigeria", "North Macedonia", "North Cyprus", "Norway", "Oman", "Pakistan", "West Bank and Gaza", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Romania",  "Russian Federation", "Saudi Arabia", "Senegal", "Serbia", "Sierra Leone", "Singapore", "Slovak Republic", "Slovenia", "South Africa", "Korea, Rep.",  "Spain", "Sri Lanka", "Sweden", "Switzerland", "Taiwan", "Tajikistan", "Tanzania", "Thailand", "Togo", "Tunisia", "Turkiye", "Uganda", "Ukraine", "United Arab Emirates", "United Kingdom", "United States", "Uruguay", "Uzbekistan", "Venezuela, RB", "Viet Nam", "Zambia", "Zimbabwe")


##################################################################
# ID
################################################################## 
## ### Create id24 =1 if ID(World Bank) is not NA
id24_df <- df[!is.na(df$ID), ]

# creates a unique list of countries 
id24_countryList <- as.list(unique(id24_df$Country))

# if we need to change the countries included in this list you can change the countries listed here
# id24_countryList <- c("Afghanistan", "Albania", "Algeria", "Argentina", "Armenia", "Australia", "Austria", "Azerbaijan", "Bahrain", "Bangladesh", "Belgium", "Benin", "Bolivia", "Bosnia and Herzegovina", "Botswana", "Brazil", "Burkina Faso", "Cambodia", "Cameroon", "Canada", "Chad", "Chile", "China", "Colombia", "Comoros", "Congo, Dem. Rep.", "Congo, Rep.", "Costa Rica", "Cote d'Ivoire", "Croatia", "Cyprus", "Czechia", "Denmark", "Dominican Republic", "Ecuador", "Egypt, Arab Rep.", "El Salvador", "Estonia", "Eswatini", "Ethiopia", "Finland", "France", "Gabon", "Gambia, The", "Georgia", "Germany", "Ghana", "Greece", "Guatemala", "Guinea", "Honduras", "Hong Kong SAR, China", "Hungary", "Iceland", "India", "Indonesia", "Iran, Islamic Rep.", "Iraq", "Ireland", "Israel", "Italy", "Japan", "Jordan", "Kazakhstan", "Kenya", "Kosovo", "Kuwait", "Kyrgyz Republic", "Lao PDR", "Latvia", "Lebanon", "Lesotho", "Liberia", "Libya", "Lithuania", "Madagascar", "Malawi", "Malaysia", "Mali", "Malta", "Mauritania", "Mauritius", "Mexico", "Moldova", "Mongolia", "Montenegro", "Morocco", "Mozambique", "Myanmar", "Namibia", "Nepal", "Netherlands", "New Zealand", "Nicaragua", "Niger", "Nigeria", "North Macedonia", "North Cyprus", "Norway", "Oman", "Pakistan", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Russian Federation", "Saudi Arabia", "Senegal", "Serbia", "Sierra Leone", "Singapore", "Slovak Republic", "Slovenia", "South Africa", "Korea, Rep.", "Spain", "Sri Lanka", "Sweden", "Switzerland", "Taiwan", "Tajikistan", "Tanzania", "Thailand", "Togo", "Tunisia", "Turkiye", "Uganda", "Ukraine", "United Arab Emirates", "United Kingdom", "United States", "Uruguay", "Uzbekistan", "Venezuela, RB", "Viet Nam", "Zambia", "Zimbabwe")

################################################################## 
# DIGITAL ID
################################################################## 

# Did24 - "digital id" - whether a person was asked the digital ID questions
did24_df <- df[df$ID %in% c(2, 4, 5, 7), ]
did24_countryList <- as.list(unique(did24_df$Country))

# list all countries
# did24_countryList <- c("Argentina", "Armenia", "Australia", "Austria", "Azerbaijan", "Bahrain", "Belgium", "Benin", "Bolivia", "Brazil", "Canada", "Chile", "China", "Colombia", "Croatia", "Cyprus", "Czechia", "Denmark", "El Salvador", "Estonia", "Finland", "France", "Germany", "Greece", "Hong Kong SAR, China", "Hungary", "Iceland", "India", "Indonesia", "Ireland", "Italy", "Japan", "Jordan", "Kazakhstan", "Kosovo", "Kuwait", "Kyrgyz Republic", "Latvia", "Malta", "Moldova", "Mongolia", "Montenegro", "Morocco", "Netherlands", "New Zealand", "North Macedonia", "Norway", "Panama", "Paraguay", "Peru", "Poland", "Portugal", "Saudi Arabia", "Serbia", "Singapore", "Slovak Republic", "Slovenia", "Korea, Rep.", "Sweden", "Switzerland", "Thailand", "Turkiye", "Uganda", "Ukraine", "United Arab Emirates", "United States", "Uruguay", "Uzbekistan", "Viet Nam")

################################################################## 
# COMPLETE ID
# Asked all all ID questions (excluding digital ID)
################################################################## 

# Did24 - "digital id" - whether a person was asked the digital ID questions
cid24_df <- df[df$ID %in% c(3, 4, 6, 7), ]
cid24_countryList <- as.list(unique(cid24_df$Country))

################################################################## 
# 2 ID
# Asked about a secondary id
################################################################## 

# Did24 - "digital id" - whether a person was asked the digital ID questions
c2id24_df <- df[df$ID %in% c(6, 7), ]
c2id24_countryList <- as.list(unique(c2id24_df$Country))

################################################################## 
# MOBILE MONEY
################################################################## 

# Filter rows where `Financial Inclusion/FINDEX (World Bank)` is  3, or 4 - these are the mobile money questionnaires
filtered_MM_df <- df[df$Findex %in% c(3, 4), ]
# Extract unique country names from filtered dataframe for Mobile Money Country list
mm_countrylist <- as.list(unique(filtered_MM_df$Country))

# Country list for Mobile Money country list
# mobileMoney_countrylist <- c("Afghanistan", "Argentina", "Armenia", "Bangladesh", "Belize", "Benin", "Bolivia", "Botswana", "Brazil", "Burkina Faso", "Cambodia", "Cameroon", "Chad", "Colombia", "Comoros", "Congo, Dem. Rep.", "Congo, Rep.", "Cote d'Ivoire", "Dominican Republic", "Ecuador", "Egypt, Arab Rep.", "El Salvador", "Eswatini", "Ethiopia", "Gabon", "Gambia, The", "Ghana", "Guatemala", "Guinea", "Honduras", "India", "Indonesia", "Iraq", "Jordan", "Kazakhstan", "Kenya", "Kyrgyz Republic", "Lao PDR", "Lebanon", "Lesotho", "Liberia", "Madagascar", "Malawi", "Malaysia", "Mali", "Mexico", "Mongolia", "Morocco", "Mozambique", "Namibia", "Nepal", "Nicaragua", "Niger", "Nigeria", "Pakistan", "West Bank and Gaza", "Panama", "Paraguay","Peru", "Philippines", "Senegal", "Sierra Leone", "South Africa", "Sri Lanka", "Tajikistan", "Tanzania", "Thailand", "Togo", "Tunisia", "Turkiye", "Uganda", "Venezuela, RB", "Viet Nam", "Zambia", "Zimbabwe")

################################################################## 
# COUNTRIES NOT ASKED MM BARRIERS 
# Questionnaire 4 but not questionnaire 3
################################################################## 

# Filter rows where `Financial Inclusion/FINDEX (World Bank)` is  4 - expanded mobile money questionnaire
filtered_MM_long_df <- df[df$Findex %in% c(4), ]
# Extract unique country names from filtered dataframe for Mobile Money Country list
mm_long_countrylist <- as.list(unique(filtered_MM_long_df$Country))

################################################################## 
# DEV indicator
# "developing" but with a few non-developing countries where the full-questionnaire is asked
################################################################## 

# dev24 - any country that is asked questionnaires 2-5 (not 1)
dev24_df <- df[df$Findex %in% c(2, 3, 4, 5), ]

dev24_countryList <- as.list(unique(dev24_df$Country))

# save dev24 country list
# dev24_countryList <- c("Afghanistan", "Albania", "Algeria", "Argentina", "Armenia", "Azerbaijan", "Bangladesh", "Belize", "Benin", "Bolivia", "Bosnia and Herzegovina", "Botswana", "Brazil", "Bulgaria", "Burkina Faso", "Cambodia", "Cameroon", "Chad", "China", "Colombia", "Comoros", "Congo, Dem. Rep.", "Congo, Rep.", "Costa Rica", "Cote d'Ivoire", "Croatia", "Dominican Republic", "Ecuador", "Egypt, Arab Rep.", "El Salvador", "Eswatini", "Ethiopia", "Gabon", "Gambia, The", "Georgia", "Ghana", "Guatemala", "Guinea", "Honduras", "India", "Indonesia", "Iran, Islamic Rep.", "Iraq", "Jordan", "Kazakhstan", "Kenya", "Kosovo", "Kyrgyz Republic", "Lao PDR", "Lebanon", "Lesotho", "Liberia", "Libya", "Madagascar", "Malawi", "Malaysia", "Mali", "Mauritania", "Mauritius", "Mexico", "Moldova", "Mongolia", "Montenegro", "Morocco", "Mozambique", "Myanmar", "Namibia", "Nepal", "Nicaragua", "Niger", "Nigeria", "North Macedonia", "Oman", "Pakistan", "West Bank and Gaza", "Panama", "Paraguay", "Peru", "Philippines", "Poland",  "Romania", "Saudi Arabia", "Senegal", "Serbia", "Sierra Leone", "South Africa", "Sri Lanka", "Tajikistan", "Tanzania", "Thailand", "Togo", "Tunisia", "Turkiye", "Uganda", "Ukraine", "Uzbekistan", "Venezuela, RB", "Viet Nam", "Zambia", "Zimbabwe")

################################################################## 
# CONNECTIVITY
################################################################## 

# Con24 - look at the connectivity data mapping and code it as 1 for every country asked any connectivity questionnaire
con24_df <- df[df$Connectivity %in% c(1,2,3,4), ]
con24_countryList <- as.list(unique(con24_df$Country))

## print con24 country list
# con24_countryList <- c("Afghanistan", "Albania", "Algeria", "Argentina", "Armenia", "Australia", "Austria", "Azerbaijan", "Bahrain", "Bangladesh", "Belgium", "Belize", "Benin", "Bolivia", "Bosnia and Herzegovina", "Botswana", "Brazil", "Bulgaria", "Burkina Faso", "Cambodia", "Cameroon", "Canada", "Chad", "Chile", "China", "Colombia", "Comoros", "Congo, Dem. Rep.", "Congo, Rep.", "Costa Rica", "Cote d'Ivoire", "Croatia", "Cyprus", "Czechia", "Denmark", "Dominican Republic", "Ecuador", "Egypt, Arab Rep.", "El Salvador", "Estonia", "Eswatini", "Ethiopia", "Finland", "France", "Gabon", "Gambia, The", "Georgia", "Germany", "Ghana", "Greece", "Guatemala", "Guinea", "Honduras", "Hong Kong SAR, China", "Hungary", "Iceland", "India", "Indonesia", "Iran, Islamic Rep.", "Iraq", "Ireland", "Israel", "Italy", "Japan", "Jordan", "Kazakhstan", "Kenya", "Kosovo", "Kuwait", "Kyrgyz Republic", "Lao PDR", "Latvia", "Lebanon", "Lesotho", "Liberia", "Libya", "Lithuania", "Madagascar", "Malawi", "Malaysia", "Mali", "Malta", "Mauritania", "Mauritius", "Mexico", "Moldova", "Mongolia", "Montenegro", "Morocco", "Mozambique", "Myanmar", "Namibia", "Nepal", "Netherlands", "New Zealand", "Nicaragua", "Niger", "Nigeria", "North Macedonia", "North Cyprus", "Norway", "Oman", "Pakistan", "West Bank and Gaza", "Panama", "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Romania", "Russian Federation", "Saudi Arabia", "Senegal", "Serbia", "Sierra Leone", "Singapore", "Slovak Republic", "Slovenia", "South Africa", "Korea, Rep.", "Spain", "Sri Lanka", "Sweden", "Switzerland", "Taiwan", "Tajikistan", "Tanzania", "Thailand", "Togo", "Tunisia", "Turkiye", "Uganda", "Ukraine", "United Arab Emirates", "United Kingdom", "United States", "Uruguay", "Uzbekistan", "Venezuela, RB", "Viet Nam", "Zambia", "Zimbabwe")

################################################################## 
# LONG CONNECTIVITY
################################################################## 

# lcon24 - some places are only asked the long connectivity questionnaire
lcon24_df <- df[df$Connectivity %in% c(2), ]
lcon24_countryList <- as.list(unique(lcon24_df$Country))

################################################################## 
# CYBERSECURITY 
# subset of connectivity
################################################################## 

# Cyb24 - "cybersecurity" - whether the person was asked the cybersecurity connectivity questions
cyb24_df <- df[df$Connectivity %in% c(2,3,4), ]
cyb24_countryList <- as.list(unique(cyb24_df$Country))

# cyb24_countryList <- c("Albania", "Algeria", "Armenia", "Australia", "Austria", "Azerbaijan", "Bahrain", "Belgium", "Bosnia and Herzegovina", "Bulgaria", "Canada", "Chile", "China", "Croatia", "Cyprus", "Czechia", "Denmark", "Estonia", "Finland", "France", "Georgia", "Germany", "Greece", "Hong Kong SAR, China", "Hungary", "Iceland", "Iran, Islamic Rep.", "Ireland", "Israel", "Italy", "Japan", "Kazakhstan", "Kosovo", "Kuwait", "Latvia", "Libya", "Lithuania", "Malta", "Mauritius", "Moldova", "Montenegro", "Myanmar", "Netherlands", "New Zealand", "North Macedonia", "North Cyprus", "Norway", "Oman", "Poland", "Portugal", "Romania","Russian Federation", "Saudi Arabia", "Serbia", "Singapore", "Slovak Republic", "Slovenia", "Korea, Rep.", "Spain", "Sweden", "Switzerland", "Taiwan", "Ukraine", "United Arab Emirates", "United Kingdom", "United States", "Uruguay")

################################################################## 
# COUNTRIES NOT ASKED FI BARRIERS 
# all of SSA with the exception of Ethiopia and Nigeria
################################################################## 

# Can see this list in Questionnaire 4 - pulled directly from there
nfi24_countryList <- c("Benin", "Botswana", "Burkina Faso", "Cambodia", "Cameroon", "Chad", "Comoros", "Congo, Dem. Rep.", "Congo, Rep.", "Cote d'Ivoire", "Eswatini", "Gabon", "Gambia, The", "Ghana", "Guinea", "Kenya", "Lesotho", "Liberia", "Madagascar", "Malawi", "Mali", "Mozambique", "Namibia", "Niger", "Senegal", "Sierra Leone", "South Africa", "Tanzania", "Togo", "Uganda", "Zambia", "Zimbabwe")

################################################################## 
# CODING IN THE IDENTIFIERS
################################################################## 

# finalize name changes for columns
df <- df %>%
  transmute(countrynewwb = Country, findex_q = Findex, id_q = ID, connect_q = Connectivity) %>%
  # use distinct so we don't have two CHINA rows
  distinct()

# merge in the above data frame to the real data - this is a left join
# convert to data table for faster execution
setDT(dataframe_2024)
setDT(df)

dataframe_2024 <- df[dataframe_2024, on = "countrynewwb"]


# create conditions for identifiers

dataframe_2024 <- dataframe_2024 %>%
  mutate(i24 = ifelse(year == 2024 & countrynewwb %in% i24_countrylist & !is.na(wp19479_r), 1, NA),
         m24 = ifelse(year == 2024 & countrynewwb %in% mm_countrylist & i24 == 1, 1, NA),
         ml24 = ifelse(year == 2024 & countrynewwb %in% mm_long_countrylist & m24 == 1, 1, NA),
         dev24 = ifelse(year == 2024 & countrynewwb %in% dev24_countryList & i24 == 1, 1, NA),
         nfi24 = ifelse(year == 2024 & !countrynewwb %in% nfi24_countryList & dev24 == 1, 1, NA), #NOTE: this is supposed to be is.na - we want to classify the countries that are missing those questions
         c24 = ifelse(year == 2024 & countrynewwb %in% con24_countryList & i24 == 1, 1, NA),
         lc24 = ifelse(year == 2024 & countrynewwb %in% lcon24_countryList & c24 == 1, 1, NA),
         cy24 = ifelse(year == 2024 & countrynewwb %in% cyb24_countryList & c24 == 1, 1, NA),
         id24 = ifelse(year == 2024 & countrynewwb %in% id24_countryList & i24 == 1, 1, NA),
         did24 = ifelse(year == 2024 & countrynewwb %in% did24_countryList & id24 == 1, 1, NA),
         cid24 = ifelse(year == 2024 & countrynewwb %in% cid24_countryList & id24 == 1, 1, NA),
         c2id24 = ifelse(year == 2024 & countrynewwb %in% c2id24_countryList & id24 == 1, 1, NA))


################################################################## 
# ADJUST ID BY AGE
################################################################## 

# IMPORTANT: SOME people who are in our survey aren't eligible for an ID because they are too young, here we 
# define the age cutoffs for ID
# **Using age cutoffs listed in the ID4D report: https://documents1.worldbank.org/curated/en/099705012232226786/pdf/P176341032c1ef0b20adf10abad304425ef.pdf

# list of countries where you must be 16 to have ID
id_age16 <- c("Bosnia and Herzegovina", "Botswana", "Congo, Rep.", "Dominican Republic", "Egypt, Arab Rep." ,
              "Gabon" ,
              "Israel" ,
              "Kazakhstan" ,
              "Kosovo" ,
              "Kyrgyz Republic" ,
              "Lesotho" ,
              "Malawi" ,
              "Mongolia" ,
              "Namibia" ,
              "Nepal" ,
              "Rwanda" ,
              "South Africa" ,
              "Tajikistan" ,
              "Turkmenistan" ,
              "West Bank and Gaza" ,
              "Zambia" ,
              "Zimbabwe")

# countries where you must be 17 to have ID
id_age17 <- c("Indonesia", "Korea, Rep.","Peru", "South Sudan")

# countries where you must be 18 to have ID
id_age18 <- c("Cameroon" ,
              "Chad" ,
              "Colombia" ,
              "Costa Rica" ,
              "El Salvador" ,
              "Ethiopia" ,
              "Guatemala" ,
              "Haiti" ,
              "Honduras" ,
              "Hong Kong SAR, China" ,
              "Jamaica" ,
              "Jordan" ,
              "Kenya" ,
              "Madagascar" ,
              "Mauritius" ,
              "Pakistan" ,
              "Panama" ,
              "Tanzania" ,
              "Tunisia")

# this code creates an ID age variable which is the age at which someone can have an ID. The ID_elig is a binary variable 
# that shows whether or not the individual respondent is eligible for an ID. We exclude adults who are not eligible from our analysis.
dataframe_2024 <- dataframe_2024 %>%
  mutate(id_age = case_when(countrynewwb %in% id_age16 ~ 16,
                            countrynewwb %in% id_age17 ~ 17,
                            countrynewwb %in% id_age18 ~ 18,
                            TRUE ~ 15),
         agenumber = wp1220,
         id_elig = ifelse(agenumber >= id_age, 1, 0)) %>%
  
  # NOTE: ID team said to suppress 2024 ID data for Chad and Liberia because of data quality concerns.
  mutate(id24 = ifelse(id_elig == 0 & !countrynewwb %in% c("Chad", "Liberia"), NA, id24),
         did24 = ifelse(id_elig == 0 & !countrynewwb %in% c("Chad", "Liberia"), NA, did24))





### faster save all data as csv file
# fwrite(dataframe_2024, "\\\\wbntpcifs\\Gallop\\Analysis, other docs, by year\\2024\\Code\\dataframe_24.csv")
