# Prereg Masterdata 2024

# NOTE: anytime you see "### UPDATE" you need to make changes for the new data

# load the gallup survey data in csv format
### UPDATE
gallup_data <- fread(file.path(folder_data, "World_Bank_032125.csv"))

################################


# Rename variables to lowercase: variables in 112715 data release were in CAPS. convert to lower
gallup_data <- gallup_data %>%  
rename_with(tolower) %>%
  mutate(wave10 = wave * 10) %>% # Create new variable 'wave10'
  mutate( # Modifying country names
    countrynewwb = case_when(
      countrynew == "Bosnia Herzegovina" ~ "Bosnia and Herzegovina",
      countrynew == "Congo Brazzaville" ~ "Congo, Rep.",
      countrynew == "Congo Kinshasa" ~ "Congo, Dem. Rep.",
      countrynew == "Czech Republic" ~ "Czechia",
      countrynew == "Egypt" ~ "Egypt, Arab Rep.",
      countrynew == "Gambia" ~ "Gambia, The",
      countrynew == "Hong Kong" ~ "Hong Kong SAR, China",
      countrynew == "Iran" ~ "Iran, Islamic Rep.",
      countrynew == "Ivory Coast" ~ "Cote d'Ivoire",  # Change for Ivory Coast
      countrynew == "Kyrgyzstan" ~ "Kyrgyz Republic",
      countrynew == "Laos" ~ "Lao PDR",
      countrynew == "Macedonia" ~ "North Macedonia",
      countrynew == "Northern Cyprus" ~ "North Cyprus",
      countrynew == "Palestine" ~ "West Bank and Gaza",
      countrynew == "Russia" ~ "Russian Federation",
      countrynew == "Slovakia" ~ "Slovak Republic",
      countrynew == "Somaliland" ~ "Somalia",
      countrynew == "South Korea" ~ "Korea, Rep.",
      countrynew == "Swaziland" ~ "Eswatini",
      countrynew == "Syria" ~ "Syrian Arab Republic",
      countrynew == "Taiwan" ~ "Taiwan, China",
      countrynew == "Turkey" ~ "Turkiye",
      countrynew == "Venezuela" ~ "Venezuela, RB",
      countrynew == "Vietnam" ~ "Viet Nam",
      countrynew == "Yemen" ~ "Yemen, Rep.",
      TRUE ~ countrynew  # Keep unchanged if not in the list
    )
  )

# Convert field_date from character to Date with the correct format
gallup_data$field_date <- as.Date(gallup_data$field_date, format = "%m/%d/%Y")

# Check the structure to confirm the conversion
# str(gallup_data$field_date)

# Now, extract the year from the field_date
gallup_data$year_ex <- as.numeric(format(gallup_data$field_date, "%Y"))

# Check the summary of the new year column
# summary(gallup_data$year_ex)

# Create a new variable 'wavenew' and directly create the 'year' column based on 'wavenew'
### UPDATE
gallup_data <- gallup_data %>%
  mutate(
    wavenew = wave * 10,
    year = case_when(
      wavenew == 10 & year_ex == 2005 ~ 2005,  # Year 2005 based on wavenew and year_ex
      wavenew == 10 & year_ex >= 2006 ~ 2006,  # Year 2006 based on wavenew and year_ex
      wavenew >= 20 & wavenew < 30 ~ 2007,
      wavenew >= 30 & wavenew < 40 ~ 2008,
      wavenew >= 40 & wavenew < 50 ~ 2009,
      wavenew >= 50 & wavenew < 60 ~ 2010,
      wavenew >= 60 & wavenew < 70 ~ 2011,
      wavenew >= 70 & wavenew < 80 ~ 2012,
      wavenew >= 80 & wavenew < 90 ~ 2013,
      wavenew >= 90 & wavenew < 100 ~ 2014,
      wavenew >= 100 & wavenew < 110 ~ 2015,
      wavenew >= 110 & wavenew < 120 ~ 2016,
      wavenew >= 120 & wavenew < 130 ~ 2017,
      wavenew >= 130 & wavenew < 140 ~ 2018,
      wavenew >= 140 & wavenew < 150 ~ 2019,
      wavenew >= 150 & wavenew < 160 ~ 2020,
      wavenew >= 160 & wavenew < 170 ~ 2021,
      wavenew >= 170 & wavenew < 180 ~ 2022,
      wavenew >= 180 & wavenew < 190 ~ 2023,
      wavenew >= 190 & wavenew < 200 ~ 2024,
      TRUE ~ NA_real_  # Assign NA if no conditions are met
    )
  )



# List observations where year might be incorrectly assigned
# observations <- gallup_data %>%
#   filter(is.na(year)) %>%
#   select(wave, wavenew, year)

# Merge strata harmonization data - this is really old - the later data won't have the wp12258 for values before 2014
strata_harmonize <- fread(file.path(folder_data, "strataharmonize_11202012.csv"))
# Perform the merge
gallup_data <- gallup_data %>%
  left_join(strata_harmonize, by = c("countrynew", "wave", "wp12258"))

# Load the master sheet data
master_sheet <- read_excel(file.path(folder_data, "Final WDI.xlsx"), sheet = "Sheet 1")

# Rename the columns in master_sheet to make them match with the gallup data
master_sheet <- master_sheet %>%
  rename(
    country_iso3 = Code,
    year = Year
  )

# Check if the columns exist in gallup_data_h
# "country_iso3" %in% names(gallup_data_h)
# "year" %in% names(gallup_data_h)

# Merge the cleaned master sheet data with the main data
gallup_data <- gallup_data %>%
  left_join(master_sheet, by = c("country_iso3", "year"), suffix = c("", ".master"))


#################################################################################
# Section C but faster using data.frame package
#################################################################################


# Convert dataframe to data.table
setDT(gallup_data)

# Step 1: Create unique numeric country ID (cid)
gallup_data[, cid := as.numeric(factor(countrynewwb))]

# Step 2: Initialize 'strata2' as NA
gallup_data[, strata2 := NA_real_]

# List of 'wave10' values ### UPDATE
wave10_list <- c(30, 31, 32, 33, 34, 40, 41, 42, 43, 50, 51, 52, 60, 61, 62, 63, 
                 64, 65, 71, 72, 73, 74, 81, 91, 92, 101, 111, 112, 121, 122, 131, 
                 132, 141, 151, 152, 153, 154, 155, 159, 161, 162, 163, 171, 172, 
                 181, 182, 191, 192, 193, 194)

# Step 3: Loop through each cid and wave10 combination
gallup_data[wave10 %in% wave10_list, strata2 := as.numeric(factor(wp12258)), by = .(cid, wave10)]
library(stringr)

# Step 4: Create the padded strings for cid, wave10, and strata2
gallup_data[, cid_s := str_pad(cid, width = 3, pad = "0")]
gallup_data[, wave10_s := str_pad(wave10, width = 3, pad = "0")]
gallup_data[, strata2_s := str_pad(strata2, width = 2, pad = "0")]

# Step 5: Create the 9-digit unique 'strata_8d'
gallup_data[, strata_8d_s := paste0("9", cid_s, wave10_s, strata2_s)]
gallup_data[, strata_8d := as.numeric(strata_8d_s)]

# Step 6: Clean up unnecessary columns
gallup_data[, c("strata2_s", "cid_s", "wave10_s", "strata_8d_s") := NULL]

# Step 7: Handle missing values for 'wp12258'
gallup_data[is.na(wp12258), strata_8d := NA_real_]



# Generating i variables across findex years
gallup_data <- gallup_data %>%
  mutate(i11 = ifelse(!is.na(wp11623) & year == 2011, 1, NA),
         i14 = ifelse(!is.na(wp14887) & year == 2014 & wave10 == 91, 1, NA),
         i17 = ifelse(!is.na(wp19548) & year == 2017 & wave10 %in% c(121, 122, 129), 1, NA),
         i21 = ifelse(!is.na(wp19548) & year == 2021 & wave10 %in% c(161, 162, 163), 1, NA),
         i22 = ifelse(!is.na(wp19548) & year == 2022 & wave10 %in% c(171, 172), 1, NA),
         i24 = case_when(!is.na(wp19548_r) & year == 2024 & countrynewwb != "China" & wave10 %in% c(191, 192, 193) ~ 1,
                         !is.na(wp19548_r) & year == 2024 & countrynewwb == "China" & wave10 == 194 ~ 1, # NOTE: the CATI/CAWI combined data for China is included in wave 194. There is 2024 data for china in wave 191 but that is NOT the complete data with both modes and should be excluded.
                         TRUE ~ NA)) %>%
# the lines 2160-2176 in stata file
# Create gfiiwave variable - this is the old name for Findex - this indicates that an observation is a findex observation regardless of year or wave
  mutate(gfiiwave = ifelse(!is.na(wp11623), 1, NA)) %>%      # [added Dec 17, 2014] [modified Feb 02, 2015]
  mutate(gfiiwave = ifelse(!is.na(i14), 1, gfiiwave)) %>%    # [added Dec 17, 2014] [modified Feb 02, 2015]
  mutate(gfiiwave = ifelse(!is.na(i17), 1, gfiiwave)) %>%    # [added Aug 10, 2017] [modified Sept 28, 2017]
  mutate(gfiiwave = ifelse(!is.na(i21), 1, gfiiwave)) %>%    # [added for 2021 wave]
  mutate(gfiiwave = ifelse(!is.na(i22), 1, gfiiwave)) %>%    # [added Dec 16, 2022]
  mutate(gfiiwave = ifelse(!is.na(i24), 1, gfiiwave)) %>%    # [added Aug 30, 2024]
  mutate(entwave = ifelse(!is.na(wp11612), 1, NA)) %>%  # Create entwave variable
  
# Count how many observations per year in all waves
  group_by(countrynewwb, year) %>%
  mutate(obs = n(), # 'n()' gives the count of observations per group
         obsgfii = sum(gfiiwave == 1, na.rm = TRUE),  # Count how many observations per year in GFII waves - need na.rm = TRUE because otherwise, if there are NA values, the whole country/year will be NA
         obsent = sum(entwave == 1, na.rm = TRUE)) %>% # Count how many observations per year in Ent waves
# following code is 2188-2192 in the stata file.
# Assuming 'gallup_data' is your main dataset

# replace wp12259=wpid if telephone==1 // no PSUs in the traditional sense exist where telephones used, essentially 
# each respondent is own psu (has equal chance of being selected after the strata stage), so should have unique psu 
# value = wpid
# wp12259 = psu 
# wp12258 = sampling stratification  
  mutate(wp12259 = ifelse(telephone == 1, wpid, wp12259),
         wp12259 = ifelse(countrynewwb == "Singapore", wpid, wp12259), # Replace wp12259 with wpid if countrynewwb == "Singapore" because singapore is all phone so no PSU
         wp12259 = ifelse(is.na(wp12259) & !is.na(strata_8d), wpid, wp12259), # Replace wp12259 with wpid if wp12259 is missing and strata_8d is not missing
         wp12259 = ifelse(wp12258 > 4 & !is.na(wp12258) & countrynewwb == "China" & year == 2011, wpid, wp12259)) # Replace wp12259 with wpid if wp12258 > 4, wp12258 is not missing, countrynewwb is "China", and year is 2011 - China has half phone, does so in strata 4(Beijing), 5(Shanghai), 6(Guangzhuo) - have to adjust
#          

####################################
# CREATE GROUP WEIGHT VARIABLES
####################################

gallup_data <- gallup_data %>%
  # corrects for the fact that # observations differs by country (this is essentially what percentage of world population 
  # is represented by each respondent in 1. ALL waves, 2. all GFII (findex) waves, and 3. all ent waves)
  mutate(rep_pop_adult_worldshare = pop_adult_worldshare_l1/obs,
         rep_pop_adult_worldsharegfii = pop_adult_worldshare_l1/obsgfii,
         rep_pop_adult_worldshareent = pop_adult_worldshare_l1/obsent) %>%
  # generate the "larger" weights that take into account the population size, number of observations, and also the respondent
  # level weight. This allows us to take averages that use many countries. For Findex, we use wgt_globalgfii
  mutate(wgt_global = wgt*rep_pop_adult_worldshare,
         wgt_globalgfii = wgt*rep_pop_adult_worldsharegfii,
         wgt_globalent = wgt*rep_pop_adult_worldshareent) %>%
# NOTE:
# wgt_global - use this for regional/aggregate statistics using data for All waves per year
# wgt_globalgfii  - use this for regional/aggregate statistics for data from GFII waves per year - this is Findex
# wgt_globalent - use this for regional/aggregate statistics for data from Ent waves per year

# code in demographic information
  mutate(adults = 1, # Create a variable 'adults' and assign value 1 to all rows
         women = ifelse(wp1219 == 2, 1, 
                        ifelse(wp1219 ==1, 0, NA)),  # Create a gender variable: 'women' is 1 if wp1219 equals 2, otherwise 0
         men = ifelse(wp1219 == 1, 1, 
                      ifelse(wp1219 ==2, 0, NA)),   # Create a gender variable: 'men' is 1 if wp1219 equals 1, otherwise 0
         young = ifelse(wp1220 < 25, 1,
                        ifelse(wp1220 >= 25, 0, NA)), # Create an age group variable: 'young' is 1 if wp1220 is less than 25, otherwise 0
         older = ifelse(wp1220 >= 25, 1,
                        ifelse(wp1220 < 25, 0, NA)), #OLDER - age 25+
         elderly = ifelse(wp1220 >= 54, 1,
                          ifelse(wp1220 < 55, 0, NA)), #ELDERLY - age 60+
         age_3groups = case_when(young == 1 ~ "ages 15-24", # young: adults 24 and below
                                 older == 1  & elderly != 1 ~ "ages 25-54", #between ages 25 and 54
                                 elderly == 1 ~ "age 55+", # age 55+
                                 TRUE ~ NA),
         # Mastercard foundation has a different age definition - adding it here so that we don't have to worry about it later
         young_MCF = ifelse(wp1220 <=35, 1,
                            ifelse(wp1220 > 35, 0, NA)),
         edu1cat = ifelse(wp3117 == 1, 1,
                          ifelse(wp3117 %in% c(2, 3), 0, NA)),  # Create education variable 'edu1cat': elementary or less (0-8), # Replace 'edu1cat' with NA if wp3117 is missing or equal to 4 or 5
         edu2cat = ifelse(wp3117 %in% c(2, 3), 1,
                          ifelse(wp3117==1, 0, NA)), # Create education variable 'edu2cat': Secondary - 3 year Tertiary, and Secondary ed 
         poor40 = ifelse(income_5 %in% c(1,2), 1,
                          ifelse(income_5 %in% c(3,4,5), 0, NA)), # Create income group variable: 'poor40' is 1 for bottom 40%, otherwise 0
         rich60 = ifelse(income_5 %in% c(3,4,5), 1,
                         ifelse(income_5 %in% c(1,2), 0, NA)), # Create 'rich60' variable with multiple conditions
         inc_q1 = ifelse(income_5 %in% c(1), 1, # create binaries for income quintiles
                         ifelse(income_5 %in% c(2,3,4,5), 0, NA)),
         inc_q2 = ifelse(income_5 %in% c(2), 1,
                         ifelse(income_5 %in% c(1,3,4,5), 0, NA)),
         inc_q3 = ifelse(income_5 %in% c(3), 1,
                         ifelse(income_5 %in% c(1,2,4,5), 0, NA)),
         inc_q4 = ifelse(income_5 %in% c(4), 1,
                         ifelse(income_5 %in% c(1,2,3,5), 0, NA)),
         inc_q5 = ifelse(income_5 %in% c(5), 1,
                         ifelse(income_5 %in% c(1,2,3,4), 0, NA)),
         emp_1 = case_when(emp_2010 == 1 ~ 1,
                          (emp_2010 == 3 | emp_2010 == 5) & wp10200 == 1 ~ 1,
                           emp_2010 != 1 ~ 0,
                          TRUE ~ NA), # employed for employer
         emp_2 = ifelse(emp_2010 == 4, 1,
                        ifelse(emp_2010 != 4, 0, NA)), # unemployed
         emp_3 = ifelse(emp_2010 == 6, 1,
                        ifelse(emp_2010 != 6, 0, NA)), # out of workforce
         emp_4 = case_when(emp_2010 == 2 ~ 1,
                           (emp_2010 == 3 | emp_2010 == 5) & wp10200 != 1 ~ 1,
                           !is.na(emp_2010) ~ 0,# self-employed
                           TRUE ~ NA),
         emp_cat = case_when(emp_1 == 1 ~ "employed for employer", # employed for employer
                             emp_2 == 1 ~ "unemployed", # unemployed
                             emp_3 == 1 ~ "out of workforce", # out of workforce
                             emp_4 == 1 ~ "self-employed", # self-employed
                             TRUE ~ NA),
         lf_in = case_when(emp_1 == 1 | emp_4 == 1 ~ 1, 
                           !is.na(emp_2010) ~ 0, # in the workforce
                           TRUE ~ NA),
         lf_out = case_when(emp_2 == 1 | emp_3 == 1 ~ 1, 
                            !is.na(emp_2010) ~ 0, # out of workforce
                            TRUE ~ NA),
         # this is a place holder urban/rural variable, the real ones are added in the march data
         # periurban is counted as RURAL
         urban = case_when(degurba == 3 ~ 1, 
                           degurba == 1 | degurba == 2 ~ 0, 
                           TRUE ~ NA),
         rural = case_when(degurba == 1 | degurba == 2 ~ 1,
                           degurba == 3 ~ 0,
                           TRUE ~ NA),
         edu_prim = case_when(edu1cat == 1 ~ 1,
                              edu2cat == 1 ~ 0,
                              TRUE ~ NA))

       
