
# Dataframe 2024 is defined in other files before

# Core Variables - key variables from the Gallup world poll
source(file.path(folder_code, "core_variables_gwp.R"))
gc()

# Findex Questionnaire
source(file.path(folder_code, "Findex_Questionnaire.R"))
gc()

# ID Questionnaire
source(file.path(folder_code, "ID_Questionnaire.R"))
gc()

# Connectivity Questionnaire
source(file.path(folder_code, "Connectivity_Questionnaire.R"))
gc()

# Constructed Variable Code
source(file.path(folder_code, "Constructed_Variables.R"))
gc()

# Time Series Variables
source(file.path(folder_code, "Time_Series_Variables.R"))
gc()

# Add Regions that weren't originally in the code
source(file.path(folder_code, "Added_Regions.R"))

# # List all objects in the environment
all_objects <- ls()
# Remove all objects except 'my_data'
rm(list = setdiff(all_objects, c("TS")))
gc()

# fwrite(TS, file.path(folder_data_output, "findex2025_respondent_lvl.csv"))


##########################################
# GWP CORE-VARIABLES
##########################################
# these variables have observations from all GWP waves, not just the findex one - CANNOT FILTER USING "i" identifiers

# add the types of employment here so they can be used for donuts.

demo1 <- c("women", "poor40", "young", "young_MCF", "urban", "lf_in", "emp_cat", "edu_prim", "emp_1", "emp_2", "emp_3", "emp_4", "age_3groups")

ts_cv <- TS %>%
  rename(codewb = country_iso3) %>%
  select(countrynewwb, codewb, year, pop_adult_l1, regionwb24_hi, incomegroupwb24, demo1, wgt, matches("^(cv)[0-9 | _]")) %>%
  mutate(all = "all")

demo <- c("all", "women", "poor40", "young","young_MCF", "urban", "lf_in", "emp_cat", "edu_prim", "age_3groups")

collapse_cv <- data.frame()

for (i in seq_along(demo)) {
  
  # Convert string to symbol
  demo_var <- sym(demo[i])
  
  cv <- ts_cv %>%
    filter(!is.na(wgt)) %>% # Ensure no missing weights
    group_by(year, countrynewwb, !!demo_var) %>%
    summarize(codewb = last(codewb),
              pop_adult_l1 = last(pop_adult_l1),
              regionwb24_hi = last(regionwb24_hi),
              incomegroupwb24 = last(incomegroupwb24) ,
              # African_Union = last(African_Union),
              # fci_region = last(fci_region),
              # fcs_fy25 = last(fcs_fy25),
              across(where(is.numeric) & !any_of(c(demo1, "pop_adult_l1", "wgt")),
                     ~ {# Calculate weighted mean
                       mean_value <- weighted.mean(.x, wgt, na.rm = TRUE)
                       # Replace NaN with NA - this prevents gross looking NaN values in the data
                       if (is.nan(mean_value)) NA else mean_value
                     }),.groups = 'drop') %>%
    mutate(group = demo[i],
           group2 = as.character(!!demo_var)) %>%
    # this will deselect the demographic variables because they are now recoded as group and group2 so we can make a long dataset
    select(-!!demo_var)
  
  # Append the result to the collapse data frame
  collapse_cv <- bind_rows(collapse_cv, cv)
  
}

# clear un-used memory - avoid crash
gc()



##########################################
# FINDEX-YEAR VARIABLES
##########################################

# add the types of employment here so they can be used for donuts.

demo1 <- c("women", "poor40", "young","young_MCF", "urban", "lf_in", "emp_cat", "edu_prim", "emp_1", "emp_2", "emp_3", "emp_4", "age_3groups")

TS <- TS %>% 
  rename(codewb = country_iso3) %>%
  select(countrynewwb, codewb, year, pop_adult_l1, regionwb24_hi,incomegroupwb24, African_Union, fci_region, fcs_fy25, demo1, wgt, wgt_globalgfii, matches("^(fin|con|ts|i|dev|m|id|did|fh)[0-9 | _]")) %>%
  mutate(all = "all",
         world = "world")

data <- TS %>%
  filter(i11 == 1 | i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) %>%
  mutate(year = ifelse(year == 2022, 2021, year)) # replace 2022 with 2021 so regional averages are correct

demo <- c("all", "women", "poor40", "young","young_MCF", "urban", "lf_in", "emp_cat", "edu_prim", "age_3groups")

collapse <- data.frame()

for (i in seq_along(demo)) {
  
  # Convert string to symbol
  demo_var <- sym(demo[i])
  
  d <- data %>%
    filter(!is.na(wgt)) %>% # Ensure no missing weights
    group_by(year, countrynewwb, !!demo_var) %>%
    summarize(codewb = last(codewb),
              pop_adult_l1 = last(pop_adult_l1),
              regionwb24_hi = last(regionwb24_hi),
              incomegroupwb24 = last(incomegroupwb24),
              African_Union = last(African_Union),
              fci_region = last(fci_region),
              fcs_fy25 = last(fcs_fy25),
              across(where(is.numeric) & !any_of(c(demo1, "pop_adult_l1", "wgt", "regionwb24_hi", "incomegroupwb24", "African_Union", "fci_region", "fcs_fy25")),
                     ~ {# Calculate weighted mean
                       mean_value <- weighted.mean(.x, wgt, na.rm = TRUE)
                       # Replace NaN with NA - this prevents gross looking NaN values in the data
                       if (is.nan(mean_value)) NA else mean_value
                     }),.groups = 'drop') %>%
    mutate(group = demo[i],
           group2 = as.character(!!demo_var)) %>%
    # this will deselect the demographic variables because they are now recoded as group and group2 so we can make a long dataset
    select(-!!demo_var)
  
  # Append the result to the collapse data frame
  collapse <- bind_rows(collapse, d)
  
}


# impute 0s for mm account variables and digital ID - people who aren't asked by definition could not have them so therefore are 0s

data <- data %>% 
  mutate(across(c("ts_mobaccount", "fin_savfor_mm_o","fin_interest_mm_o", "fin_borfor_mm", "ts_savfor_mm", "ts_accmob_o", "ts_accany_b","con18_mm", "con19_mm",  'fin_mm_filtered24',"fin_mm_filtered21", starts_with(c("fin13", "fin14", "fin15", "fin16"))), 
                ~if_else(i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1, 
                         replace_na(.x, 0), .x))) %>%
  mutate(across(c("id_dig_o", "id_both", "fin50_all", "fin51_all"), 
                ~if_else(id24 == 1, 
                         replace_na(.x, 0), .x))) %>%
  # create a fin12 variable for only places asked mobile money questions
  mutate(fin12_MMonly = case_when(m24 == 1 & fin12_all == 1 ~ 1,
                                  m24 == 1 & fin12_all == 0 ~ 0,
                                  i24 == 1 & m24 != 1 ~ 0,
                                  TRUE ~ NA))


# Define a function to compute weighted averages for different groupings
compute_averages <- function(data, group_var) {
  collapse_data <- data.frame()
  
  for (i in seq_along(demo)) {
    
    # Convert string to symbol
    demo_var <- sym(demo[i])
    group_sym <- sym(group_var)
    
    d <- data %>%
      filter(!is.na(wgt_globalgfii)) %>% # Ensure no missing weights
      group_by(year, !!group_sym, !!demo_var) %>%
      summarize(across(where(is.numeric) & !any_of(c(demo1, "pop_adult_l1", "wgt", "wgt_globalgfii")),
                       ~ {# Calculate weighted mean
                         mean_value <- weighted.mean(.x, wgt_globalgfii, na.rm = TRUE)
                         if (is.nan(mean_value)) NA else mean_value
                       }), .groups = 'drop') %>%
      mutate(group = demo[i],
             group2 = as.character(!!demo_var),
             countrynewwb = as.character(!!group_sym)) %>%  
      select(-!!demo_var)
    
    collapse_data <- bind_rows(collapse_data, d)
  }
  
  return(collapse_data)
}

# Compute averages for different groupings
collapse_world <- compute_averages(data, "world") %>% mutate(aggregate_level = "world")
collapse_lmic <- compute_averages(data %>% filter(incomegroupwb24 != "High income"), "world") %>% mutate(countrynewwb = "LMIC") %>% mutate(aggregate_level = "LMIC") 

collapse_inc <- compute_averages(data, "incomegroupwb24") %>% mutate(aggregate_level = "income_group")
collapse_reg_exclu <- compute_averages(data %>% filter(regionwb24_hi %in% c("South Asia (excluding high income)") & 
                                                         !countrynewwb %in% c("India")), "regionwb24_hi") %>% 
  mutate(countrynewwb = case_when(countrynewwb == "South Asia (excluding high income)" ~ "SAR (excluding India)", TRUE ~ NA)) %>%
  mutate(aggregate_level = "regions_w_exclusions")
collapse_reg_all <- compute_averages(data, "regionwb24_hi") %>% mutate(aggregate_level = "region_all")


data_noq5 <- data %>% filter(!countrynewwb %in% c("Algeria", "China","Iran, Islamic Rep.","Libya","Russian Federation", "Ukraine"))

collapse_reg <- compute_averages(data_noq5, "regionwb24_hi") %>% mutate(aggregate_level = "region_noq5") %>%
  mutate(countrynewwb = case_when(countrynewwb == "East Asia & Pacific (excluding high income)" ~ "EAP (ex V5 countries)",
                                  countrynewwb == "Europe & Central Asia (excluding high income)" ~ "ECA (ex V5 countries)",
                                  countrynewwb == "Latin America & Caribbean (excluding high income)" ~ "LAC (ex V5 countries)",
                                  countrynewwb == "Middle East & North Africa (excluding high income)" ~ "MENA (ex V5 countries)",
                                  countrynewwb == "South Asia (excluding high income)" ~ "SAR (ex V5 countries)",
                                  countrynewwb == "Sub-Saharan Africa (excluding high income)" ~ "SSA (ex V5 countries)",
                                  TRUE ~ countrynewwb))

collapse_lmic_noq5 <- compute_averages(data_noq5 %>% filter(incomegroupwb24 != "High income"), "world") %>% mutate(countrynewwb = "LMIC (ex V5 countries)") %>% mutate(aggregate_level = "LMIC_noq5") 
collapse_au <- compute_averages(data_noq5, "African_Union") %>% mutate(aggregate_level = "African_Union")



# merge together different subsets

country <- collapse %>%
  mutate(aggregate_level = "country_level",
         country_level = 1)

groups <- bind_rows(collapse_world, collapse_lmic, collapse_reg, collapse_reg_all, collapse_inc, collapse_au, collapse_reg_exclu, collapse_lmic_noq5) %>%
  mutate(country_level = 0)

final <- bind_rows(country, groups) %>%
  full_join(collapse_cv)



# fix the group labels

final <- final %>%
  filter(!is.na(countrynewwb)) %>%
  mutate(group2 = case_when(
    group == "Demographic Category" ~ "Demographic sub-category",
    group == "all" ~ "all",
    group == "women" & group2 == 1 ~ "women",
    group == "women" & group2 == 0 ~ "men",
    group == "poor40" & group2 == 1 ~ "poorest 40%",
    group == "poor40" & group2 == 0 ~ "richest 60%",
    group == "young" & group2 == 1 ~ "ages 15-24",
    group == "young" & group2 == 0 ~ "age 25+",
    group == "young_MCF" & group2 == 1 ~ "ages 15-35",
    group == "young_MCF" & group2 == 0 ~ "age 36+",
    group == "urban" & group2 == 1 ~ "urban",
    group == "urban" & group2 == 0 ~ "rural",
    group == "lf_in" & group2 == 1 ~ "in laborforce",
    group == "lf_in" & group2 == 0 ~ "out of laborforce",
    group == "edu_prim" & group2 == 1 ~ "prim edu or less",
    group == "edu_prim" & group2 == 0 ~ "secondary edu or more",
    TRUE ~ as.character(group2)),
    group = case_when(group == "women" ~ "gender",
                      group == "poor40" ~ "income",
                      group == "young" ~ "age_cat",
                      group == "young_MCF" ~ "MCF_age_cat",
                      group == "urban" ~ "urbanicity",
                      group == "lf_in" ~  "workforce",
                      group == "edu_prim" ~  "education",
                      group == "emp_cat" ~  "employment",
                      group == "age_3groups" ~ "expanded_ages",
                      TRUE ~ as.character(group))) %>%
  filter(group2 != ".") %>%
  select(!wgt_globalgfii) %>%
  select(1:6, group, group2, country_level, aggregate_level, everything())


# drop aggregates that we don't have complete data for
# High income for anything not asked in Questionnaire 1 (findex) or 

final <- final %>%
  mutate(across(everything(), ~ if_else(countrynewwb %in% c("High income", "world") & 
                                          !cur_column() %in% c("countrynewwb", "year", "group", "group2", "country_level", "aggregate_level",
                                                               "ts_account", "ts_FIaccount", "ts_mobaccount","ts_accmob_o", "ts_accfin_o", "ts_accany_b",
                                                               "fin1_all", "fin2_all", "fin12_all", "fin13_all",
                                                               "con1_all", "con24_all", "con25_all", "con_internet3", "con_sp_world",
                                                               "fin46_all", "fin50_all", "fin51_all", "id_any"), NA, .x)),
         across(all_of(starts_with("fin11")), 
                ~ if_else(countrynewwb == "Sub-Saharan Africa (excluding high income)" |
                            aggregate_level == "African_Union", NA, .x)))



fwrite(final, file.path(folder_data_output, "TS_for_Figures_24_REGIONS.csv"))

