
TS <- dataframe_2024 %>%
  mutate(ts_account = case_when(acc11any == 1 & i11 == 1 ~ 1,
                                acc14any == 1 & i14 == 1 ~ 1,
                                acc17any == 1 & i17 == 1 ~ 1,
                                acc21_22any == 1 & i21_22 == 1 ~ 1,
                                # acc22any == 1 & i22 == 1 ~ 1,
                                acc24any == 1 & i24 == 1 ~ 1,
                                i11 == 1 | i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1 ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(ts_account = "Time series: Any account [of adults]") %>%
  
  mutate(ts_FIaccount = case_when(acc11fin == 1 & i11 == 1 ~ 1,
                                  acc14fin == 1 & i14 == 1 ~ 1,
                                  acc17fin == 1 & i17 == 1 ~ 1,
                                  acc21_22fin == 1 & i21_22 == 1 ~ 1,
                                  acc24fin == 1 & i24 == 1 ~ 1,
                                  i11 == 1 | i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1 ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(ts_FIaccount = "Time series: Account at a financial institution [of adults]") %>%
  
  mutate(ts_mobaccount = case_when(acc14mob == 1 & m14 == 1 ~ 1,
                            acc17mob == 1 & m17 == 1 ~ 1,
                            acc21_22mob == 1 & m21_22 == 1 ~ 1,
                            acc24mob == 1 & m24 == 1 ~ 1,
                            m14 == 1 | m17 == 1 | m21_22 == 1 | m24 == 1 ~ 0,
                            TRUE ~ NA)) %>%
  set_variable_labels(ts_mobaccount = "Time series: Mobile Money account [of adults]") %>%
  
  mutate(ts_accfin_o = case_when(i11 == 1 & acc11fin == 1 ~ 1, # in 2011 there was no option to say that you had a MM account
                                 i14 == 1 & acc14fin_o == 1 ~ 1,
                                 i17 == 1 & acc17fin_o == 1 ~ 1,
                                 i21_22 == 1 & acc21_22fin_o == 1 ~ 1,
                                 i24 == 1 & acc24fin_o == 1 ~ 1,
                                 i11 == 1 | i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(ts_accfin_o = "Time series: Have an account at a financial institution only [of adults]") %>%
  
  mutate(ts_accmob_o = case_when(i14 == 1 & acc14mob_o == 1 ~ 1,
                                 i17 == 1 & acc17mob_o == 1 ~ 1,
                                 i21_22 == 1 & acc21_22mob_o == 1 ~ 1,
                                 i24 == 1 & acc24mob_o == 1 ~ 1,
                                 i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(ts_accmob_o = "Time series: Mobile Money account only [of adults]") %>%
  
  mutate(ts_accany_b = case_when(i14 == 1 & acc14any_b == 1 ~ 1,
                                 i17 == 1 & acc17any_b == 1 ~ 1,
                                 i21_22 == 1 & acc21_22any_b == 1 ~ 1,
                                 i24 == 1 & acc24any_b == 1 ~ 1,
                                 i11 == 1 | i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1 ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(ts_accany_b = "Time series: Both FI and mobile money account [of adults]") %>%
  
  mutate(ts_anysavings = case_when(dev24 == 1 & (wp15165_r == 1 | 
                                                   wp21375_r == 1 | 
                                                   wp19486_r == 1 | 
                                                   wp21374_r == 1 | 
                                                   wp14914_r == 1) ~ 1, # anysavings24 created in Findex_Questionnaire.R document
                                   # 2021/22 savings variables:  For old age, Formal financial insitution, Informal savings group, Using mobile money account GSMA, Any reason	
                                   i21_22 == 1 & (wp15165 == 1 | 
                                                    wp19486 == 1	| 
                                                    wp21375 == 1 | 
                                                    wp14914 == 1 |
                                                    wp21374 == 1) ~ 1, 
                                   # 2017 savings variables: To start a business, For old age, Formal financial insitution, Informal savings group**ONLY ASKED TO F2F COUNTRIES, Any other reason
                                   i17 == 1 & (wp19484 == 1 | 
                                                 wp19485 == 1 | 
                                                 wp15165 == 1 | 
                                                 wp19486 == 1 | 
                                                 wp14914 == 1) ~ 1,
                                   i14 == 1 & (wp14911 == 1|
                                                 wp14912 == 1 |
                                                 wp15164 == 1 |
                                                 wp15165 == 1 |
                                                 wp15166 == 1 |
                                                 wp14914 == 1) ~ 1,
                                   # this line will classify people who were asked savings questions who didn't answer yes to be coded as 0
                                   (dev24 == 1 | i22 == 1 | i21 == 1 | i17 == 1 | i14 == 1) ~ 0,
                                   TRUE ~ NA)) %>% # the rest are coded as missing
  set_variable_labels(ts_anysavings = "Time series: Any savings [of adults]") %>%
  
  mutate(ts_savfor_fi = case_when(dev24 == 1 & wp15165_r == 1 ~ 1, 
                                  (i21_22 == 1 | i17 == 1 | i14 == 1) & wp15165 == 1 ~ 1, # wp15165 is formal savings for 2014-2022
                                  (i11 == 1 & wp11648 == 1 & wp11645 == 1) ~ 1, # wp11648 is save using a bank, wp11645 is saving in the last 12 months - sourced from time series file and end of prereg file
                                  (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1 | i11 == 1) ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(ts_savfor_fi = "Time series: Formal savings using a bank account [of adults]") %>%
  
  mutate(ts_savfor_mm = case_when(dev24 == 1 & m24 == 1 & wp21375_r == 1 ~ 1, # save using mobile money
                                  i21_22 == 1 & m21_22 == 1 & wp21375 == 1 ~ 1,
                                  (dev24 == 1 & m24 == 1 ) | (i21_22 == 1 & m21_22 == 1) ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(ts_savfor_mm = "Time series: Formal savings using a mobile money account [of adults]") %>%
  
  # NOTE: THIS IS FORMAL SAVINGS!!!!!!!!! - it has to be constructed like this becuase if I try to use all of the components I get NA when a country isn't MM
  mutate(ts_savfor_fi_mm = case_when(ts_savfor_fi == 1 | ts_savfor_mm == 1 ~ 1, 
                                     (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1 | i11 == 1) ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(ts_savfor_fi_mm = "Time series: Formal savings using a bank or a mobile money account [of adults]") %>%
  
  mutate(ts_savfor_mm_MErank = case_when(ts_savfor_mm == 1 & ts_savfor_fi != 1 ~ 1, # save using mobile money but not using FI
                                         (dev24 == 1 & m24 == 1 ) | (i21_22 == 1 & m21_22 == 1) ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(ts_savfor_mm_MErank = "Time series: Formal savings using a mobile money account and NOT a bank account [of adults]") %>%
  
  # save formally using FI account and DID NOT SAVE FORMALLY USING MM
  mutate(ts_savfor_fi_MErank = case_when(ts_savfor_fi == 1 & (ts_savfor_mm != 1 | is.na(ts_savfor_mm)) ~ 1,  #don't ask about MM before 2021 so no need to exclude
                                         (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1 | i11 == 1) ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(ts_savfor_fi_MErank = "Time series: Formal savings using a bank account and NOT a mobile money account [of adults]") %>%
  
  mutate(ts_savsemfor = case_when(dev24 == 1 & wp19486_r == 1 ~ 1,
                                  (i21_22 == 1 | i17 == 1) & wp19486 == 1 ~ 1,
                                  i14 == 1 & wp15166 == 1 ~ 1,
                                  (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1) ~ 0, # no semiformal savings in 2011
                                  TRUE ~ NA)) %>%
  set_variable_labels(ts_savsemfor = "Time series: Save semiformally [of adults]") %>%
  
  mutate(ts_savsemfor_MErank = case_when(dev24 == 1 & wp19486_r == 1 & ts_savfor_fi_mm != 1 ~ 1,
                                         i21_22 == 1 & wp19486 == 1 & ts_savfor_fi_mm != 1 ~ 1, # no MM - 
                                         i17 == 1 & wp19486 == 1 & ts_savfor_fi != 1 ~ 1,
                                         i14 == 1 & wp15166 == 1 & ts_savfor_fi != 1~ 1,
                                         i11 == 1 & (wp11649 == 1 | wp11645 == 1) & ts_savfor_fi != 1 ~ 1,
                                         (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1 | i11 == 1) ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(ts_savsemfor_MErank = "Time series: Save semiformally and NOT formally [of adults]") %>%
  
  mutate(ts_savsemfor_MErank_mm = case_when(ts_mobaccount == 1 & ts_savsemfor_MErank == 1 ~ 1,
                                            (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1 | i11 == 1) ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(ts_savsemfor_MErank_mm = "Time series: Save semiformally and NOT formally and have a mobile money account [of adults]") %>%
 
  
  mutate(ts_savother = case_when(ts_anysavings == 1 & ts_savfor_fi_mm != 1 & ts_savsemfor != 1 ~ 1,
                                 (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1 | i11 == 1) ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(ts_savother = "Time series: Save in some other way [of adults]") %>%
  
  mutate(ts_savold = case_when(dev24 == 1 & wp21374_r == 1 ~ 1, #WP21374
                               (i21_22 == 1 | i17 == 1 | i14 == 1) & (wp14912== 1 | wp19485 == 1 |wp21374 == 1) ~ 1,
                               (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1) ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(ts_savold = "Time series: Save for old age [of adults]") %>% #note that 2024 is only formal saving
  
  mutate(ts_anyborrowing = case_when(dev24 == 1 & (wp19489_r == 1 | 
                                                     wp23996 == 1 | 
                                                     wp19490_r == 1 | 
                                                     wp19491_r == 1 | 
                                                     wp19487_r == 1 | 
                                                     wp23997 == 1 | 
                                                     wp23998 == 1 | 
                                                     wp19476_r == 1 | 
                                                     wp14924_r == 1) ~ 1,
                                     i21_22 == 1 & (wp21365 == 1 |
                                                      wp19487 == 1 |
                                                      wp19489 == 1 |
                                                      wp19490 == 1 |
                                                      wp19491 == 1 |
                                                      wp14924 == 1 |
                                                      wp19476 == 1) ~ 1, #credit card
                                     i17 == 1 & (wp19487==1 | 
                                                   wp19488==1 | 
                                                   wp19489==1 | 
                                                   wp19490==1 | 
                                                   wp19491==1 | 
                                                   wp14924==1 |
                                                   wp19476==1) ~ 1, # old code/STATA had (wp19489==1 | wp19476==1)) ~ 1, as an additional statement at the end
                                     i14 == 1 & ((wp14917 == 1 | 
                                                    wp14918 == 1 | 
                                                    wp14919 == 1 | 
                                                    wp14920 == 1 | 
                                                    wp14921 == 1 | 
                                                    wp14922 == 1 | 
                                                    wp14923 == 1 |
                                                    wp14924 == 1) |  
                                                   wp14892==1) ~ 1,
                                     (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1) ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(ts_anyborrowing = "Time series: Any borrowing [of adults]") %>% 
  
  mutate(ts_borrfor_fi = case_when(dev24 == 1 & wp19489_r == 1 ~ 1,
                                   (i21_22 == 1 | i17 == 1 | i14 == 1) & (wp14917 == 1 | wp19489==1) ~ 1,
                                   (dev24 | i21_22 == 1 | i17 == 1 | i14 == 1) ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfor_fi = "Time series: Borrow formally using a bank account [of adults]") %>% 
  
  # borrow formally using FI account or credit card
  mutate(ts_borrfor_fi_cc = case_when(dev24 == 1 & (wp19489_r == 1 | wp19476_r == 1) ~ 1,
                                      i21_22 == 1 & (wp19489 == 1 | wp19476 == 1) ~ 1,
                                      i17 == 1 & (wp19489==1 | wp19476==1) ~ 1,
                                      i14 == 1 & (wp14917 == 1 | wp14892==1) ~ 1,
                                      (dev24 | i21_22 == 1 | i17 == 1 | i14 == 1) ~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfor_fi_cc = "Time series: Borrow formally using a bank account or credit card [of adults]") %>% 
  
  # Used credit card in past year (% age 15+)
  mutate(ts_cc_use = case_when(i14 == 1 & wp14892 == 1 ~ 1,
                               i17 == 1 & wp19476 == 1 ~ 1,
                               i21_22 == 1 & wp19476 == 1 ~ 1,
                               dev24 == 1 & fin22G_all == 1 ~ 1,
                               i14 == 1| i17 == 1 | i21_22 == 1 | dev24 == 1 ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(ts_cc_use = "Time series: Used a credit card in the past year [of adults]") %>% 
  
  mutate(ts_borrfor_mm = case_when(dev24 == 1 & m24 == 1 & wp23996 == 1 ~ 1,
                                   m21_22 == 1 & (wp21365 == 1 & wp19480c == 1) ~ 1,
                                   (dev24 == 1 & m24 == 1) | m21_22 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfor_mm = "Time series: Borrow formally using mobile money [of adults]") %>% 
  
  mutate(ts_borrfor_mm_MErank = case_when(ts_borrfor_mm == 1 & ts_borrfor_fi_cc != 1~ 1,
                                          (dev24 == 1 & m24 == 1) | m21_22 == 1 ~ 0,
                                          TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfor_mm_MErank = "Time series: Borrow formally using mobile money and NOT a bank account[of adults]") %>% 
  
  # NOTE: like with savings you have to do it this way so we don't get NA for no MM countries
  mutate(ts_borrfor_fi_cc_mm = case_when(ts_borrfor_fi_cc == 1  ~ 1,
                                         ts_borrfor_mm == 1 ~ 1,
                                         (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1) ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfor_fi_cc_mm = "Time series: Borrow formally using mobile money, a credit card, or a bank account[of adults]") %>% 
  
  # borrow formally using FI account or credit card but NOT MM account
  mutate(ts_borrfor_fi_cc_MErank = case_when(dev24 == 1 & (wp19489_r == 1 | wp19476_r == 1) & (ts_borrfor_mm != 1 | is.na(ts_borrfor_mm)) ~ 1,
                                             i21_22 == 1 & (wp19489 == 1 | wp19476 == 1) & (ts_borrfor_mm != 1 | is.na(ts_borrfor_mm)) ~ 1,
                                             i17 == 1 & (wp19489==1 | wp19476==1) ~ 1, # no MM listed here because we don't ask MM in 2014 or 2017
                                             i14 == 1 & (wp14917 == 1 | wp14892==1) ~ 1,
                                             (dev24 | i21_22 == 1 | i17 == 1 | i14 == 1) ~ 0,
                                             TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfor_fi_cc_MErank = "Time series: Borrow formally using FI account or credit card but NOT MM account[of adults]") %>% 
  
  # borrow formally ONLY using a credit card
  mutate(ts_borrfor_cc_MErank = case_when(ts_cc_use == 1  & ts_borrfor_fi != 1 & (ts_borrfor_mm != 1 | is.na(ts_borrfor_mm)) ~ 1,
                                          (dev24 == 1 | i21_22 == 1 | i17 == 1 | i14 == 1) ~ 0,
                                          TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfor_cc_MErank = "Time series: Borrow formally ONLY using a credit card (no MM or FI) [of adults]") %>% 
  
  mutate(ts_borr_semifor = case_when(dev24 == 1 & wp19491_r == 1 ~ 1,
                                     (i21_22 == 1 | i17 ==1) & wp19491 == 1 ~ 1,
                                     (dev24 | i21_22 == 1 | i17 == 1) ~ 0,
                                     TRUE ~ NA)) %>%
  set_variable_labels(ts_borr_semifor = "Time series: Borrow semiformally [of adults]") %>% 
  
  # people who borrow semiformally and who do NOT borrow formally
  mutate(ts_borr_semifor_MErank = case_when(dev24 == 1 & wp19491_r == 1 & ts_borrfor_fi_cc_mm != 1 ~ 1,
                                            i21_22 == 1 & wp19491 == 1 & ts_borrfor_fi_cc_mm != 1 ~ 1,
                                            i17 ==1 & wp19491 == 1 & ts_borrfor_fi_cc != 1 ~ 1, # no MM saving asked in 2017
                                            (dev24 | i21_22 == 1 | i17 == 1) ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(ts_borr_semifor_MErank = "Time series: Borrow semiformally and not formally [of adults]") %>% 
  
  mutate(ts_borrfam = case_when(dev24 == 1 & wp19490_r == 1 ~ 1,
                                (i14 == 1 | i17 == 1  | i21_22 == 1) & (wp14919 == 1 | wp19490 == 1) ~ 1,
                                (i14 == 1 | i17 == 1  | i21_22 == 1 | dev24 == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfam = "Time series: Borrow from friends or family [of adults]") %>% 
  
  mutate(ts_borrfam_MErank = case_when(dev24 == 1 & wp19490_r == 1 & ts_borrfor_fi_cc_mm != 1 & ts_borr_semifor != 1 ~ 1,
                                       i21_22 == 1 & (wp14919 == 1 | wp19490 == 1) & ts_borrfor_fi_cc_mm != 1 & ts_borr_semifor != 1 ~ 1,
                                       (i14 == 1 | i17 == 1) & (wp14919 == 1 | wp19490 == 1) & ts_borrfor_fi_cc != 1 & ts_borr_semifor != 1 ~ 1, # no MM saving asked 
                                       (i14 == 1 | i17 == 1  | i21_22 == 1 | dev24 == 1) ~ 0,
                                       TRUE ~ NA)) %>%
  set_variable_labels(ts_borrfam = "Time series: Borrow from friends or family and not semiformally or formally [of adults]") %>% 
  
  mutate(ts_borrhealth = case_when(dev24 == 1 & wp19487_r == 1 ~ 1,
                                   (i14 == 1 | i17 == 1 | i21_22 == 1) & (wp14922 == 1 | wp19487 == 1) ~ 1,
                                   (i14 == 1 | i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(ts_borrhealth = "Time series: Borrow for health reasons [of adults]") %>% 
  
  ####################################################################
# DIGITAL PAYMENTS
####################################################################

# to create making and receiving digital payments, the original STATA code iterates through many different steps to get to the final value.To have values that match previously
# published values, we also have to do this here - I make all of the year-values here first and then create the time series after

##################
# 2014
##################

# Note - used the code from digital payments but then had to also create values for the _d variables that were constructed in Prereg_Masterdata_Findex14v2.do

mutate(
  any14_1  = as.integer(acc14any == 1 & wp15163 == 1),  # 1. used mobile money
  any14_2  = as.integer(acc14any == 1 & wp14890 == 1),  # 2. used debit card
  any14_3  = as.integer(acc14any == 1 & wp14892 == 1),  # 3. used credit card
  any14_4  = as.integer(acc14any == 1 & (wp14942 == 1 | (wp14943 == 1 & acc14mob == 1))),  # 4. paid bills (acc & mob)
  any14_5  = as.integer(acc14any == 1 & (wp15174 == 1 |(wp15175 == 1 & acc14mob == 1))),  # 5. school fees (FI account)
  any14_6  = as.integer(acc14any == 1 & wp15161 == 1),  # 6. used mobile to make payment from account
  any14_7  = as.integer(acc14any == 1 & (((wp14928 == 1 & wp15169 == 1) & acc14fin == 1)|(wp14928 == 1 & wp15170 == 1 & acc14mob == 1))),  # 7. sent remittances (acc & mob)
  any14_8  = as.integer(acc14any == 1 & wp14910 == 1),  # 8. personally, made payments on bills or bought things online using the Internet
  any14_9  = as.integer(acc14any == 1 & ((wp14934 == 1 & wp14937 == 1 & acc14fin == 1)|(wp14934 == 1 & wp14938 == 1 & acc14mob == 1))),  # 9. received remittances (acc & mob)
  any14_10 = as.integer(acc14any == 1 & ((wp15184 == 1 & wp15186== 1) | (wp15184 == 1 & wp15187 == 1))),  # 10. agricultural payments
  any14_11 = as.integer(acc14any == 1 & (wp14947 == 1 | wp14948 == 1 | (wp14948 == 1 & m14))),  # 11. wages
  any14_12 = as.integer(acc14any == 1 &  (wp15179 == 1 | wp15180 == 1 | (wp15181 == 1 & m14 == 1)))  # 12. transfers
) %>%
  
  # Create `g20_14_AA` by checking if any of the 12 conditions are met
  mutate(g20_14_AA = as.integer(!is.na(i14) & acc14any == 1 & 
                                  (any14_1 == 1 | any14_2 == 1 | any14_3 == 1 | any14_4 == 1 | any14_5 == 1 |
                                     any14_6 == 1 | any14_7 == 1 | any14_8 == 1 | any14_9 == 1 | any14_10 == 1 |
                                     any14_11 == 1 | any14_12 == 1)),  # Indicator for any payment-related activities
         # Create `g20_14_made_AA` based on the first 7 conditions
         g20_14_made_AA = as.integer(!is.na(i14) & acc14any == 1 & 
                                       (any14_1 == 1 | any14_2 == 1 | any14_3 == 1 | any14_4 == 1 | 
                                          any14_5 == 1 | any14_6 == 1 | any14_7 == 1)),  # Indicator for made payment-related activities
         # Create `g20_14_receive_AA` based on the conditions 8-12
         g20_14_receive_AA = as.integer(!is.na(i14) & acc14any == 1 & 
                                          (any14_8 == 1 | any14_9 == 1 | any14_10 == 1 | any14_11 == 1 | 
                                             any14_12 == 1))) %>%  # Indicator for received payment-related activities
  
  ##################
# 2017
##################
mutate(
  any17v1_1  = as.integer(acc17any == 1 & wp19480c == 1),  # 1. used mobile money
  any17v1_2  = as.integer(acc17any == 1 & (wp19473 == 1 | wp19549 == 1)),  # 2. Used debit card + marginal
  any17v1_3  = as.integer(acc17any == 1 & wp19476 == 1),  # 3. used credit card
  any17v1_4  = as.integer(acc17any == 1 & (wp19504 == 1 | (wp19505 == 1 & acc17mob == 1))),  # 4. paid bills (acc & mob)
  any17v1_5  = as.integer(acc17any == 1 & (wp19474 == 1 | wp19550 == 1)),  # 5. used mobile to make payment from account + marginal
  any17v1_6  = as.integer(acc17any == 1 & ((wp19495 == 1 & acc17fin == 1) | (wp19496 == 1 & acc17mob == 1))),  # 6. sent remittances (acc & mob)
  any17v1_7  = as.integer(acc17any == 1 & (wp19481 == 1 | (wp19482 == 1 & wp19483 == 1))),  # 7. internet
  any17v1_8  = as.integer(acc17any == 1 & ((wp19500 == 1 & acc17fin == 1) | (wp19501 == 1 & acc17mob == 1))),  # 8. received remittances (acc & mob)
  any17v1_9  = as.integer(acc17any == 1 & ((wp19523 == 1) | (wp19524 == 1 & m17 == 1))),  # 9. agricultural payments (acc & mob)
  any17v1_10 = as.integer(acc17any == 1 & ((wp19508 == 1) | (wp19509 == 1 & m17 == 1) | (wp19511 == 1))),  # 10. wages
  any17v1_11 = as.integer(acc17any == 1 & (wp19514 == 1 & wp19515 != 1) & ((wp19516 == 1 | wp19519 == 1) | (wp19517 == 1 & m17 == 1))),  # 11. transfers (acc & mob)
  any17v1_12 = as.integer(acc17any == 1 & (wp19515 == 1) & ((wp19516 == 1 | wp19519 == 1) | (wp19517 == 1 & m17 == 1)))  # 12. pension (acc & mob)
) %>%
  
  # Create `g20_17v1_AA` by checking if any of the 12 conditions are met
  mutate(
    g20_17v1_AA = as.integer(!is.na(i17) & acc17any == 1 & 
                               (any17v1_1 == 1 | any17v1_2 == 1 | any17v1_3 == 1 | any17v1_4 == 1 |
                                  any17v1_5 == 1 | any17v1_6 == 1 | any17v1_7 == 1 | any17v1_8 == 1 |
                                  any17v1_9 == 1 | any17v1_10 == 1 | any17v1_11 == 1 | any17v1_12 == 1)),  # Indicator for any account-related activities
    # Create `g20_17v1_made_AA` based on the first 7 conditions
    g20_17v1_made_AA = as.integer(!is.na(i17) & acc17any == 1 & 
                                    (any17v1_1 == 1 | any17v1_2 == 1 | any17v1_3 == 1 | any17v1_4 == 1 |
                                       any17v1_5 == 1 | any17v1_6 == 1 | any17v1_7 == 1)),  # Indicator for made account-related activities
    # Create `g20_17v1_receive_AA` based on conditions 8 to 12
    g20_17v1_receive_AA = as.integer(!is.na(i17) & acc17any == 1 & 
                                       (any17v1_8 == 1 | any17v1_9 == 1 | any17v1_10 == 1 | any17v1_11 == 1 | any17v1_12 == 1))) %>%  # Indicator for received account-related activities
  
  ##################
# 2021/22
##################

mutate(
  any21v1_adults_1  = as.integer(!is.na(i21_22) & acc21_22any == 1 & wp19480c == 1), # used mobile money
  any21v1_adults_2  = as.integer(!is.na(i21_22) & acc21_22any == 1 & wp19473 == 1), # used a debit card
  any21v1_adults_3  = as.integer(!is.na(i21_22) & acc21_22any == 1 & wp19476 == 1), # used a credit card
  any21v1_adults_4  = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp19504 == 1 | (wp19505 == 1 & acc21_22mob == 1))), # paid bills (acc & mob)
  any21v1_adults_5  = as.integer(!is.na(i21_22) & acc21_22any == 1 & wp21355 == 1), # used mobile to make payment from account 
  any21v1_adults_6  = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp21379 == 1 | wp21380 == 1)), # sent remittances (acc & mob)
  any21v1_adults_7  = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp21368 == 1 | wp21369 == 1 | wp21370 == 1 & (wp21371 == 1 | wp21371 == 3))), # internet
  any21v1_adults_8  = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp21381 == 1 | wp21416 == 1)), # recieved remittances (acc & mob)
  any21v1_adults_9  = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp19523 == 1 | (wp19524 == 1 & m21_22 == 1))), # agricultural payments (acc & mob)
  any21v1_adults_10 = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp19508 == 1 | (wp19509 == 1 & m21_22 == 1) | wp21385 == 1)), # wages
  any21v1_adults_11 = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp21386 == 1 & wp19515 != 1) & ((wp19516 == 1 | wp21389 == 1) | (wp19517 == 1 & m21_22 == 1))), # transfers (acc & mob)
  any21v1_adults_12 = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp19515 == 1) & ((wp19516 == 1 | wp21389 == 1) | (wp19517 == 1 & m21_22 == 1))), # pension (acc & mob)
  any21v1_adults_13 = as.integer(!is.na(i21_22) & acc21_22any == 1 & (wp21367 == 1 | wp21354 == 1 | wp21356 == 1))) %>% # Instore mobile payment and dccard
  
  # Create `g20_21v1` by checking if any of the 13 conditions are met
  mutate(g20_21v1 = case_when(!is.na(i21_22) & acc21_22any == 1 & 
                                (any21v1_adults_1 == 1 | any21v1_adults_2 == 1 | any21v1_adults_3 == 1 |
                                   any21v1_adults_4 == 1 | any21v1_adults_5 == 1 | any21v1_adults_6 == 1 |
                                   any21v1_adults_7 == 1 | any21v1_adults_8 == 1 | any21v1_adults_9 == 1 |
                                   any21v1_adults_10 == 1 | any21v1_adults_11 == 1 | any21v1_adults_12 == 1 |
                                   any21v1_adults_13 == 1) ~ 1,
                              !is.na(i21_22) ~ 0, 
                              TRUE ~ NA),
         # Create `g20_21v1_made` based on first 7 conditions
         g20_21v1_made = as.integer(!is.na(i21_22) & acc21_22any == 1 & 
                                      (any21v1_adults_1 == 1 | any21v1_adults_2 == 1 | any21v1_adults_3 == 1 |
                                         any21v1_adults_4 == 1 | any21v1_adults_5 == 1 | any21v1_adults_6 == 1 |
                                         any21v1_adults_7 == 1)),
         # Create `g20_21v1_received` based on conditions 8-12
         g20_21v1_receive = as.integer(!is.na(i21_22) & acc21_22any == 1 & 
                                         (any21v1_adults_8 == 1 | any21v1_adults_9 == 1 | any21v1_adults_10 == 1 |
                                            any21v1_adults_11 == 1 | any21v1_adults_12 == 1))) %>%
  
  
###########################
# Combining digital payments
###########################

mutate(ts_digpay = case_when(i14 == 1 & acc14any == 1 & g20_14_AA == 1 ~ 1,
                             i17 == 1 & acc17any == 1 & g20_17v1_AA == 1 ~ 1,
                             i21_22 == 1 & acc21_22any == 1 & g20_21v1 == 1 ~ 1,
                             dev24 == 1 & acc24any == 1 & fin_digpay == 1 ~ 1,
                             (dev24 == 1 & findex_q != 5) | i21_22 == 1 | i17 == 1 | i14 == 1 ~ 0,
                             TRUE ~ NA))  %>%
  set_variable_labels(ts_digpay = "Time series: Made OR received a digital payment [of adults]") %>% 
  
  mutate(ts_digpay_make = case_when(i14 == 1 & acc14any == 1 & g20_14_made_AA == 1 ~ 1,
                                    i17 == 1 & acc17any == 1 & g20_17v1_made_AA == 1 ~ 1,
                                    i21_22 == 1 & acc21_22any == 1 & g20_21v1_made == 1 ~ 1,
                                    dev24 == 1 & acc24any == 1 & fin_digpay_make == 1 ~ 1,
                                    (dev24 == 1 & findex_q != 5) | i21_22 == 1 | i17 == 1 | i14 == 1 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(ts_digpay_make = "Time series: Made a digital payment [of adults]") %>% 
  
  mutate(ts_digpay_receive = case_when(i14 == 1 & acc14any == 1 & g20_14_receive_AA == 1 ~ 1,
                                       i17 == 1 & acc17any == 1 & g20_17v1_receive_AA == 1 ~ 1,
                                       i21_22 == 1 & acc21_22any == 1 & g20_21v1_receive == 1 ~ 1,
                                       dev24 == 1 & acc24any == 1 & fin_digpay_receive == 1 ~ 1,
                                       (dev24 == 1 & findex_q != 5)| i21_22 == 1 | i17 == 1 | i14 == 1 ~ 0,
                                       TRUE ~ NA)) %>%
  set_variable_labels(ts_digpay_receive = "Time series: Received a digital payment [of adults]") %>% 
  
  mutate(ts_digpay_both = case_when(i14 == 1 & acc14any == 1 & g20_14_receive_AA == 1 & g20_14_made_AA == 1 ~ 1,
                                    i17 == 1 & acc17any == 1 & g20_17v1_receive_AA == 1 & g20_17v1_made_AA == 1 ~ 1,
                                    i21_22 == 1 & acc21_22any == 1 & g20_21v1_receive == 1 & g20_21v1_made == 1 ~ 1,
                                    dev24 == 1 & acc24any == 1 & fin_digpay_receive == 1 & fin_digpay_make == 1 ~ 1,
                                    (dev24 == 1 & findex_q != 5) | i21_22 == 1 | i17 == 1 | i14 == 1 & findex_q != 5 ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(ts_digpay_both = "Time series: Made AND received a digital payment [of adults]") %>% 
  
  #MERCHANT PAYMENTS
  
  mutate(ts_merpaydig = case_when(i21_22 == 1 & ((wp21371 ==1 |wp21371 == 3) | (wp21367 ==1 | wp21356 == 1| wp21354 == 1)) ~ 1,
                                  dev24 == 1 & fin_merpaydig == 1 ~ 1,
                                  dev24 == 1 | i21_22 == 1 ~ 0,
                                  TRUE ~ NA)) %>% 
  set_variable_labels(ts_merpaydig = "TS: Made a digital merchant payment (online or in-store)  (age 15+)") %>%
  
  
  
  mutate(ts_merpaydig_acc = case_when(i21_22 == 1 & ((wp21371 ==1 |wp21371 == 3) | (wp21367 ==1 | wp21356 == 1| wp21354 == 1)) & acc21_22any == 1 ~ 1,
                                      dev24 == 1 & fin_merpaydig == 1 & acc24any == 1 ~ 1,
                                      dev24 == 1 | i21_22 == 1 ~ 0,
                                      TRUE ~ NA)) %>% 
  set_variable_labels(ts_merpaydig_acc = "TS: Made a digital merchant payment (online or in-store) and have an account (age 15+)") %>%
  
  mutate(ts_instore_mer_dig = case_when(i21_22 == 1 & (wp21367 ==1 | wp21356 == 1| wp21354 == 1) ~ 1,
                                        dev24 == 1 & fin25E_2 == 1 ~ 1,
                                        dev24 == 1 | i21_22 == 1 ~ 0,
                                        TRUE ~ NA)) %>% 
  set_variable_labels(ts_instore_mer_dig = "TS: Made a digital IN-STORE merchant payment (age 15+)") %>%
  
  mutate(ts_instore_mer_dig_acc = case_when(i21_22 == 1 & (wp21367 ==1 | wp21356 == 1| wp21354 == 1) & acc21_22any == 1 ~ 1,
                                            dev24 == 1 & fin25E_2 == 1 & acc24any == 1 ~ 1,
                                            dev24 == 1 | i21_22 == 1 ~ 0,
                                            TRUE ~ NA)) %>% 
  set_variable_labels(ts_instore_mer_dig_acc = "TS: Made a digital IN-STORE merchant payment and have an account (age 15+)") %>%
  
  #in 2024, 6 countries were asked a shortened questionnaire by phone - many of the "receiving digital payments" questions were not included.
  # so that we can create regional averages, we impute digital payments, coding someone as having made/received a digital payment 
  # this is coded as 1 if a person made a digital payment, made a digital merchant payment (online or in-store), OR, used their card or phone to make a payment with their bank (fin3)
  # located here because it draws on merchant payment variable
  mutate(ts_digpay_imputed = case_when(dev24 == 1 & findex_q == 5 & (fin_digpay_make_q5 == 1 | fin3_all == 1 | ts_merpaydig_acc == 1) ~ 1,
                                       dev24 == 1 & findex_q == 5 ~ 0,
                                       TRUE ~ ts_digpay))  %>%
  set_variable_labels(ts_digpay = "Time series: Made OR received a digital payment (imputed for 2024 Q5 countries) [of adults]") %>% 
  
########################
# Misc. Payments
########################

# Agricultural payment

mutate(ts_agpay_any = case_when(i14 == 1 & wp15184 == 1 ~ 1,
                                (i17 == 1 | i21_22 == 1 | i24 == 1) & wp19522 == 1 ~ 1,
                                (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                TRUE ~ NA)) %>%
  set_variable_labels(ts_agpay_any = "TS: Received agricultural payments (age 15+)") %>%
  
  mutate(ts_agpay_dig = case_when(i14 == 1 & (wp15186 == 1 | wp15187 == 1) ~ 1,
                                  i17 == 1 &  (wp19523 == 1 | (wp19524 == 1 & m17 == 1) | wp19526 == 1) ~ 1,
                                  i21_22 == 1 & (wp19523 == 1 | (wp19524 == 1 & m21_22 == 1) | wp21393 == 1) ~ 1,
                                  i24 == 1 &  (wp19523_r == 1 | (wp19524 == 1 & m24 == 1) | wp21393_r == 1) ~1,
                                  (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(ts_agpay_dig = "TS: Received agricultural payments digitally (account, card, phone) (age 15+)") %>% 
  
  
  mutate(ts_agpay_cashonly = case_when(i14 == 1 & wp15185 == 1 & ts_agpay_dig != 1 ~ 1,
                                       i17 == 1 & wp19525 == 1 & ts_agpay_dig != 1 ~ 1,
                                       i21_22 == 1 & wp21392 == 1 & ts_agpay_dig != 1 ~ 1,
                                       i24 == 1 & wp21392_r == 1  & ts_agpay_dig != 1 ~ 1,
                                       (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                       TRUE ~ NA)) %>%
  set_variable_labels(ts_agpay_cashonly = "TS: Received agricultural payments ONLY in cash(age 15+)") %>%  
  
  mutate(ts_agpay_other = case_when(ts_agpay_any == 1 & ts_agpay_dig != 1 & ts_agpay_cashonly != 1 ~ 1,
                                    (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(ts_agpay_other = "TS: Received agricultural payments, other (age 15+)") %>%
  
  mutate(ts_agpay_cash_mm = case_when(ts_agpay_cashonly == 1 & ts_mobaccount == 1  ~ 1,
                                      (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(ts_agpay_cash_mm = "TS: Received agricultural payments only in cash and have a mobile money account (age 15+)") %>%
  
  
  # Utilities

mutate(ts_util_any = case_when((i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) & wp14940 == 1 ~ 1,
                               (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                               TRUE ~ NA)) %>%
  set_variable_labels(ts_util_any = "TS: Made utility payments (age 15+)") %>%
  
  mutate(ts_util_dig = case_when(i14 == 1 & (wp14942 == 1 | wp14943 == 1) ~ 1,
                                 i17 == 1 & (wp19504==1 | (wp19505 == 1 & m17 == 1)) ~ 1,
                                 i21_22 == 1 & (wp19504==1 | (wp19505 == 1 & m21_22 ==1)) ~ 1,
                                 i24 == 1 & wp19504_r == 1 | (m24 == 1 & wp19505 == 1) ~ 1,
                                 (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(ts_util_dig = "TS: Made utility payment digitally (age 15+)") %>%
  
  
  # First time for COVID - 2021 only but important for time series - to include in figure, you need to subtract this from digital utilites
  mutate(ts_util_dig_1cov = case_when(i21_22 == 1 & ts_util_dig == 1 &  wp22438 == 1 ~ 1, # wp22438 is people who paid utiliteis digitally but DID NOT do that before covid
                                     i21_22 == 1 ~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(ts_util_dig_1cov = "TS: Made utility payment digitally for the first time after the start of COVID-19(age 15+)") %>%
  
  mutate(ts_util_cashonly = case_when(i14 == 1 & wp14941 == 1 & ts_util_dig != 1 ~ 1,
                                      i17 == 1 & wp19506 == 1 & ts_util_dig != 1 ~ 1,
                                      i21_22 == 1 & wp21382 == 1 & ts_util_dig != 1 ~ 1,
                                      i24 == 1 & wp24010 == 1 & ts_util_dig != 1 ~ 1,
                                      (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                      TRUE ~ NA)) %>%
  set_variable_labels(ts_util_cashonly = "TS: Made utility payment ONLY in cash (age 15+)") %>%
  
  
  mutate(ts_util_other = case_when(ts_util_any == 1 & ts_util_dig != 1 & ts_util_cashonly != 1 ~ 1,
                                   (i14 == 1 | i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(ts_util_other = "TS: Made utility payment, other (age 15+)") %>%
  
  
  
  # Government transfers or pensions
  mutate(ts_gpay_any = case_when(i17 == 1 & (wp19515 == 1 | wp19514 == 1) ~ 1,
                                 i21_22 == 1 & (wp19515 == 1 | wp21386 == 1) ~ 1,
                                 dev24 == 1 & (wp19515 == 1 | wp21386 == 1) ~ 1,
                                 i17 == 1 | i21_22 == 1 | dev24 == 1 ~ 0, 
                                 TRUE ~ NA))  %>%
  set_variable_labels(ts_gpay_any = "Time series: any government transfer payment or pension [of adults]") %>%
  
  mutate(ts_gpay_dig = case_when(i17 == 1 & (wp19514  == 1 | wp19515 == 1) & (wp19516 == 1 | (wp19517 == 1 & m17==1) | wp19519 == 1) ~ 1,
                                 i21_22 == 1 & (wp19515 == 1 | wp21386 == 1) & (wp19516 == 1 | wp19517 == 1 & (m21_22 == 1)| wp21389 == 1) ~ 1,
                                 dev24 == 1 & findex_q != 5 &
                                   (fin39A == 1 | #Government transfer payment or pension into an account
                                      fin39B == 1 | #Government transfer payment or pension into an mobile phone
                                      fin39D == 1) ~ 1, # Government payments: into a card 
                                 i17 == 1 | i21_22 == 1 | dev24 == 1 ~ 0, 
                                 TRUE ~ NA))  %>%
  set_variable_labels(ts_gpay_dig = "TS: Received government transfer payment or pension digitally (account, card, phone) [of adults]") %>%
  
  
  mutate(ts_gpay_cashonly = case_when(i17 == 1 & wp19518 == 1 & ts_gpay_dig != 1 ~ 1,
                                      i21_22 == 1 & wp21388 == 1 & ts_gpay_dig != 1 ~ 1,
                                      dev24 == 1 & findex_q != 5 &
                                        fin39C == 1 & # fin39C Government payments: in cash (age 15+)
                                        ts_gpay_dig != 1 ~ 1,
                                      i17 == 1 | i21_22 == 1 | dev24 == 1 ~ 0, 
                                      TRUE ~ NA))  %>%
  set_variable_labels(ts_gpay_cashonly = "TS: Received a government transfer payment or pension ONLY in cash [of adults]") %>%
  
  mutate(ts_gpay_other = case_when(ts_gpay_any == 1 & ts_gpay_dig != 1 & ts_gpay_cashonly != 1 ~ 1,
                                   ( i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(ts_agpay_other = "TS: Received government transfer payment or pension, other (age 15+)") %>%
  
  #ts_G2P series (incudes government payments/ government transfers, pensions, and wages)
  mutate(ts_g2p_any = case_when(
    i17 == 1 & (wp19514 == 1 | wp19515 == 1 | wp14945 == 1) ~ 1, # Year 2017 condition
    i21_22 == 1 & (wp19515 == 1 | wp21386 == 1 | wp14945 == 1) ~ 1,
    dev24 == 1 & (wp14945_r == 1 | wp19515 == 1 | wp21386 == 1) ~ 1,
    dev24 == 1 | i17 == 1 | i21_22 == 1  ~ 0, 
    TRUE ~ NA)) %>%
  set_variable_labels(ts_g2p_any = "Time series: any G2P payment [of adults]") %>%
  
  mutate(ts_g2p_dig = case_when(i17 == 1 & ((wp19516 == 1 | (wp19517 == 1 & m17==1) | wp19519 == 1) | # government transfer/pension
                                              (wp14945 == 1 & (wp19508 == 1 | (wp19509 == 1 & m17==1) | wp19511 == 1))) ~ 1, # public wages
                                i21_22 == 1 & ((wp19516 == 1 | (wp19517 == 1 & m21_22 == 1)| wp21389 == 1) | 
                                                 (wp14945 == 1 & (wp19508 == 1 | (wp19509 == 1 & m21_22 == 1) | wp21385 == 1))) ~ 1,
                                dev24 == 1 & findex_q != 5 &
                                  (fin39A == 1 | #Government transfer payment or pension into an account
                                     fin39B == 1 | #Government transfer payment or pension into an mobile phone
                                     fin39D == 1 | #Government transfer payment or pension into a card
                                     fin_wgpub_dig == 1) ~ 1, # Received Public Sector Wages Digitally
                                i17 == 1 | i21_22 == 1 | dev24 == 1 ~ 0,
                                TRUE ~ NA))  %>%
  set_variable_labels(ts_g2p_dig = "TS: Received a g2p payment digitally [of adults]") %>%
  
  
  mutate(ts_g2p_cashonly = case_when(i17 == 1 & (wp19518 == 1 | (wp14945 == 1	& wp19510 == 1)) & ts_g2p_dig != 1 ~ 1,
                                     i21_22 == 1 & (wp21388 == 1 |(wp14945 == 1 & wp21384 == 1)) & ts_g2p_dig != 1 ~ 1,
                                     dev24 == 1 & findex_q != 5 &
                                       (fin39C == 1 | fin_wgpub_cashonly == 1) & # fin39C Government payments: in cash (age 15+)
                                       ts_g2p_dig != 1 ~ 1,
                                     i17 == 1 | i21_22 == 1 | dev24 == 1 ~ 0,
                                     TRUE ~ NA))  %>%
  set_variable_labels(ts_g2p_cashonly = "TS: Received a g2p payment ONLY in cash [of adults]") %>%
  
  
  
  mutate(ts_g2p_other = case_when(ts_g2p_any == 1 & ts_g2p_dig != 1 & ts_g2p_cashonly != 1 ~ 1,
                                  ( i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(ts_g2p_other = "TS: Received g2p payments, other (age 15+)") %>%
  
  
  # Percent who receive a govt payment in cash AND have a mobile money account
  mutate(ts_g2p_cashonly_mm = case_when(ts_g2p_cashonly == 1 & ts_mobaccount == 1  ~ 1,
                                        ( i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                        TRUE ~ NA)) %>%
  set_variable_labels(ts_g2p_cashonly_mm = "TS: Received govt payments only in cash and have a mobile money account (age 15+)") %>%
  

  # Received Any Public Sector Wages
  mutate(ts_fin_wgpub = case_when(
    i14 == 1 & wp14945 == 1 & wp14944 == 1 ~ 1,
    i17 == 1 & wp14945 == 1 & wp19507 == 1  ~ 1,
    i21_22 == 1 & wp14945 == 1 & wp19507 == 1 ~ 1,
    dev24 == 1 & findex_q != 5 & fin32 == 1 & fin33 == 1  ~ 1, # Other methods
    dev24 == 1 | i17 == 1 | i21_22 == 1 | i14 == 1 ~ 0,
    TRUE ~ NA)) %>%
  set_variable_labels(ts_fin_wgpub = "Time series: Received Any Public Sector Wages [of adults]") %>%

  # Received Public Sector Wages Digitally
  mutate(ts_fin_wgpub_dig = case_when(
    i14 == 1 & wp14945 == 1 & wp14944 == 1 & (wp14947 == 1 | wp14948 == 1 | wp14949 == 1) ~ 1,
    i17 == 1 & wp14945 == 1 & wp19507 == 1 & (wp19508 == 1 | wp19509 == 1 | wp19511 == 1) ~ 1,
    i21_22 == 1 & wp14945 == 1 & wp19507 == 1 & (wp19508 == 1 | wp19509 == 1 | wp21385== 1) ~ 1,
    dev24 == 1 & findex_q != 5 & fin32 == 1 &
      fin33 == 1 & #Employed by the government, military, or public sector in the past 12 months (age 15+)
      (fin34A == 1 | fin34B == 1 | fin34D == 1) ~ 1, # Return `dev24` value instead of just 1
    dev24 == 1 | i17 == 1 | i21_22 == 1 | i14 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_fin_wgpub_dig = "Time series: Received Public Sector Wages Digitally [of adults]") %>%

  # Received Public Sector Wages in cash only
  mutate(ts_fin_wgpub_cashonly = case_when(
    i14 == 1 & ts_fin_wgpub == 1 & wp14946 == 1 & ts_fin_wgpub_dig != 1 ~ 1,
    (i17 == 1 & wp14945 == 1 & wp19507 == 1) & wp19510 == 1 & wp19508 != 1 & wp19509 != 1 & wp19511 != 1 ~ 1,
    i21_22 == 1 & wp14945 == 1 & wp19507 == 1 &  (!is.na(wp21384) & wp21384 == 1) & ts_fin_wgpub_dig != 1 ~ 1,
    dev24 == 1 & findex_q != 5 & fin32 == 1 & fin33 == 1 & #Employed by the government, military, or public sector in the past 12 months (age 15+)
      fin34C == 1 & #Wage payments: in cash (age 15+)
      (fin34A != 1 & #Wage payments: directly into an account at a bank or a financial institution (age 15+)
         fin34B != 1 & #Wage payments: through a mobile phone (age 15+)
         fin34D != 1) ~ 1, #Wage payments: into a card (age 15+)
    dev24 == 1 | i17 == 1 | i21_22 == 1 | i14 ==1  ~ 0,
    TRUE ~ NA)) %>%
  set_variable_labels(ts_fin_wgpub_cashonly = "Time series: Received Public Sector Wages in cash only [of adults]") %>%

  # Received Public Wages Other
  mutate(ts_fin_wgpub_other = case_when(
    i14 == 1 & ts_fin_wgpub == 1 & ts_fin_wgpub_dig != 1 & ts_fin_wgpub_cashonly != 1 ~ 1,
    i17 == 1 & wp14945 == 1 & wp19507 == 1 & wp19510 != 1 & wp19508 != 1 & wp19509 != 1 & wp19511 != 1 ~ 1,
    i21_22 == 1 & wp14945 == 1 & wp19507 == 1 & wp21384 != 1 & wp19508 != 1 & wp19509 != 1 & wp21385 != 1 ~ 1,
    dev24 == 1 & findex_q != 5 & fin32 == 1 & fin33 == 1 & fin34A != 1 & fin34B != 1 & fin34D != 1 & fin34C != 1 ~ 1, # Other methods
    dev24 == 1 | i17 == 1 | i21_22 == 1 | i14 == 1 ~ 0,
    TRUE ~ NA)) %>%
  set_variable_labels(ts_fin_wgpub_other = "Time series: Received Public Wages Other [of adults]") %>%

  # Received Any Private Sector Wages in the past year
  mutate(ts_fin_wgpriv = case_when(
    i14 == 1 & wp14944 == 1 & wp14945 != 1 ~ 1,
    i17 == 1 & wp19507 == 1 &  wp14945 != 1 ~ 1,
    i21_22 == 1 & wp19507 == 1 &  wp14945 != 1 ~ 1,
    dev24 == 1 & wp19507_r == 1 &  wp14945_r != 1 ~ 1,
    dev24 == 1| i21_22 == 1|i17 == 1 |i14 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_fin_wgpriv = "Time series: Received Private Sector Wages in the past year [of adults]") %>%

  # Received private Sector Wages Digitally
  mutate(ts_fin_wgpriv_dig = case_when(
    i14 == 1 & wp14945 != 1 & wp14944 == 1 & (wp14947 == 1 |wp14948 == 1 | wp14949 == 1) ~ 1,
    i17 == 1 & wp14945 != 1 & wp19507 == 1 & (wp19508 == 1 | wp19509 == 1 | wp19511 == 1) ~ 1,
    i21_22 == 1 & wp14945 != 1 & wp19507 == 1 & (wp19508 == 1 | wp19509 == 1 | wp21385== 1) ~ 1,
    dev24 == 1 & findex_q != 5 & fin32 == 1 &
      fin33 != 1 & #Employed by the government, military, or public sector in the past 12 months (age 15+)
      (fin34A == 1 | fin34B == 1 | fin34D == 1) ~ 1, # Return `dev24` value instead of just 1
    dev24 == 1 | i17 == 1 | i21_22 == 1 | i14 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_fin_wgpriv_dig = "Time series: Received Private Sector Wages Digitally [of adults]") %>%

  # Received private Sector  Wages in cash only
  mutate(ts_fin_wgpriv_cashonly = case_when(
    (i14 == 1 & wp14945 != 1 & wp14944 == 1) & wp14946 == 1 & ts_fin_wgpriv_dig != 1 ~ 1,
    (i17 == 1 & wp14945 != 1 & wp19507 == 1) & wp19510 == 1 & wp19508 != 1 & wp19509 != 1 & wp19511 != 1 ~ 1,
    i21_22 == 1 & wp14945 != 1 & wp19507 == 1 &  (!is.na(wp21384) & wp21384 == 1) & ts_fin_wgpriv_dig != 1 ~ 1,
    dev24 == 1 & findex_q != 5 & fin32 == 1 & fin33 != 1 & #Employed by the government, military, or public sector in the past 12 months (age 15+)
      fin34C == 1 & #Wage payments: in cash (age 15+)
      (fin34A != 1 & #Wage payments: directly into an account at a bank or a financial institution (age 15+)
         fin34B != 1 & #Wage payments: through a mobile phone (age 15+)
         fin34D != 1) ~ 1, #Wage payments: into a card (age 15+)
    dev24 == 1 | i17 == 1 | i21_22 == 1 | i14 == 1 ~ 0,
    TRUE ~ NA)) %>%
  set_variable_labels(ts_fin_wgpriv_cashonly = "Time series: Received Private Sector Wages in cash only [of adults]") %>%

  # Received private Sector Wages Other
  mutate(ts_fin_wgpriv_other = case_when(
    i14 == 1 & wp14945 != 1 & wp14944 == 1 & wp14946 != 1 & wp14944 != 1 & wp14948 != 1 & wp14949 != 1 ~1,
    i17 == 1 & wp14945 != 1 & wp19507 == 1 & wp19510 != 1 & wp19508 != 1 & wp19509 != 1 & wp19511 != 1 ~ 1,
    i21_22 == 1 & wp14945 != 1 & wp19507 == 1 & wp21384 != 1 & wp19508 != 1 & wp19509 != 1 & wp21385 != 1 ~ 1,
    dev24 == 1 & findex_q != 5 & fin32 == 1 & fin33 != 1 & fin34A != 1 & fin34B != 1 & fin34D != 1 & fin34C != 1 ~ 1, # Other methods
    dev24 == 1 | i17 == 1 | i21_22 == 1 | i14 == 1 ~ 0,
    TRUE ~ NA)) %>%
  set_variable_labels(ts_fin_wgpriv_other = "Time series: Received Public Wages Other [of adults]") %>%


  
#######################################################
# FINANCIAL HEALTH/RESILIENCE
#######################################################

mutate(ts_resil_poss = case_when(i21_22 == 1 & !is.na(wp21376) & wp21376 %in% c(1,2,3,4,5,6) ~ 1,
                                 dev24 == 1 & !is.na(wp21376_r) & wp21376_r %in% c(1,2,3,4,5,6) ~ 1,
                                 ( i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_poss = "TS: Possible to come up with emergency money in 30 days: POSSIBLE (age 15+)") %>%
  
  mutate(ts_resil_Nposs = case_when(i21_22 == 1 & !is.na(wp21376) & wp21376 == 7 ~ 1,
                                    dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 7 ~ 1,
                                    ( i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_Nposs = "TS: Possible to come up with emergency money in 30 days: NOT POSSIBLE (age 15+)") %>%
  
  mutate(ts_resil_dkr = case_when(i21_22 == 1 & !is.na(wp21376) & wp21376 %in% c(8,9) ~ 1,
                                  dev24 == 1 & !is.na(wp21376_r) & wp21376_r %in% c(8,9) ~ 1,
                                  ( i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                  TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_dkr = "TS: Possible to come up with emergency money in 30 days: DK/Refused (age 15+)") %>%
  
  # difficulty for POSSIBLE
  mutate(ts_resil_SD_ND = case_when(i21_22 == 1 & !is.na(wp21377) & wp21377 %in% c(2,3) ~ 1,
                                    dev24 == 1 & !is.na(wp21377_r) & wp21377_r %in% c(2,3) ~ 1,
                                    ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                    TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_SD_ND = "TS: Coming up with emergency money: Somewhat or not difficult (age 15+)") %>%
  
  # SOMEWHAT OR NOT DIFFICULT BY EMERGENCY MONEY MODE
  
  mutate(ts_resil_savings_SD_ND = case_when(i21_22 == 1 & wp21376 == 1 & ts_resil_SD_ND == 1 ~ 1,
                                            dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 1 & ts_resil_SD_ND == 1 ~ 1,
                                            ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_savings_SD_ND  = "TS: Main source of money in case of emergency: Savings, somewhat or not difficult (age 15+)") %>%
  
  mutate(ts_resil_family_SD_ND  = case_when(i21_22 == 1 & wp21376 == 2 & ts_resil_SD_ND == 1 ~ 1,
                                            dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 2 & ts_resil_SD_ND == 1 ~ 1,
                                            ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_family_SD_ND  = "TS: Main source of money in case of emergency: Family, relatives or friends, somewhat or not difficult (age 15+)") %>%
  
  mutate(ts_resil_working_SD_ND  = case_when(i21_22 == 1 & wp21376 == 3 & ts_resil_SD_ND == 1 ~ 1,
                                             dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 3 & ts_resil_SD_ND == 1 ~ 1,
                                             ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                             TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_working_SD_ND  = "TS: Main source of money in case of emergency: Money from working, somewhat or not difficult (age 15+)") %>%
  
  mutate(ts_resil_loan_SD_ND  = case_when(i21_22 == 1 & wp21376 == 4 & ts_resil_SD_ND == 1 ~ 1,
                                          dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 4 & ts_resil_SD_ND == 1 ~ 1,
                                          ( i17 == 1 | i21_22 == 1 | i24 == 1) ~ 0,
                                          TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_loan_SD_ND  = "TS: Main source of money in case of emergency: A loan from a financial institution, an employer or private lender, somewhat or not difficult (age 15+)") %>%
  
  mutate(ts_resil_selling_SD_ND = case_when(i21_22 == 1 & wp21376 == 5 & ts_resil_SD_ND == 1 ~ 1,
                                            dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 5 & ts_resil_SD_ND == 1 ~ 1,
                                            ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                            TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_selling_SD_ND  = "TS: Main source of money in case of emergency: Selling something of own such as jewellery or livestock, somewhat or not difficult (age 15+)") %>%
  
  mutate(ts_resil_other_SD_ND  = case_when(i21_22 == 1 & wp21376 == 6 & ts_resil_SD_ND == 1 ~ 1,
                                           dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 6 & ts_resil_SD_ND == 1 ~ 1,
                                           ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                           TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_other_SD_ND  = "TS: Main source of money in case of emergency: Some other source, somewhat or not difficult (age 15+)") %>%
  
  
  # VERY DIFFICULT BY EMERGENCY MONEY MODE - fin24A_VD is coded in findex raw variable file
  
  mutate(ts_resil_VD = case_when(i21_22 == 1 & wp21377 == 1 ~ 1,
                                 dev24 == 1 & !is.na(wp21377_r) & wp21377_r == 1 ~ 1,
                                 ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                 TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_VD = "TS: Very difficult coming up with emergency money (age 15+)") %>%
  
  mutate(ts_resil_savings_VD = case_when(i21_22 == 1 & wp21376 == 1 & ts_resil_VD == 1 ~ 1,
                                         dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 1 & ts_resil_VD == 1 ~ 1,
                                         ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_savings_VD  = "TS: Main source of money in case of emergency: Savings, very difficult (age 15+)") %>%
  
  mutate(ts_resil_family_VD  = case_when(i21_22 == 1 & wp21376 == 2 & ts_resil_VD == 1 ~ 1,
                                         dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 2 & ts_resil_VD == 1 ~ 1,
                                         ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                         TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_family_VD  = "TS: Main source of money in case of emergency: Family, relatives or friends, very difficult (age 15+)") %>%
  
  mutate(ts_resil_working_VD  = case_when(i21_22 == 1 & wp21376 == 3 & ts_resil_VD == 1 ~ 1,
                                          dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 3 & ts_resil_VD == 1 ~ 1,
                                          ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                          TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_working_VD  = "TS: Main source of money in case of emergency: Money from working, very difficult (age 15+)") %>%
  
  mutate(ts_resil_loan_VD  = case_when(i21_22 == 1 & wp21376 == 4 & ts_resil_VD == 1 ~ 1,
                                       dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 4 & ts_resil_VD == 1 ~ 1,
                                       ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                       TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_loan_VD  = "TS: Main source of money in case of emergency: A loan from a financial institution, an employer or private lender, very difficult (age 15+)") %>%
  
  mutate(ts_resil_selling_VD  = case_when(i21_22 == 1 & wp21376 == 5 & ts_resil_VD == 1 ~ 1,
                                          dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 5 & ts_resil_VD == 1 ~ 1,
                                          ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                          TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_selling_VD  = "TS: Main source of money in case of emergency: Selling something of own such as jewellery or livestock, very difficult (age 15+)") %>%
  
  mutate(ts_resil_other_VD  = case_when(i21_22 == 1 & wp21376 == 6 & ts_resil_VD == 1 ~ 1,
                                        dev24 == 1 & !is.na(wp21376_r) & wp21376_r == 6 & ts_resil_VD == 1 ~ 1,
                                        ( i17 == 1 | i21_22 == 1 | dev24 == 1) ~ 0,
                                        TRUE ~ NA)) %>%
  set_variable_labels(ts_resil_other_VD  = "TS: Main source of money in case of emergency: Some other source, very difficult (age 15+)") %>%
  
  
  ### Waterfall Variables: SOMEWHAT TO NOT DIFFICULT TO COME UP WITH EMERGENCY MONEY ####

# Family
mutate(ts_ef_fam_SD_ND = case_when(
  dev24 == 1 & wp21376_r == 2 & wp21377_r %in% c(2, 3) ~ 1,
  i21_22 == 1 & wp21376 == 2 & wp21377 %in% c(2, 3) ~ 1,
  i21_22 == 1 | dev24 == 1 ~ 0,
  TRUE ~ NA
)) %>%
  set_variable_labels(ts_ef_fam_SD_ND = "Time series: Emerg funds: family not difficult to somewhat difficult [of adults]") %>%
  
  # Work
  mutate(ts_ef_work_SD_ND = case_when(
    dev24 == 1 & wp21376_r == 3 & wp21377_r %in% c(2, 3) ~ 1,
    i21_22 == 1 & wp21376 == 3 & wp21377 %in% c(2, 3) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_work_SD_ND = "Time series: Emerg funds: work not difficult to somewhat difficult [of adults]") %>%
  
  # Saving
  mutate(ts_ef_saving_SD_ND = case_when(
    dev24 == 1 & wp21376_r == 1 & wp21377_r %in% c(2, 3) ~ 1,
    i21_22 == 1 & wp21376 == 1 & wp21377 %in% c(2, 3) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_saving_SD_ND = "Time series: Emerg funds: savings not difficult to somewhat difficult [of adults]") %>%
  
  # Borrow
  mutate(ts_ef_borrow_SD_ND = case_when(
    dev24 == 1 & wp21376_r == 4 & wp21377_r %in% c(2, 3) ~ 1,
    i21_22 == 1 & wp21376 == 4 & wp21377 %in% c(2, 3) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_borrow_SD_ND = "Time series: Emerg funds: borrow, not difficult to somewhat difficult [of adults]") %>%
  
  # Sell assets
  mutate(ts_ef_asset_SD_ND = case_when(
    dev24 == 1 & wp21376_r == 5 & wp21377_r %in% c(2, 3) ~ 1,
    i21_22 == 1 & wp21376 == 5 & wp21377 %in% c(2, 3) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_asset_SD_ND = "Time series: Emerg funds: selling assets, not difficult to somewhat difficult [of adults]") %>%
  
  # Other
  mutate(ts_ef_other_SD_ND = case_when(
    dev24 == 1 & wp21376_r == 6 & wp21377_r %in% c(2, 3) ~ 1,
    i21_22 == 1 & wp21376 == 6 & wp21377 %in% c(2, 3) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_other_SD_ND = "Time series: Emerg funds: other, not difficult to somewhat difficult [of adults]") %>%
  
  # Any source
  mutate(ts_ef_any_SD_ND = case_when(
    dev24 == 1 & wp21377_r %in% c(2, 3) & wp21376_r %in% c(1,2,3,4,5,6) ~ 1,
    i21_22 == 1 & wp21377 %in% c(2, 3) & wp21376 %in% c(1,2,3,4,5,6) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_any_SD_ND = "Time series: Emerg funds: any, not difficult to somewhat difficult [of adults]") %>%
  
  # saving
  mutate(
    ts_ef_saving_SD_ND = case_when(
      dev24 == 1 & wp21376_r == 1 & wp21377_r %in% c(2, 3) ~ 1,
      i21_22 == 1 & wp21376 == 1 & wp21377 %in% c(2, 3) ~ 1,
      i21_22 == 1 | dev24 == 1 ~ 0,
      TRUE ~ NA)) %>%
  set_variable_labels(ts_ef_saving_SD_ND = "Time series: Emerg funds: savings not difficult to somewhat difficult [of adults]") %>% 
  
  # borrow 
  mutate(
    ts_ef_borrow_SD_ND = case_when(
      dev24 == 1 & wp21376_r == 4 & wp21377_r %in% c(2, 3) ~ 1,
      i21_22 == 1 & wp21376 == 4 & wp21377 %in% c(2, 3) ~ 1,
      i21_22 == 1 | dev24 == 1 ~ 0,
      TRUE ~ NA)) %>%
  set_variable_labels(ts_ef_borrow_SD_ND = "Time series: Emerg funds: borrow, not difficult to somewhat difficult [of adults]") %>%
  
  # sell assets
  mutate(
    ts_ef_asset_SD_ND = case_when(
      dev24 == 1 & wp21376_r == 5 & wp21377_r %in% c(2, 3) ~ 1,
      i21_22 == 1 & wp21376 == 5 & wp21377 %in% c(2, 3) ~ 1,
      i21_22 == 1 | dev24 == 1 ~ 0,
      TRUE ~ NA)) %>%
  set_variable_labels(ts_ef_asset_SD_ND = "Time series:Emerg funds:  selling assets,not difficult to somewhat difficult [of adults]") %>%
  
  # other
  mutate(
    ts_ef_other_SD_ND = case_when(
      dev24 == 1 & wp21376_r == 6 & wp21377_r %in% c(2, 3) ~ 1,
      i21_22 == 1 & wp21376 == 6 & wp21377 %in% c(2, 3) ~ 1,
      i21_22 == 1 | dev24 == 1 ~ 0,
      TRUE ~ NA)) %>%
  set_variable_labels(ts_ef_other_SD_ND = "Time series: Emerg funds: other, not difficult to somewhat difficult [of adults]") %>% 
  
  # any source
  mutate(
    ts_ef_any_SD_ND = case_when(
      dev24 == 1 & wp21377_r  %in% c(2, 3)  & wp21376_r %in% c(1,2,3,4,5,6) ~ 1,
      i21_22 == 1 & wp21377  %in% c(2, 3) & wp21376 %in% c(1,2,3,4,5,6) ~ 1,
      i21_22 == 1 | dev24 == 1 ~ 0,
      TRUE ~ NA)) %>%
  set_variable_labels(ts_ef_any_SD_ND = "Time series: Emerg funds: any, not difficult to somewhat difficult [of adults]") %>%
  
  #### VERY DIFFICULT TO COME UP WITH EMERGENCY MONEY #########

# Family
mutate(ts_ef_fam_VD = case_when(
  dev24 == 1 & wp21377_r == 1 & wp21376_r == 2 ~ 1,
  i21_22 == 1 & wp21377 == 1 & wp21376 == 2 ~ 1,
  i21_22 == 1 | dev24 == 1 ~ 0,
  TRUE ~ NA
)) %>%
  set_variable_labels(ts_ef_fam_VD = "Time series: Emerg funds: family, very difficult [of adults]") %>%
  
  # Work
  mutate(ts_ef_work_VD = case_when(
    dev24 == 1 & wp21377_r == 1 & wp21376_r == 3 ~ 1,
    i21_22 == 1 & wp21377 == 1 & wp21376 == 3 ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_work_VD = "Time series: Emerg funds: work very difficult [of adults]") %>%
  
  # Savings
  mutate(ts_ef_saving_VD = case_when(
    dev24 == 1 & wp21377_r == 1 & wp21376_r == 1 ~ 1,
    i21_22 == 1 & wp21377 == 1 & wp21376 == 1 ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_saving_VD = "Time series: Emerg funds: savings very difficult [of adults]") %>%
  
  # Borrow
  mutate(ts_ef_borrow_VD = case_when(
    dev24 == 1 & wp21377_r == 1 & wp21376_r == 4 ~ 1,
    i21_22 == 1 & wp21377 == 1 & wp21376 == 4 ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_borrow_VD = "Time series: Emerg funds: borrow very difficult [of adults]") %>%
  
  # Sell Assets
  mutate(ts_ef_asset_VD = case_when(
    dev24 == 1 & wp21377_r == 1 & wp21376_r == 5 ~ 1,
    i21_22 == 1 & wp21377 == 1 & wp21376 == 5 ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_asset_VD = "Time series: Emerg funds: selling assets, very difficult [of adults]") %>%
  
  # Other
  mutate(ts_ef_other_VD = case_when(
    dev24 == 1 & wp21377_r == 1 & wp21376_r == 6 ~ 1,
    i21_22 == 1 & wp21377 == 1 & wp21376 == 6 ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_other_VD = "Time series: Emerg funds: other, very difficult [of adults]") %>%
  
  # Any Source
  mutate(ts_ef_any_VD = case_when(
    dev24 == 1 & wp21377_r == 1 & wp21376_r %in% c(1, 2, 3, 4, 5, 6) ~ 1,
    i21_22 == 1 & wp21377 == 1 & wp21376 %in% c(1, 2, 3, 4, 5, 6) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_any_VD = "Time series: Emerg funds: any, very difficult [of adults]") %>%
  
  # Not Possible
  mutate(ts_ef_np = case_when(
    dev24 == 1 & wp21376_r == 7 ~ 1,
    i21_22 == 1 & wp21376 == 7 ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_ef_np = "Time series: Emerg funds: Not possible [of adults]") %>%
  
  
  # Don't Know/Refused
  mutate(ts_fin24_dkr = case_when(
    dev24 == 1 & wp21376_r %in% c(8, 9) ~ 1,
    i21_22 == 1 & wp21376 %in% c(8, 9) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_fin24_dkr = "Possible to come up with emergency money in 30 days: DK/Refused (age 15+)") %>%
  
  
  
  ### Greatest financial worry #########
#####################################
# please note that in 2024 respondents had to choose one option, there was not a "not worried" option

mutate(
  # Most worried about old age
  ts_Mworry_old = case_when(
    dev24 == 1 & wp21398_r == 1 ~ 1,
    i21_22 == 1 & (wp21398 == 1 |
                     (wp21394 %in% c(1, 2) &
                        !wp21395%in% c(1, 2) &
                        !wp21396 %in% c(1, 2) &
                        !wp21397 %in% c(1, 2))) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA)) %>%
  set_variable_labels(ts_Mworry_old = "TS: Most worried: money for old age [of adults]") %>%
  
  # Most worried about business 
  mutate(ts_Mworry_bus = case_when(dev24 == 1 & wp21398_r == 2 ~ 1,
                                   dev24 == 1 ~ 0,
                                   TRUE ~ NA)) %>%
  set_variable_labels(ts_Mworry_bus = "TS: Most worried: money for business") %>%
  
  mutate(
    # Most worried about medical costs in case of a serious illness or accident
    ts_Mworry_med = case_when(
      dev24 == 1 & wp21398_r == 3 ~ 1,
      i21_22 == 1 & (wp21398 == 2 | 
                       (wp21395 %in% c(1, 2) & 
                          !wp21394 %in% c(1, 2) & 
                          !wp21396 %in% c(1, 2) & 
                          !wp21397 %in% c(1, 2))) ~ 1,
      i21_22 == 1 | dev24 == 1 ~ 0,
      TRUE ~ NA
    )
  ) %>%
  set_variable_labels(ts_Mworry_med = "TS: Most worried: medical costs [of adults]") %>%
  
  
  mutate(
    # Most worried about monthly expenses or bills
    ts_Mworry_exp = case_when(
      dev24 == 1 & wp21398_r == 4 ~ 1,
      i21_22 == 1 & (wp21398 == 3 |
                       (wp21396 %in% c(1, 2) &
                          !wp21394 %in% c(1, 2) &
                          !wp21395 %in% c(1, 2) &
                          !wp21397 %in% c(1, 2))) ~ 1,
      i21_22 == 1 | dev24 == 1 ~ 0,
      TRUE ~ NA
    )
  ) %>%
  
  
  # Most worried about paying school or education fees
  mutate(ts_Mworry_sch = case_when(
    dev24 == 1 & wp21398_r == 5 ~ 1,
    i21_22 == 1 & (wp21398 == 4 | 
                     (wp21397 %in% c(1,2) & 
                        !wp21394 %in% c(1,2) & 
                        !wp21395 %in% c(1,2) & 
                        !wp21396 %in% c(1,2))) ~ 1,
    i21_22 == 1 | dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_Mworry_sch = "TS: Most worried: money for education [of adults]") %>%
  
  # Most worried about other
  mutate(ts_Mworry_other = case_when(
    dev24 == 1 & wp21398_r == 6 ~ 1,
    dev24 == 1 ~ 0,
    TRUE ~ NA
  )) %>%
  set_variable_labels(ts_Mworry_other = "TS: Most worried: money for some other reason [of adults]")
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  
  