##############
# NOTE: 
# there is definitely a way to loop through this whole file and make it faster
# if an enterprising person would like to do that, please feel free

dataframe_2024 <- dataframe_2024 %>%
  
  # Generate ls (life satisfaction today) and set to NA if ls > 100
  mutate(
    ls = ifelse(wp16 * 10 <= 100, wp16 * 10, NA_real_),  # Calculate ls; set to NA if > 100
    ls_future = ifelse(wp18 * 10 <= 100, wp18 * 10, NA_real_)  # Calculate ls_future; set to NA if > 100
  ) %>%
  # Add variable labels
  set_variable_labels(
    ls = "Life satisfaction today",
    ls_future = "Life satisfaction in 5 years"
  )


# Define the variables
binary_vars <- c("wp27", "wp61", "wp63", "wp67", "wp69", "wp70", "wp74")
scale_vars <- c("ls", "ls_future", "ls_fut_cur", "pos_ind", "neg_ind", "psych")

dataframe_2024 <- dataframe_2024 %>%
  # Ensure binary_vars exist before creating binary indicators
  mutate(across(all_of(binary_vars), ~ ifelse(!is.na(.) & . == 1, 1, 0), .names = "yn_{.col}")) %>%
  
  # Add new calculated columns to ensure scale_vars exist
  mutate(
    pos_ind = 100 * (yn_wp63 + yn_wp67) / 2,
    neg_ind = 100 * (yn_wp69 + yn_wp70 + yn_wp74) / 3,
    psych = 100 * (yn_wp61 + yn_wp27) / 2,
    ls_future = ifelse(!is.na(ls_future), ls_future, 0),  # Ensure ls_future exists
    ls = ifelse(!is.na(ls), ls, 0),                      # Ensure ls exists
    ls_fut_cur = ls_future / ls
  ) %>%
  
  # Perform scaling for selected variables with renaming
  mutate(across(all_of(scale_vars), ~ ./100, .names = "cv_{.col}")) %>%

# variable names
  set_variable_labels(ls = "life satisfaction today") %>% 
  set_variable_labels(ls_future = "life satisfaction in 5 years") %>% 
  set_variable_labels(pos_ind = "Positive Index") %>% 
  set_variable_labels(neg_ind = "Negative Index") %>% 
  set_variable_labels(psych = "Psychological effects") %>% 
  set_variable_labels(ls_fut_cur = "Ratio of life satisfaction in future versus current life satisfaction") %>%

###################################################################################################


# Divide each selected variable by 100 to convert from percentage to decimal format
  mutate(
    ls = ls / 100,
    ls_future = ls_future / 100,
    ls_fut_cur = ls_fut_cur / 100,
    pos_ind = pos_ind / 100,
    neg_ind = neg_ind / 100,
    psych = psych / 100
  ) %>%

# making wp23 and wp27 binary, (wp23=Health problems, wp27 = count on relatives and friends)

  mutate(
    cv_wp23 = case_when(
      wp23 == 1 ~ 1,  # Binary: 1 if wp23 is 1
      !is.na(wp23) ~ 0,
      TRUE ~ NA                     # 0 for all other cases
    ),
    cv_wp27 = case_when(
      wp27 == 1 ~ 1,  # Binary: 1 if wp27 is 1
      !is.na(wp27) ~ 0,
      TRUE ~ NA                      # 0 for all other cases
    )
  ) %>%
  set_variable_labels(
    cv_wp23 = "Health problems prevent",
    cv_wp27 = "Can count on relatives and friends"
  ) %>%

  # Create binary indicators for wp30
  mutate(
    cv1_wp30 = case_when(
      !is.na(wp30) & wp30 == 1 ~ 1,  # Satisfied
      !is.na(wp30) ~ 0,
      TRUE ~ NA
    ),
    cv2_wp30 = case_when(
      !is.na(wp30) & wp30 == 2 ~ 1,  # Dissatisfied
      !is.na(wp30) ~ 0,
      TRUE ~ NA
    ),
    
    # Create binary indicators for wp31
    cv1_wp31 = case_when(
      !is.na(wp31) & wp31 == 1 ~ 1,  # Getting better
      !is.na(wp31) ~ 0,
      TRUE ~ NA
    ),
    cv2_wp31 = case_when(
      !is.na(wp31) & wp31 == 2 ~ 1,  # Same
      !is.na(wp31) ~ 0,
      TRUE ~ NA
    ),
    cv3_wp31 = case_when(
      !is.na(wp31) & wp31 == 3 ~ 1,  # Getting worse
      !is.na(wp31) ~ 0,
      TRUE ~ NA
    )
  ) %>%
  # Assign labels to the new variables
  set_variable_labels(
    cv1_wp30 = "Satisfied with standard of living",
    cv2_wp30 = "Dissatisfied with standard of living",
    cv1_wp31 = "Standard of living: getting better",
    cv2_wp31 = "Standard of living: same",
    cv3_wp31 = "Standard of living: getting worse"
  ) %>%

# creating variables with cv at the start of variable names for wp40, wp43, wp10200, and wp10202
  # Create binary indicators
  mutate(
    cv_wp40 = case_when(
      !is.na(wp40) & wp40 == 1 ~ 1,  # Set to 1 if wp40 == 1
      !is.na(wp40) ~ 0,
      TRUE ~ NA                      # Otherwise, set to 0
    ), 
    cv_wp43 = case_when(
      !is.na(wp43) & wp43 == 1 ~ 1,  # Set to 1 if wp43 == 1
      !is.na(wp43) ~ 0,
      TRUE ~ NA                       # Otherwise, set to 0
    ),
    cv_wp10200 = case_when(
      !is.na(wp10200) & wp10200 == 1 ~ 1,  # Set to 1 if wp10200 == 1
      !is.na(wp10200) ~ 0,
      TRUE ~ NA                             # Otherwise, set to 0
    ),
    cv_wp10202 = case_when(
      !is.na(wp10202) & wp10202 == 1 ~ 1,  # Set to 1 if wp10202 == 1
      !is.na(wp10200) ~ 0,
      TRUE ~ NA                            # Otherwise, set to 0
    )
  ) %>%
  # Assign labels to the new variables
  set_variable_labels(
    cv_wp40 = "Buy food that family needs",
    cv_wp43 = "Provide adequate shelter",
    cv_wp10200 = "Wage employed: last 7 days",
    cv_wp10202 = "Self-employed: last 7 days"
  ) %>%

# create binary indicators for specific wp variables with cv_ prefix with each variable
  # Create binary indicators for specified variables
  mutate(
    cv_wp60 = case_when(!is.na(wp60) & wp60 == 1 ~ 1,
                        !is.na(wp60) ~ 0,
                        TRUE ~ NA),
    cv_wp61 = case_when(!is.na(wp61) & wp61 == 1 ~ 1,
                        !is.na(wp61) ~ 0,
                        TRUE ~ NA),
    cv_wp63 = case_when(!is.na(wp63) & wp63 == 1 ~ 1,
                        !is.na(wp63) ~ 0,
                        TRUE ~ NA),
    cv_wp65 = case_when(!is.na(wp65) & wp65 == 1 ~ 1,
                        !is.na(wp65) ~ 0,
                        TRUE ~ NA),
    cv_wp67 = case_when(!is.na(wp67) & wp67 == 1 ~ 1,
                        !is.na(wp67) ~ 0,
                        TRUE ~ NA),
    cv_wp68 = case_when(!is.na(wp68) & wp68 == 1 ~ 1,
                        !is.na(wp68) ~ 0,
                        TRUE ~ NA),
    cv_wp69 = case_when(!is.na(wp69) & wp69 == 1 ~ 1,
                        !is.na(wp69) ~ 0,
                        TRUE ~ NA),
    cv_wp70 = case_when(!is.na(wp70) & wp70 == 1 ~ 1,
                        !is.na(wp70) ~ 0,
                        TRUE ~ NA),
    cv_wp71 = case_when(!is.na(wp71) & wp71 == 1 ~ 1,
                        !is.na(wp71) ~ 0,
                        TRUE ~ NA),
    cv_wp74 = case_when(!is.na(wp74) & wp74 == 1 ~ 1,
                        !is.na(wp74) ~ 0,
                        TRUE ~ NA),
  ) %>%
  # Assign descriptive labels to the binary variables
  set_variable_labels(
    cv_wp60 = "Well-rested yesterday",
    cv_wp61 = "Treated with respect yesterday",
    cv_wp63 = "Smile or laugh a lot yesterday",
    cv_wp65 = "Learn or do something interesting yesterday",
    cv_wp67 = "Enjoyment yesterday",
    cv_wp68 = "Physical pain yesterday",
    cv_wp69 = "Worry yesterday",
    cv_wp70 = "Sadness yesterday",
    cv_wp71 = "Stress yesterday",
    cv_wp74 = "Anger yesterday"
  ) %>%

  # Create binary indicators
  mutate(
    # Binary indicators for wp83
    cv1_wp83 = case_when(
      !is.na(wp83) & wp83 == 1 ~ 1,  # Satisfied
      !is.na(wp83) ~ 0,
      TRUE ~ NA                      # Dissatisfied or NA
    ),
    cv2_wp83 = case_when(
      !is.na(wp83) & wp83 == 2 ~ 1,  # Dissatisfied
      !is.na(wp83) ~ 0,
      TRUE ~ NA                       # Satisfied or NA
    ),
    
    # Binary indicators for wp85
    cv1_wp85 = case_when(
      !is.na(wp85) & wp85 == 1 ~ 1,  # Likely to move
      !is.na(wp85) ~ 0,
      TRUE ~ NA                       # Unlikely to move or NA
    ),
    cv2_wp85 = case_when(
      !is.na(wp85) & wp85 == 2 ~ 1,  # Unlikely to move
      !is.na(wp85) ~ 0,
      TRUE ~ NA                       # Likely to move or NA
    ),
    
    # Binary indicators for wp86
    cv1_wp86 = case_when(
      !is.na(wp86) & wp86 == 1 ~ 1,  # Recommend the city
      !is.na(wp86) ~ 0,
      TRUE ~ NA                       # Would not recommend or NA
    ),
    cv2_wp86 = case_when(
      !is.na(wp86) & wp86 == 2 ~ 1,  # Would not recommend the city
      !is.na(wp86) ~ 0,
      TRUE ~ NA                      # Recommend the city or NA
    )
  ) %>% 
  # Assign descriptive labels
  set_variable_labels(
    cv1_wp83 = "Satisfied with the city where you live",
    cv2_wp83 = "Dissatisfied with the city where you live",
    cv1_wp85 = "Likely to move",
    cv2_wp85 = "Unlikely to move",
    cv1_wp86 = "Recommend the city",
    cv2_wp86 = "Would not recommend the city"
  ) %>%

  # Create binary indicators for economic conditions
  mutate(
    cv1_wp19472 = if_else(!is.na(wp19472) & wp19472 == 4, 1, 0),  # Excellent
    cv2_wp19472 = if_else(!is.na(wp19472) & wp19472 == 3, 1, 0),  # Good
    cv3_wp19472 = if_else(!is.na(wp19472) & wp19472 == 2, 1, 0),  # Fair
    cv4_wp19472 = if_else(!is.na(wp19472) & wp19472 == 1, 1, 0)   # Poor
  ) %>%
  # Assign descriptive labels
  set_variable_labels(
    cv1_wp19472 = "Economic conditions in city or area today: Excellent",
    cv2_wp19472 = "Economic conditions in city or area today: Good",
    cv3_wp19472 = "Economic conditions in city or area today: Fair",
    cv4_wp19472 = "Economic conditions in city or area today: Poor"
  ) %>%

# create binary indicators for wp88 (economic conditions in the area) & wp89 (job market conditions)
  # Create binary indicators for wp88 and wp89
  mutate(
    cv1_wp88 = if_else(!is.na(wp88) & wp88 == 1, 1, 0),
    cv2_wp88 = if_else(!is.na(wp88) & wp88 == 2, 1, 0),
    cv3_wp88 = if_else(!is.na(wp88) & wp88 == 3, 1, 0),
    cv1_wp89 = if_else(!is.na(wp89) & wp89 == 1, 1, 0),
    cv2_wp89 = if_else(!is.na(wp89) & wp89 == 2, 1, 0)
  ) %>%
  set_variable_labels(
    cv1_wp88 = "Economic conditions in the area: getting better",
    cv2_wp88 = "Economic conditions in the area: same",
    cv3_wp88 = "Economic conditions in the area: getting worse",
    cv1_wp89 = "Good time to find a job",
    cv2_wp89 = "Bad time to find a job"
  ) %>% 
  
  mutate(
    # Binary indicators for satisfaction/dissatisfaction
    cv1_wp91 = case_when(!is.na(wp91) & wp91 == 1 ~ 1,
                         !is.na(wp91) ~ 0,
                         TRUE ~ NA),
    cv2_wp91 = case_when(!is.na(wp91) & wp91 == 2 ~ 1,
                         !is.na(wp91) ~ 0,
                         TRUE ~ NA),
    
    cv1_wp92 = case_when(!is.na(wp92) & wp92 == 1 ~ 1,
                         !is.na(wp92) ~ 0,
                         TRUE ~ NA),
    cv2_wp92 = case_when(!is.na(wp92) & wp92 == 2 ~ 1, 
                         !is.na(wp92) ~ 0,
                         TRUE ~ NA),
    
    cv1_wp93 = case_when(!is.na(wp93) & wp93 == 1 ~ 1, 
                         !is.na(wp93) ~ 0,
                         TRUE ~ NA),
    cv2_wp93 = case_when(!is.na(wp93) & wp93 == 2 ~ 1, 
                         !is.na(wp93) ~ 0,
                         TRUE ~ NA),
    
    cv1_wp94 = case_when(!is.na(wp94) & wp94 == 1 ~ 1,
                         !is.na(wp94) ~ 0,
                         TRUE ~ NA),
    cv2_wp94 = case_when(!is.na(wp94) & wp94 == 2 ~ 1, 
                         !is.na(wp94) ~ 0,
                         TRUE ~ NA),
    
    cv1_wp95 = case_when(!is.na(wp95) & wp95 == 1 ~ 1,
                         !is.na(wp95) ~ 0,
                         TRUE ~ NA),
    cv2_wp95 = case_when(!is.na(wp95) & wp95 == 2 ~ 1, 
                         !is.na(wp95) ~ 0,
                         TRUE ~ NA),
    
    cv1_wp97 = case_when(!is.na(wp97) & wp97 == 1 ~ 1,
                         !is.na(wp97) ~ 0,
                         TRUE ~ NA),
    cv2_wp97 = case_when(!is.na(wp97) & wp97 == 2 ~ 1,
                         !is.na(wp97) ~ 0,
                         TRUE ~ NA),
    
    cv1_wp98 = case_when(!is.na(wp98) & wp98 == 1 ~ 1,
                         !is.na(wp98) ~ 0,
                         TRUE ~ NA),
    cv2_wp98 = case_when(!is.na(wp98) & wp98 == 2 ~ 1,
                         !is.na(wp98) ~ 0,
                         TRUE ~ NA),
    
    cv1_wp10248 = case_when(!is.na(wp10248) & wp10248 == 1 ~ 1,
                            !is.na(wp10248) ~ 0,
                            TRUE ~ NA),
    cv2_wp10248 = case_when(!is.na(wp10248) & wp10248 == 2 ~ 1,
                            !is.na(wp10248) ~ 0,
                            TRUE ~ NA),
    
    cv1_wp103 = case_when(!is.na(wp103) & wp103 == 1 ~ 1,
                          !is.na(wp103) ~ 0,
                          TRUE ~ NA),
    cv2_wp103 = case_when(!is.na(wp103) & wp103 == 2 ~ 1,
                          !is.na(wp103) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp105 = case_when(!is.na(wp105) & wp105 == 1 ~ 1,
                          !is.na(wp105) ~ 0,
                          TRUE ~ NA),
    cv2_wp105 = case_when(!is.na(wp105) & wp105 == 2 ~ 1, 
                          !is.na(wp105) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp106 = case_when(!is.na(wp106) & wp106 == 1 ~ 1, 
                          !is.na(wp106) ~ 0,
                          TRUE ~ NA),
    cv2_wp106 = case_when(!is.na(wp106) & wp106 == 2 ~ 1,
                          !is.na(wp106) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp11589 = case_when(!is.na(wp11589) & wp11589 == 1 ~ 1,
                            !is.na(wp11589) ~ 0,
                            TRUE ~ NA),
    cv2_wp11589 = case_when(!is.na(wp11589) & wp11589 == 2 ~ 1, 
                            !is.na(wp11589) ~ 0,
                            TRUE ~ NA),
  ) %>%
  set_variable_labels(
    cv1_wp91 = "Satisfied with public transportation",
    cv2_wp91 = "Dissatisfied with public transportation",
    
    cv1_wp92 = "Satisfied with roads and highways",
    cv2_wp92 = "Dissatisfied with roads and highways",
    
    cv1_wp93 = "Satisfied with educational systems or schools",
    cv2_wp93 = "Dissatisfied with educational systems or schools",
    
    cv1_wp94 = "Satisfied with quality of air",
    cv2_wp94 = "Dissatisfied with quality of air",
    
    cv1_wp95 = "Satisfied with quality of water",
    cv2_wp95 = "Dissatisfied with quality of water",
    
    cv1_wp97 = "Satisfied with quality of health care",
    cv2_wp97 = "Dissatisfied with quality of health care",
    
    cv1_wp98 = "Satisfied with availability of affordable housing",
    cv2_wp98 = "Dissatisfied with availability of affordable housing",
    
    cv1_wp10248 = "Satisfied with opportunities to make friends",
    cv2_wp10248 = "Dissatisfied with opportunities to make friends",
    
    cv1_wp103 = "Good place for: racial & ethnic minorities",
    cv2_wp103 = "Not a good place for: racial & ethnic minorities",
    
    cv1_wp105 = "Good place for: gay or lesbian",
    cv2_wp105 = "Not a good place for: gay or lesbian",
    
    cv1_wp106 = "Good place for: immigrants from other countries",
    cv2_wp106 = "Not a good place for: immigrants from other countries",
    
    cv1_wp11589 = "Good place for: starting a new business",
    cv2_wp11589 = "Not a good place for: starting a new business"
  ) %>%


# Creating Binary Indicators for Economic and Social Conditions
  mutate(
    # Binary indicators using case_when for single conditions
    cv_wp112 = case_when(!is.na(wp112) & wp112 == 1 ~ 1, 
                         !is.na(wp112) ~ 0,
                         TRUE ~ NA),
    cv_wp113 = case_when(!is.na(wp113) & wp113 == 1 ~ 1,
                         !is.na(wp113) ~ 0,
                         TRUE ~ NA),
    cv_wp117 = case_when(!is.na(wp117) & wp117 == 1 ~ 1,
                         !is.na(wp117) ~ 0,
                         TRUE ~ NA),
    cv_wp118 = case_when(!is.na(wp118) & wp118 == 1 ~ 1,
                         !is.na(wp118) ~ 0,
                         TRUE ~ NA),
    cv_wp119 = case_when(!is.na(wp119) & wp119 == 1 ~ 1, 
                         !is.na(wp119) ~ 0,
                         TRUE ~ NA),
    cv_wp128 = case_when(!is.na(wp128) & wp128 == 1 ~ 1, 
                         !is.na(wp128) ~ 0,
                         TRUE ~ NA),
    cv_wp129 = case_when(!is.na(wp129) & wp129 == 1 ~ 1,
                         !is.na(wp129) ~ 0,
                         TRUE ~ NA),
    cv_wp130 = case_when(!is.na(wp130) & wp130 == 1 ~ 1, 
                         !is.na(wp130) ~ 0,
                         TRUE ~ NA),
    cv_wp9050 = case_when(!is.na(wp9050) & wp9050 == 1 ~ 1, 
                          !is.na(wp9050) ~ 0,
                          TRUE ~ NA),
  ) %>%
  set_variable_labels(
    cv_wp112 = "confidence in police force",
    cv_wp113 = "safe at night",
    cv_wp117 = "money or property stolen",
    cv_wp118 = "assaulted or mugged",
    cv_wp119 = "religion an important part",
    cv_wp128 = "can get ahead by working hard",
    cv_wp129 = "children are treated with respect/dignity",
    cv_wp130 = "children have the opportunity to learn and grow",
    cv_wp9050 = "women are treated with respect/dignity"
  ) %>%
  
  mutate(
    # Binary indicators for wp131 using case_when
    cv1_wp131 = case_when(!is.na(wp131) & wp131 == 1 ~ 1, 
                          !is.na(wp131) ~ 0,
                          TRUE ~ NA),
    cv2_wp131 = case_when(!is.na(wp131) & wp131 == 2 ~ 1, 
                          !is.na(wp131) ~ 0,
                          TRUE ~ NA),
    
    # Binary indicators for wp132
    cv1_wp132 = case_when(!is.na(wp132) & wp132 == 1 ~ 1, 
                          !is.na(wp132) ~ 0,
                          TRUE ~ NA),
    cv2_wp132 = case_when(!is.na(wp132) & wp132 == 2 ~ 1,
                          !is.na(wp132) ~ 0,
                          TRUE ~ NA),
    
    # Binary indicators for wp134
    cv1_wp134 = case_when(!is.na(wp134) & wp134 == 1 ~ 1,
                          !is.na(wp134) ~ 0,
                          TRUE ~ NA),
    cv2_wp134 = case_when(!is.na(wp134) & wp134 == 2 ~ 1,
                          !is.na(wp134) ~ 0,
                          TRUE ~ NA),
    
    # Single binary indicators for other variables
    cv_wp137 = case_when(!is.na(wp137) & wp137 == 1 ~ 1,
                         !is.na(wp137) ~ 0,
                         TRUE ~ NA),
    cv_wp138 = case_when(!is.na(wp138) & wp138 == 1 ~ 1,
                         !is.na(wp138) ~ 0,
                         TRUE ~ NA),
    cv_wp139 = case_when(!is.na(wp139) & wp139 == 1 ~ 1,
                         !is.na(wp139) ~ 0,
                         TRUE ~ NA),
    cv_wp141 = case_when(!is.na(wp141) & wp141 == 1 ~ 1,
                         !is.na(wp141) ~ 0,
                         TRUE ~ NA),
    cv_wp144 = case_when(!is.na(wp144) & wp144 == 1 ~ 1, 
                         !is.na(wp144) ~ 0,
                         TRUE ~ NA),
    cv_wp10251 = case_when(!is.na(wp10251) & wp10251 == 1 ~ 1,
                           !is.na(wp10251) ~ 0,
                           TRUE ~ NA),
    cv_wp145 = case_when(!is.na(wp145) & wp145 == 1 ~ 1,
                         !is.na(wp145) ~ 0,
                         TRUE ~ NA),
    cv_wp146 = case_when(!is.na(wp146) & wp146 == 1 ~ 1,
                         !is.na(wp146) ~ 0,
                         TRUE ~ NA),
  ) %>%
  set_variable_labels(
    cv1_wp131 = "satisfied with efforts for poor",
    cv2_wp131 = "dissatisfied with efforts for poor",
    
    cv1_wp132 = "satisfied with efforts for environment",
    cv2_wp132 = "dissatisfied with efforts for environment",
    
    cv1_wp134 = "satisfied with freedom of choice",
    cv2_wp134 = "dissatisfied with freedom of choice",
    
    cv_wp137 = "confidence in military",
    cv_wp138 = "confidence in judicial system/courts",
    cv_wp139 = "confidence in national govt.",
    cv_wp141 = "confidence in financial institutions or banks",
    cv_wp144 = "confidence in honesty of elections",
    cv_wp10251 = "media have a lot of freedom",
    cv_wp145 = "corruption widespread within businesses",
    cv_wp146 = "corruption widespread within govt."
  ) %>%

# Creating Binary Indicators and Labels for Leadership Approval, Mobility Preferences, and Employment Characteristics
  mutate(
    # Binary indicators for approval and disapproval
    cv1_wp150 = case_when(!is.na(wp150) & wp150 == 1 ~ 1, 
                          !is.na(wp150) ~ 0,
                          TRUE ~ NA),
    cv2_wp150 = case_when(!is.na(wp150) & wp150 == 2 ~ 1,
                          !is.na(wp150) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp151 = case_when(!is.na(wp151) & wp151 == 1 ~ 1,
                          !is.na(wp151) ~ 0,
                          TRUE ~ NA),
    cv2_wp151 = case_when(!is.na(wp151) & wp151 == 2 ~ 1,
                          !is.na(wp152) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp153 = case_when(!is.na(wp153) & wp153 == 1 ~ 1,
                          !is.na(wp153) ~ 0,
                          TRUE ~ NA),
    cv2_wp153 = case_when(!is.na(wp153) & wp153 == 2 ~ 1,
                          !is.na(wp153) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp155 = case_when(!is.na(wp155) & wp155 == 1 ~ 1, 
                          !is.na(wp155) ~ 0,
                          TRUE ~ NA),
    cv2_wp155 = case_when(!is.na(wp155) & wp155 == 2 ~ 1,
                          !is.na(wp155) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp156 = case_when(!is.na(wp156) & wp156 == 1 ~ 1,
                          !is.na(wp156) ~ 0,
                          TRUE ~ NA),
    cv2_wp156 = case_when(!is.na(wp156) & wp156 == 2 ~ 1,
                          !is.na(wp156) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp157 = case_when(!is.na(wp157) & wp157 == 1 ~ 1, 
                          !is.na(wp157) ~ 0,
                          TRUE ~ NA),
    cv2_wp157 = case_when(!is.na(wp157) & wp157 == 2 ~ 1,
                          !is.na(wp157) ~ 0,
                          TRUE ~ NA),
    
    cv1_wp1325 = case_when(!is.na(wp1325) & wp1325 == 1 ~ 1,
                           !is.na(wp1325) ~ 0,
                           TRUE ~ NA),
    cv2_wp1325 = case_when(!is.na(wp1325) & wp1325 == 2 ~ 1,
                           !is.na(wp1325) ~ 0,
                           TRUE ~ NA),
    cv_wp11612 = case_when(!is.na(wp11612) & wp11612 == 1 ~ 1,
                           !is.na(wp11612) ~ 0,
                           TRUE ~ NA),
    cv1_wp14456 = case_when(!is.na(wp14456) & wp14456 == 1 ~ 1,
                            !is.na(wp14456) ~ 0,
                            TRUE ~ NA),
    cv2_wp14456 = case_when(!is.na(wp14456) & wp14456 == 2 ~ 1,
                            !is.na(wp14456) ~ 0,
                            TRUE ~ NA),
  ) %>%
  
  set_variable_labels(
    cv1_wp150 = "approve of country leadership's performance",
    cv2_wp150 = "disapprove of country leadership's performance",
    
    cv1_wp151 = "approve of USA's leadership's performance",
    cv2_wp151 = "disapprove of USA's leadership's performance",
    
    cv1_wp153 = "approve of Germany's leadership's performance",
    cv2_wp153 = "disapprove of Germany's leadership's performance",
    
    cv1_wp155 = "approve of Russia's leadership's performance",
    cv2_wp155 = "disapprove of Russia's leadership's performance",
    
    cv1_wp156 = "approve of China's leadership's performance",
    cv2_wp156 = "disapprove of China's leadership's performance",
    
    cv1_wp157 = "approve of Japan's leadership's performance",
    cv2_wp157 = "disapprove of Japan's leadership's performance",
    
    cv1_wp1325 = "like to move to another country",
    cv2_wp1325 = "like to continue living in this country",
    cv_wp11612 = "business owner",
    cv1_wp14456 = "job, working for the government",
    cv2_wp14456 = "job, working for a business"
  ) %>%

# ## *wp11613_clean 
# lab val wp11613_clean wp11613_clean 
# lab var wp11613_clean  "employees at business"

  mutate(
    # Assign age categories 
    age_category = case_when(
      is.na(wp1220) ~ NA_real_,                               # Set to NA if wp1220 is NA
      wp1220 == 100 ~ NA_real_,                               # Set to NA if wp1220 is 100
      wp1220 > 14 & wp1220 < 25 ~ 1,                          # Ages 15-24
      wp1220 > 24 & wp1220 < 65 ~ 2,                          # Ages 25-64
      wp1220 > 64 & wp1220 < 102 ~ 3,                         # Ages 65-101
      TRUE ~ NA_real_                                         # Catch-all for other cases
    )
  ) %>%
  set_variable_labels(age_category = "Age category groups: 1 is ages 15-24, 2 is ages 25-64, and 3 is ages 65+") %>% 

  mutate(
    age_category_2 = case_when(
      is.na(wp1220) ~ NA_real_,
      wp1220 == 100 ~ NA_real_,
      wp1220 > 17 & wp1220 < 26 ~ 1,
      wp1220 > 25 & wp1220 < 51 ~ 2,
      wp1220 > 50 & wp1220 < 102 ~ 3,
      TRUE ~ NA_real_
    )
  ) %>%
  set_variable_labels(age_category_2 = "age categories: 1 is ages 18-25, 2 is ages 26-50, 3 is ages 51+") %>%

# Categorizing Age Groups and Creating Binary Indicators for Financial Help Variables
  # Create binary indicators for wp9086
  mutate(
    cv1_wp9086 = case_when(!is.na(wp9086) & wp9086 == 1 ~ 1, !is.na(wp9086) ~ 0, TRUE ~ NA_real_),
    cv2_wp9086 = case_when(!is.na(wp9086) & wp9086 == 2 ~ 1, !is.na(wp9086) ~ 0, TRUE ~ NA_real_),
    cv3_wp9086 = case_when(!is.na(wp9086) & wp9086 == 3 ~ 1, !is.na(wp9086) ~ 0, TRUE ~ NA_real_),
    
    # Create binary indicators for wp12316
    cv1_wp12316 = case_when(!is.na(wp12316) & wp12316 == 1 ~ 1, !is.na(wp12316) ~ 0, TRUE ~ NA_real_),
    cv2_wp12316 = case_when(!is.na(wp12316) & wp12316 == 2 ~ 1, !is.na(wp12316) ~ 0, TRUE ~ NA_real_),
    cv3_wp12316 = case_when(!is.na(wp12316) & wp12316 == 3 ~ 1, !is.na(wp12316) ~ 0, TRUE ~ NA_real_)) %>%

# Create combined binary indicator for wp9086(Receive Money or Goods ) and wp12316(Sent Financial Help )
  mutate(
    cv_wp9086_cv1_12316 = case_when(
      (!is.na(wp9086) | !is.na(wp12316)) & (wp9086 == 1 | wp12316 == 1) ~ 1,
      (!is.na(wp9086) | !is.na(wp12316)) ~ 0,
      TRUE ~ NA_real_
    ) %>%
      set_variable_labels(cv_wp9086_cv1_12316 = "send or receieve help: within this country")) %>%
  
  mutate(
    cv1_wp9086_cv2_12316 = case_when(
      (!is.na(wp9086) | !is.na(wp12316)) & (wp9086 == 2 | wp12316 == 2) ~ 1, 
      (!is.na(wp9086) | !is.na(wp12316)) ~ 0,                              
      TRUE ~ NA_real_                                                      
    )
  ) %>%
  set_variable_labels(
    cv1_wp9086_cv2_12316 = "Send or receive help: outside this country"
  ) %>%
  
  mutate(
    cv1_wp9086_cv3_12316 = case_when(
      (!is.na(wp9086) | !is.na(wp12316)) & (wp9086 == 3 | wp12316 == 3) ~ 1, 
      (!is.na(wp9086) | !is.na(wp12316)) ~ 0,                              
      TRUE ~ NA_real_                                                   
    )
  ) %>% 
  
  set_variable_labels(
    cv1_wp9086_cv3_12316 = "Send or receive help: both within and outside this country"
  ) %>%

# Binary indicators for wp2319 (present income)
  mutate(
    # Binary indicators for wp2319 (present income)
    cv1_wp2319 = case_when(!is.na(wp2319) & wp2319 == 1 ~ 1, 
                           !is.na(wp2319) ~ 0,
                           TRUE ~ NA), # Income level: Live comfortably
    cv2_wp2319 = case_when(!is.na(wp2319) & wp2319 == 2 ~ 1,
                           !is.na(wp2319) ~ 0,
                           TRUE ~ NA),# Income level: Get by
    cv3_wp2319 = case_when(!is.na(wp2319) & wp2319 == 3 ~ 1,
                           !is.na(wp2319) ~ 0,
                           TRUE ~ NA),# Income level: Find it difficult
    cv4_wp2319 = case_when(!is.na(wp2319) & wp2319 == 4 ~ 1, 
                           !is.na(wp2319) ~ 0,
                           TRUE ~ NA),# Income level: Find it very difficult
    
    # Binary indicators for wp4657 (country of birth)
    cv1_wp4657 = case_when(!is.na(wp4657) & wp4657 == 1 ~ 1, 
                           !is.na(wp4657) ~ 0,
                           TRUE ~ NA), # Born in this country
    cv2_wp4657 = case_when(!is.na(wp4657) & wp4657 == 2 ~ 1, 
                           !is.na(wp4657) ~ 0,
                           TRUE ~ NA), # Born in another country
    
    # Binary indicator for wp9042 (moved to country within past 5 years)
    cv_wp9042 = case_when(!is.na(wp9042) & wp9042 == 1 ~ 1,
                          !is.na(wp9042) ~ 0,
                          TRUE ~ NA), # Moved to the country within the past 5 years
    
    # Binary indicators for internet access and usage
    cv_wp16056 = case_when(!is.na(wp16056) & wp16056 == 1 ~ 1, 
                           !is.na(wp16056) ~ 0,
                           TRUE ~ NA), # Access to the internet
    cv_wp15862 = case_when(!is.na(wp15862) & wp15862 == 1 ~ 1, 
                           !is.na(wp15862) ~ 0,
                           TRUE ~ NA), # Used the internet in the past 7 days (among those with access)
    cv1_wp15862 = case_when(!is.na(wp16056) & wp15862 == 1 ~ 1, 
                            !is.na(wp16056) ~ 0,
                            TRUE ~ NA), # Used the internet in the past 7 days (among all adults)
    
    # Binary indicators for landline and mobile ownership
    cv_wp17625 = case_when(!is.na(wp17625) & wp17625 == 1 ~ 1, 
                           !is.na(wp17625) ~ 0,
                           TRUE ~ NA), # Landline in the home for personal calls
    cv_wp17626 = case_when(!is.na(wp17626) & wp17626 == 1 ~ 1, 
                           !is.na(wp17626) ~ 0,
                           TRUE ~ NA), # Own a mobile phone for personal calls
    
    # Binary indicator for mobile with internet access
    cv_wp19544 = case_when(!is.na(wp19544) & wp19544 == 1 ~ 1, 
                           !is.na(wp19544) ~ 0,
                           TRUE ~ 1) # Own a mobile phone with internet access
  ) %>%
  
  set_variable_labels(
    cv1_wp2319 = "present income: live comfortably", # Label for cv1_wp2319
    cv2_wp2319 = "present income: get by", # Label for cv2_wp2319
    cv3_wp2319 = "present income: find it difficult", # Label for cv3_wp2319
    cv4_wp2319 = "present income: find it very difficult", # Label for cv4_wp2319
    cv1_wp4657 = "born in this country", # Label for cv1_wp4657
    cv2_wp4657 = "born in another country", # Label for cv2_wp4657
    cv_wp9042 = "Moved to country within past 5 years", # Label for cv_wp9042
    cv_wp16056 = "access to the internet", # Label for cv_wp16056
    cv_wp15862 = "used internet in the past 7 days [of those with access]", # Label for cv_wp15862
    cv1_wp15862 = "used internet in the past 7 days [of all adults]", # Label for cv1_wp15862
    cv_wp17625 = "landline in home for personal calls [of all adults]", # Label for cv_wp17625
    cv_wp17626 = "own mobile for personal calls [of all adults]", # Label for cv_wp17626
    cv_wp19544 = "own mobile that has internet access [of those who own mobile phone]" # Label for cv_wp19544
  ) %>%


############################
# * -- internet & mobile ###
############################
  mutate(
    # Create mobileint: 1 if has phone and internet access, 0 otherwise
    # Set to 1 if wp17626 (owns mobile) is 1 and wp16056 (internet access) is 1, otherwise 0
    mobileint = case_when(wp17626 == 1 & wp16056 == 1 ~ 1, 
                          !is.na(wp17626) & !is.na(wp16056) ~ 0,
                          TRUE ~ NA), 
    
    # Create mobileintuse: 1 if has phone and internet use, 0 otherwise
    # Set to 1 if wp17626 (owns mobile) is 1 and wp15862 (internet use) is 1, otherwise 0
    
    mobileintuse = case_when(wp17626 == 1 & wp15862 == 1 ~ 1, 
                             !is.na(wp17626) & !is.na(wp15862) ~ 0,
                             TRUE ~ NA) 
  ) %>%
  set_variable_labels(
    mobileint = "Has phone and internet access [of adults]",
    mobileintuse = "Has phone and internet use [of adults]"
  ) %>%

############################
# * -- internet OR mobile ##
############################

  mutate(
    # Create mobileORint: 1 if has phone OR internet access, 0 otherwise
    mobileORint = case_when((wp17626 == 1 | wp16056 == 1) ~ 1, 
                            !is.na(wp17626) | !is.na(wp16056) ~ 0,
                            TRUE ~ NA),
    
    # Create mobileORintuse: 1 if has phone OR internet use, 0 otherwise
    mobileORintuse = case_when((wp17626 == 1 | wp15862 == 1) ~ 1, 
                               !is.na(wp17626) & !is.na(wp15862) ~ 0,
                               TRUE ~ NA)
  ) %>%
  # Set variable labels
  set_variable_labels(
    mobileORint = "Has phone OR internet access [of adults]",
    mobileORintuse = "Has phone OR internet use [of adults]") %>%


# Create wp9608d1 for "Engaged" status
  mutate(
    # Create cv1_wp9608 for "Engaged" status
    cv1_wp9608 = case_when(
      !is.na(wp9608) & wp9608 == 3 ~ 1,  # Set to 1 if wp9608 is 3 (Engaged)
      !is.na(wp9608) ~ 0,               # Set to 0 for other non-missing values
      TRUE ~ NA_real_                   # Set to NA for missing values
    ),
    
    # Create cv2_wp9608 for "Not Engaged" status
    cv2_wp9608 = case_when(
      !is.na(wp9608) & wp9608 == 2 ~ 1,  # Set to 1 if wp9608 is 2 (Not Engaged)
      !is.na(wp9608) ~ 0,               # Set to 0 for other non-missing values
      TRUE ~ NA_real_                   # Set to NA for missing values
    ),
    
    # Create cv3_wp9608 for "Actively Disengaged" status
    cv3_wp9608 = case_when(
      !is.na(wp9608) & wp9608 == 1 ~ 1,  # Set to 1 if wp9608 is 1 (Actively Disengaged)
      !is.na(wp9608) ~ 0,               # Set to 0 for other non-missing values
      TRUE ~ NA_real_                   # Set to NA for missing values
    )
  ) %>%
  # Add variable labels
  set_variable_labels(
    cv1_wp9608 = "Employment engagement: engaged",
    cv2_wp9608 = "Employment engagement: not engaged",
    cv3_wp9608 = "Employment engagement: actively disengaged"
  ) %>%

  # Own business [of SE]
  mutate(
    cv_ownbus_SE = case_when(
      !is.na(i17) & emp_4 == 1 & wp11612 == 1 ~ 1,    # Set to 1 if all conditions match
      !is.na(i17) & emp_4 == 1 ~ 0,                  # Set to 0 if i17 is not missing and emp_4 == 1
      TRUE ~ NA_real_                                # Set NA for all other cases
    )
  ) %>%
  set_variable_labels(cv_ownbus_SE = "Own business [of SE]") %>%
  
  # Own business [of adults]
  mutate(
    cv_ownbus = case_when(
      !is.na(i17) & wp11612 == 1 ~ 1,   # Set to 1 if i17 is not missing and wp11612 == 1
      !is.na(i17) ~ 0,                  # Set to 0 if i17 is not missing
      TRUE ~ NA_real_                   # Set NA for all other cases
    )
  ) %>%
  set_variable_labels(cv_ownbus = "Own business [of adults]") %>%
  
  # Self-employed [of those owning a business]
  mutate(
    cv_SE_ownbus = case_when(
      !is.na(i17) & wp11612 == 1 & emp_4 == 1 ~ 1,    # Set to 1 if all conditions match
      !is.na(i17) & wp11612 == 1 ~ 0,                 # Set to 0 if i17 is not missing and wp11612 == 1
      TRUE ~ NA_real_                                 # Set NA for all other cases
    )
  ) %>%
  set_variable_labels(cv_SE_ownbus = "Self-employed [of those owning a business]") %>%


  # Confidence in private corporations
  mutate(
    cv_wp9707 = case_when(
      !is.na(wp9707) & wp9707 == 1 ~ 1, # Confidence in private corporations
      !is.na(wp9707) ~ 0,
      TRUE ~ NA_real_
    )
  ) %>%
  set_variable_labels(cv_wp9707 = "Confidence in private corporations") %>%
  
  # Approval/disapproval of leader's job
  mutate(
    cv1_wp13125 = case_when(
      !is.na(wp13125) & wp13125 == 1 ~ 1, # Approve
      !is.na(wp13125) ~ 0,
      TRUE ~ NA_real_
    ),
    cv2_wp13125 = case_when(
      !is.na(wp13125) & wp13125 == 2 ~ 1, # Disapprove
      !is.na(wp13125) ~ 0,
      TRUE ~ NA_real_
    )
  ) %>%
  set_variable_labels(
    cv1_wp13125 = "Approve of the way the leader of the country is handling their job",
    cv2_wp13125 = "Disapprove of the way the leader of the country is handling their job"
  ) %>%

# binary indicators for charity actions
  # Binary indicators for charity actions
  mutate(across(
    c(wp108, wp109, wp110, wp111),
    ~ if_else(!is.na(.) & . == 1, 1, 0),  # Create binary indicators for charity actions
    .names = "cv_{.col}"                 # Add 'cv_' prefix to variable names
  )) %>%
  set_variable_labels(
    cv_wp108 = "Donated money to charity",
    cv_wp109 = "Volunteered time to an organization",
    cv_wp110 = "Helped a stranger",
    cv_wp111 = "Voiced opinion to a public official"
  ) %>%
  
  # Respondent's living area
  mutate(
    cv1_wp14 = if_else(!is.na(wp14) & wp14 == 1, 1, 0),  # Rural area/farm
    cv2_wp14 = if_else(!is.na(wp14) & wp14 == 2, 1, 0),  # Small town/village
    cv3_wp14 = if_else(!is.na(wp14) & wp14 == 3, 1, 0),  # Large city
    cv4_wp14 = if_else(!is.na(wp14) & wp14 == 6, 1, 0)   # Suburb of a large city
  ) %>%
  set_variable_labels(
    cv1_wp14 = "Respondent lives in: Rural area/farm",
    cv2_wp14 = "Respondent lives in: Small town/village",
    cv3_wp14 = "Respondent lives in: Large city",
    cv4_wp14 = "Respondent lives in: Suburb of a large city"
  ) %>%

# Marital Status
  # Current marital status
  mutate(
    cv_married = case_when(
      wp1223 == 2 ~ 1,                    # Married
      wp1223 %in% c(6, 7) ~ NA_real_,     # Missing values for DK/Refused
      !is.na(wp1223) ~ 0,
      TRUE ~ NA                            # Other cases
    ),
    cv_divorced = case_when(
      wp1223 %in% c(3, 4) ~ 1,            # Divorced/separated
      wp1223 %in% c(6, 7) ~ NA_real_,
      !is.na(wp1223) ~ 0,
      TRUE ~ NA
    ),
    cv_widowed = case_when(
      wp1223 == 5 ~ 1,                    # Widowed
      wp1223 %in% c(6, 7) ~ NA_real_,
      !is.na(wp1223) ~ 0,
      TRUE ~ NA
    ),
    cv_single = case_when(
      wp1223 %in% c(1, 8) ~ 1,            # Single
      wp1223 %in% c(6, 7) ~ NA_real_,
      !is.na(wp1223) ~ 0,
      TRUE ~ NA
    )
  ) %>%
  # Assign variable labels
  set_variable_labels(
    cv_married = "Marital status: Married",
    cv_divorced = "Marital status: Divorced/separated",
    cv_widowed = "Marital status: Widowed",
    cv_single = "Marital status: Single"
  ) %>%

# Labor force participavtion and unemployment/underemployment indices
  mutate(
    cv_emp_lfpr = case_when(!is.na(emp_lfpr) & emp_lfpr == 1 ~ 1, 
                            !is.na(emp_lfpr) ~ 0,
                            TRUE ~ NA),  # Participated in labor force
    cv1_emp_unemp = case_when(!is.na(emp_unemp) & emp_unemp == 1 ~ 1, 
                              !is.na(emp_unemp) ~ 0,
                              TRUE ~ NA),  # Unemployed
    cv2_emp_unemp = case_when(!is.na(emp_unemp) & emp_unemp == 0 ~ 1, 
                              !is.na(emp_unemp) ~ 0,
                              TRUE ~ NA),  # Not unemployed
    cv1_emp_under = case_when(!is.na(emp_under) & emp_under == 1 ~ 1,
                              !is.na(emp_unemp) ~ 0,
                              TRUE ~ NA),# Underemployed
    cv2_emp_under = case_when(!is.na(emp_under) & emp_under == 0 ~ 1,
                              !is.na(emp_unemp) ~ 0,
                              TRUE ~ NA),# Not underemployed
  ) %>%
  
  set_variable_labels(
    cv_emp_lfpr = "Participated in the labor force",
    cv1_emp_unemp = "Unemployment index: Unemployed",
    cv2_emp_unemp = "Unemployment index: Not unemployed",
    cv1_emp_under = "Underemployment index: Underemployed",
    cv2_emp_under = "Underemployment index: Not underemployed"
  ) %>%

# Adjust ages: Convert ages above 90 to 90; set NA for DK/refused (98 and 99)

  mutate(
    cv_wp1230 = case_when(
      wp1230 == 97 ~ 90,                            # Set to 90 if age is 97
      wp1230 != 98 & wp1230 != 99 ~ wp1230,         # Keep original value if not 98/99
      TRUE ~ NA_real_                               # Set NA for DK/refused
    )
  ) %>%
  set_variable_labels(cv_wp1230 = "Number of under 15 children in the household") %>%
  
  # Keep valid religion responses; set NA for invalid values
  mutate(
    cv_wp1233 = case_when(
      wp1233 != 27 & wp1233 != 99 & wp1233 != 98 & wp1233 != 97 ~ wp1233, # Keep valid responses
      TRUE ~ NA_real_                                                    # Set NA for invalid responses
    )
  ) %>%
  set_variable_labels(cv_wp1233 = "Religion") %>%
  
  # Convert wp9048 to character and factor
  mutate(
    cv_wp9048 = as.character(wp9048),       # Convert wp9048 to character
    cv_wp9048_str = factor(wp9048)          # Convert wp9048 to factor
  ) %>%
  set_variable_labels(
    cv_wp9048 = "Original wp9048 as character",
    cv_wp9048_str = "Original wp9048 as factor")


