
# 1.2.2. Frequency of MM deposit, send and withdrawal.

# combine sending and withdrawing
fig <- TS %>% filter(dev24 == 1 & African_Union != "") %>%   
  select(countrynewwb,African_Union, wgt_globalgfii, year, ts_mobaccount,
         fin13B_mm_w, fin13B_mm_m, fin13B_mm_lm, fin13B_mm_n,
         fin13C_mm_w ,fin13C_mm_m, fin13C_mm_lm, fin13C_mm_n)%>%
  filter(!is.na(countrynewwb)) %>%
  rename(
    send_w = fin13B_mm_w,
    send_m = fin13B_mm_m,
    send_lm = fin13B_mm_lm,
    send_n = fin13B_mm_n,
    withdraw_w = fin13C_mm_w,
    withdraw_m = fin13C_mm_m,
    withdraw_lm = fin13C_mm_lm,
    withdraw_n = fin13C_mm_n)

# define your frequency order
freq_order <- c("weekly", "monthly", "less_monthly", "never")

fig2 <- fig %>%
  filter(ts_mobaccount == 1) %>%
  rowwise() %>%
  mutate(
    send_level = match(1, c(send_w, send_m, send_lm, send_n)),
    withdraw_level = match(1, c(withdraw_w, withdraw_m, withdraw_lm, withdraw_n)),
    combined_level = min(send_level, withdraw_level, na.rm = TRUE),
    send_or_withdraw = freq_order[combined_level]) %>%
  select(African_Union, wgt_globalgfii, send_or_withdraw) %>%
  mutate(send_or_withdraw = ifelse(is.na(send_or_withdraw), "dk/r", send_or_withdraw),
         sw_w = ifelse(send_or_withdraw == "weekly", 1, 0),
         sw_m = ifelse(send_or_withdraw == "monthly", 1, 0),
         sw_lm = ifelse(send_or_withdraw == "less_monthly", 1, 0),
         sw_n= ifelse(send_or_withdraw == "never", 1, 0))%>%
  select(African_Union, wgt_globalgfii, starts_with("sw")) %>%
  group_by(African_Union) %>%
  summarise(across(where(is.numeric) & !any_of(c("wgt_globalgfii")),
                   ~ {# Calculate weighted mean
                     mean_value <- weighted.mean(.x, wgt_globalgfii, na.rm = TRUE)
                     # Replace NaN with NA - this prevents gross looking NaN values in the data
                     if (is.nan(mean_value)) NA else mean_value
                   }),.groups = 'drop') %>%
  mutate(sw_mm = sw_w + sw_m + sw_lm + sw_n)  %>%
  rename(countrynewwb = "African_Union")




data <- data %>%
  filter(group == "all") %>%
  mutate(deposit_mm = fin13A_mm_w + fin13A_mm_m + fin13A_mm_lm + fin13A_mm_n) %>%
  left_join(fig2)
         # send_mm = fin13B_mm_w + fin13B_mm_m + fin13B_mm_lm + fin13B_mm_n,
         # withdraw_mm = fin13C_mm_w + fin13C_mm_m + fin13C_mm_lm + fin13C_mm_n)

MM_deposit_send_withdrawal_Frequency <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  filter(aggregate_level == "African_Union" & countrynewwb != "AU_North") %>%
  merge(fig2)%>%
  select(countrynewwb, year, fin13A_mm_w ,fin13A_mm_m, fin13A_mm_lm, fin13A_mm_n,
         # fin13B_mm_w, fin13B_mm_m, fin13B_mm_lm, fin13B_mm_n,
         # fin13C_mm_w ,fin13C_mm_m, fin13C_mm_lm, fin13C_mm_n
         sw_w, sw_m, sw_lm, sw_n
  )%>%
  # filter(!fin13A_mm_w== 0) %>%
  rename(
    deposit_w = fin13A_mm_w,
    deposit_m = fin13A_mm_m,
    deposit_lm = fin13A_mm_lm,
    deposit_n = fin13A_mm_n,
    # send_w = fin13B_mm_w,
    # send_m = fin13B_mm_m,
    # send_lm = fin13B_mm_lm,
    # send_n = fin13B_mm_n,
    # withdraw_w = fin13C_mm_w,
    # withdraw_m = fin13C_mm_m,
    # withdraw_lm = fin13C_mm_lm,
    # withdraw_n = fin13C_mm_n
  ) %>%
  filter(!is.na(deposit_w))

# Reshape data to long format for ggplot
MM_deposit_send_withdrawal_Frequency_long_data <- MM_deposit_send_withdrawal_Frequency %>%
  pivot_longer(cols = starts_with("deposit") | starts_with("sw"), #| starts_with("withdraw"),
               names_to = c("type", "category"),
               names_pattern = "(.*)_(.*)",
               values_to = "value") %>%
  mutate(type = factor(type, levels = c("deposit", "sw")), #"withdraw")),
         category = factor(category, levels = c("w", "m", "lm", "n"),
                           labels = c("Weekly", "Monthly", "Less than once a month", "Never")))

# Normalize the data to 100% by country and type (data_purchase or internet_access)
MM_deposit_send_withdrawal_Frequency_long_data <- MM_deposit_send_withdrawal_Frequency_long_data %>%
  group_by(countrynewwb, type) %>%
  # Ensure all categories (w, m, lm) are included for each country
  complete(category = factor(c("Weekly", "Monthly", "Less than once a month", "Never"), 
                             levels = c("Weekly", "Monthly", "Less than once a month", "Never"))) %>%
  filter(!is.na(value)) %>%
  mutate(percentage = value / sum(value, na.rm = TRUE) * 100) %>%
  ungroup()


# Check the number of unique countries in countrynewwb
length_unique_countries <- MM_deposit_send_withdrawal_Frequency_long_data %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

unique_countries_list <- MM_deposit_send_withdrawal_Frequency_long_data %>%
  distinct(countrynewwb) %>%
  pull(countrynewwb)

deposit_label_data <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  filter(countrynewwb %in% unique_countries_list) %>%
  select(countrynewwb, deposit_mm) %>%
  rename(total_deposit =  deposit_mm)

send_label_data <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  filter(countrynewwb %in% unique_countries_list) %>%
  select(countrynewwb, sw_mm) %>%
  rename(total_send =  sw_mm)

# withdrawal_label_data <- data %>%
#   filter(group == "all") %>%
#   filter(year %in% c(2024)) %>%
#   filter(countrynewwb %in% unique_countries_list) %>%
#   select(countrynewwb, withdraw_mm) %>%
#   rename(total_withdraw =  withdraw_mm)


# Merge the total data for Deposit, Send, and Withdrawal with the long data
long_data_with_labels <- MM_deposit_send_withdrawal_Frequency_long_data %>%
  left_join(deposit_label_data, by = "countrynewwb") %>%
  left_join(send_label_data, by = "countrynewwb") %>%
  # left_join(withdrawal_label_data, by = "countrynewwb") %>%
  mutate(
    label = case_when(
      type == "deposit" ~ total_deposit,    # For deposit bars, use the total value
      type == "sw" ~ total_send,       # For send bars, use the total value
      # type == "withdraw" ~ total_withdraw, # For withdrawal bars, use the total value
      TRUE ~ NA_real_               # Default to NA for any other type
    )
  ) %>%
  drop_na(label) %>%
  drop_na(total_deposit) %>%
  drop_na(total_send) 
  # drop_na(total_withdraw)

long_data_with_labels <- long_data_with_labels %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "AU_Central" = "Central Africa",
                               "AU_East" = "East Africa",
                               "AU_Southern" = "Southern Africa",
                               "AU_West" = "West Africa"))
# Plotting the graph
ggplot(long_data_with_labels) +
  # Use interaction to create separate bars for each type and country combination
  geom_bar(aes(x = factor(type), 
               y = percentage, 
               fill = factor(category, levels = c("Never", "Less than once a month", "Monthly", "Weekly"))),
           stat = "identity", 
           position = "stack", 
           width = 0.75,
           color = "black") +
  
  # Custom colors for the categories
  scale_fill_manual(values = c("Weekly" ="#D12891", "Monthly" = "#F087B6","Less than once a month"= "#FCD6E8", "Never" = "#C2C0C0"),
                    breaks = c("Weekly", "Monthly", "Less than once a month", "Never"),
                    labels = c("Weekly", "Monthly", "Less than once a month", "Never")) +
  
  # Adjusting y-axis to show percentage
  scale_y_continuous(labels = function(x) round(x)) +
  
  # Facet by country, no need for interaction here as we don't want to display country names on the x-axis
  facet_grid(. ~ factor(countrynewwb), 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 16, multi_line = TRUE)) +
  
  scale_x_discrete(
    labels = function(x) {
      # Map the old labels to the new names and wrap the text
      x <- recode(x, 
                  "deposit" = "Received or deposited money", 
                  "send" = "Sent money",
                  "sw" = "Sent or withdrew money",
                  "withdraw" = "Withdrew money")
      str_wrap(x, width = 9) 
    }
  ) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.y = element_text(size = 16, family = "Nunito Sans"),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      angle = 0,
      size = 16),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      angle = 0,
      size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 18, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 18, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.direction = "horizontal",
    strip.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  labs(subtitle = "Adults who own a mobile money account (standardized to 100%), 2024", 
       title = "Frequency of mobile money account use in SSA subregions",
       caption = "The Global Findex Database")

# Save the plot
# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("S3.4.png")),
  width = width_num+10,
  height = height_num+5,
  device = 'png',
  dpi = 120
)
