c_list_all <- c(
  "Albania", "Algeria", "Argentina", "Armenia", "Australia", "Austria", "Azerbaijan", 
  "Bahrain", "Bangladesh", "Belgium", "Belize", "Benin", "Bolivia", "Bosnia and Herzegovina", 
  "Botswana", "Brazil", "Bulgaria", "Burkina Faso", "Cambodia", "Cameroon", "Canada", "Chad", 
  "Chile", "China", "Colombia", "Comoros", "Congo, Dem. Rep.", "Congo, Rep.", "Costa Rica", 
  "Cote d'Ivoire", "Croatia", "Cyprus", "Czechia", "Denmark", "Dominican Republic", "Ecuador", 
  "Egypt, Arab Rep.", "El Salvador", "Estonia", "Eswatini", "Ethiopia", "Finland", "France", 
  "Gabon", "Gambia, The", "Georgia", "Germany", "Ghana", "Greece", "Guatemala", "Guinea", 
  "Honduras", "Hong Kong SAR, China", "Hungary", "Iceland", "India", "Indonesia", 
  "Iran, Islamic Rep.", "Iraq", "Ireland", "Israel", "Italy", "Japan", "Jordan", "Kazakhstan", 
  "Kenya", "Korea, Rep.", "Kosovo", "Kuwait", "Kyrgyz Republic", "Lao PDR", "Latvia", "Lebanon", 
  "Lesotho", "Liberia", "Libya", "Lithuania", "Madagascar", "Malawi", "Malaysia", "Mali", 
  "Malta", "Mauritania", "Mauritius", "Mexico", "Moldova", "Mongolia", "Montenegro", "Morocco", 
  "Mozambique", "Myanmar", "Namibia", "Nepal", "Netherlands", "New Zealand", "Nicaragua", 
  "Niger", "Nigeria", "North Cyprus", "North Macedonia", "Norway", "Oman", "Pakistan", "Panama", 
  "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Romania", "Russian Federation", 
  "Saudi Arabia", "Senegal", "Serbia", "Sierra Leone", "Singapore", "Slovak Republic", 
  "Slovenia", "South Africa", "Spain", "Sri Lanka", "Sweden", "Switzerland", "Taiwan, China", "Tajikistan", 
  "Tanzania", "Thailand", "Togo", "Trinidad and Tobago", "Tunisia", "Turkiye", "Uganda", "Ukraine", 
  "United Arab Emirates", "United Kingdom", "United States", "Uruguay", "Uzbekistan", "Venezuela, RB", 
  "Viet Nam", "West Bank and Gaza", "Zambia", "Zimbabwe")

### EAP 

data_dot_line <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2011, 2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "East Asia & Pacific (excluding high income)") %>%
  select(year, countrynewwb, ts_account) %>%  # Select relevant columns
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>%
  ungroup() %>%
  filter(!is.na(ts_account)) %>%  # Remove rows with missing ts_account values
  group_by(countrynewwb) %>%
  mutate(
    earliest_year = min(year),  # Identify the earliest year for each country
    ts_account_percentage = ts_account * 100  # Convert ts_account to percentage
  ) %>%
  filter(year %in% c(earliest_year, 2024)) %>%  # Keep only the earliest year and 2024
  ungroup() %>%
  mutate(
    year_label = ifelse(year == 2024, "2024", "2011"),  # Labels for the legend
    countrynewwb = factor(countrynewwb))



# Check the number of unique countries in countrynewwb
length_unique_countries <- data_dot_line %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot(data_dot_line, aes(x = ts_account_percentage, y = fct_rev(countrynewwb), group = countrynewwb)) +
  geom_line(color = "#C2C0C0", size = 1) +  # Connect the dots with a neutral gray line
  geom_point(aes(color = year_label), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c("2011" = "#5696D0", "2024" = "#0F72BC"),  # Assign colors
    labels = c("2011", "2024")  # Legend labels
  ) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # Set x-axis range and breaks
  
  theme_bw() +  # Use white background
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 22, family = "Nunito Sans", color = "black", angle = 0),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",  # Legend at the bottom
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans", hjust = 0),  # Left-align subtitle
    plot.title = element_text(size = 22, family = "Nunito Sans", face = "bold", hjust = 0),  # Left-align title
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    title = "Change in Account Ownership Over Time",  # Title
    subtitle = "Adults with an account (%), 2011-24",
    caption = "Source: Global Findex Database 2025", # Subtitle
    color = "Year"  # Legend title
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("figure_2_1_3_a.png")),
  width = width_num,
  height = height_num,
  units = "in",
  device = 'png',
  dpi = 120,
  limitsize = FALSE)

### ECA

data_dot_line <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2011, 2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "Europe & Central Asia (excluding high income)") %>%
  select(year, countrynewwb, ts_account) %>%  # Select relevant columns
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>%
  ungroup() %>%
  filter(!is.na(ts_account)) %>%  # Remove rows with missing ts_account values
  group_by(countrynewwb) %>%
  mutate(
    earliest_year = min(year),  # Identify the earliest year for each country
    ts_account_percentage = ts_account * 100  # Convert ts_account to percentage
  ) %>%
  filter(year %in% c(earliest_year, 2024)) %>%  # Keep only the earliest year and 2024
  ungroup() %>%
  mutate(
    year_label = ifelse(year == 2024, "2024", "2011"),  # Labels for the legend
    countrynewwb = factor(countrynewwb))



# Check the number of unique countries in countrynewwb
length_unique_countries <- data_dot_line %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot(data_dot_line, aes(x = ts_account_percentage, y = fct_rev(countrynewwb), group = countrynewwb)) +
  geom_line(color = "#C2C0C0", size = 1) +  # Connect the dots with a neutral gray line
  geom_point(aes(color = year_label), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c("2011" = "#5696D0", "2024" = "#0F72BC"),  # Assign colors
    labels = c("2011", "2024")  # Legend labels
  ) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # Set x-axis range and breaks
  
  theme_bw() +  # Use white background
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 22, family = "Nunito Sans", color = "black", angle = 0),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",  # Legend at the bottom
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans", hjust = 0),  # Left-align subtitle
    plot.title = element_text(size = 22, family = "Nunito Sans", face = "bold", hjust = 0),  # Left-align title
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    title = "Change in Account Ownership Over Time",  # Title
    subtitle = "Adults with an account (%), 2011-24",
    caption = "Source: Global Findex Database 2025", # Subtitle
    color = "Year"  # Legend title
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("figure_2_1_3_b.png")),
  width = width_num,
  height = height_num+2,
  units = "in",
  device = 'png',
  dpi = 120,
  limitsize = FALSE)

### LAC

data_dot_line <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2011, 2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "Latin America & Caribbean (excluding high income)") %>%
  select(year, countrynewwb, ts_account) %>%  # Select relevant columns
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>%
  ungroup() %>%
  filter(!is.na(ts_account)) %>%  # Remove rows with missing ts_account values
  group_by(countrynewwb) %>%
  mutate(
    earliest_year = min(year),  # Identify the earliest year for each country
    ts_account_percentage = ts_account * 100  # Convert ts_account to percentage
  ) %>%
  filter(year %in% c(earliest_year, 2024)) %>%  # Keep only the earliest year and 2024
  ungroup() %>%
  mutate(
    year_label = ifelse(year == 2024, "2024", "2011"),  # Labels for the legend
    countrynewwb = factor(countrynewwb))



# Check the number of unique countries in countrynewwb
length_unique_countries <- data_dot_line %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot(data_dot_line, aes(x = ts_account_percentage, y = fct_rev(countrynewwb), group = countrynewwb)) +
  geom_line(color = "#C2C0C0", size = 1) +  # Connect the dots with a neutral gray line
  geom_point(aes(color = year_label), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c("2011" = "#5696D0", "2024" = "#0F72BC"),  # Assign colors
    labels = c("2011", "2024")  # Legend labels
  ) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # Set x-axis range and breaks
  
  theme_bw() +  # Use white background
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 22, family = "Nunito Sans", color = "black", angle = 0),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",  # Legend at the bottom
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans", hjust = 0),  # Left-align subtitle
    plot.title = element_text(size = 22, family = "Nunito Sans", face = "bold", hjust = 0),  # Left-align title
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    title = "Change in Account Ownership Over Time",  # Title
    subtitle = "Adults with an account (%), 2011-24",
    caption = "Source: Global Findex Database 2025", # Subtitle
    color = "Year"  # Legend title
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("figure_2_1_3_c.png")),
  width = width_num,
  height = height_num+1,
  units = "in",
  device = 'png',
  dpi = 120,
  limitsize = FALSE)

### MENA

data_dot_line <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2011, 2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "Middle East & North Africa (excluding high income)") %>%
  select(year, countrynewwb, ts_account) %>%  # Select relevant columns
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>%
  ungroup() %>%
  filter(!is.na(ts_account)) %>%  # Remove rows with missing ts_account values
  group_by(countrynewwb) %>%
  mutate(
    earliest_year = min(year),  # Identify the earliest year for each country
    ts_account_percentage = ts_account * 100  # Convert ts_account to percentage
  ) %>%
  filter(year %in% c(earliest_year, 2024)) %>%  # Keep only the earliest year and 2024
  ungroup() %>%
  mutate(
    year_label = ifelse(year == 2024, "2024", "2011"),  # Labels for the legend
    countrynewwb = factor(countrynewwb))



# Check the number of unique countries in countrynewwb
length_unique_countries <- data_dot_line %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot(data_dot_line, aes(x = ts_account_percentage, y = fct_rev(countrynewwb), group = countrynewwb)) +
  geom_line(color = "#C2C0C0", size = 1) +  # Connect the dots with a neutral gray line
  geom_point(aes(color = year_label), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c("2011" = "#5696D0", "2024" = "#0F72BC"),  # Assign colors
    labels = c("2011", "2024")  # Legend labels
  ) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # Set x-axis range and breaks
  
  theme_bw() +  # Use white background
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 22, family = "Nunito Sans", color = "black", angle = 0),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",  # Legend at the bottom
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans", hjust = 0),  # Left-align subtitle
    plot.title = element_text(size = 22, family = "Nunito Sans", face = "bold", hjust = 0),  # Left-align title
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    title = "Change in Account Ownership Over Time",  # Title
    subtitle = "Adults with an account (%), 2011-24",
    caption = "Source: Global Findex Database 2025", # Subtitle
    color = "Year"  # Legend title
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("figure_2_1_3_d.png")),
  width = width_num,
  height = height_num+1,
  units = "in",
  device = 'png',
  dpi = 120,
  limitsize = FALSE)

### SA

data_dot_line <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2011, 2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "South Asia (excluding high income)") %>%
  select(year, countrynewwb, ts_account) %>%  # Select relevant columns
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>%
  ungroup() %>%
  filter(!is.na(ts_account)) %>%  # Remove rows with missing ts_account values
  group_by(countrynewwb) %>%
  mutate(
    earliest_year = min(year),  # Identify the earliest year for each country
    ts_account_percentage = ts_account * 100  # Convert ts_account to percentage
  ) %>%
  filter(year %in% c(earliest_year, 2024)) %>%  # Keep only the earliest year and 2024
  ungroup() %>%
  mutate(
    year_label = ifelse(year == 2024, "2024", "2011"),  # Labels for the legend
    countrynewwb = factor(countrynewwb))



# Check the number of unique countries in countrynewwb
length_unique_countries <- data_dot_line %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot(data_dot_line, aes(x = ts_account_percentage, y = fct_rev(countrynewwb), group = countrynewwb)) +
  geom_line(color = "#C2C0C0", size = 1) +  # Connect the dots with a neutral gray line
  geom_point(aes(color = year_label), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c("2011" = "#5696D0", "2024" = "#0F72BC"),  # Assign colors
    labels = c("2011", "2024")  # Legend labels
  ) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # Set x-axis range and breaks
  
  theme_bw() +  # Use white background
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 22, family = "Nunito Sans", color = "black", angle = 0),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",  # Legend at the bottom
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans", hjust = 0),  # Left-align subtitle
    plot.title = element_text(size = 22, family = "Nunito Sans", face = "bold", hjust = 0),  # Left-align title
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    title = "Change in Account Ownership Over Time",  # Title
    subtitle = "Adults with an account (%), 2011-24",
    caption = "Source: Global Findex Database 2025", # Subtitle
    color = "Year"  # Legend title
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("figure_2_1_3_e.png")),
  width = width_num,
  height = height_num+1,
  units = "in",
  device = 'png',
  dpi = 120,
  limitsize = FALSE)


### SSA

data_dot_line <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2011, 2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "Sub-Saharan Africa (excluding high income)") %>%
  #filter(!countrynewwb %in% c("SSA", "SSA (ex V5 countries)", "SAR (excluding India)")) %>%
  select(year, countrynewwb, ts_account) %>%  # Select relevant columns
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>%
  ungroup() %>%
  filter(!is.na(ts_account)) %>%  # Remove rows with missing ts_account values
  group_by(countrynewwb) %>%
  mutate(
    earliest_year = min(year),  # Identify the earliest year for each country
    ts_account_percentage = ts_account * 100  # Convert ts_account to percentage
  ) %>%
  filter(year %in% c(earliest_year, 2024)) %>%  # Keep only the earliest year and 2024
  ungroup() %>%
  mutate(
    year_label = ifelse(year == 2024, "2024", "2011"),  # Labels for the legend
    countrynewwb = factor(countrynewwb))



# Check the number of unique countries in countrynewwb
length_unique_countries <- data_dot_line %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot(data_dot_line, aes(x = ts_account_percentage, y = fct_rev(countrynewwb), group = countrynewwb)) +
  geom_line(color = "#C2C0C0", size = 1) +  # Connect the dots with a neutral gray line
  geom_point(aes(color = year_label), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c("2011" = "#5696D0", "2024" = "#0F72BC"),  # Assign colors
    labels = c("2011", "2024")  # Legend labels
  ) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # Set x-axis range and breaks
  
  theme_bw() +  # Use white background
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 22, family = "Nunito Sans", color = "black", angle = 0),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",  # Legend at the bottom
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans", hjust = 0),  # Left-align subtitle
    plot.title = element_text(size = 22, family = "Nunito Sans", face = "bold", hjust = 0),  # Left-align title
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    title = "Change in Account Ownership Over Time",  # Title
    subtitle = "Adults with an account (%), 2011-24",
    caption = "Source: Global Findex Database 2025", # Subtitle
    color = "Year"  # Legend title
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("figure_2_1_3_f.png")),
  width = width_num-12,
  height = height_num+3,
  units = "in",
  device = 'png',
  dpi = 120,
  limitsize = FALSE)

### High income
data_dot_line <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2011, 2014, 2017, 2021, 2024)) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "High income") %>%
  #filter(!countrynewwb %in% c("SSA", "SSA (ex V5 countries)", "SAR (excluding India)")) %>%
  select(year, countrynewwb, ts_account) %>%  # Select relevant columns
  group_by(countrynewwb) %>%
  filter(any(year == 2024)) %>%
  ungroup() %>%
  filter(!is.na(ts_account)) %>%  # Remove rows with missing ts_account values
  group_by(countrynewwb) %>%
  mutate(
    earliest_year = min(year),  # Identify the earliest year for each country
    ts_account_percentage = ts_account * 100  # Convert ts_account to percentage
  ) %>%
  filter(year %in% c(earliest_year, 2024)) %>%  # Keep only the earliest year and 2024
  ungroup() %>%
  mutate(
    year_label = ifelse(year == 2024, "2024", "2011"),  # Labels for the legend
    countrynewwb = factor(countrynewwb))



# Check the number of unique countries in countrynewwb
length_unique_countries <- data_dot_line %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot(data_dot_line, aes(x = ts_account_percentage, y = fct_rev(countrynewwb), group = countrynewwb)) +
  geom_line(color = "#C2C0C0", size = 1) +  # Connect the dots with a neutral gray line
  geom_point(aes(color = year_label), size = 4) +
  geom_point(size = 4, shape = 1, color = "black") +
  scale_color_manual(
    values = c("2011" = "#5696D0", "2024" = "#0F72BC"),  # Assign colors
    labels = c("2011", "2024")  # Legend labels
  ) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # Set x-axis range and breaks
  
  theme_bw() +  # Use white background
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 22, family = "Nunito Sans", color = "black", angle = 0),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",  # Legend at the bottom
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans", hjust = 0),  # Left-align subtitle
    plot.title = element_text(size = 22, family = "Nunito Sans", face = "bold", hjust = 0),  # Left-align title
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    title = "Change in Account Ownership Over Time",  # Title
    subtitle = "Adults with an account (%), 2011-24",
    caption = "Source: Global Findex Database 2025", # Subtitle
    color = "Year"  # Legend title
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("figure_2_1_3_g.png")),
  width = width_num-12,
  height = height_num+3,
  units = "in",
  device = 'png',
  dpi = 120,
  limitsize = FALSE)

