c_list_all <- c(
  "Albania", "Algeria", "Argentina", "Armenia", "Australia", "Austria", "Azerbaijan", 
  "Bahrain", "Bangladesh", "Belgium", "Belize", "Benin", "Bolivia", "Bosnia and Herzegovina", 
  "Botswana", "Brazil", "Bulgaria", "Burkina Faso", "Cambodia", "Cameroon", "Canada", "Chad", 
  "Chile", "China", "Colombia", "Comoros", "Congo, Dem. Rep.", "Congo, Rep.", "Costa Rica", 
  "Cote d'Ivoire", "Croatia", "Cyprus", "Czechia", "Denmark", "Dominican Republic", "Ecuador", 
  "Egypt, Arab Rep.", "El Salvador", "Estonia", "Eswatini", "Ethiopia", "Finland", "France", 
  "Gabon", "Gambia, The", "Georgia", "Germany", "Ghana", "Greece", "Guatemala", "Guinea", 
  "Honduras", "Hong Kong SAR, China", "Hungary", "Iceland", "India", "Indonesia", 
  "Iran, Islamic Rep.", "Iraq", "Ireland", "Israel", "Italy", "Japan", "Jordan", "Kazakhstan", 
  "Kenya", "Korea, Rep.", "Kosovo", "Kuwait", "Kyrgyz Republic", "Lao PDR", "Latvia", "Lebanon", 
  "Lesotho", "Liberia", "Libya", "Lithuania", "Madagascar", "Malawi", "Malaysia", "Mali", 
  "Malta", "Mauritania", "Mauritius", "Mexico", "Moldova", "Mongolia", "Montenegro", "Morocco", 
  "Mozambique", "Myanmar", "Namibia", "Nepal", "Netherlands", "New Zealand", "Nicaragua", 
  "Niger", "Nigeria", "North Cyprus", "North Macedonia", "Norway", "Oman", "Pakistan", "Panama", 
  "Paraguay", "Peru", "Philippines", "Poland", "Portugal", "Romania", "Russian Federation", 
  "Saudi Arabia", "Senegal", "Serbia", "Sierra Leone", "Singapore", "Slovak Republic", 
  "Slovenia", "South Africa", "Spain", "Sri Lanka", "Sweden", "Switzerland", "Taiwan, China", "Tajikistan", 
  "Tanzania", "Thailand", "Togo", "Trinidad and Tobago", "Tunisia", "Turkiye", "Uganda", "Ukraine", 
  "United Arab Emirates", "United Kingdom", "United States", "Uruguay", "Uzbekistan", "Venezuela, RB", 
  "Viet Nam", "West Bank and Gaza", "Zambia", "Zimbabwe")






# East Asia and Pacific

phone_type_gender <- data %>% 
  filter(group == "gender") %>%  # Filter gender group
  filter(year %in% c(2024)) %>%  # Filter for year 2024
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi %in% c("East Asia & Pacific (excluding high income)")) %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>% 
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all)) %>% 
  mutate(group2 = factor(group2, levels = c("men", "women"))) %>%  # Ensure proper order
  mutate(con9_all_basic_2 = con9_all_basic - con10_all) %>%  # Calculate con9_all_basic_2
  select(-con9_all_basic) %>%  # Remove con9_all_basic
  mutate(
    total = (con9_all_smart + con10_all + con9_all_basic_2) * 100 
  ) %>% 
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>% 
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),  # Labels appear only if value >= 20
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) 

region_summary <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(regionwb24_hi == "East Asia & Pacific (excluding high income)") %>%
  filter(countrynewwb == "East Asia & Pacific (excluding high income)") %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>%
  mutate(group2 = "all") %>%  # To match gender structure
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all),
         con9_all_basic_2 = con9_all_basic - con10_all) %>%
  select(-con9_all_basic) %>%
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>%
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific"
  ))

combined_data <- bind_rows(region_summary, phone_type_gender) %>%
  mutate(
    countrynewwb = factor(countrynewwb,
                          levels = c("East Asia and Pacific", 
                                     sort(unique(phone_type_gender$countrynewwb))))
  )

combined_data <- combined_data %>%
  mutate(group2 = ifelse(group2 == "all", "", str_to_title(group2))) %>% 
  mutate(group2 = factor(group2, levels = c("", "Men", "Women")))

ggplot(combined_data) +
  geom_bar(aes(
    y = group2,  # Correct factor levels for group2
    x = value,
    fill = group # Add black stroke around the bars
  ),
  stat = "identity", 
  position = "stack",
  width = 0.75,
  color = "black"
  ) +  # Stacked bar chart
  scale_fill_manual(values = c("con9_all_smart" = "#D12891",
                               "con10_all" = "#8066AB",
                               "con9_all_basic_2" = "#5696D0"),  
                    breaks = c("con9_all_basic_2", "con10_all", "con9_all_smart"),  # Keep legend order the same
                    labels = c("Basic text phone",
                               "Feature phone",
                               "Smartphone")) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  
  # Facet by country
  facet_grid(factor(countrynewwb)~., 
             scales = "free", 
             space = "free", 
             switch = "both"
  ) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),  # Size for facet labels (y-axis)
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),   # Size for facet labels (x-axis)
    strip.text.y = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y.left = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 22,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 22,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0,
                                size = 16,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  
  # Labels for the plot
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone ownership is widespread around the world, though women are less likely than men to own one"
  )

ggsave(
  filename = file.path(folder_path, "1.1.1_EAP.png"),
  width = 12,  
  height = 9,  
  device = 'png',
  dpi = 120,
  limitsize = FALSE  
)

# ggsave(
#   filename = file.path(folder_path, "1.1.1_EAP.eps"),
#   width = 12,  
#   height = 9,  
#   device = 'eps',
#   dpi = 120,
#   limitsize = FALSE  
# )

# Europe & Central Asia

phone_type_gender <- data %>% 
  filter(group == "gender") %>%  # Filter gender group
  filter(year %in% c(2024)) %>%  # Filter for year 2024
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi %in% c("Europe & Central Asia (excluding high income)")) %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>% 
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all)) %>% 
  mutate(group2 = factor(group2, levels = c("men", "women"))) %>%  # Ensure proper order
  mutate(con9_all_basic_2 = con9_all_basic - con10_all) %>%  # Calculate con9_all_basic_2
  select(-con9_all_basic) %>%  # Remove con9_all_basic
  mutate(
    total = (con9_all_smart + con10_all + con9_all_basic_2) * 100 
  ) %>% 
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>% 
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),  # Labels appear only if value >= 20
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) 

region_summary <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(regionwb24_hi == "Europe & Central Asia (excluding high income)") %>%
  filter(countrynewwb == "Europe & Central Asia (excluding high income)") %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>%
  mutate(group2 = "all") %>%  # To match gender structure
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all),
         con9_all_basic_2 = con9_all_basic - con10_all) %>%
  select(-con9_all_basic) %>%
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>%
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia"
  ))

combined_data <- bind_rows(region_summary, phone_type_gender) %>%
  mutate(
    countrynewwb = factor(countrynewwb,
                          levels = c("Europe and Central Asia", 
                                     sort(unique(phone_type_gender$countrynewwb))))
  )

combined_data <- combined_data %>%
  mutate(group2 = ifelse(group2 == "all", "", str_to_title(group2))) %>% 
  mutate(group2 = factor(group2, levels = c("", "Men", "Women")))

ggplot(combined_data) +
  geom_bar(aes(
    y = group2,  # Correct factor levels for group2
    x = value,
    fill = group # Add black stroke around the bars
  ),
  stat = "identity", 
  position = "stack",
  width = 0.75,
  color = "black"
  ) +  # Stacked bar chart
  scale_fill_manual(values = c("con9_all_smart" = "#D12891",
                               "con10_all" = "#8066AB",
                               "con9_all_basic_2" = "#5696D0"),  
                    breaks = c("con9_all_basic_2", "con10_all", "con9_all_smart"),  # Keep legend order the same
                    labels = c("Basic text phone",
                               "Feature phone",
                               "Smartphone")) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  
  # Facet by country
  facet_grid(factor(countrynewwb)~., 
             scales = "free", 
             space = "free", 
             switch = "both"
  ) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),  # Size for facet labels (y-axis)
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),   # Size for facet labels (x-axis)
    strip.text.y = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y.left = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 22,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 22,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0,
                                size = 16,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  
  # Labels for the plot
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone ownership is widespread around the world, though women are less likely than men to own one"
  )

ggsave(
  filename = file.path(folder_path, "1.1.1_ECA.png"),
  width = 12,  
  height = 18,  
  device = 'png',
  dpi = 120,
  limitsize = FALSE  
)

# ggsave(
#   filename = file.path(folder_path, "1.1.1_ECA.eps"),
#   width = 12,  
#   height = 18,  
#   device = 'eps',
#   dpi = 120,
#   limitsize = FALSE  
# )

# Latin America and the Caribbean

phone_type_gender <- data %>% 
  filter(group == "gender") %>%  # Filter gender group
  filter(year %in% c(2024)) %>%  # Filter for year 2024
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi %in% c("Latin America & Caribbean (excluding high income)")) %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>% 
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all)) %>% 
  mutate(group2 = factor(group2, levels = c("men", "women"))) %>%  # Ensure proper order
  mutate(con9_all_basic_2 = con9_all_basic - con10_all) %>%  # Calculate con9_all_basic_2
  select(-con9_all_basic) %>%  # Remove con9_all_basic
  mutate(
    total = (con9_all_smart + con10_all + con9_all_basic_2) * 100 
  ) %>% 
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>% 
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),  # Labels appear only if value >= 20
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) 

region_summary <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(regionwb24_hi == "Latin America & Caribbean (excluding high income)") %>%
  filter(countrynewwb == "Latin America & Caribbean (excluding high income)") %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>%
  mutate(group2 = "all") %>%  # To match gender structure
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all),
         con9_all_basic_2 = con9_all_basic - con10_all) %>%
  select(-con9_all_basic) %>%
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>%
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean"
  ))

combined_data <- bind_rows(region_summary, phone_type_gender) %>%
  mutate(
    countrynewwb = factor(countrynewwb,
                          levels = c("Latin America and the Caribbean", 
                                     sort(unique(phone_type_gender$countrynewwb))))
  )

combined_data <- combined_data %>%
  mutate(group2 = ifelse(group2 == "all", "", str_to_title(group2))) %>% 
  mutate(group2 = factor(group2, levels = c("", "Men", "Women")))

ggplot(combined_data) +
  geom_bar(aes(
    y = group2,  # Correct factor levels for group2
    x = value,
    fill = group # Add black stroke around the bars
  ),
  stat = "identity", 
  position = "stack",
  width = 0.75,
  color = "black"
  ) +  # Stacked bar chart
  scale_fill_manual(values = c("con9_all_smart" = "#D12891",
                               "con10_all" = "#8066AB",
                               "con9_all_basic_2" = "#5696D0"),  
                    breaks = c("con9_all_basic_2", "con10_all", "con9_all_smart"),  # Keep legend order the same
                    labels = c("Basic text phone",
                               "Feature phone",
                               "Smartphone")) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  
  # Facet by country
  facet_grid(factor(countrynewwb)~., 
             scales = "free", 
             space = "free", 
             switch = "both"
  ) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),  # Size for facet labels (y-axis)
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),   # Size for facet labels (x-axis)
    strip.text.y = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y.left = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 22,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 22,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0,
                                size = 16,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  
  # Labels for the plot
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone ownership is widespread around the world, though women are less likely than men to own one"
  )

ggsave(
  filename = file.path(folder_path, "1.1.1_LAC.png"),
  width = 12,  
  height = 17,  
  device = 'png',
  dpi = 120,
  limitsize = FALSE  
)

# ggsave(
#   filename = file.path(folder_path, "1.1.1_LAC.eps"),
#   width = 12,  
#   height = 17,  
#   device = 'eps',
#   dpi = 120,
#   limitsize = FALSE  
# )

# Middle East and North Africa

phone_type_gender <- data %>% 
  filter(group == "gender") %>%  # Filter gender group
  filter(year %in% c(2024)) %>%  # Filter for year 2024
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi %in% c("Middle East & North Africa (excluding high income)")) %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>% 
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all)) %>% 
  mutate(group2 = factor(group2, levels = c("men", "women"))) %>%  # Ensure proper order
  mutate(con9_all_basic_2 = con9_all_basic - con10_all) %>%  # Calculate con9_all_basic_2
  select(-con9_all_basic) %>%  # Remove con9_all_basic
  mutate(
    total = (con9_all_smart + con10_all + con9_all_basic_2) * 100 
  ) %>% 
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>% 
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),  # Labels appear only if value >= 20
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) 

region_summary <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(regionwb24_hi == "Middle East & North Africa (excluding high income)") %>%
  filter(countrynewwb == "Middle East & North Africa (excluding high income)") %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>%
  mutate(group2 = "all") %>%  # To match gender structure
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all),
         con9_all_basic_2 = con9_all_basic - con10_all) %>%
  select(-con9_all_basic) %>%
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>%
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa"
  ))

combined_data <- bind_rows(region_summary, phone_type_gender) %>%
  mutate(
    countrynewwb = factor(countrynewwb,
                          levels = c("Middle East and North Africa", 
                                     sort(unique(phone_type_gender$countrynewwb))))
  )

combined_data <- combined_data %>%
  mutate(group2 = ifelse(group2 == "all", "", str_to_title(group2))) %>% 
  mutate(group2 = factor(group2, levels = c("", "Men", "Women")))

ggplot(combined_data) +
  geom_bar(aes(
    y = group2,  # Correct factor levels for group2
    x = value,
    fill = group # Add black stroke around the bars
  ),
  stat = "identity", 
  position = "stack",
  width = 0.75,
  color = "black"
  ) +  # Stacked bar chart
  scale_fill_manual(values = c("con9_all_smart" = "#D12891",
                               "con10_all" = "#8066AB",
                               "con9_all_basic_2" = "#5696D0"),  
                    breaks = c("con9_all_basic_2", "con10_all", "con9_all_smart"),  # Keep legend order the same
                    labels = c("Basic text phone",
                               "Feature phone",
                               "Smartphone")) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  
  # Facet by country
  facet_grid(factor(countrynewwb)~., 
             scales = "free", 
             space = "free", 
             switch = "both"
  ) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),  # Size for facet labels (y-axis)
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),   # Size for facet labels (x-axis)
    strip.text.y = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y.left = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 22,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 22,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0,
                                size = 16,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  
  # Labels for the plot
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone ownership is widespread around the world, though women are less likely than men to own one"
  )

ggsave(
  filename = file.path(folder_path, "1.1.1_MENA.png"),
  width = 12,  
  height = 10,  
  device = 'png',
  dpi = 120,
  limitsize = FALSE  
)

# ggsave(
#   filename = file.path(folder_path, "1.1.1_MENA.eps"),
#   width = 12,  
#   height = 10,  
#   device = 'eps',
#   dpi = 120,
#   limitsize = FALSE  
# )

# South Asia

phone_type_gender <- data %>% 
  filter(group == "gender") %>%  # Filter gender group
  filter(year %in% c(2024)) %>%  # Filter for year 2024
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi %in% c("South Asia (excluding high income)")) %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>% 
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all)) %>% 
  mutate(group2 = factor(group2, levels = c("men", "women"))) %>%  # Ensure proper order
  mutate(con9_all_basic_2 = con9_all_basic - con10_all) %>%  # Calculate con9_all_basic_2
  select(-con9_all_basic) %>%  # Remove con9_all_basic
  mutate(
    total = (con9_all_smart + con10_all + con9_all_basic_2) * 100 
  ) %>% 
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>% 
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),  # Labels appear only if value >= 20
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) 

region_summary <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(regionwb24_hi == "South Asia (excluding high income)") %>%
  filter(countrynewwb == "South Asia (excluding high income)") %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>%
  mutate(group2 = "all") %>%  # To match gender structure
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all),
         con9_all_basic_2 = con9_all_basic - con10_all) %>%
  select(-con9_all_basic) %>%
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>%
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "South Asia (excluding high income)" = "South Asia"
  ))

combined_data <- bind_rows(region_summary, phone_type_gender) %>%
  mutate(
    countrynewwb = factor(countrynewwb,
                          levels = c("South Asia", 
                                     sort(unique(phone_type_gender$countrynewwb))))
  )

combined_data <- combined_data %>%
  mutate(group2 = ifelse(group2 == "all", "", str_to_title(group2))) %>% 
  mutate(group2 = factor(group2, levels = c("", "Men", "Women")))

ggplot(combined_data) +
  geom_bar(aes(
    y = group2,  # Correct factor levels for group2
    x = value,
    fill = group # Add black stroke around the bars
  ),
  stat = "identity", 
  position = "stack",
  width = 0.75,
  color = "black"
  ) +  # Stacked bar chart
  scale_fill_manual(values = c("con9_all_smart" = "#D12891",
                               "con10_all" = "#8066AB",
                               "con9_all_basic_2" = "#5696D0"),  
                    breaks = c("con9_all_basic_2", "con10_all", "con9_all_smart"),  # Keep legend order the same
                    labels = c("Basic text phone",
                               "Feature phone",
                               "Smartphone")) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  
  # Facet by country
  facet_grid(factor(countrynewwb)~., 
             scales = "free", 
             space = "free", 
             switch = "both"
  ) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),  # Size for facet labels (y-axis)
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),   # Size for facet labels (x-axis)
    strip.text.y = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y.left = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 22,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 22,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0,
                                size = 16,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  
  # Labels for the plot
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone ownership is widespread around the world, though women are less likely than men to own one"
  )

ggsave(
  filename = file.path(folder_path, "1.1.1_SA.png"),
  width = 12,  
  height = 7,  
  device = 'png',
  dpi = 120,
  limitsize = FALSE  
)

# ggsave(
#   filename = file.path(folder_path, "1.1.1_SA.eps"),
#   width = 12,  
#   height = 7,  
#   device = 'eps',
#   dpi = 120,
#   limitsize = FALSE  
# )

### Sub-Saharan Africa

phone_type_gender <- data %>% 
  filter(group == "gender") %>%  # Filter gender group
  filter(year %in% c(2024)) %>%  # Filter for year 2024
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi %in% c("Sub-Saharan Africa (excluding high income)")) %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>% 
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all)) %>% 
  mutate(group2 = factor(group2, levels = c("men", "women"))) %>%  # Ensure proper order
  mutate(con9_all_basic_2 = con9_all_basic - con10_all) %>%  # Calculate con9_all_basic_2
  select(-con9_all_basic) %>%  # Remove con9_all_basic
  mutate(
    total = (con9_all_smart + con10_all + con9_all_basic_2) * 100 
  ) %>% 
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>% 
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),  # Labels appear only if value >= 20
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) 

region_summary <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(regionwb24_hi == "Sub-Saharan Africa (excluding high income)") %>%
  filter(countrynewwb == "Sub-Saharan Africa (excluding high income)") %>%
  select(countrynewwb, year, group2, con9_all_smart, con10_all, con9_all_basic, con1_all) %>%
  mutate(group2 = "all") %>%  # To match gender structure
  mutate(con10_all = ifelse(is.na(con10_all), 0, con10_all),
         con9_all_basic_2 = con9_all_basic - con10_all) %>%
  select(-con9_all_basic) %>%
  gather(group, value, con9_all_smart, con9_all_basic_2, con10_all) %>%
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),
    group = factor(group, levels = c("con9_all_smart", "con10_all", "con9_all_basic_2"))
  ) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
  ))

combined_data <- bind_rows(region_summary, phone_type_gender) %>%
  mutate(
    countrynewwb = factor(countrynewwb,
                          levels = c("Sub-Saharan Africa", 
                                     sort(unique(phone_type_gender$countrynewwb))))
  )

combined_data <- combined_data %>%
  mutate(group2 = ifelse(group2 == "all", "", str_to_title(group2))) %>% 
  mutate(group2 = factor(group2, levels = c("", "Men", "Women")))

ggplot(combined_data) +
  geom_bar(aes(
    y = group2,  # Correct factor levels for group2
    x = value,
    fill = group # Add black stroke around the bars
  ),
  stat = "identity", 
  position = "stack",
  width = 0.75,
  color = "black"
  ) +  # Stacked bar chart
  scale_fill_manual(values = c("con9_all_smart" = "#D12891",
                               "con10_all" = "#8066AB",
                               "con9_all_basic_2" = "#5696D0"),  
                    breaks = c("con9_all_basic_2", "con10_all", "con9_all_smart"),  # Keep legend order the same
                    labels = c("Basic text phone",
                               "Feature phone",
                               "Smartphone")) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  
  # Facet by country
  facet_grid(factor(countrynewwb)~., 
             scales = "free", 
             space = "free", 
             switch = "both"
  ) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),  # Size for facet labels (y-axis)
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),   # Size for facet labels (x-axis)
    strip.text.y = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y.left = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 22,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 22,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0,
                                size = 16,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  
  # Labels for the plot
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone ownership is widespread around the world, though women are less likely than men to own one"
  )

ggsave(
  filename = file.path(folder_path, "1.1.1_SSA.png"),
  width = 12,  
  height = 20,  
  device = 'png',
  dpi = 120,
  limitsize = FALSE  
)

# ggsave(
#   filename = file.path(folder_path, "1.1.1_SSA.eps"),
#   width = 12,  
#   height = 20,  
#   device = 'eps',
#   dpi = 120,
#   limitsize = FALSE  
# )

### High income

hi_1 <- c("High income",
          "Australia", "Austria", "Bahrain", "Belgium", "Canada", "Chile", "Croatia", "Cyprus",
          "Czechia", "Denmark", "Estonia", "Finland", "France", "Germany", "Greece", "Hong Kong SAR, China",
          "Hungary", "Iceland", "Ireland", "Israel", "Italy", "Japan", "Korea, Rep.", "Kuwait")
hi_2 <- c("High income", "Latvia", "Lithuania", "Malta", "Netherlands", "New Zealand", "Norway", "Oman", 
          "Panama", "Poland", "Portugal", "Romania", "Saudi Arabia", "Singapore", "Slovak Republic", 
          "Slovenia", "Spain", "Sweden", "Switzerland", "Taiwan, China", "Trinidad and Tobago", "United Arab Emirates", "United Kingdom",
          "United States", "Uruguay")
phone_type_gender <- data %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% hi_1) %>%
  filter(
    (countrynewwb == "High income" & group == "all") |
      (countrynewwb != "High income" & group == "gender")
  ) %>%
  select(countrynewwb, year, group2, con_sp_world, cv_wp17626, con1_all) %>%
  mutate(group2 = factor(group2, levels = c("men", "women"))) %>%
  mutate(con9_basic = cv_wp17626 - con_sp_world) %>%
  mutate(total = cv_wp17626 * 100) %>%
  gather(group, value, con_sp_world, con9_basic) %>%
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),
    group = factor(group, levels = c("con_sp_world", "con9_basic"))
  ) %>%
  mutate(group2 = ifelse(is.na(group2) | group2 == "all", "", str_to_title(group2))) %>%
  mutate(group2 = factor(group2, levels = c("", "Men", "Women")))

length_unique_countries <- phone_type_gender %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4 # default setting as 8 countries
} else {
  # Every two countries added, width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height
cat("Width:", width_num, "\n")

ggplot(phone_type_gender) +
  geom_bar(aes(
    y = group2,  # Correct factor levels for group2
    x = value,
    fill = group # Add black stroke around the bars
  ),
  stat = "identity", 
  position = "stack",
  width = 0.9,
  color = "black"
  ) +  # Stacked bar chart
  scale_fill_manual(values = c("con_sp_world" = "#D12891",
                               "con9_basic" = "#5696D0"),  
                    breaks = c("con9_basic", "con_sp_world"),  # Keep legend order the same
                    labels = c("Basic text phone",
                               "Smartphone")) +
  scale_x_continuous(limits = c(0, 120), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  
  # Facet by country
  facet_grid(factor(countrynewwb, levels = hi_1)~., 
             scales = "free", 
             space = "free", 
             switch = "both"
  ) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),  # Size for facet labels (y-axis)
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),   # Size for facet labels (x-axis)
    strip.text.y = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y.left = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 22,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 22,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0,
                                size = 16,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  
  # Labels for the plot
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone ownership is widespread around the world, though women are less likely than men to own one"
  )

# Export the plot to a file
ggsave(
  filename = file.path(folder_path, "1.1.1_HI_1.png"),
  width = 12,  # Inches
  height = 16,  # Inches
  device = 'png',
  dpi = 120,
  limitsize = FALSE 
)

# ggsave(
#   filename = file.path(folder_path, "1.1.1_HI_1.eps"),
#   width = 12,  
#   height = 16,  
#   device = 'eps',
#   dpi = 120,
#   limitsize = FALSE  
# )


phone_type_gender <- data %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% hi_2) %>%
  filter(
    (countrynewwb == "High income" & group == "all") |
      (countrynewwb != "High income" & group == "gender")
  ) %>%
  select(countrynewwb, year, group2, con_sp_world, cv_wp17626) %>%
  mutate(group2 = factor(group2, levels = c("men", "women"))) %>%
  mutate(con9_basic = cv_wp17626 - con_sp_world) %>%
  mutate(total = cv_wp17626 * 100) %>%
  gather(group, value, con_sp_world, con9_basic) %>%
  mutate(
    value = value * 100,
    lab = ifelse(value >= 20, round(value), NA),
    group = factor(group, levels = c("con_sp_world", "con9_basic"))
  ) %>%
  #filter(!is.na(value)) %>%
  mutate(group2 = ifelse(is.na(group2) | group2 == "all", "", str_to_title(group2))) %>%
  mutate(group2 = factor(group2, levels = c("", "Men", "Women")))

length_unique_countries <- phone_type_gender %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4 # default setting as 8 countries
} else {
  # Every two countries added, width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height
cat("Width:", width_num, "\n")


ggplot(phone_type_gender) +
  geom_bar(aes(
    y = group2,  # Correct factor levels for group2
    x = value,
    fill = group # Add black stroke around the bars
  ),
  stat = "identity", 
  position = "stack",
  width = 0.9,
  color = "black"
  ) +  # Stacked bar chart
  scale_fill_manual(values = c("con_sp_world" = "#D12891",
                               "con9_basic" = "#5696D0"),  
                    breaks = c("con9_basic", "con_sp_world"),  # Keep legend order the same
                    labels = c("Basic text phone",
                               "Smartphone")) +
  scale_x_continuous(limits = c(0, 120), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  
  # Facet by country
  facet_grid(factor(countrynewwb, levels = hi_2)~., 
             scales = "free", 
             space = "free", 
             switch = "both"
  ) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),  # Size for facet labels (y-axis)
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),   # Size for facet labels (x-axis)
    strip.text.y = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.text.y.left = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 22,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 22,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0,
                                size = 16,
                                family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  
  # Labels for the plot
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone ownership is widespread around the world, though women are less likely than men to own one"
  )

# Export the plot to a file
ggsave(
  filename = file.path(folder_path, "1.1.1_HI_2.png"),
  width = 12,  # Inches
  height = 16,  # Inches
  device = 'png',
  dpi = 120,
  limitsize = FALSE 
)

# ggsave(
#   filename = file.path(folder_path, "1.1.1_HI_2.eps"),
#   width = 12,  
#   height = 16,  
#   device = 'eps',
#   dpi = 120,
#   limitsize = FALSE  
# )

