Sim_own_gender_data <- data %>%
  filter(group == "gender") %>%
  filter(year == 2024) %>%
  filter(regionwb24_hi == "Sub-Saharan Africa (excluding high income)") %>%
  filter(countrynewwb %in% c_list_all) %>%
  select(countrynewwb, group2, con1_all, con11_all) %>%
  filter(!is.na(con11_all) & !is.na(group2)) %>%  # Ensure no missing values in gender
  mutate(
    "gap1" = con11_all,  
    "gap2" = con1_all - con11_all,
    "total" = con1_all
  ) %>% 
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group) & !is.na(value)) %>%  # Ensure no missing values
  mutate(
    total = total * 100,
    value = value * 100
  ) %>%
  filter(!is.na(total))

# Drop unused levels in factor group2
Sim_own_gender_data$group2 <- factor(Sim_own_gender_data$group2, levels = unique(Sim_own_gender_data$group2))


# Check the number of unique countries in countrynewwb
length_unique_countries <- Sim_own_gender_data %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(Sim_own_gender_data $total, na.rm = TRUE) +15
if (max_val >92) {
  max_val <- 110
}


ggplot(Sim_own_gender_data) +
  geom_bar(aes(
    y = factor(group2, levels = c("men", "women")),  # Correct factor levels for group2 (men, women)
    x = value,
    fill = factor(group, levels = c("gap1", "gap2"))  # Correct fill mapping for gap1 and gap2
  ), 
  stat = "identity", 
  position = "stack",
  width = 0.75,
  color = "black") +  # Stacked bar chart
  
  # Fix color scale for both gap1 and gap2
  scale_fill_manual(values = c("gap1" = "#D12891","gap2" = "#B8CB33"),
                    breaks = c("gap2", "gap1"),
                    labels = c("Own a phone that has a SIM card registered in someone else's name", "Own a phone that has a SIM card registered in own name")) +
  
  # X-axis scaling
  scale_x_continuous(limits = c(0, 120), breaks = seq(0, 100, by = 20)) +  # X-axis scaling
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  # Facet by country
  facet_grid(factor(countrynewwb, levels = c_list_all) ~ ., 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 20, multi_line = TRUE)) +
  
  # Theme settings
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),
    strip.text.x = element_text(size = 22, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 22),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 22, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 24, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(size = 22, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 18, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  
  # Guide for fill legend (labels and order of levels)
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "A subset of mobile phone owners do not have a SIM card registered in their name"
  )

# Export the image
ggsave(
  filename = file.path(folder_path, sprintf("1.1.3.png")),
  width = 10.5,
  height = 19,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("1.1.3.eps")),
  width = 10.5,
  height = 19,
  device = 'eps',
  dpi = 120
)

