Phone_use_Frequency <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  #filter(regionwb24_hi == "Sub-Saharan Africa (excluding high income)") %>%
  filter(aggregate_level == "African_Union") %>%
  filter(!countrynewwb == "AU_North") %>%
  filter(group == "all") %>%
  select(countrynewwb, year,con12_all_d, con12_all_w, con12_all_m, con12_all_lm, con12_all_n) %>%
  mutate(gap1 = con12_all_n + con12_all_lm,
         gap2 = con12_all_m, 
         gap3 = con12_all_w,
         gap4 = con12_all_d) %>%
  filter(!is.na(con12_all_w)) %>%
  na.omit() %>%
  gather(group, value, gap1, gap2, gap3, gap4) %>%
  filter(group %in% c("gap1", "gap2", "gap3", "gap4")) %>%
  # Calculate percentage
  group_by(countrynewwb) %>%
  mutate(value = value / sum(value) * 100) %>%
  ungroup()



# Check the number of unique countries in countrynewwb
length_unique_countries <- Phone_use_Frequency %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) /4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) /4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

unique_countries_list <- Phone_use_Frequency  %>%
  distinct(countrynewwb) %>%
  pull(countrynewwb)
## Get top number

Phone_use_label_data <- data %>%
  filter(group == "all") %>%
  filter(year %in% c(2024)) %>%
  filter(countrynewwb %in% unique_countries_list) %>%
  select(countrynewwb, con1_all) %>%
  rename(total = con1_all)

Phone_use_Frequency <- Phone_use_Frequency %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "AU_Central" = "Central Africa",
                               "AU_East" = "East Africa",
                               "AU_North" = "North Africa",
                               "AU_Southern" = "Southern Africa",
                               "AU_West" = "West Africa"))
Phone_use_Frequency$countrynewwb <- factor(Phone_use_Frequency$countrynewwb, 
                                           levels = rev(levels(factor(Phone_use_Frequency$countrynewwb))))

# Create the plot
ggplot(Phone_use_Frequency, aes(y = countrynewwb, x = value)) +
  geom_bar(aes(fill = factor(group, levels = c("gap1", "gap2", "gap3", "gap4"))),
           stat = "identity", 
           position = "stack", 
           width = 0.75,
           color = "black") +
  scale_fill_manual(values = c("#0F72BC","#5696D0","#B2D6F7", "#cccccc"),
                    limits = c("gap4", "gap3", "gap2","gap1"),
                    labels = c( "At least daily", 
                                "At least weekly", 
                                "At least monthly", 
                                "Less than once a month")) +
  scale_x_continuous(limits = c(0, 110), breaks = seq(0, 110, by = 20)) +
  scale_y_discrete(labels = wrap_format(20)) +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.y = element_text(size = 16, family = "Nunito Sans"), 
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16),
    axis.text.y = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 16,
      hjust = 0),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(size = 14, family = "Nunito Sans"),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.direction = "horizontal",
    strip.text.x = element_text(family = "Nunito Sans",
                                color = "black",
                                size = 16),
    plot.caption.position = "plot",
    plot.caption = element_text(hjust = 0, size = 12)
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Phone owners use their devices daily") +
  theme(
    # Increase space for y-axis labels
    plot.margin = margin(r = 20)
  )


# saving image
ggsave(
  filename = file.path(folder_path, ("5104_phone_freq_SSA.png")), 
  width = 8, 
  height = 5,
  units = "in",
  device = 'png', 
  dpi = 120,
  limitsize = FALSE  # Override the dimension limit warning
  
)
