# 4.3.1. New figure: Difficulty no ID


# Create the data frame
NoID_Diff <- data %>%
  filter(regionwb24_hi == "Sub-Saharan Africa (excluding high income)") %>%
  filter(!countrynewwb %in% c("Benin", "Chad", "Liberia")) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  select(countrynewwb, fin46_all, fin49A_nID, fin49B_nID, fin49C_nID, fin49D_nID, fin49E_nID, fin49F_nID)%>%
  filter(fin46_all <= 0.7) %>%
  filter(!is.na(fin49A_nID)) %>%  # Fix the parentheses here
  mutate(fin46_no_all = 1 - fin46_all) %>%
  select(-fin46_all)


# Create the mapping for labels
indicator_mapping <- data.frame(
  indicator = c("fin49A_nID", "fin49B_nID", "fin49C_nID", "fin49D_nID", "fin49E_nID", "fin48F_nID"),
  label = c(
    "Receiving support",
    "Using financial services",  
    "Obtaining SIM",
    "Participating in elections",
    "Applying for a job",  
    "Receiving medical care"
  )
)




# Reshape data to long format for con30a-h
NoID_Diff_long <- NoID_Diff %>%
  pivot_longer(
    cols = starts_with("fin49"), 
    names_to = "indicator", 
    values_to = "value"
  ) %>%
  left_join(indicator_mapping, by = "indicator")  # Join with mapping

# Check the number of unique countries in countrynewwb
length_unique_countries <- NoID_Diff_long %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4  # Default setting as 8 countries
} else {
  # Every two countries added, width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height for this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot() +
  # Bar chart for fin46_no_all
  geom_bar(data = NoID_Diff_long, 
           aes(x = countrynewwb, y = fin46_no_all * 100, fill = "fin46_no_all"),
           stat = "identity", position = "dodge", fill = "#cccccc", alpha = 0.5, color = "black") +
  
  # Bar chart for fin49 indicators (other reasons)
  geom_bar(data = NoID_Diff_long, 
           aes(x = countrynewwb, y = value*fin46_no_all * 100, fill = factor(indicator,
                                                                levels = c("fin49A_nID", "fin49B_nID", 
                                                                           "fin49C_nID", "fin49D_nID", 
                                                                           "fin49E_nID", "fin49F_nID"))),  # Use 'indicator' directly
           stat = "identity", position = "dodge", alpha = 0.9, color = "black") +
  
  # # Add labels for fin49 indicators
  # geom_text(data = NoID_Diff_long, 
  #           aes(x = countrynewwb, 
  #               y = value * fin46_no_all * 40,  # Position labels at the top of the bars
  #               fill = factor(indicator,
  #                             levels = c("fin49A_nID", "fin49B_nID", 
  #                                        "fin49C_nID", "fin49D_nID", 
  #                                        "fin49E_nID", "fin49F_nID")), 
  #               label = ifelse(value > 0.1, round(value*fin46_no_all * 100), "")), # Show labels if value > 10%
  #           position = position_dodge(width = 0.9), 
  #           vjust = 0.5,            # Position text above the bars
  #           color = "white",         # Text color (white for contrast inside dark bars)
  #           size = 4,                # Size of text
  #           angle = 0) +             # Angle of the text (0 means horizontal)
  
  # Custom color scale for the fill colors
  scale_fill_manual(values = c("fin49A_nID" = "#fbb615", "fin49B_nID" = "#f9ef6d", 
                               "fin49C_nID" = "#5697d1", "fin49D_nID" = "#8066ac", 
                               "fin49E_nID" = "#15afb7", "fin49F_nID" = "#69c9d0",
                               "fin46_no_all" = "#cccccc"),  # Adding the color for fin46_no_all
                    breaks =  c("fin49A_nID", "fin49B_nID", 
                                "fin49C_nID", "fin49D_nID", 
                                "fin49E_nID", "fin49F_nID"),
                    labels = c(
                      "Receiving support",
                      "Using financial services",  
                      "Obtaining SIM",
                      "Participating in elections",
                      "Applying for a job",  
                      "Receiving medical care"
                    )) +
  scale_y_continuous(limits = c(0, 70),
                     breaks = seq(0, 70, by = 20)) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 4, byrow = TRUE)) +  # Place guides here
  labs(
    title = "People without ID have trouble getting a SIM card, voting, and participating in other social activities",
    subtitle = "Adults who do not own an ID (%), 2024",
    caption = "Source: Global Findex Database 2025"
  )



# Export the image
ggsave(
  filename = file.path(folder_path, sprintf("4301_challenge_noID.png")),
  width = width_num + 3,
  height = height_num,
  device = 'png',
  dpi = 120
)



