
# Prepare the data
data_internet <- data %>%
  filter(year == 2024) %>%
  filter(group == "all") %>%
  filter(countrynewwb %in% c(c_region, "LMIC")) %>%
  filter(!countrynewwb == "High income") %>%
  mutate(internet = con_internet3 * 100) %>%
  select(countrynewwb, internet) %>%
  filter(!is.na(internet))

# Define the max value for y-axis limits
max_val <- max(data_internet$internet, na.rm = TRUE) + 8

# Check the number of unique countries in countrynewwb
length_unique_countries <- data_internet %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

data_internet <- data_internet %>%
  filter(countrynewwb != "High income") %>%
  mutate(countrynewwb = recode(countrynewwb,
                               # "High income" = "High income",
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa",
                               "LMIC" = "Low- and middle-income economies"))

order_levels <- c("Low- and middle-income economies", 
                  "East Asia and Pacific", 
                  "Europe and Central Asia", 
                  "Latin America and the Caribbean", 
                  "Middle East and North Africa", 
                  "South Asia", 
                  "Sub-Saharan Africa")

# Reorder the 'countrynewwb' factor based on the specified order
data_internet$countrynewwb <- factor(data_internet$countrynewwb, levels = order_levels)

# Plot the data
ggplot(data_internet) +
  geom_bar(aes(x = countrynewwb,
               y = internet),
           fill = "#D12891", 
           stat = "identity", 
           width = 0.6,
           color = "black") +
  
  # Customize the y-axis
  scale_y_continuous(limits = c(0, max_val),
                     breaks = seq(0, max_val, by = 20)) +
  
  # Customize the x-axis labels (if needed)
  scale_x_discrete(labels = scales::wrap_format(15)) +

  # Theme adjustments
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "none",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_line(),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_blank(),
    legend.key = element_blank(),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  
  # Add subtitle and title
  labs(
    caption = "Source: Global Findex Database 2025 \nThe data included in the regional and low- and middle-income averages exclude several large economies that were surveyed by phone, \nincluding China and Russia. See the Methodology section in Annex X for a detailed list of all included countries and survey methods. ",
    subtitle = "Adults who used the internet in the past three months (%), 2024",
    title = "Across low- and middle-income economies, 66 percent of adults use the internet, though rates vary \nwidely by region "
  )

# Export the image
ggsave(
  filename = file.path(folder_path, sprintf("5301_internet_use.png")),
  width = width_num+0.5, 
  height = height_num+0.5, 
  units = "in", 
  device = 'png', 
  dpi = 120
)

