# Create the plot
Sent_Read_Text_cat_data <- data %>%
  filter(group == "all") %>%
  filter(aggregate_level == "African_Union") %>%
  filter(!countrynewwb == "AU_North") %>%
  filter(year == 2024) %>%
  select(countrynewwb, con1_all,con_send_text_o, con_read_text_o, con_text_b) %>%
  filter(!is.na(con_send_text_o)) %>%
  mutate(
    "con_sentR_no" = con1_all - con_send_text_o-con_read_text_o-con_text_b) %>% 
  gather(group, value,con_send_text_o, con_read_text_o,con_text_b,con_sentR_no) %>%
  filter(!is.na(group), !is.na(value)) %>%  # filter NA values
  mutate(con1_all = con1_all* 100,
         value = value * 100,
         lab = ifelse(group == "con_send_text_o", round(con1_all), NA)) %>%
  filter(!is.na(con1_all))


# Check the number of unique countries in countrynewwb
length_unique_countries <- Sent_Read_Text_cat_data %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(Sent_Read_Text_cat_data$con1_all, na.rm = TRUE) +15
if (max_val >92) {
  max_val <- 100
}

Sent_Read_Text_cat_data <- Sent_Read_Text_cat_data %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "AU_Central" = "Central Africa",
                               "AU_East" = "East Africa",
                               #"AU_North" = "North Africa",
                               "AU_Southern" = "Southern Africa",
                               "AU_West" = "West Africa"))

Sent_Read_Text_cat_data$countrynewwb <- factor(Sent_Read_Text_cat_data$countrynewwb, 
                                            levels = rev(levels(factor(Sent_Read_Text_cat_data$countrynewwb))))


ggplot(Sent_Read_Text_cat_data) +
  geom_bar(aes(x = value,
               y = factor(countrynewwb),
               fill = factor(group, 
                             levels = c("con_sentR_no", "con_text_b", "con_read_text_o","con_send_text_o"))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black")+
  scale_fill_manual(values = c("con_send_text_o" = "#803c53",
                               "con_read_text_o" = "#5696D0",
                               "con_text_b" = "#B2D6F7",
                               "con_sentR_no" =  "#cccccc"),
                    breaks = c("con_read_text_o", "con_text_b", "con_sentR_no"),
                    labels = c("Read text only", "Sent and read text", "Did not read or send text"))+
  scale_x_continuous(limits=c(0, 100),
                     breaks = seq(0, 100, by = 20)) +

  #scale_y_discrete(labels = wrap_format(19))+
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    legend.position ="bottom",
    legend.justification='center',
    legend.key.size = unit(4,"mm"),
    legend.spacing.x = unit(1.5, "cm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 14),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 14,
      hjust = 0),
    axis.ticks.x = element_line(),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 14,
                                 color = "black",
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              color = "black",
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 14,
                               color = "black",
                               family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0,
                                vjust = 0,
                                size = 12,
                                color = "black",
                                family = "Nunito Sans"),
    plot.caption.position =  "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE))+
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "Most phone owners use text to both receive and send messages") +
  theme(
    # Increase space for y-axis labels
    plot.margin = margin(r = 20)
  )


# export image - play with the size but the more countries and years the wider it has to be - default should be 8X4
ggsave(
  filename = file.path(folder_path, sprintf("5111_text_SR_AU.png")),
  width = 8,
  height = 4,
  device = 'png',
  dpi = 120,
  limitsize = FALSE  # Override the dimension limit warning
)
