language_SA <- data %>% 
  filter(group == "gender") %>% 
  filter(year == 2024) %>% 
  filter(countrynewwb %in% c_list_all) %>% 
  filter(regionwb24_hi == "South Asia (excluding high income)") %>%
  select(countrynewwb, group2, con1_all, con15_all) %>% 
  filter(!is.na(con1_all)) %>% 
  mutate("gap1" = con15_all,  
         "gap2" = con1_all - con15_all,
         "total" = con1_all) %>% 
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value))%>%  # filter NA values
  mutate(total = total* 100,
         value = value * 100,
         lab = ifelse(group == "gap1", round(total), NA)) %>%
  filter(!is.na(total))



# Check the number of unique countries in countrynewwb
length_unique_countries <- language_SA  %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4  # default setting as 8 countries
} else {
  # Every two country added, width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height for this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(language_SA$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}

# Create the plot
ggplot(language_SA) +
  geom_bar(aes(y = factor(group2, levels = c("men", "women")),
               x = value,
               fill = factor(group, levels = c("gap2", "gap1"))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black") +
  
  scale_fill_manual(values = c("gap1" = "#D12891",
                               "gap2" = "#CCCCCC"),
                    breaks = c("gap1", "gap2"),
                    labels = c("Can read and understand a text message written in the Latin alphabet",
                               "Cannot read or understand a text message written in the Latin alphabet")) +
  scale_x_continuous(limits = c(0, max_val),
                     breaks = seq(0, max_val, by = 20)) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  # Facet by country
  facet_grid(factor(countrynewwb, levels = c_list_all)~., 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 10, multi_line = TRUE)) +
  # Theme settings for aesthetics
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y.left = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  
  # Apply guides() outside theme() function
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    title = 'In South Asia, women are less likely than men to be able to read text messages written in the Latin alphabet',
    subtitle = "Adults with a mobile phone (%), 2024")
# Export the image
ggsave(
  filename = file.path(folder_path, ("5301_SA_read_diff_gender.png")),
  width = width_num+2,
  height = height_num+1,
  device = 'png',
  dpi = 120
)
