library(tidyverse)

Dig_skill_all_data_filtered <- data %>%
  filter(group == "all") %>%
  #filter(group == "income") %>%
  filter(countrynewwb %in% c_region_LMIC) %>%
  #filter(regionwb24_hi == "South Asia (excluding high income)") %>%
  filter(year == 2024) %>%
  select(countrynewwb, con_internet3,
         con30a_all, con30b_all, con30c_all,
         con30d_all, con30e_all, con30g_all, 
         con30f_all, con30h_all
  ) %>%
  filter(!is.na(con30a_all)) %>%
  #Ensure con_internet3 is at least 20%
  filter(con_internet3 >= 0.2) %>%
  select(-c(con_internet3)) %>%
  mutate(across(starts_with("con30"), ~ . * 100))

Dig_skill_all_data_filtered <- Dig_skill_all_data_filtered %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "LMIC" = "Low- and middle-income economies",
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

activity_labels <- c(
  "con30a_all" = "Sent a voice message from a mobile phone",
  "con30b_all" = "Sent a photo from a mobile phone",
  "con30c_all" = "Used social media",
  "con30d_all" = "Read news or current events online",
  "con30e_all" = "Accessed online info to learn/train/educate",
  "con30f_all" = "Used apps/websites to earn money",
  "con30g_all" = "Accessed government services/info online",
  "con30h_all" = "Searched for a job online"
)

custom_colors <- c("#878787", "#5696D0", "#0F72BC", "#B6A5CE", "#8066AB", "#F087B6", "#D12891")

# Reshape to long format
Dig_skill_long <- Dig_skill_all_data_filtered %>%
  pivot_longer(
    cols = starts_with("con30"),
    names_to = "activity",
    values_to = "value"
  ) %>%
  mutate(
    activity = factor(activity, levels = names(activity_labels), labels = activity_labels)
  ) %>%
  mutate(countrynewwb = factor(countrynewwb,
                               levels = rev(c("Low- and middle-income economies",
                                          "East Asia and Pacific",
                                          "Europe and Central Asia",
                                          "Latin America and the Caribbean",
                                          "Middle East and North Africa",
                                          "South Asia",
                                          "Sub-Saharan Africa"))))

Dig_skill_long <- Dig_skill_long %>%
  mutate(
    countrynewwb_legend = factor(countrynewwb,
                                 levels = c("Low- and middle-income economies",
                                            "East Asia and Pacific",
                                            "Europe and Central Asia",
                                            "Latin America and the Caribbean",
                                            "Middle East and North Africa",
                                            "South Asia",
                                            "Sub-Saharan Africa")),
    countrynewwb_bar = factor(countrynewwb,
                              levels = rev(levels(countrynewwb_legend)))
  ) %>%
  mutate(activity = factor(activity,
                          levels = c("Used social media",
                                     "Sent a voice message from a mobile phone",
                                     "Sent a photo from a mobile phone",
                                     "Read news or current events online",
                                     "Accessed online info to learn/train/educate",
                                     "Accessed government services/info online",
                                     "Searched for a job online",
                                     "Used apps/websites to earn money")))

ggplot(Dig_skill_long, aes(y = fct_rev(factor(activity)), x = value, fill = countrynewwb_legend)) +
  geom_bar(stat = "identity", position = position_dodge2(width = 0.8), color = "black", width = 0.7, aes(group = countrynewwb_bar)) +
  scale_fill_manual(values = custom_colors) +
  scale_x_continuous(limits=c(0, 100),
                     breaks = seq(0, 100, by = 10))+
  scale_y_discrete(labels = wrap_format(18))+
  theme_minimal() +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans",colour = "black", angle = 0),
    plot.background = element_rect(fill = "white"),
    panel.background = element_rect(fill = "white", color = NA),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    legend.position ="bottom",
    legend.justification='center',
    legend.box.margin=margin(0,0,0,0),
    legend.key.size = unit(4,"mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",         
      size = 16,
    ),
    axis.text.y = element_text(size = 16, family = "Nunito Sans", color = "black"),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(),
    plot.subtitle = element_text(size = 16,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(size = 16,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0,
                                size = 12,
                                family = "Nunito Sans"),
    plot.caption.position =  "plot") +
  guides(fill = guide_legend(nrow = 7, byrow = TRUE)) +
  labs(
    title = "Social media is the most popular digital use after texting",
    subtitle = "Adults(%), 2024",
    caption = "Source: Global Findex Database 2025"
  )

ggsave(
  filename = file.path(folder_path, ("1.2.6_NEW.png")),
  width = 8, 
  height = 10, 
  units="in", 
  device = 'png', 
  dpi = 120)
