# 5.4.2: password use among MM account owners

# Create the plot
phone_password <- data %>%
  filter(group == "gender") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_region) %>%
  select(countrynewwb, group2, con1_all, con18_all, con19_all)%>%
  filter(!is.na(con19_all)) %>%
  mutate("gap1" = con19_all,  
         "gap2" = con18_all - con19_all,
         "gap3" = con1_all - con18_all,
         "total" = con1_all) %>% 
  gather(group, value, gap1, gap2, gap3) %>%
  filter(!is.na(group), !is.na(value)) %>%  # filter NA values
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) 

# Check the number of unique countries in countrynewwb
length_unique_countries <- phone_password %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(phone_password$total, na.rm = TRUE) +15
if (max_val >92) {
  max_val <- 110
}

phone_password <- phone_password %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

ggplot(phone_password) +
  geom_bar(aes(y = factor(group2, levels = c("men", "women")),
               x = value,
               fill = factor(group, levels = c("gap3","gap2","gap1"))),
           stat = "identity", 
           position = "stack", 
           width = 0.75,
           color = "black") +
  scale_fill_manual(values = c("#D12891","#FCD6E8", "#B8CB33"),
                    breaks = c("gap1", "gap2", "gap3"),
                    labels = c("Have a pin/password and able to change it",
                               "Have a pin/password and unable to change it",
                               "Do not have a pin/password")) +
  scale_x_continuous(limits = c(0, 100),  # Set x-axis limits to range from 0 to 100
                     breaks = seq(0, 100, by = 20)) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  
  facet_grid(factor(countrynewwb) ~ ., 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 32, multi_line = TRUE)) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 1),
    axis.text.y.left = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 18, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults who own a mobile phone (%), 2024",
    title = "45 percent of mobile phone owners in low- and middle-income economies do not have \na password ontheir mobile phones—women more so than men"
  )

# Export the plot
ggsave(
  filename = file.path(folder_path, sprintf("phone_password.png")),
  width = width_num+1,
  height = height_num+3,
  device = 'png',
  dpi = 120
)


