c_listA <- c("Kenya", "Ghana", "Zambia", "Uganda", "Senegal", "Gabon", 
             "Cameroon", "Lesotho", "Cote d'Ivoire", "Tanzania", "Nigeria")

# 5.4.4: phone scam - sent money

# Modify the dataset
Scam_phoneOwner_data <- data %>%
  filter(group == "all") %>%  # Use group == "all"
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_listA) %>%
  select(countrynewwb, group2, con1_all, con21_all, con22_all) %>%
  filter(!is.na(con21_all)) %>%
  mutate(
    gap1 = con1_all - con21_all,
    gap2 = con21_all - con22_all,
    gap3 = con22_all,
    total = con1_all
  ) %>%
  gather(group, value, gap1, gap2, gap3) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(group2 = "all")  # Set group2 to "all"

# Check the number of unique countries
length_unique_countries <- Scam_phoneOwner_data %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Calculate width and height based on unique countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(Scam_phoneOwner_data$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 120
}

# Create the plot
ggplot(Scam_phoneOwner_data) +
  geom_bar(
    aes(
      y = fct_rev(factor(countrynewwb, levels = c_listA)), # Y-axis: country names
      x = value,
      fill = factor(group, levels = c("gap1", "gap2", "gap3"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap3" = "#B8CB33", "gap2" = "#D8E157", "gap1" = "#D12891"),
    breaks = c("gap3", "gap2", "gap1"),
    labels = c(
      "Sent money to scammer",
      "Received a spam call and did not send money to scammer",
      "Not exposed to scams"
    )
  ) +
  scale_x_continuous(
    limits = c(0, 100),
    breaks = seq(0, 100, by = 20)
  ) +
  scale_y_discrete(labels = wrap_format(20))+
  theme(
    strip.placement = "outside",
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 16
    ),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16,
      hjust = 0),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 16,
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults with a phone (%), 2024",
    title = "A significant share of phone owners are exposed to scams, though a small minority fall for them"
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("5403_phone_scam.png")),
  width = width_num-3,
  height = height_num,
  device = 'png',
  dpi = 120
)
