# 5.1.1. New figure: Phone ownership by type

Phone_Type_data <- data %>%
  filter(group == "all") %>%
  select(countrynewwb, year,
         con9_all_smart, group2,con10_all, con9_all_basic, con1_all) %>%
  filter(year %in% c("2024")) %>%
  filter(!countrynewwb == "Mauritius") %>% 
  mutate(gap1 = con9_all_smart,
         gap2 = con10_all,
         gap3 = con9_all_basic - con10_all,
         total = con1_all)%>%
  gather(group, value, gap1, gap2, gap3) %>%
  filter(countrynewwb %in% c_region)%>%
  filter(!(is.na(value)))%>%
  dplyr::group_by(countrynewwb, group2) %>%
  mutate(value = value*100)%>%
  mutate(total = sum(value),
         value_lab = ifelse(group == "gap3", value, NA)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

max_val <- max(Phone_Type_data$total, na.rm = TRUE) +5

if (max_val > 100) {
  max_val <- 108
}

ggplot(Phone_Type_data)+
  geom_bar(aes(x = factor(countrynewwb),
               y= value,
               fill = factor(group, 
                             levels = c("gap1",
                                        "gap2",
                                        "gap3"
                             ))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black")+

  scale_fill_manual(values =c("#5696D0","#8066AB","#D12891"),
                    limits = c("gap3","gap2","gap1"),
                    labels = c(
                      "Basic text phone",
                      "Feature phone",
                      "Smartphone"),
  )+
  scale_y_continuous(limits=c(0, max_val+5),
                     breaks = seq(0, max_val+5, by = 20))+
  scale_x_discrete(labels = wrap_format(16))+
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans",colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    legend.position ="bottom",
    legend.justification='center',
    legend.box.margin=margin(0,0,0,0),
    legend.key.size = unit(4,"mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",         
      size = 16,
    ),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",         
      size = 16,
    ),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(size = 16,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0,
                                size = 6,
                                vjust = 5,
                                family = "Nunito Sans"),
    plot.caption.position =  "plot") +
  guides(fill = guide_legend(nrow = 1,byrow = TRUE)) +
  labs(
    subtitle = "Adults with a phone (%), 2024") +
  ggtitle(label = "86 percent of adults worldwide own a mobile phone, though smartphones are less common in some regions")

ggsave(
  filename = file.path(folder_path, ("figure_0_2.png")),
  width = 11, 
  height = 7, 
  units="in", 
  device = 'png', 
  dpi = 120)

# ggsave(
#   filename = file.path(folder_path, ("figure_0_2.eps")),
#   width = 11, 
#   height = 7, 
#   units="in", 
#   device = 'eps', 
#   dpi = 120)

