# 3.1.1.Biggest Financial Worry 



worried <-
  data %>%
  filter(group == "all") %>%
  # filter(aggregate_level == "African_Union") %>%
  # filter(!countrynewwb == "AU_North") %>%
  filter(countrynewwb %in% c_region) %>%
  filter(year == "2024") %>%
  mutate(gap1 = fin45_other, 
         gap2 = fin45_expenses,
         gap3 = fin45_business,
         gap4 = fin45_oldage, 
         gap5 = fin45_education,
         gap6 = fin45_medical)%>%
  gather(group, value, fin45_other, fin45_expenses, fin45_business, fin45_oldage, fin45_education, fin45_medical) %>%
  filter(!is.na(value))

worried <- worried %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

worried <- worried %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "AU_Central" = "Central Africa",
                               "AU_East" = "East Africa",
                               # "AU_North" = "North Africa",
                               "AU_Southern" = "Southern Africa",
                               "AU_West" = "West Africa"))

worried  %>%
  mutate(value = value*100)%>%
  filter(group %in% c("fin45_other", "fin45_expenses", 
                      "fin45_business", "fin45_oldage", 
                      "fin45_education", "fin45_medical")) %>%
  ggplot(aes(x = factor(countrynewwb),
             y = value))+
  geom_bar(aes(x = factor(countrynewwb),
               y= value,
               fill = factor(group, 
                             levels = c(
                               "fin45_other",
                               "fin45_expenses",
                               "fin45_business",
                               "fin45_oldage",
                               "fin45_education",
                               "fin45_medical"
                             ))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           size = 0.25,
           color = "black")+
  scale_fill_manual(values =c(
    "#15AFB7","#5696D0", "#8066AB","#B8CB33", "#F087B6", "#c2c0c0"),
    limits = c("fin45_medical", "fin45_education","fin45_oldage","fin45_business",
               "fin45_expenses","fin45_other"
    ),
    labels = c("Medical expenses",
               "School fees",
               "Money for old age",
               "Money for own business",
               "Monthly expenses",
               "Other"
    ))+
  scale_y_continuous(#labels = scales::percent_format(accuracy = 1),
    limits=c(0, 100),
    breaks = seq(0, 100, by = 20))+
  scale_x_discrete(labels = wrap_format(18))+
  theme(
    # legend.position = "none",
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.y = element_text(size = 16, family = "Nunito Sans"), #,colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16),
    axis.text.y = element_text(size = 16, color = "black",
                               family = "Nunito Sans"),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(#hjust = 0,
      size = 16,
      family = "Nunito Sans"),
    legend.position ="bottom",
    legend.justification='center',
    legend.direction = "horizontal",
    strip.text.x = element_text(family = "Nunito Sans",
                                color = "black",
                                size = 16),
    plot.caption.position =  "plot",
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),) +
  guides(fill = guide_legend(nrow = 2,byrow = TRUE)) +
  labs(
    subtitle = "Adults identifying their biggest financial worry (%), 2024",
    title = sprintf("The largest share of adults worry most about monthly bills and medical expenses "),
    caption = "Source: Global Findex Database 2025")

ggsave(
  filename = file.path(folder_path, ("3101_worry.png")),
  width = 8,
  height = 6,
  units = "in",
  device = 'png',
  dpi = 120)


