c_region <- c(#"High income", 
  "East Asia & Pacific (excluding high income)", "Europe & Central Asia (excluding high income)", 
  "Latin America & Caribbean (excluding high income)", "Middle East & North Africa (excluding high income)", 
  "South Asia (excluding high income)", "Sub-Saharan Africa (excluding high income)")

# Create the plot
borrow_health_income <- data %>%
  filter(group == "income") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_region) %>%
  select(countrynewwb, group2, fin22D_all)%>%
  filter(!is.na(fin22D_all)) %>%
  mutate(value = fin22D_all * 100)

# Check the number of unique countries in countrynewwb
length_unique_countries <- borrow_health_income %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check the max value for the y-axis
max_val <- max(borrow_health_income$value, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 120
}

borrow_health_income <- borrow_health_income %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

ggplot(borrow_health_income) +
  geom_bar(aes(x = factor(group2, levels = c("poorest 40%", "richest 60%")),
               y = value),
           stat = "identity", 
           fill = "#15AFB7", 
           color = "black", 
           width = 0.6) +
  scale_y_continuous(limits = c(0, 40),
                     breaks = seq(0, 40, by = 10)) +
  scale_x_discrete(
    labels = c("poorest 40%" = "Poorest\n40%", 
               "richest 60%" = "Wealthiest\n60%")) +
  # Facet by country
  facet_grid(~ factor(countrynewwb), 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 18, multi_line = TRUE)) +
  # Theme settings for aesthetics
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 20, family = "Nunito Sans", colour = "black", angle = 0),
    strip.text.y = element_text(size = 20, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 20, angle = 0),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 20),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 20, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 20, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 16, family = "Nunito Sans", margin = margin(t = 45)),
    plot.caption.position = "plot",
    plot.margin = margin(t = 10, r = 10, b = 10, l = 10),
    legend.box.margin = margin(t = 10, r = 0, b = 30, l = 0)) +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  labs(
    caption = expression(paste("Source: Global Findex Database 2025")),
    subtitle = "Adults borrowing for health or medical purposes in the past year (%), 2024",
    title = "Twenty percent of adults in low- and middle-income economies borrow for health purposes")

ggsave(
  filename = file.path(folder_path, sprintf("4.1.3.png")),
  width = 18,
  height = 8,
  device = 'png',
  dpi = 120
)

# ggsave(
#   filename = file.path(folder_path, sprintf("4.1.3.eps")),
#   width = 20,
#   height = 8,
#   device = 'eps',
#   dpi = 120
# )

