



# Create the plot
borrow_buz <- data %>%
  filter(group == "all", year == 2024) %>%
  filter(aggregate_level == "region_all") %>%
  select(countrynewwb, fin22E_all) %>%
  filter(!is.na(fin22E_all)) %>%
  mutate(value = fin22E_all * 100)  # Scale to percent

# Recode region names (optional, for clarity)
borrow_buz <- borrow_buz %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
  ))

# Plot
ggplot(borrow_buz) +
  geom_bar(aes(x = countrynewwb, y = value), 
           stat = "identity", 
           fill = "#D8E157", 
           color = "black", 
           width = 0.6) +
  scale_y_continuous(limits = c(0, 40), breaks = seq(0, 40, by = 10)) +
  scale_x_discrete(labels = function(x) str_wrap(x, width = 16)) +
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'left',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.y = element_line(),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, vjust = 0, size = 12, color = "black", family = "Nunito Sans", margin = margin(t = 30)),
    plot.caption.position = "plot",
    plot.margin = margin(t = 10, r = 10, b = 10, l = 10),
    legend.box.margin = margin(t = 10, r = 0, b = 40, l = 0)) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    caption = expression(paste("Source: Global Findex Database 2025")),
    subtitle = "Adults borrowing to start or operate a business in the past year (%), 2024",
    title = "Borrowing for a business may help people achieve their goals")

# export image - play with the size but the more countries and years the wider it has to be - default should be 8X4
ggsave(
  filename = file.path(folder_path, sprintf("4.1.4.png")),
  width = 9,
  height = 5,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("4.1.4.eps")),
  width = 9,
  height = 5,
  device = 'eps',
  dpi = 120)
