# 2.2.2. New figure: Save for old age type


# Create the plot
sav_for_old <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_region) %>%
  select(countrynewwb, fin_anysavings24, fin_savfor_old)%>%
  filter(!is.na(fin_anysavings24)) %>%
  mutate("gap1" = fin_savfor_old, 
         "gap2" = fin_anysavings24 - fin_savfor_old,
         "total" = fin_anysavings24) %>% 
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%  # filter NA values
  mutate(total = total* 100,
         value = value * 100,
         lab = ifelse(group == "gap1", round(total), NA)) %>%
  filter(!value == 0) %>%
  filter(!is.na(total))


# Check the number of unique countries in countrynewwb
length_unique_countries <- sav_for_old %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check the max value for the y-axis
max_val <- max(sav_for_old$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 120
}


sav_for_old <- sav_for_old %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))
ggplot(sav_for_old) +
  geom_bar(aes(y = fct_rev(factor(countrynewwb)),
               x = value,
               fill = factor(group, 
                             levels = c("gap2","gap1"))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black")+
  scale_fill_manual(values = c("gap1" = "#8066AB", 
                               "gap2" = "#c2C0c0"),
                    breaks = c("gap1", "gap2"),
                    labels = c("Saving for old age",
                               "Saving for other reasons"))+
  scale_x_continuous(limits=c(0, 100),
                     breaks = seq(0, 100, by = 20)) +
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.x = element_line(),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, vjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults who save (%), 2024",
    title = "Savings for old age")

#Please check the three variables

# export image - play with the size but the more countries and years the wider it has to be - default should be 8X4
ggsave(
  filename = file.path(folder_path, sprintf("2202_savings_old_age.png")),
  width = width_num,
  height = height_num,
  device = 'png',
  dpi = 120
)
