c_region <- c(#"High income", 
  "East Asia & Pacific (excluding high income)", "Europe & Central Asia (excluding high income)", 
  "Latin America & Caribbean (excluding high income)", "Middle East & North Africa (excluding high income)", 
  "South Asia (excluding high income)", "Sub-Saharan Africa (excluding high income)")

high_fee <- data %>%
  filter(group == "all", year == 2024, countrynewwb %in% c_region) %>%
  select(
    countrynewwb,
    fin41, fin_gpay_dig,
    fin35, fin_wage_dig
  ) %>%
  pivot_longer(2:5) %>%
  mutate(type = ifelse(name %in% c("fin_gpay_dig", "fin41"), "gpay", "wage"),
         mode = ifelse(name %in% c("fin41", "fin35"), "fee", "digpay")) %>%
  select(!name) %>%
  pivot_wider(names_from = mode, values_from = value) %>%
  
  mutate(
    gap1 = fee,
    gap2 = digpay-fee,
    total = digpay
  ) %>%
  gather(group, value, gap1, gap2) %>%
  mutate(value = value*100) %>%
  
  # filter(!is.na(fin_gpay_dig) & !is.na(fin_wage_dig)) %>%
  # mutate(
  #   gpay_fee = fin41,
  #   gpay_dig = fin_gpay_dig - fin41,
  #   wage_fee = fin35,
  #   wage_dig = fin_wage_dig - fin35
  # ) %>%
  # select(countrynewwb, gpay_fee, gpay_dig, wage_fee, wage_dig) %>%
  # pivot_longer(
  #   cols = c(gpay_fee, gpay_dig, wage_fee, wage_dig),
  #   names_to = "group",
  #   values_to = "value"
  # # ) %>%
  # separate(group, into = c("payment_type", "paid_fee"), sep = "_") %>%
  
  #############################
  # mutate(
  #   group = ifelse(paid_fee == "fee", "Paid a withdrawal fee higher than expected", 
  #                  "Did not pay a withdrawal fee higher than expected"),
  #   payment_type = recode(payment_type,
  #                         "gpay" = "Government payments",
  #                         "wage" = "Wage payments"),
  #   value = value * 100
  # ) %>%
  # filter(!is.na(value)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa")) %>%
  mutate(type = recode(type,
                       "gpay" = "Government \npayment",
                       "wage" = "Wage"))

# Check the number of unique countries in countrynewwb
length_unique_countries <- high_fee %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")
# 
# max_val <- high_fee %>%
#   group_by(countrynewwb, payment_type) %>%
#   summarize(total = sum(value), .groups = "drop") %>%
#   pull(total) %>%
#   max() + 15
# if (max_val > 92) max_val <- 110

# Plot: two stacked bars per country, per payment_type, faceted by country
high_fee <- high_fee %>%
  mutate(
    group = factor(group, levels = c("gap2",
                                     "gap1")))
    # payment_type = factor(payment_type, levels = c("Government payments", "Wage payments"))
  

# Plot raw percentages without normalization
ggplot(high_fee) +
  geom_bar(aes(x = type, y = value, fill = group),
           stat = "identity", position = "stack", width = 0.75, color = "black") +
  
  scale_fill_manual(
                    breaks = c("gap2",
                               "gap1"),
                    values = c("gap2" = "#C2C0C0",
                               "gap1" = "#B8CB33"),
                    labels = c("Paid a withdrawal fee that was higher than expected",
                               "Did not pay a withdrawal fee that was higher than expected")) +
  
  facet_grid(. ~ factor(countrynewwb), 
             scales = "free", 
             space = "free", 
             switch = "both", 
             labeller = label_wrap_gen(width = 16, multi_line = TRUE)) +
  
  labs(
    title = "In every region, the share of adults paying unexpectedly high fees to cash out money is higher for wage payment recipients\nthan for government payment recipients",
    subtitle = "Adults who receive a wage payment or a government transfer or pension into an account (%), 2024 ",
    caption = "Source: Global Findex Database 2025"
  ) +
  scale_y_continuous(
    limits = c(0, 50),
    breaks = seq(0, 50, by = 10)
  ) +
  scale_x_discrete(labels = function(x) str_wrap(x, width = 10)) +
  theme_minimal(base_family = "Nunito Sans") +
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 16, color = "black", family = "Nunito Sans"),
    panel.background = element_rect(fill = "white", color = NA),  
    plot.background = element_rect(fill = "white", color = NA), 
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 18, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 18, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, vjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  
  guides(fill = guide_legend(nrow = 2, byrow = TRUE))

# Export the image
ggsave(
  filename = file.path(folder_path, sprintf("4.3.1.png")),
  width = 12,
  height = 8,
  device = 'png',
  dpi = 120
)

