
# 1.3.4. New Figure: Sent money from wrong number/got reimbursed (fin13F)

# Create the plot
wrongN_Sent_data <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(aggregate_level == "African_Union") %>%
  filter(!countrynewwb == c("AU_North")) %>%
  select(countrynewwb, fin13F,fin13F_1, ts_mobaccount) %>%
  mutate(
    gap1 = fin13F_1, 
    gap2 = fin13F - fin13F_1,
    gap3 = ts_mobaccount - fin13F,
    total = ts_mobaccount) %>%
  pivot_longer(cols = c(gap1, gap2,gap3), names_to = "group", values_to = "value") %>%
  filter(!is.na(group), !is.na(value)) %>%  # Filter NA values
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total))  # Remove NA values in total


# Check the number of unique countries in countrynewwb
length_unique_countries <- wrongN_Sent_data  %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(wrongN_Sent_data$total, na.rm = TRUE) +15
if (max_val >92) {
  max_val <- 110
}

wrongN_Sent_data <- wrongN_Sent_data %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "AU_Central" = "Central Africa",
                               "AU_East" = "East Africa",
                                "AU_North" = "North Africa",
                               "AU_Southern" = "Southern Africa",
                               "AU_West" = "West Africa"))

ggplot(wrongN_Sent_data) +
  geom_bar(aes(x = factor(countrynewwb),
               y = value,
               fill = factor(group, 
                             levels = c("gap3","gap2","gap1"))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black")+
  scale_fill_manual(values = c("gap1" = "#B8CB33", 
                               "gap2" = "#D8E157",
                               "gap3" = "#C2C0C0"),
                    breaks = c("gap1","gap2", "gap3"),
                    
                    labels = c("Sent money to a wrong number and got the money back",
                               "Sent money to a wrong number and did not get the money back",
                               "Did not send money to a wrong number"))+
  scale_y_continuous(limits=c(0,50),
                     breaks = seq(0, 50, by = 20)) +

  scale_x_discrete(labels = wrap_format(16))+
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    legend.position ="bottom",
    legend.justification='center',
    legend.key.size = unit(4,"mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16,
                                 color = "black",
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              color = "black",
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0,
                               size = 16,
                               color = "black",
                               family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0,
                                vjust = 0,
                                size = 12,
                                color = "black",
                                family = "Nunito Sans"),
    plot.caption.position =  "plot") +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE))+
  labs(
    # caption = expression(paste(italic("Source:"),"Global Findex Database 2021.")),
    subtitle = "Adults with a mobile money account (%), 2024",
    title = "Only half of mobile money account owners in Sub-Saharan Africa who sent money to the \nwrong person got it back",
    caption = "Source: Global Findex Database 2025")

# export image - play with the size but the more countries and years the wider it has to be - default should be 8X4
ggsave(
  filename = file.path(folder_path, ("1304_MM_sent_wrong.png")),
  width = width_num,
  height = height_num+1,
  device = 'png',
  dpi = 120
)
