#install.packages("patchwork")  # if not installed
library(patchwork)

exposure_data_region <- data %>%
  filter(year == 2024, group == "all", countrynewwb %in% c_region) %>%
  mutate(exposure = fin24C * 100) %>%
  filter(!is.na(exposure)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

plot_a <- ggplot(exposure_data_region) +
  geom_bar(aes(x = factor(countrynewwb), y = exposure), 
           fill = "#B8CB33", stat = "identity", width = 0.5, color = "black") +
  scale_y_continuous(limits = c(0, 100), breaks = seq(0, 100, 20)) +
  scale_x_discrete(labels = wrap_format(13)) +
  labs(title = "a. Exposure to natural disasters varies by region",
       subtitle = "Adults (%), 2024",
       caption = "Source: Global Findex Database 2025") +
  theme_minimal(base_family = "Nunito Sans") +
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "none",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 17),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 17),
    axis.ticks.y = element_line(color = "black"),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 20, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 20, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_blank(),
    legend.key = element_blank(),
    legend.text.align = 0,
    plot.caption.position = "plot",
    plot.caption = element_text(hjust = 0, size = 14, family = "Nunito Sans")
  )

# --- Plot B: High Exposure Countries ---
exposure_data_countries <- data %>%
  filter(year == 2024, group == "all", countrynewwb %in% c_list_all, fin24C > 0.5) %>%
  mutate(exposure = fin24C * 100) %>%
  filter(!is.na(exposure)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

plot_b <- ggplot(exposure_data_countries) +
  geom_bar(aes(x = factor(countrynewwb), y = exposure), 
           fill = "#B8CB33", stat = "identity", width = 0.5, color = "black") +
  scale_y_continuous(limits = c(0, 100), breaks = seq(0, 100, 20)) +
  scale_x_discrete(labels = wrap_format(10)) +
  labs(title = "b. In high-exposure economies, up to 75% of adults may be exposed",
       subtitle = "Adults (%), 2024") +
  theme_minimal(base_family = "Nunito Sans") +
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "none",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 17),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 17),
    axis.ticks.y = element_line(color = "black"),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 20, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 20, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_blank(),
    legend.key = element_blank(),
    legend.text.align = 0,
    plot.caption.position = "plot"
  )

# --- Combine Panels ---
combined_plot <- plot_a + plot_b + plot_layout(widths = c(0.8, 1.2))
combined_plot
# --- Save the combined plot ---
ggsave(
  filename = file.path(folder_path, "disaster_exposure_combined.png"),
  plot = combined_plot,
  width = 18, height = 8, units = "in", dpi = 120
)
