# 4.1. Any ID

# Create the plot
AnyID_cat_data <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_region) %>%
  select(countrynewwb, id_regular_o, id_dig_o, id_both, id_any)%>%
  mutate(id_one = id_regular_o + id_dig_o) %>%
  gather(group, value, id_one, id_both) %>%
  filter(!is.na(group), !is.na(value)) %>%  # Filter out NA values
  mutate(id_any = id_any * 100,
         value = value * 100) %>%
  filter(!is.na(id_any))

# Check the number of unique countries in countrynewwb
length_unique_countries <- AnyID_cat_data  %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4  # Default setting as 8 countries
} else {
  # Every two countries added, width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height for this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(AnyID_cat_data$id_any, na.rm = TRUE)
if (max_val > 92) {
  max_val <- 110
}

AnyID_cat_data <- AnyID_cat_data %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

# Create the plot
ggplot(AnyID_cat_data) +
  geom_bar(
    aes(
      x = countrynewwb,
      y = id_any
    ),
    stat = "identity",
    position = "stack",
    width = 0.7,
    fill = "#8066AB",
    color = "black"
  ) +
  scale_y_continuous(
    limits = c(0, max_val),
    breaks = seq(0, max_val, by = 20)
  ) +
  scale_x_discrete(labels = wrap_format(16)) +
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.position = "none",  # no legend for a single group
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.y = element_line(),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    caption = "Source: The Global Findex Database 2025, Identification for Development–Findex series.",
    subtitle = "Adults (%), 2024",
    title = "Ownership of ID is nearly universal across regions except for Sub-Saharan Africa"
  )
# Export the image
ggsave(
  filename = file.path(folder_path, "id_reg.png"),
  width = width_num+1,
  height = height_num+1,
  device = 'png',
  dpi = 120
)
