
library(ggplot2)
library(dplyr)
library(tidyr)
library(forcats)
library(stringr)


id_SSA_all <- data %>%
  filter(group == "gender") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "Sub-Saharan Africa (excluding high income)") %>%
  filter(fin46_all < 0.7) %>%
  filter(!countrynewwb %in% c("Benin", "Chad", "Liberia")) %>%
  select(countrynewwb, year, group, group2, id_any) %>%
  mutate(group2 = recode(group2,
                         "women" = "Women",
                         "men" = "Men")) %>%
  
  group_by(group, group2) %>%
  mutate(value = id_any * 100) %>%
  filter(!is.na(value))

ggplot(id_SSA_all) +
  geom_bar(
    aes(y = factor(group2, levels = c("Men", "Women")), x = value),
    fill = "#8066AB",                     
    stat = "identity",
    position = "dodge",
    width = 0.75,
    color = "black"
  ) +
  scale_x_continuous(
    limits = c(0, 100),
    breaks = seq(0, 100, by = 20)
  ) +
  facet_grid(
    countrynewwb~.,
    scales = "free",
    space = "free",
    switch = "both"
  ) +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'left',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 1, byrow = TRUE)) +
  labs(
    caption = "Source: ID4D-Global Findex Database 2025",
    subtitle = "Adults with an ID (%), 2024",
    title = "Even though eight economies have low ID rates in Sub-Saharan Africa, average ID ownership\nexceeds 70 percent for women and men in all four subregions "
  )

ggsave(
  filename = file.path(folder_path, "S1.1.1.3.png"),
  width = 8,
  height = 7,
  device = 'png',
  dpi = 120
)
# 
# ggsave(
#   filename = file.path(folder_path, "S1.1.eps"),
#   width = 8,
#   height = 6,
#   device = 'eps',
#   dpi = 120
# )
