# 4.3.1. New figure: Barriers to ID


# Create the data frame
NoID_reason_data <- data %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(group == "all") %>%
  filter(regionwb24_hi == "Sub-Saharan Africa (excluding high income)") %>%
  filter(!countrynewwb %in% c("Benin", "Chad", "Liberia")) %>%
  filter(year == 2024) %>%
  #select(countrynewwb,fin46_all, fin48A_all, fin48B_all, fin48C_all, fin48D_all, fin48E_all, fin48F_all)%>%
  select(countrynewwb,fin46_all, fin48A_nID, fin48B_nID, fin48C_nID, fin48D_nID, fin48E_nID, fin48F_nID)%>%
  filter(fin46_all < 0.7) %>%
  filter(!is.na(fin48A_nID)) %>%  # Fix the parentheses here
  mutate(fin46_no_all = 1 - fin46_all) %>%
  select(-fin46_all)


# Create the mapping for labels
indicator_mapping <- data.frame(
  indicator = c("fin48A_nID", "fin48B_nID", "fin48C_nID", "fin48D_nID", "fin48E_nID", "fin48F_nID"),
  label = c(
    "Have another ID",
    "Do not need an ID", 
    "Too expensive",
    "No documents",
    "Travel too far", 
    "Uncomfortable sharing info"
  )
)



# Reshape data to long format for con30a-h
NoID_reason_data_long <- NoID_reason_data %>%
  pivot_longer(
    cols = starts_with("fin48"), 
    names_to = "indicator", 
    values_to = "value"
  ) %>%
  left_join(indicator_mapping, by = "indicator")  # Join with mapping

# Check the number of unique countries in countrynewwb
length_unique_countries <- NoID_reason_data_long %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4  # Default setting as 8 countries
} else {
  # Every two countries added, width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# Print width and height for this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

ggplot() +
  # Bar chart for fin46_no_all
  geom_bar(data = NoID_reason_data, 
           aes(y = fct_rev(factor(countrynewwb)), x = fin46_no_all * 100, fill = "fin46_no_all"),
           stat = "identity", position = "dodge", alpha = 1, color = "black") +
  
  # Bar chart for con3 indicators (other reasons)
  geom_bar(data = NoID_reason_data_long, 
           aes(y = fct_rev(factor(countrynewwb)), x = value* fin46_no_all * 100, fill = factor(indicator, 
                                                                levels = c("fin48F_nID", "fin48E_nID", 
                                                                           "fin48D_nID", "fin48C_nID", 
                                                                           "fin48B_nID", "fin48A_nID"))),  # Use factor() to ensure proper order of bars
           stat = "identity", position = "dodge", alpha = 0.9, color = "black") +
  
  # Custom color scale for the fill colors
  scale_fill_manual(values = c("fin48A_nID" = "#8066AB", "fin48B_nID" = "#D12891", 
                               "fin48C_nID" = "#0F72BC", "fin48D_nID" = "#B8CB33", 
                               "fin48E_nID" = "#15afb7", "fin48F_nID" = "#F2B533", 
                               "fin46_no_all" = "#C2C0C0"),
                    breaks = c("fin48A_nID", "fin48B_nID", 
                               "fin48C_nID", "fin48D_nID", 
                               "fin48E_nID", "fin48F_nID", "fin46_no_all"),
                    labels = c(
                      "Have another ID",
                      "Do not need an ID",
                      "Too expensive",
                      "No documents",
                      "Travel too far",
                      "Uncomfortable sharing info",
                      "Do not own an ID"
                    )) +
  
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(angle = 0),
    strip.text.y = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0, hjust = 0),
    axis.ticks.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_line(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans",  margin = margin(b = 10)),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 4, byrow = TRUE)) +  # Place guides here
  labs(
    caption = "Source:  ID4D-Global Findex Database 2025",
    title = "The expense of an ID and the burden of travel to get one are the most common barriers to ID ownership",
    subtitle = "Adults without an ID (%), 2024"
  )

# Export the image
ggsave(
  filename = file.path(folder_path, sprintf("S1.1.5.png")),
  width = width_num,
  height = height_num+5,
  device = 'png',
  dpi = 120
)

# ggsave(
#   filename = file.path(folder_path, sprintf("S1.1.5.eps")),
#   width = width_num+1,
#   height = height_num+5,
#   device = 'eps',
#   dpi = 120
# )
