# df <- read_csv("\\\\wbntpcifs\\Gallop\\Anh\\sp_natural_disaster.csv")

account_nd <- data %>%
  filter(aggregate_level == "region_all" & i24 == 1 & group == "all") %>%
  mutate(
    # gap1 = acc_fi_nd,
         gap2 = fin24D_3,
         gap3 = (fin_account_nd*fin24C) - fin24D_3,
         gap4 = fin24C - (fin_account_nd*fin24C),
         total = fin24C) %>%
  gather(group, value, gap2, gap3, gap4) %>%
  filter(!(is.na(value))) %>%
  mutate(value = value*100) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

ggplot(account_nd)+
  geom_bar(aes(x = factor(countrynewwb),
               y= value,
               fill = factor(group, 
                             levels = c("gap4", "gap2", "gap3"))),
           stat = "identity", 
           position = "stack",
           width = 0.7,
           color = "black",
           size = 0.5)+
  scale_fill_manual(values = c("#D8E157", "#5696D0", "#C2C0C0"),
                    limits = c("gap2", "gap3", "gap4"),
                    labels = c(
                      "Have an account but lost access to it after a natural disaster",
                      "Have an account and did not lose access",
                      "Do not have an account")) +
  scale_y_continuous(limits=c(0, 40),
                     breaks = seq(0, 40, by = 10))+
  scale_x_discrete(labels = wrap_format(16))+
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans",colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border=element_blank(),
    legend.title = element_blank(),
    legend.position ="bottom",
    legend.justification='center',
    legend.box.margin=margin(0,0,0,0),
    legend.key.size = unit(4,"mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text( 
      family = "Nunito Sans",
      color = "black",         
      size = 16,
    ),
    axis.text.y = element_text(size = 16, family = "Nunito Sans", color = "black"),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16,
                                 family = "Nunito Sans"),
    plot.title = element_text(hjust = 0,
                              size = 16,
                              family = "Nunito Sans",
                              face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(size = 16,
                               family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0,
                                size = 12,
                                family = "Nunito Sans"),
    plot.caption.position =  "plot") +
  guides(fill = guide_legend(nrow = 4,byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults who experienced a natural disaster or extreme weather event (%), 2024") +
  ggtitle(label = "Most adults who have been exposed to a natural disaster are financially included, though gaps remain ")

ggsave(
  #filename = "\\\\wbntpcifs\\gallop\\alexandra\\S4.1.5.eps",
  filename = file.path(folder_path, ("S4.1.5.png")),
  width = 9, 
  height = 8, 
  units="in", 
  device = 'png', 
  dpi = 120)

