


make_or_receive <- data %>%
  filter(group == "all", countrynewwb == "LMIC") %>%
  filter(!year == 2011) %>%
  select(year, ts_digpay_imputed, ts_account, countrynewwb) %>%
  filter(!is.na(ts_digpay_imputed), !is.na(ts_account)) %>%
  mutate(gap1 = ts_digpay_imputed,
         gap2 = ts_account - ts_digpay_imputed,
         total = ts_account) %>%
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(total = total * 100, value = value * 100, 
         lab = ifelse(group == "gap1", round(total), NA)) %>%
  filter(!is.na(total))

# # Check the number of unique countries in countrynewwb
length_unique_countries <- make_or_receive %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4 # default setting as 8 countries
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 3) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 3)
}

# Print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(make_or_receive$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 120
}

# Generate the plot
ggplot(make_or_receive) +
  geom_bar(aes(x = factor(year),
               y = value,
               fill = factor(group, levels = c("gap2", "gap1"))),
           stat = "identity", position = "stack", width = 0.7, color = "black") +
  scale_fill_manual(values = c("gap1" = "#15afb7", "gap2" = "#cccccc"),
                    breaks = c("gap1", "gap2"),
                    labels = c("Made or received a digital payment", "Did not make or receive a digital payment")) +
  scale_y_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +

  scale_x_discrete(labels = wrap_format(10))+
  
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, vjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(subtitle = "Adults with an account (%), 2014-24",
       title = "The share of adults using digital payments continues to grow  ",
       caption = "Source: Global Findex Database 2025")

# Export image
ggsave(
  filename = file.path(folder_path, sprintf("3.3.1.png")),
  width = width_num+1,
  height = height_num+1,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.1.eps")),
  width = width_num+1,
  height = height_num+1,
  device = 'eps',
  dpi = 120
)



