
ag_payments <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  #filter(countrynewwb %in% c_region) %>%
  filter(aggregate_level == "African_Union") %>%
  filter(!countrynewwb == "AU_North") %>%
  select(countrynewwb, group2, fin_agpay_dig, fin_agpay_mob, fin_agpay_cashonly, fin_agpay_any)%>%
  filter(!is.na(fin_agpay_dig)) %>%
  mutate("gap1" = fin_agpay_dig,  
         "gap2" = fin_agpay_any - fin_agpay_dig,
         "total" = fin_agpay_any) %>% 
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%  # filter NA values
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "AU_Central" = "Central Africa",
                               "AU_East" = "East Africa",
                               "AU_Southern" = "Southern Africa",
                               "AU_West" = "West Africa"))

# Check the number of unique countries in countrynewwb
length_unique_countries <- ag_payments %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(ag_payments$total, na.rm = TRUE) +15
if (max_val >92) {
  max_val <- 110
}

ggplot(ag_payments) +
  geom_bar(aes(x = countrynewwb,
               y = value,
               fill = factor(group, levels = c("gap2","gap1"))),
           stat = "identity", 
           position = "stack", 
           width = 0.75,
           color = "black") +
  scale_fill_manual(values = c("#0F72BC", "#F48E35"),
                    breaks = c("gap1", "gap2"),
                    labels = c("Into an account",
                               "In cash or some other way")) +
  scale_y_continuous(limits = c(0, 100),  # Set x-axis limits to range from 0 to 100
                     breaks = seq(0, 100, by = 20)) +
  scale_x_discrete(labels = c(
    "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
    "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
    "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
    "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
    "South Asia (excluding high income)" = "South Asia",
    "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"
  )) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.text.y.left = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  
  labs(
    subtitle = "Adults receiving an agriculture payment in the past year (%), 2024",
    title = "In Sub-Saharan Africa economies, payments for agricultural payments\nwere mostly in cash despite some notable exceptions ",
    caption = "Source: Global Findex Database 2025"
  )


# Export the plot
ggsave(
  filename = file.path(folder_path, sprintf("3.3.12.png")),
  width = width_num-2,
  height = height_num+1,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.12.eps")),
  width = width_num-2,
  height = height_num+1,
  device = 'eps',
  dpi = 120
)


