

first_acc_receive <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(aggregate_level == "region_noq5") %>%
  select(countrynewwb, ts_FIaccount, fin4_all) %>%
  filter(!is.na(ts_FIaccount)) %>%
  mutate(
    gap1 = fin4_all,
    gap2 = ts_FIaccount - fin4_all,
    total = ts_FIaccount
  ) %>%
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(
    countrynewwb = recode(countrynewwb,
                          "EAP (ex V5 countries)" = "East Asia and Pacific",
                          "ECA (ex V5 countries)" = "Europe and Central Asia",
                          "LAC (ex V5 countries)" = "Latin America and the Caribbean",
                          "MENA (ex V5 countries)" = "Middle East and North Africa",
                          "SAR (ex V5 countries)" = "South Asia",
                          "SSA (ex V5 countries)" = "Sub-Saharan Africa"
    )
  )

# Check the number of unique countries
length_unique_countries <- first_acc_receive %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)


# Calculate width and height based on unique countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(first_acc_receive$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 110
}

# Create the plot
ggplot(first_acc_receive) +
  geom_bar(
    aes(
      x = countrynewwb,
      y = value,
      fill = factor(group, levels = c("gap2", "gap1"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap1" = "#0F72BC", "gap2" = "#C2C0C0"),
    breaks = c("gap1", "gap2"),
    labels = c(
      "Opened first account to receive a wage or government payment",
      "Did not open first account to receive a wage or government payment"
    )
  ) +
  scale_y_continuous(
    limits = c(0, 100),
    breaks = seq(0, 100, by = 20)
  ) +
  scale_x_discrete(labels = wrap_format(16))+
  theme(
    strip.placement = "outside",
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      size =16
    ),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 16,
      hjust = 0),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(color = "black"),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 16,
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(size = 16, family = "Nunito Sans"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025\nNote: Due to lack of data averages exclude Algeria, China, Iran, Libya, Mauritius, Russia, and Ukraine.",
    subtitle = "Adults with an account at a bank or similar financial institution, 2024",
    title = "Between one-third and two-thirds of adults with an account at a bank or similar institution opened their first\nto receive a G2P or wage payment"
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("3.3.16.png")),
  width = width_num+1,
  height = height_num+3,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.16.eps")),
  width = width_num+1,
  height = height_num+3,
  device = 'eps',
  dpi = 120
)
