


make_or_receive <- data %>%
  #filter(group == "all", countrynewwb %in% c_region) %>%
  filter(group == "gender", countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "South Asia (excluding high income)") %>%
  filter(year == 2024) %>%
  select(countrynewwb, group2, ts_digpay_imputed, ts_account) %>%
  filter(!is.na(ts_digpay_imputed), !is.na(ts_account)) %>%
  mutate(gap1 = ts_digpay_imputed,
         gap2 = ts_account - ts_digpay_imputed,
         total = ts_account) %>%
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(total = total * 100, value = value * 100, 
         lab = ifelse(group == "gap1", round(total), NA)) %>%
  filter(!is.na(total)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

# Check the number of unique countries in countrynewwb
length_unique_countries <- make_or_receive %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4 # default setting as 8 countries
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 3) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 3)
}

# Print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(make_or_receive$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 120
}

# Generate the plot
ggplot(make_or_receive) +
  geom_bar(aes(y = factor(group2, levels = c("men", "women")),
               x = value,
               fill = factor(group, levels = c("gap2", "gap1"))),
           stat = "identity", position = "stack", width = 0.7, color = "black") +
  scale_fill_manual(values = c("gap1" = "#15afb7", "gap2" = "#cccccc"),
                    breaks = c("gap1", "gap2"),
                    labels = c("Made or received a digital payment", "Did not make or receive a digital payment")) +
  scale_x_continuous(limits = c(0, 100), breaks = seq(0, 100, by = 20)) +
  scale_y_discrete(labels = function(x) str_to_title(x)) +
  facet_grid(factor(countrynewwb) ~., 
             scales = "free", 
             space = "free", 
             switch = "y", 
             labeller = label_wrap_gen(width = 18, multi_line = TRUE)) +
  
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(family = "Nunito Sans", color = "black", size = 16, angle = 0, hjust = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, vjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  labs(subtitle = "Adults with an account (%), 2024",
       title = "Gender gaps in digital payment use among account owners are highest in South Asia, and exist in every\neconomy except for Pakistan",
       caption = "Source: Global Findex Database 2025")

# Export image
ggsave(
  filename = file.path(folder_path, sprintf("3.3.3.png")),
  width = width_num+1,
  height = height_num+3,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.3.eps")),
  width = width_num+1,
  height = height_num+3,
  device = 'eps',
  dpi = 120
)


