


online_purchase <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(countrynewwb %in% c_list_all) %>%
  filter(regionwb24_hi == "East Asia & Pacific (excluding high income)") %>%
  select(countrynewwb, group2, ts_buyonline, ts_buyonline_dig, ts_buyonline_cash) %>%
  filter(!is.na(ts_buyonline)) %>%
  mutate(
    gap1 = ts_buyonline_dig,
    gap2 = ts_buyonline_cash,
    #gap3 = ts_buyonline - ts_buyonline_dig - ts_buyonline_cash - ts_buyonline_both,
    total = ts_buyonline
  ) %>%
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))

# Check the number of unique countries
length_unique_countries <- online_purchase %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Calculate width and height based on unique countries
if (length_unique_countries < 8) {
  width_num <- 8
  height_num <- 4
} else {
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check max value for y-axis
max_val <- max(online_purchase$total, na.rm = TRUE) + 15
if (max_val > 92) {
  max_val <- 120
}

# Create the plot
ggplot(online_purchase) +
  geom_bar(
    aes(
      y = fct_rev(factor(countrynewwb)), # Y-axis: country names
      x = value,
      fill = factor(group, levels = c("gap2", "gap1"))
    ),
    stat = "identity",
    position = "stack",
    width = 0.75,
    color = "black"
  ) +
  scale_fill_manual(
    values = c("gap1" = "#0F72BC", "gap2" = "#F48E35"),
    breaks = c("gap1", "gap2"),
    labels = c(
      "Paid online",
      "Paid in cash when order is delivered"
    )
  ) +
  scale_x_continuous(
    limits = c(0, 100),
    breaks = seq(0, 100, by = 20)
  ) +
  scale_y_discrete(labels = wrap_format(35))+
  theme(
    strip.placement = "outside",
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = "center",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(
      family = "Nunito Sans",
      color = "black",
      size = 20
    ),
    axis.text.y = element_text( 
      family = "Nunito Sans",
      color = "black",
      size = 20,
      hjust = 0),
    axis.ticks.y = element_blank(),
    axis.ticks.x = element_line(color = "black"),
    plot.subtitle = element_text(size = 20, family = "Nunito Sans"),
    plot.title = element_text(
      hjust = 0,
      size = 20,
      family = "Nunito Sans",
      face = "bold"
    ),
    plot.title.position = "plot",
    legend.text = element_text(size = 20, family = "Nunito Sans"),
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 14, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 3, byrow = TRUE)) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults who made an online purchase (%), 2024",
    title = "In certain East Asian economies, a high share of adults shop online but pay on delivery"
  )

# Save the plot
ggsave(
  filename = file.path(folder_path, sprintf("3.3.7.png")),
  width = width_num,
  height = height_num+2,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.7.eps")),
  width = width_num,
  height = height_num+2,
  device = 'eps',
  dpi = 120
)
