# library(dplyr)
# library(tidyr)
# library(ggplot2)
# library(showtext)
# # 
# # Load Nunito Sans font
# font_add_google("Nunito Sans", "Nunito Sans")
# showtext_auto()

# bills <- read_csv("\\\\wbntpcifs\\Gallop\\Alexandra\\bills_for_anh.csv")
  
# Filter and format data
online_bills <- data %>% 
  filter(group == "all" & (aggregate_level == "region_all" | countrynewwb == "ECA (excluding Russia)")) %>%
  filter(countrynewwb != "Europe & Central Asia (excluding high income)") %>%
  filter(year %in% c(2017, 2021, 2024)) %>%
  select(year, countrynewwb, ts_mob_int_bills) %>%
  filter(!countrynewwb == "High income") %>%
  mutate(value = ts_mob_int_bills * 100) %>%
  filter(!is.na(value)) %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                               "ECA (excluding Russia)" = "Europe and Central Asia",
                               "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                               "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                               "South Asia (excluding high income)" = "South Asia",
                               "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))


ggplot(online_bills) +
  geom_bar(
    aes(x = factor(year), y = value),
    fill = "#15AFB7",
    position = "dodge",
    stat = "identity",
    width = 0.75,
    color = "black"
  ) +
  scale_y_continuous(limits = c(0, 100),
                     breaks = seq(0, 100, by = 20)) +
  scale_x_discrete(labels = scales::wrap_format(16)) +
  facet_grid(
    . ~ countrynewwb,
    scales = "free",
    space = "free",
    switch = "both",
    labeller = label_wrap_gen(width = 16, multi_line = TRUE)
  ) +
  theme(
    strip.placement = "outside",
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),  # fix here
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "none",
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.y = element_line(),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_blank(),
    legend.key = element_blank(),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults making online bill payments in the past year (%), 2017-24",
    title = "In low- and middle-income economies, 37 percent of adults pay bills online"
  )


ggsave(
  filename = file.path(folder_path, "3.3.8.png"),
  width = 10,
  height = 7,
  units = "in",
  device = 'png',
  dpi = 120
)

# ggsave(
#   filename = file.path(folder_path, "3.3.8.eps"),
#   width = 10,
#   height = 7,
#   units = "in",
#   device = 'eps',
#   dpi = 120
# )

