

g2p_payments <- data %>%
  filter(group == "all") %>%
  filter(year == 2024) %>%
  filter(aggregate_level == "region_noq5") %>%
  select(countrynewwb, group2, fin_g2p_dig, fin_g2p_mob, fin_g2p_any)%>%
  filter(!is.na(fin_g2p_dig)) %>%
  mutate("gap1" = fin_g2p_dig, 
         "gap2" = fin_g2p_any - fin_g2p_dig,
         "total" = fin_g2p_any) %>% 
  gather(group, value, gap1, gap2) %>%
  filter(!is.na(group), !is.na(value)) %>%  # filter NA values
  mutate(
    total = total * 100,
    value = value * 100,
    lab = ifelse(group == "gap1", round(total), NA)
  ) %>%
  filter(!is.na(total)) 

# Check the number of unique countries in countrynewwb
length_unique_countries <- g2p_payments %>%
  summarise(unique_countries = n_distinct(countrynewwb)) %>%
  pull(unique_countries)

# Check list of real data set country length
if (length_unique_countries < 8) {
  width_num <-8
  height_num <-4 # default setting as 8 countries
} else{
  # Every two country added ,width as 2, height as 1
  width_num <- 8 + floor((length_unique_countries - 1) / 4) * 2
  height_num <- 4 + floor((length_unique_countries - 1) / 4)
}

# print width and height as this round
cat("Width:", width_num, "\n")
cat("Height:", height_num, "\n")

# Check about max value of y axis
max_val <- max(g2p_payments$total, na.rm = TRUE) +15
if (max_val >92) {
  max_val <- 110
}

ggplot(g2p_payments) +
  geom_bar(aes(x = countrynewwb,
               y = value,
               fill = factor(group, levels = c("gap2","gap1"))),
           stat = "identity", 
           position = "stack", 
           width = 0.75,
           color = "black") +
  scale_fill_manual(values = c("#0F72BC", "#F48E35"),
                    breaks = c("gap1", "gap2"),
                    labels = c("Into an account", "In cash or some other way")) +
  scale_y_continuous(limits = c(0, 100),  # Set x-axis limits to range from 0 to 100
                     breaks = seq(0, 100, by = 20)) +
  scale_x_discrete(labels = function(x) {
    x <- recode(x,
                "EAP (ex V5 countries)" = "East Asia and Pacific",
                "ECA (ex V5 countries)" = "Europe and Central Asia",
                "LAC (ex V5 countries)" = "Latin America and the Caribbean",
                "MENA (ex V5 countries)" = "Middle East and North Africa",
                "SAR (ex V5 countries)" = "South Asia",
                "SSA (ex V5 countries)" = "Sub-Saharan Africa"
    )
    stringr::str_wrap(x, width = 16)
  }) +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.text.y.left = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_line(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, family = "Nunito Sans"),
    legend.text.align = 0,
    legend.key.size = unit(4, "mm"),
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  ) +
  guides(fill = guide_legend(nrow = 2, byrow = TRUE)) +
  
  labs(
    subtitle = "Adults receiving a G2P payment in the past year (%), 2024",
    title = "More than half of G2P payment recipients in every region received their money into an account",
    caption = "Source: Global Findex Database 2025\nNote: Due to lack of data averages exclude Algeria, China, Iran, Libya, Mauritius, Russia, and Ukraine."
  )

# Export the plot
ggsave(
  filename = file.path(folder_path, sprintf("3.3.9.png")),
  width = width_num,
  height = height_num+2,
  device = 'png',
  dpi = 120
)

ggsave(
  filename = file.path(folder_path, sprintf("3.3.9.eps")),
  width = width_num,
  height = height_num+2,
  device = 'eps',
  dpi = 120
)
