
# 2.2.2 demographic breakdown of unbanked 

data_cut <- TS %>%
  # filter for only 2024 and unbanked adults to then get demo breakdown
  filter(i24 == 1 & ts_account != 1 & regionwb24_hi != "High income") %>%
  group_by(regionwb24_hi) %>%
  summarise(women_ub = weighted.mean(women, wgt_globalgfii, na.rm = T),
            poor40_ub = weighted.mean(poor40, wgt_globalgfii, na.rm = T))
  # read_csv("\\\\wbntpcifs\\Gallop\\Analysis, other docs, by year\\2024\\Output\\Donut_Data\\TS_UNBANKED_denom_region.csv")

data_cut2 <- TS %>%
  # filter for only 2024 
  filter(i24 == 1 & regionwb24_hi != "High income") %>%
  group_by(regionwb24_hi) %>%
  summarise(women_all = weighted.mean(women, wgt_globalgfii, na.rm = T),
            poor40_all = weighted.mean(poor40, wgt_globalgfii, na.rm = T))
  # read_csv("\\\\wbntpcifs\\Gallop\\Analysis, other docs, by year\\2024\\Output\\Donut_Data\\All_adult_demo_region.csv")



df <- merge(data_cut, data_cut2, 
  all.x = TRUE
) %>%
  mutate(regionwb24_hi = recode(regionwb24_hi,
                                "East Asia & Pacific (excluding high income)" = "East Asia and Pacific",
                                "Europe & Central Asia (excluding high income)" = "Europe and Central Asia",
                                "Latin America & Caribbean (excluding high income)" = "Latin America and the Caribbean",
                                "Middle East & North Africa (excluding high income)" = "Middle East and North Africa",
                                "South Asia (excluding high income)" = "South Asia",
                                "Sub-Saharan Africa (excluding high income)" = "Sub-Saharan Africa"))


# 
df_women <- df %>%
  # filter(group == "women") %>%
  mutate(ub_women = women_ub * 100,
         total = 100 - ub_women) %>%
  gather(group, value, ub_women, total)

# Create the plot
ggplot(df_women) +
  geom_bar(aes(fct_rev(regionwb24_hi),
               x = value,
               fill = factor(group, levels = c("total", "ub_women"))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black") +
  geom_segment(aes(
    x = women_all * 100,
    xend = women_all * 100,
    y = as.numeric(factor(regionwb24_hi)) - 0.375,
    yend = as.numeric(factor(regionwb24_hi)) + 0.375,
    linetype = "Low income adults as a share of all adults"
  ),
  color = "black",
  size = 1.2) +
  
  scale_fill_manual(values = c("ub_women" = "#D12891",
                               "total" = "#CCCCCC"),
                    breaks = c("ub_women"),
                    labels = c("Low income adults as a share of adults without an account")) +
  scale_linetype_manual(
    name = NULL,
    values = c("Low income adults as a share of all adults" = "solid")
  ) +
  
  scale_x_continuous(limits = c(0, 100),
                     breaks = seq(0, 100, by = 20)) +
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.box.just = "left", 
    legend.box = "vertical",
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, vjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(
    fill = guide_legend(nrow = 1, byrow = TRUE),
    linetype = guide_legend(nrow = 1, byrow = TRUE, override.aes = list(color = "black", size = 1.2))
  ) +
  
  # Add titles and subtitle
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults without an account (%), 2024",
    title = "Adults without accounts in low- and middle-income economies are disproportionately women and poor adults"
  )

# Export the image
ggsave(
  filename = file.path(folder_path, ("2.2.2a.png")),
  width = 9,
  height = 6,
  device = 'png',
  dpi = 120
)







df_poor <- df %>% 
  # filter(group == "poor40") %>%
  mutate(ub_women = poor40_ub * 100,
         total = 100 - ub_women) %>%
  gather(group, value, ub_women, total)

# Create the plot
ggplot(df_poor) +
  geom_bar(aes(fct_rev(regionwb24_hi),
               x = value,
               fill = factor(group, levels = c("total", "ub_women"))),
           stat = "identity", 
           position = "stack",
           width = 0.75,
           color = "black") +
  geom_segment(aes(
    x = poor40_all * 100,
    xend = poor40_all * 100,
    y = as.numeric(factor(regionwb24_hi)) - 0.375,
    yend = as.numeric(factor(regionwb24_hi)) + 0.375,
    linetype = "Low income adults as a share of all adults"
  ),
  color = "black",
  size = 1.2) +
  
  scale_fill_manual(values = c("ub_women" = "#D12891",
                               "total" = "#CCCCCC"),
                    breaks = c("ub_women"),
                    labels = c("Low income adults as a share of adults without an account")) +
  scale_linetype_manual(
    name = NULL,
    values = c("Low income adults as a share of all adults" = "solid")
  ) +
  
  scale_x_continuous(limits = c(0, 100),
                     breaks = seq(0, 100, by = 20)) +
  theme(
    strip.placement = "outside",
    strip.text = element_blank(),
    panel.background = element_blank(),
    strip.background  = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.box.just = "left", 
    legend.box = "vertical",
    legend.key.size = unit(4, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.x = element_text(family = "Nunito Sans", color = "black", size = 16),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),
    axis.ticks.x = element_blank(),
    axis.ticks.y = element_blank(),
    plot.subtitle = element_text(size = 16, color = "black", family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    legend.text = element_text(hjust = 0, size = 16, color = "black", family = "Nunito Sans"),
    legend.text.align = 0,
    plot.caption = element_text(hjust = 0, vjust = 0, size = 12, color = "black", family = "Nunito Sans"),
    plot.caption.position = "plot") +
  guides(
    fill = guide_legend(nrow = 1, byrow = TRUE),
    linetype = guide_legend(nrow = 1, byrow = TRUE, override.aes = list(color = "black", size = 1.2))
  ) +
  
  # Add titles and subtitle
  labs(
    caption = "Source: Global Findex Database 2025",
    subtitle = "Adults without an account (%), 2024",
    title = "Adults without accounts in low- and middle-income economies are disproportionately women and poor adults"
  )

# Export the image
ggsave(
  filename = file.path(folder_path, ("2.2.2b.png")),
  width = 9,
  height = 6,
  device = 'png',
  dpi = 120
)
# 
# ggsave(
#   filename = file.path(folder_path, ("2.2.2b.eps")),
#   width = 9,
#   height = 6,
#   device = 'eps',
#   dpi = 120
# )
