# TS <- fread("\\\\wbntpcifs\\Gallop\\Analysis, other docs, by year\\2024\\Analysis\\Findex_2024_individual.csv")



# NOTE!!! CHANTE TO AU REGIONS AND MM BARRIERS


# remove countries with >88% account ownership - reason why we're recoding
mm_bar <- TS %>% 
  filter(i24 == 1 & regionwb24_hi %in% c("Sub-Saharan Africa (excluding high income)") & !countrynewwb %in% c("Kenya", "Mauritius")) %>%
  mutate(regionwb24_hi = str_replace(regionwb24_hi, " \\(excluding high income\\)", ""),
         regionwb24_hi = str_replace(regionwb24_hi, "& ", "and\n")) %>%
  select(African_Union, wgt_globalgfii, starts_with("fin14")) %>%
  group_by(African_Union) %>%
  summarize(across(where(is.numeric) & !any_of(c("wgt_globalgfii")),
                   ~ {# Calculate weighted mean
                     mean_value <- weighted.mean(.x, wgt_globalgfii, na.rm = TRUE)
                     # Replace NaN with NA - this prevents gross looking NaN values in the data
                     if (is.nan(mean_value)) NA else mean_value
                   }),.groups = 'drop') %>%
  mutate(countrynewwb = African_Union)  %>%
  filter(African_Union != "AU_North")



# Filter data
unbanked_reason_data_filtered <- mm_bar %>%
  # filter(countrynewwb %in% c_list) %>%
  # filter(group == "all") %>%
  # filter(year == 2024) %>%
  select(countrynewwb, fin14A_ub, fin14B_ub, fin14C_ub,
         fin14D_ub, fin14E_ub) 

# Create the mapping for labels
indicator_mapping <- data.frame(
  indicator = c("fin14A_ub", "fin14B_ub", "fin14C_ub",
                "fin14D_ub", "fin14E_ub"),
  unbanked_label = c(
    "Distance from mobile money agents",
    "Mobile money products are too expensive",
    "Lack necessary documentation",
    "Not enough money",
    "Worried about safety of money in account"
  )
)

# Reshape data to long format for fin14a-g
unbanked_reason_data_long <- unbanked_reason_data_filtered %>%
  pivot_longer(
    cols = starts_with("fin14"), 
    names_to = "indicator", 
    values_to = "value"
  ) %>%
  left_join(indicator_mapping, by = "indicator")  # Join with mapping

# Convert the 'Value' column to percentages (multiply by 100)
unbanked_reason_data_long <- unbanked_reason_data_long %>%
  mutate(value = value * 100)

# Check for missing values
sum(is.na(unbanked_reason_data_long$value))  # Ensure no NAs are present in the value column
unbanked_reason_data_long$value[is.na(unbanked_reason_data_long$value)] <- 0  # Replace NAs with 0

# Find the min and max values of 'Value' for proper scaling
min_value <- min(unbanked_reason_data_long$value, na.rm = TRUE)
max_value <- max(unbanked_reason_data_long$value, na.rm = TRUE)

# Debug: Print min and max values to check
print(paste("Min value:", min_value))
print(paste("Max value:", max_value))

unbanked_reason_data_long <- unbanked_reason_data_long %>%
  mutate(countrynewwb = recode(countrynewwb,
                               "AU_Central" = "Central Africa",
                               "AU_East" = "East Africa",
                               "AU_Southern" = "Southern Africa",
                               "AU_West" = "West Africa"
  ))

# Add the phone ownership percentage (con1_all) next to the country name
# unbanked_reason_data_long <- unbanked_reason_data_long %>%
#   mutate(country_label = paste(countrynewwb)
# Create the heatmap with 'countrynewwb' on y-axis and 'noMM_label' on x-axis
heatmap_plot <- ggplot(unbanked_reason_data_long, aes(x = unbanked_label,  y = fct_rev(countrynewwb),  
                                                      fill = value)) +
  geom_tile(color = "black") +
  scale_fill_gradient2(low = "#FFEEA4", mid = "#F2B533", high ="#DB660F",
                       midpoint = (max_value + min_value) / 2,
                       limits = c(min_value, max_value),
                       name = "Value (%)",
                       labels = label_percent(scale = 1)) +  # Format the legend as percentages
  geom_text(aes(label = paste0(round(value), "%")), color = "black", size = 5) +  # Add percentage labels
  scale_x_discrete(position = "top") +
  facet_wrap(~ str_wrap(unbanked_label, width = 12), scales = "free_x", nrow = 1) +  # Wrap the label to fit
  
  # Use str_wrap to wrap the noMM_label for better visualization
  labs(title = "A lack of money is the most common reason why unbanked adults in Sub-Saharan Africa do not have\nmobile money accounts ",
       subtitle = "Adults with no account (%), 2024") +
  theme(
    strip.placement = "outside",
    strip.text.y.left = element_text(angle = 0),
    strip.text.x = element_text(size = 16, family = "Nunito Sans", colour = "black", angle = 0),
    panel.background = element_blank(),
    strip.background = element_blank(),
    panel.grid.major.x = element_blank(),
    panel.grid.minor.x = element_blank(),
    panel.grid.major.y = element_blank(),
    panel.grid.minor.y = element_blank(),
    panel.border = element_blank(),
    legend.title = element_blank(),
    legend.position = "bottom",
    legend.justification = 'center',
    legend.text = element_text(hjust = 0, size = 12, family = "Nunito Sans"),  # Corrected the legend text definition
    legend.key.size = unit(10, "mm"),
    axis.title.x = element_blank(),
    axis.title.y = element_blank(),
    axis.text.y = element_text(family = "Nunito Sans", color = "black", size = 16, hjust = 0),  # Adjust y-axis text size
    axis.ticks.y = element_blank(),
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    plot.subtitle = element_text(size = 16, family = "Nunito Sans"),
    plot.title = element_text(hjust = 0, size = 16, family = "Nunito Sans", face = "bold"),
    plot.title.position = "plot",
    plot.caption = element_text(hjust = 0, size = 12, family = "Nunito Sans"),
    plot.caption.position = "plot"
  )

heatmap_plot

ggsave(
  filename = file.path(folder_path, "2.2.5.png"),
  plot = heatmap_plot,
  width = 12,
  height = 6,
  units = "in",
  device = 'png',
  dpi = 120
)
